var Pp=Object.defineProperty;var e0=(i,r,o)=>r in i?Pp(i,r,{enumerable:!0,configurable:!0,writable:!0,value:o}):i[r]=o;var Hu=(i,r,o)=>e0(i,typeof r!="symbol"?r+"":r,o);import{j as a,N as jt,M as Xm,u as t0,a as un,b as vc,C as n0,R as yc,L as jc,J as a0,X as l0,c as i0,d as Se,B as s0,e as c0}from"./@react-libs-PgwxcVIh.js";import{P as Qm,g as r0,M as C,R as b,N as u0,_ as Z,Q as za,r as ue,T as o0,U as Zu,V as Vm,W as Zm,X as d0,Y as f0,Z as h0,$ as m0,a0 as x0,a1 as g0,a2 as p0,a3 as v0,a4 as y0,a5 as j0,a6 as b0,a7 as S0,a8 as w0,a9 as C0,aa as _0,O as T0}from"./@app-libs-DFb4Vfds.js";import{u as k,i as E0,B as A0,a as D0,b as M0}from"./@lang-libs-baFnk7ws.js";import{P as De,F as ae,f as Km,a as Fm,b as Jm,c as bc,d as O0,e as z0,g as N0,h as Pu,i as B0,j as R0,k as U0,l as Li,m as eo,n as Wm,o as L0,p as Im,q as k0,r as H0,s as Pm,t as ex,u as tx,v as q0,w as $0,x as G0,y as Y0,z as X0,A as Q0,B as V0,C as Z0,D as K0,E as F0,G as J0}from"./@fontawesome-libs-DLpYpYOK.js";(function(){const r=document.createElement("link").relList;if(r&&r.supports&&r.supports("modulepreload"))return;for(const d of document.querySelectorAll('link[rel="modulepreload"]'))u(d);new MutationObserver(d=>{for(const f of d)if(f.type==="childList")for(const m of f.addedNodes)m.tagName==="LINK"&&m.rel==="modulepreload"&&u(m)}).observe(document,{childList:!0,subtree:!0});function o(d){const f={};return d.integrity&&(f.integrity=d.integrity),d.referrerPolicy&&(f.referrerPolicy=d.referrerPolicy),d.crossOrigin==="use-credentials"?f.credentials="include":d.crossOrigin==="anonymous"?f.credentials="omit":f.credentials="same-origin",f}function u(d){if(d.ep)return;d.ep=!0;const f=o(d);fetch(d.href,f)}})();async function W0(i){const r=await fetch("/incursions/api/auth/whoami");r.status!==200&&i(null);const o=await r.json();var u={};o.access.forEach(m=>{u[m]=!0});const d=window.localStorage&&parseInt(window.localStorage.getItem("selectedCharacter"));var f=0;d&&(f=o.characters.findIndex(m=>m.id===d),f=f===-1?0:f),i({...o,current:o.characters[f],access:u})}var qu={exports:{}},ot={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var om;function I0(){if(om)return ot;om=1;var i=Qm();function r(p){var v="https://react.dev/errors/"+p;if(1<arguments.length){v+="?args[]="+encodeURIComponent(arguments[1]);for(var j=2;j<arguments.length;j++)v+="&args[]="+encodeURIComponent(arguments[j])}return"Minified React error #"+p+"; visit "+v+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function o(){}var u={d:{f:o,r:function(){throw Error(r(522))},D:o,C:o,L:o,m:o,X:o,S:o,M:o},p:0,findDOMNode:null},d=Symbol.for("react.portal");function f(p,v,j){var O=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:d,key:O==null?null:""+O,children:p,containerInfo:v,implementation:j}}var m=i.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function x(p,v){if(p==="font")return"";if(typeof v=="string")return v==="use-credentials"?v:""}return ot.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=u,ot.createPortal=function(p,v){var j=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!v||v.nodeType!==1&&v.nodeType!==9&&v.nodeType!==11)throw Error(r(299));return f(p,v,null,j)},ot.flushSync=function(p){var v=m.T,j=u.p;try{if(m.T=null,u.p=2,p)return p()}finally{m.T=v,u.p=j,u.d.f()}},ot.preconnect=function(p,v){typeof p=="string"&&(v?(v=v.crossOrigin,v=typeof v=="string"?v==="use-credentials"?v:"":void 0):v=null,u.d.C(p,v))},ot.prefetchDNS=function(p){typeof p=="string"&&u.d.D(p)},ot.preinit=function(p,v){if(typeof p=="string"&&v&&typeof v.as=="string"){var j=v.as,O=x(j,v.crossOrigin),D=typeof v.integrity=="string"?v.integrity:void 0,M=typeof v.fetchPriority=="string"?v.fetchPriority:void 0;j==="style"?u.d.S(p,typeof v.precedence=="string"?v.precedence:void 0,{crossOrigin:O,integrity:D,fetchPriority:M}):j==="script"&&u.d.X(p,{crossOrigin:O,integrity:D,fetchPriority:M,nonce:typeof v.nonce=="string"?v.nonce:void 0})}},ot.preinitModule=function(p,v){if(typeof p=="string")if(typeof v=="object"&&v!==null){if(v.as==null||v.as==="script"){var j=x(v.as,v.crossOrigin);u.d.M(p,{crossOrigin:j,integrity:typeof v.integrity=="string"?v.integrity:void 0,nonce:typeof v.nonce=="string"?v.nonce:void 0})}}else v==null&&u.d.M(p)},ot.preload=function(p,v){if(typeof p=="string"&&typeof v=="object"&&v!==null&&typeof v.as=="string"){var j=v.as,O=x(j,v.crossOrigin);u.d.L(p,j,{crossOrigin:O,integrity:typeof v.integrity=="string"?v.integrity:void 0,nonce:typeof v.nonce=="string"?v.nonce:void 0,type:typeof v.type=="string"?v.type:void 0,fetchPriority:typeof v.fetchPriority=="string"?v.fetchPriority:void 0,referrerPolicy:typeof v.referrerPolicy=="string"?v.referrerPolicy:void 0,imageSrcSet:typeof v.imageSrcSet=="string"?v.imageSrcSet:void 0,imageSizes:typeof v.imageSizes=="string"?v.imageSizes:void 0,media:typeof v.media=="string"?v.media:void 0})}},ot.preloadModule=function(p,v){if(typeof p=="string")if(v){var j=x(v.as,v.crossOrigin);u.d.m(p,{as:typeof v.as=="string"&&v.as!=="script"?v.as:void 0,crossOrigin:j,integrity:typeof v.integrity=="string"?v.integrity:void 0})}else u.d.m(p)},ot.requestFormReset=function(p){u.d.r(p)},ot.unstable_batchedUpdates=function(p,v){return p(v)},ot.useFormState=function(p,v,j){return m.H.useFormState(p,v,j)},ot.useFormStatus=function(){return m.H.useHostTransitionStatus()},ot.version="19.1.0",ot}var dm;function nx(){if(dm)return qu.exports;dm=1;function i(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(i)}catch(r){console.error(r)}}return i(),qu.exports=I0(),qu.exports}var P0=nx();const ax=r0(P0),En=C.div`
  position: fixed;
  background-color: ${i=>i.theme.colors[i.$variant].color};
  color: ${i=>i.theme.colors[i.$variant].text};
  border-radius: 15px;
  padding: 20px;
  max-width: 400px;
  transition-property: bottom, right, opacity, padding;
  transition-timing-function: ease-in-out;
  transition-duration: 0.3s;
  box-sizing: content-box;
  z-index: 101;
`;En.Container=C.div`
  > ${En} {
    display: none;
  }
  > ${En}:nth-last-child(1) {
    display: block;
    padding: 20px;
    bottom: 50px;
    right: 50px;
    opacity: 1;
  }
  > ${En}:nth-last-child(2) {
    display: block;
    padding: 15px;
    bottom: 90px;
    right: 55px;
    opacity: 0.8;
  }
  > ${En}:nth-last-child(3) {
    display: block;
    padding: 10px;
    bottom: 130px;
    right: 60px;
    opacity: 0.6;
  }
`;En.Title=C.strong`
  font-weight: bold;
`;function ev({title:i,message:r,variant:o}){return a.jsxs(En,{$variant:o,children:[i?a.jsxs(a.Fragment,{children:[a.jsx(En.Title,{children:i})," "]}):null,r]})}function tv({toasts:i,setToasts:r}){return b.useEffect(()=>{var o=setInterval(()=>{const u=new Date;i.filter(d=>d.expire<=u).length>0&&r(i.filter(d=>d.expire>u))},1e3);return()=>clearInterval(o)},[i,r]),ax.createPortal(a.jsx(En.Container,{children:i.map(o=>a.jsx(ev,{...o},o.id))}),document.body)}function ca(i,{title:r="",message:o,variant:u,time:d=1e4}){var f=Math.random().toString(36),m=new Date(new Date().getTime()+d);i({id:f,title:r,message:o,variant:u,expire:m})}const Te=b.createContext(null),ie=b.createContext(()=>{}),ki=b.createContext(null),ct=C.div`
  color: ${i=>i.theme.colors.text};

  p,
  ul,
  ol {
    margin-bottom: 1em;
    line-height: 1.5em;
  }

  a {
    font-weight: bold;
    text-decoration: none;
    color: ${i=>i.theme.colors.highlight.text};
    &:hover:not(:disabled):not(.static) {
      cursor: pointer;
      color: ${i=>i.theme.colors.highlight.active};
    }
  }

  i,
  em {
    font-style: italic;
  }

  b,
  strong {
    font-weight: bold;
  }

  h1,
  h2,
  h3,
  h4,
  h5,
  h6 {
    margin-top: 1em;
  }

  h1 + h2,
  h2 + h3,
  h3 + h4,
  h4 + h5,
  h5 + h6 {
    margin-top: 0;
  }

  h1 {
    margin-top: 0;
    font-size: 3em;
  }

  h2 {
    font-size: 2em;
  }

  h3 {
    font-size: 1.5em;
    font-weight: 600;
  }

  h4 {
    font-size: 1.2em;
    font-weight: 500;
  }

  ul {
    list-style-type: disc;
    padding-left: 2em;
  }

  ol {
    list-style-type: number;
    padding-left: 2em;
  }

  pre {
    font-family: ${i=>i.theme.font.monospaceFamily};
    font-size: 0.8em;
    padding: 1em;
    margin-bottom: 1em;
    border-radius: 5px;
    background-color: ${i=>i.theme.colors.accent1};
  }

  img {
    max-width: 100%;
  }
`,ra=C.h1`
  font-size: 3em;
  margin-bottom: 0.5em;

  @media (max-width: 480px) {
    font-size: 2em;
  }
`,_e=C.h2`
  font-size: 1.5em;
`,we=C.div`
  background-color: ${i=>i.theme.colors.background};
  padding: 1.5em;
  border-radius: 5px;
  @media (max-width: 480px) {
    padding: ${i=>i.mpadding?i.mpadding:"0.6em"};
    width: 100%;
  }
`,Ft=u0`
  position: relative;
  padding: 0 1em;
  font-size: 1em;
  border: solid ${i=>i.$variant?"0px":"1px"};
  border-color: ${i=>i.theme.colors.accent2};
  border-radius: 20px;
  background-color: ${i=>i.theme.colors[i.$variant||"input"].color};
  color: ${i=>i.theme.colors[i.$variant||"input"].text} !important;
  display: inline-block;
  font: inherit;
  &.active {
    border-color: ${i=>i.theme.colors.accent2};
  }
  &:hover:not(:disabled):not(.static) {
    color: ${i=>i.theme.colors[i.$variant||"input"].text};
    border-color: ${i=>i.theme.colors.accent3};
    background-color: ${i=>i.theme.colors[i.$variant||"input"].accent};
    &.active {
      border-color: ${i=>i.theme.colors.active};
    }
  }
  &:focus:not(:disabled):not(.static) {
    outline: none;
  }
  &:disabled {
    cursor: not-allowed;
  }
  &.static {
    cursor: default;
  }
  &:disabled,
  &.static {
    color: ${i=>i.theme.colors[i.$variant||"input"].disabled};
  }
  @media (max-width: 480px) {
    padding: 0 0.8em;
  }
`,q=C.button.attrs(i=>({className:`${i.$active?"active":""} ${i.static?"static":""}`}))`
  ${Ft}
  min-height: 2.5em;
  height: 2.5em;
  cursor: pointer;
  &:disabled {
    opacity: 0.6;
  }
  border-color: ${i=>i.theme.colors[i.$variant||"input"].color};
  @media (max-width: 700px) {
    height: max-content;
  }
`,fm=C.button.attrs(i=>({className:`${i.$active?"active":""} ${i.static?"static":""}`}))`
  ${Ft}
  height: 2.5em;
  width: 3.35em;
  background-color: #00000063;
  align-self: center;
  cursor: pointer;
  border: unset;
  @media (min-width: 481px) {
    display: none;
  }
  &:hover:not(:disabled):not(.static) {
    background-color: #000000a3;
  }
  color: #cccccc !important;
`,lx=C.a.attrs(i=>({className:`${i.$active?"active":""} ${i.static?"static":""}`}))`
  ${Ft}
  height: 2.5em;
  text-decoration: none;
  line-height: 2.5em;
  &:hover:not(:disabled):not(.static) {
    cursor: pointer;
  }
  border-color: ${i=>i.theme.colors[i.$variant||"input"].color};
`,ix=C.a.attrs(i=>({className:`${i.$active?"active":""} ${i.static?"static":""}`}))`
  ${Ft}
  height: 2.5em;
  text-decoration: none;
  line-height: 2.5em;
  border: unset;
  background-color: #ffffff0a;
  color: #cccccc !important;
  &:hover:not(:disabled):not(.static) {
    background-color: #f9f9f921;
  }
`,ke=C.label`
  display: block;
  margin-bottom: 10px;

  &[required] {
    ::after {
      content: "  *";
      color: red;
      font-size: 15px;
      font-weight: bolder;
    }
  }
`,ln=C(jt).attrs(i=>({className:`${i.$active?"active":""} ${i.static?"static":""}`}))`
  ${Ft}
  height: 2.5em;
  text-decoration: none;
  line-height: 2.5em;
  border-color: ${i=>i.theme.colors[i.$variant||"input"].color};
`,nv=C(jt).attrs(i=>({className:`${i.$active?"active":""} ${i.static?"static":""}`}))`
  ${Ft}
  height: 2.5em;
  text-decoration: none;
  line-height: 2.5em;
  border: unset;
  background-color: #ffffff0a;
  color: #cccccc !important;

  &:hover:not(:disabled):not(.static) {
    background-color: #f9f9f921;
  }
`,cn=C.input`
  ${Ft}
  height: 2.5em;
`,av=C.input.attrs({type:"radio"})`
  ${Ft}
`,rn=C.select`
  ${Ft}
  height: 2.5em;
  appearance: none;
  > option {
    background-color: ${i=>i.theme.colors.background};
    color: ${i=>i.theme.colors.text};
  }
`,lv=C.select`
  ${Ft}
  height: 2.5em;
  appearance: listbox;
  background-color: #ffffff0a;
  color: #cccccc !important;
  &:hover:not(:disabled):not(.static) {
    background-color: #f9f9f921;
  }

  > option {
    color: black;
  }
`,Kt=C.textarea`
  ${Ft}
  padding: 1em;

  &:focus::placeholder {
    color: transparent;
  }
`,Oe=C.div`
  display: flex;

  flex-wrap: nowrap;
  > * {
    z-index: 1;
    margin: 0;
  }
  > :not(:last-child) {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0;
  }
  > :not(:first-child) {
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
    margin-left: -1px;
  }
  > .active:hover {
    z-index: 4;
  }
  > .active {
    z-index: 3;
  }
  > :hover {
    z-index: 2;
  }
  @media (max-width: 480px) {
    ${i=>!i.$fixed&&`
    * {
      padding-right: 0.4em;
      padding-left: 0.4em;
      font-size: 0.85em;
      svg {
        padding: 0;
        margin: 0 0.3em 0 0.3em;
      }
    }
  `}
  }
  box-shadow: 3px 3px 1px ${i=>i.theme.colors.shadow};
  border-radius: 20px;
  width: fit-content;
  height: fit-content;
`,hm=C(Oe)`
  box-shadow: none;
`,bt=C.div`
  display: flex;
  flex-wrap: wrap;
  > * {
    margin-bottom: ${i=>i.marginb?i.marginb:"0.5em"};
    margin-right: 0.5em;
  }
  > :not(:last-child) {
    @media (max-width: 480px) {
      margin-bottom: 0.4em;
      margin-right: 0.3em;
    }
  }
`,El=C.div`
  display: flex;
  justify-content: center;
  > * {
    width: ${i=>i.size?i.size:"inherit"};
    margin: 0.2em;
  }
`,iv=C.b`
  color: ${i=>i.theme.colors.highlight.text};
  &:hover:not(:disabled):not(.static) {
    cursor: pointer;
    color: ${i=>i.theme.colors.highlight.active};
  }
`,an=C.div`
  display: flex;
  flex-direction: column;
  align-items: center;
  text-align: center;
  width: 100%;
`;an.Head=C.h3`
  font-weight: bold;
  font-size: 1.5em;
  text-decoration: underline;
`;an.Paragraph=C.div`
  margin: 0;
  border-top: 2px solid;
  padding: 2em 5em;
  @media (max-width: 720px) {
    padding: 1em;
  }
  border-color: ${i=>i.theme.colors.accent2};
`;an.ParagraphALT=C.div`
  margin: 0;
  padding: 2em 5em;
  @media (max-width: 720px) {
    padding: 1em;
  }
  b {
    display: block;
  }
  border-color: ${i=>i.theme.colors.accent2};
`;const zi=C.div`
  display: ${i=>i.open?"flex":"none"};
  position: fixed;
  top: 0;
  left: 0;
  bottom: 0;
  right: 0;
  padding: 20px;
  z-index: 50;
  min-width: 100%;
`;zi.Background=C.div`
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  background-color: ${i=>i.theme.colors.modal};
`;zi.Content=C.div`
  position: relative;
  margin: auto;
  max-height: 100%;
  overflow-y: auto;
  > ${we} {
    min-width: 200px;
    min-height: 200px;
    max-width: 1300px;
  }
  width: ${i=>i.fill&&"70%"};

  ${i=>i.fill&&`
  @media (max-width: 900px) {
    width: 100%;
  }
`}
`;function ze({children:i,open:r=!1,setOpen:o,fill:u}){return b.useEffect(()=>{const d=f=>{f.key==="Escape"&&o(!1)};return window.addEventListener("keydown",d),()=>window.removeEventListener("keydown",d)},[o]),ax.createPortal(a.jsxs(zi,{open:r,children:[a.jsx(zi.Background,{onClick:()=>o(!1)}),a.jsx(zi.Content,{fill:u,children:i})]}),document.body)}function mm({children:i,onConfirm:r,title:o,setOpen:u,...d}){const{t:f}=k();return a.jsx(ze,{setOpen:u,...d,children:a.jsxs(we,{children:[a.jsx("h2",{style:{fontWeight:"bolder"},children:o||f("Please confirm!")}),i,a.jsxs(Oe,{children:[a.jsx(q,{$variant:"danger",onClick:r,children:f("Yes")}),a.jsx(q,{$variant:"secondary",onClick:()=>u(!1),children:f("No")})]})]})})}const Yt=C.span`
  background-color: ${i=>(i.theme.colors[i.$variant]||{}).color||"transparent"};
  color: ${i=>(i.theme.colors[i.$variant]||{}).text||i.theme.colors.text};
  filter: drop-shadow(0px 1px 1px ${i=>i.theme.colors.shadow});
  padding: 0 0.74em 0 0.74em;
  border-radius: 4px;
  height: 2em;
  font-size: 0.75em;
  display: inline-flex;
  align-items: center;
  white-space: nowrap;
`,sv=C.span`
  display: flex;
  align-items: center;
`,sa=C.div`
  margin: 0em 0.5em 0.5em 0;
  border: solid 2px ${i=>i.theme.colors.accent2};
  border-radius: 5px;
  background-color: ${i=>i.theme.colors.background};
  font-size: 1em;
  filter: drop-shadow(0px 3px 4px ${i=>i.theme.colors.shadow});
  width: 220px;
  height: 2.6em;
  a {
  }
  &:hover:not(:disabled):not(.static) {
    border-color: ${i=>i.theme.colors.accent3};
    cursor: pointer;
  }
  @media (max-width: 480px) {
    width: 100%;
    height: 4em;
    margin: 0em 0.5em 1em 0;
  }
`;sa.Content=C.div`
  display: flex;
  height: 100%;
  align-items: center;
  color: ${i=>i.theme.colors.text};
  img {
    border-radius: 3px 0px 0px 3px;
    margin-right: 0.5em;
    align-self: flex-start;
  }
}
`;sa.Icon=C.div`
  display: flex;
  flex-wrap: wrap;
  margin-right: 0.2em;
  width: fit-content;
  padding: 0em 0.4em 0em;
  @media (max-width: 480px) {
    font-size: 1.3em;
  }
`;const Ri=C.div`
  width: 480px;
  @media (max-width: 580px) {
    width: 100%;
  }
`;Ri.Title=C.div`
  border-bottom: 3px solid;
  padding-bottom: 5px;
  margin-bottom: 1em;
  display: flex;
  border-color: ${i=>i.theme.colors.accent3};
`;const to=["HQ-FC","TRAINEE","DPS","LOGI","ALT","VINDI","AMULET","WARPSPEED","HYBRID","ELITE","ELITE-GOLD"],_l={"HQ-FC":{type:"shield",color:"purple",letter:"H",name:"HQ FC"},TRAINEE:{type:"shield",color:"neutral",letter:"T",name:"Training FC"},TRAINER:{type:"shield",color:"purple",letter:"T",name:"FC Trainer"},LEADERSHIP:{type:"shield",color:"purple",letter:"DN",name:"leadership"},DPS:{type:"shield",color:"yellow",letter:"T",name:"DPS"},LOGI:{type:"shield",color:"red",letter:"L",name:"Logi Specialist"},ALT:{type:"shield",color:"green",letter:"A",name:"Alt approved"},VINDI:{type:"shield",color:"blue",letter:"!",name:"Vindication"},UNKNOWN:{type:"shield",color:"neutral",letter:"?",name:null}},sn=({type:i="UNKNOWN",height:r="1.2em"})=>{const o=_l[i]??_l.UNKNOWN;return o.type==="shield"?a.jsx(Ku,{...o,h:r,title:o.name}):a.jsx("img",{src:o.href,title:o.name,alt:o.name,style:{height:r}})};sn.propTypes={type:De.oneOf(Object.keys(_l))};function Ku({color:i,letter:r,title:o,h:u="1.2em"}){const d=b.useContext(za);return a.jsx(sv,{title:o,children:a.jsx("svg",{style:{height:u,filter:`drop-shadow(0px 1px 1px ${d.colors.shadow})`},viewBox:"0 0 26.5 27.8",xmlns:"http://www.w3.org/2000/svg",children:a.jsxs("g",{children:[a.jsx("path",{style:{fill:d.colors.tdfShields[i]},d:"m 13.229167,0 c 0,0 6.085417,0.79375 13.229167,3.96875 0,0 -0.79375,10.054167 -3.961217,15.955009 -2.275956,4.239997 -6.622116,7.857491 -9.26795,7.857491 M 13.229167,0 C 13.229167,0 7.14375,0.79375 0,3.96875 c 0,0 0.79375,10.054167 3.9612174,15.955009 2.2759552,4.239997 6.6221156,7.857491 9.2679496,7.857491"}),a.jsx("text",{style:{fontSize:"20px",fontWeight:"700",textAnchor:"middle",fill:d.colors.tdfShields.text,textRendering:"geometricPrecision"},x:"13.25",y:"20.5",children:r})]})})})}function sx({tags:i,height:r="40px"}){const o=Z.sortBy(i,function(d){return to.indexOf(d)});var u=[];return Z.forEach(o,d=>{d in _l&&u.push(a.jsx("div",{style:{marginRight:"0.2em"},children:a.jsx(sn,{type:d,height:r})},d))}),a.jsx("div",{style:{display:"flex",marginBottom:"0.6em",flexWrap:"wrap"},children:u})}function qe(i){ue.useEffect(()=>{let r=document.title;return no(i),()=>document.title=r})}function no(i){document.title=`AA: ${i}`}function cx(i){const r=i.split(`
`)[0];return r.substring(r.indexOf(" "))}function cv(i){return i.split(" ").map(r=>r[0].toUpperCase()+r.substr(1).toLowerCase()).join(" ")}const xm=C.div`
  display: flex;
  flex-wrap: wrap;
  margin-top: 1em;
`,rv={};function Sl({name:i,icon:r,children:o}){const[u,d]=b.useState(!1);return a.jsxs(a.Fragment,{children:[u?a.jsx(ze,{open:!0,setOpen:d,children:a.jsx(we,{children:a.jsxs(Ri,{children:[a.jsxs(Ri.Title,{children:[a.jsx("div",{style:{display:"flex",alignItems:"center"},children:a.jsx(sn,{type:r,height:"40px"})}),a.jsxs(_e,{children:[i,"  "]})]}),o]})})}):null,a.jsx(sa,{children:a.jsx("a",{onClick:()=>d(!0),children:a.jsxs(sa.Content,{children:[a.jsx(sa.Icon,{children:a.jsx(sn,{type:r,height:"50px"})}),i]})})})]})}function uv(){qe("Badges");const[i,r]=b.useState(!1);return a.jsxs(a.Fragment,{children:[i?a.jsx(ze,{open:!0,setOpen:r,children:a.jsx(we,{style:{width:"100%"},children:a.jsx("img",{src:rv["./examplediscord.png"],alt:"examplediscord",style:{width:"100%"}})})}):null,a.jsxs(ct,{style:{marginBottom:"2em"},children:[a.jsx("h1",{children:"Badges"}),a.jsxs("p",{children:["To get the T, A, or ! badge, use the",a.jsx("a",{href:"https://discord.com/channels/930000021083005028/930014112635826196/1287232984495423570",target:"_blank",rel:"noopener noreferrer",style:{marginLeft:"0.5em"},children:"ticket"})," ","system on Discord. Make sure your screenshot is saved on an image hosting website & shows the highlighted areas as per the",a.jsx(lx,{onClick:()=>r(!0),style:{marginLeft:"0.5em"},children:"example"})]}),a.jsx(_e,{children:"Pilot Badge"}),a.jsxs(xm,{children:[a.jsx(Sl,{name:"DPS",icon:"DPS",children:"The DPS Badge is given to a pilot that has met the main DPS Values on the fitting page. You must have implant slots 9 & 10 to get this badge."}),a.jsx(Sl,{name:"Logi",icon:"LOGI",children:"The Logi Badge is given out by an FC that has vouched for your logi performance. It is not required to fly Logi."}),a.jsxs(Sl,{name:"Alt Approved",icon:"ALT",children:["The Alt Approved Badge is given to a pilot that has met the DPS Values for alts on the fitting page. Your main or T badge must have a ",a.jsx("b",{children:"full"})," implant set before you can apply for this badge and recieve your guaranteed alt spot."]}),a.jsx(Sl,{name:"VINDICATION!",icon:"VINDI",children:"The VINDICATION badge is given to a pilot that has met the DPS and Web values on the fitting page."})]}),a.jsx(_e,{children:"Commander Badges"}),a.jsxs(xm,{children:[a.jsx(Sl,{name:"Training FC",icon:"TRAINEE",children:"Trainee isk bringers"}),a.jsx(Sl,{name:"Fleet Commander",icon:"HQ-FC",children:"Isk bringers"})]})]})]})}/*! js-cookie v3.0.5 | MIT */function uc(i){for(var r=1;r<arguments.length;r++){var o=arguments[r];for(var u in o)i[u]=o[u]}return i}var ov={read:function(i){return i[0]==='"'&&(i=i.slice(1,-1)),i.replace(/(%[\dA-F]{2})+/gi,decodeURIComponent)},write:function(i){return encodeURIComponent(i).replace(/%(2[346BF]|3[AC-F]|40|5[BDE]|60|7[BCD])/g,decodeURIComponent)}};function Fu(i,r){function o(d,f,m){if(!(typeof document>"u")){m=uc({},r,m),typeof m.expires=="number"&&(m.expires=new Date(Date.now()+m.expires*864e5)),m.expires&&(m.expires=m.expires.toUTCString()),d=encodeURIComponent(d).replace(/%(2[346B]|5E|60|7C)/g,decodeURIComponent).replace(/[()]/g,escape);var x="";for(var p in m)m[p]&&(x+="; "+p,m[p]!==!0&&(x+="="+m[p].split(";")[0]));return document.cookie=d+"="+i.write(f,d)+x}}function u(d){if(!(typeof document>"u"||arguments.length&&!d)){for(var f=document.cookie?document.cookie.split("; "):[],m={},x=0;x<f.length;x++){var p=f[x].split("="),v=p.slice(1).join("=");try{var j=decodeURIComponent(p[0]);if(m[j]=i.read(v,j),d===j)break}catch{}}return d?m[d]:m}}return Object.create({set:o,get:u,remove:function(d,f){o(d,"",uc({},f,{expires:-1}))},withAttributes:function(d){return Fu(this.converter,uc({},this.attributes,d))},withConverter:function(d){return Fu(uc({},this.converter,d),this.attributes)}},{attributes:{value:Object.freeze(r)},converter:{value:Object.freeze(i)}})}var dv=Fu(ov,{path:"/"});async function W(i,{json:r,...o}){var u={...o};u.headers||(u.headers={});const d=dv.get("csrftoken");d&&(u.headers["x-csrftoken"]=d),r&&(u.method||(u.method="POST"),u.headers["Content-Type"]="application/json",u.body=JSON.stringify(r));const f=await fetch(i,u);var m;if((f.headers.get("Content-Type")||"").match(/json/)?m=await f.json():m=await f.text(),f.status>=400)throw m;return m}async function Xt(i,r){try{const o=await r;ca(i,{message:o,variant:"success"})}catch(o){console.error(o),ca(i,{message:o.toString(),variant:"danger"})}}async function oe(i,r){try{await r}catch(o){console.error(o),ca(i,{title:"Error",message:o.toString(),variant:"danger"})}}function he(i){const r=b.useContext(ie),[o,u]=b.useState(null),d=b.useCallback(()=>{i&&oe(r,W(i,{}).then(u,f=>{throw u(null),f}))},[r,i]);return b.useEffect(()=>{u(null),d()},[d]),[o,d]}const Dn=C.table.withConfig({shouldForwardProp:i=>!["fullWidth","edgeLine"].includes(i)})`
  table-layout: fixed;
  ${({fullWidth:i})=>i&&"width: 100%;"}
  ${({edgeLine:i,theme:r})=>i&&`
    border-top: solid 1px ${r.colors.accent2};
    border-bottom: solid 1px ${r.colors.accent2};
  `}

  @media (max-width: 480px) {
    width: 100%;
    font-size: 3.4vw;
  }
`,Na=C.thead`
  border-bottom: solid 2px ${i=>i.theme.colors.accent2};
`,Mn=C.tbody``,Re=C.tr`
  background-color: ${i=>i.theme.colors.background};
  ${i=>i.background&&`
    background-color: ${i.theme.colors.accent1};
    box-shadow: 2px 2px 5px ${i.theme.colors.shadow};

  `}

  &:last-child {
    border-bottom: none;
  }
  ${i=>!i.noAlternating&&`
    border-bottom: solid 1px ${i.theme.colors.accent2};
    &:nth-child(odd) {
      background-color: ${i.theme.colors.accent1};
    }

  `}
`,Je=C.th`
  text-align: left;
  padding: 0.5em;
  font-weight: 600;
`,fv=C.th`
  text-align: left;
  padding: 0.5em;
  font-weight: 600;
  width: 75px;
  @media (max-width: 480px) {
    width: 60px;
  }
`,I=C.td`
  padding: 0.5em;
  color: ${i=>i.theme.colors.text};
  a {
    color: ${i=>i.theme.colors.text};
  }
  @media (max-width: 480px) {
    padding: 0.3em;
  }
`,An=C.td`
  color: ${i=>i.theme.colors.text};
  a {
    color: ${i=>i.theme.colors.text};
  }
  @media (max-width: 480px) {
    padding: 0.3em;
  }
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  padding-right: 0.3em;
`,hv=C.td`
  position: relative;
  text-align: end;
  padding: 0 0.5em;
  &::before {
    content: "";
    position: absolute;
    left: 50%;
    top: 0;
    bottom: 0;
    width: 2px;
    background-color: ${i=>i.theme.colors.accent2};
  }

  ${i=>i.warn&&`
      &::after {
      content: "";
      position: absolute;
      left: 40%;
      top: 0;
      bottom: 0;
      width: 10%;
      background: ${i.warn};
      }
    `}
`,mv=C.span`
  a {
    color: ${i=>i.theme.colors.highlight.text};
    text-decoration: none;
    font-weight: bold;

    &:hover:not(:disabled):not(.static) {
      cursor: pointer;
      color: ${i=>i.theme.colors.highlight.active};
    }
  }
`,xv=C.div`
  h2, h3, h4, h5, h6 {
    display: inline;
    &:hover a {
      visibility: visible;
      opacity: 1;
    }

    a {
      margin-left: 10px;
      font-size: smaller;
      text-decoration: none;
      visibility: hidden;
      opacity: 0;
      transition: visibility 0.05s, opacity 0.05s linear;

      &:after {
        content: "#";
      }

      &:hover {
        color: ${i=>i.theme.colors.highlight.active};
      }
    }
  }
`,gv=C.ul`
  padding-left: 1.2em;
  list-style-type: none;
  font-size: 0.9em;
  margin-bottom: 1em;

  li {
    margin: 0.3em 0;
  }

  a {
    text-decoration: none;
    color: ${i=>i.theme.colors.text};
    &:hover {
      color: ${i=>i.theme.colors.highlight.text};
    }
  }
`;function pv({href:i,children:r,...o}){return a.jsx(mv,{children:i.startsWith("/")?a.jsx(jt,{to:i,end:!0,...o,children:r}):a.jsx("a",{href:i,target:"_blank",rel:"noopener noreferrer",...o,children:r})})}function vv({headings:i}){return i.length?a.jsx(gv,{children:i.map(({text:r,slug:o},u)=>a.jsx("li",{children:a.jsx("a",{href:`#${o}-${u}`,children:r})},u))}):null}function Hi({...i}){const[r,o]=ue.useState([]),u=({level:f,children:m})=>{const x=m.map(j=>{var O;return typeof j=="string"?j:((O=j==null?void 0:j.props)==null?void 0:O.children)??""}).flat().join(" "),p=encodeURIComponent(x.replace(/[^a-zA-Z0-9 ]/g,"").replace(/\s+/g,"-").toLowerCase()),v=`${p}-${r.length}`;return o(j=>j.some(O=>O.slug===p)?j:[...j,{text:x,slug:p}]),a.jsx(xv,{children:b.createElement(`h${f}`,{id:v},a.jsxs(a.Fragment,{children:[m,a.jsx("a",{href:`#${v}`,"aria-label":`Link to heading ${x}`})]}))})};ue.useEffect(()=>{var m;const{hash:f}=window.location;f&&((m=document.getElementById(f.substring(1)))==null||m.scrollIntoView())},[]);const d={h2:u,h3:u,h4:u,h5:u,h6:u,a:pv,table:Dn,thead:Na,tbody:Mn,th:Je,td:I,tr:Re};return a.jsxs(a.Fragment,{children:[a.jsx(vv,{headings:r}),a.jsx(Xm,{components:d,remarkPlugins:[o0],...i})]})}const ao=C.div`
  margin: 0.4em 0;
  margin-right: 1em;
  @media (max-width: 480px) {
    width: 100%;
    margin-right: 0;
  }
  width: 330px;
`,yv=C.div`
  padding-bottom: 0.5em;

  background-color: ${i=>i.theme.colors.accent1};
  filter: drop-shadow(0px 1px 1px ${i=>i.theme.colors.shadow});
  border-radius: 5px;
  border: solid 1px ${i=>(i.theme.colors[i.$variant]||{}).color||"transparent"};
  height: 100%;
  &:hover {
    border: solid 1px ${i=>i.theme.colors.accent2};
  }
`,jv=C.h3`
  font-weight: 600;
  padding: 0.2em 0.5em;
`,bv=C.div`
  padding: 0.5em 0.5em 0em;
`,rx=C.div`
  display: flex;
  align-items: stretch;
  flex-wrap: wrap;
`;function ux({variant:i,title:r,size:o,children:u,...d}){return a.jsxs(yv,{size:o,$variant:i,...d,children:[a.jsx(jv,{$variant:i,children:r}),a.jsx(bv,{children:u})]})}const Ei={},Sv=C(ct)`
  max-width: 800px;
`,wv=C.div`
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  height: 150px;
  background-color: ${i=>i.theme.colors.accent1};
  border-radius: 5px;
  cursor: pointer;
  &:hover {
    border: solid 1px ${i=>i.theme.colors.accent2};
  }
  @media (max-width: 600px) {
    width: 100%;
  }
  box-shadow: 3px 3px 1px ${i=>i.theme.colors.shadow};
`,Cv=C.img`
  height: 40px;
  margin-bottom: 5px;
`,_v=C.span`
  font-size: 20px;
`,Tv=C.span`
  font-size: 14px;
  color: gray;
`,Ev=C.div`
  display: flex;
  align-items: stretch;
  flex-wrap: wrap;
  border-top: 2px solid;
  padding-top: 5em;
  border-color: ${i=>i.theme.colors.accent2};
`,$u=({imageSrc:i,slug:r,title:o,subtitle:u,children:d})=>a.jsx(ao,{children:a.jsx(jt,{style:{textDecoration:"inherit",color:"inherit"},to:`${r}`,children:a.jsxs(wv,{children:[a.jsxs("div",{style:{display:"flex",height:"40px"},children:[d,i&&a.jsx(Cv,{src:i})]}),a.jsx(_v,{children:o}),a.jsx(Tv,{children:u})]})})});function Av(){const i=b.useContext(ie),{guideName:r}=t0(),[o,u]=b.useState(null),d=`./${r}`,f=`${d}/guide.md`;b.useEffect(()=>{if(u(null),!(f in Ei))return;let x=document.title;return oe(i,fetch(Ei[f]).then(p=>p.text()).then(p=>{u(p),no(cx(p))})),()=>document.title=x},[i,f]);const m=x=>{const p=`${d}/${x}`;return p in Ei?Ei[p]:x};return Ei[f]?o?a.jsx(Sv,{style:{maxWidth:"800px"},children:a.jsx(Hi,{transformImageUri:m,transformLinkUri:null,children:o})}):a.jsx(a.Fragment,{children:a.jsx("em",{children:"Loading..."})}):a.jsxs(a.Fragment,{children:[a.jsx("strong",{children:"Not found!"})," The guide could not be loaded."]})}function Dv(){return qe("Guides"),a.jsxs(a.Fragment,{children:[a.jsx(ra,{style:{marginLeft:"40%",marginBottom:"1em"},children:"Guides"}),a.jsxs(Ev,{style:{justifyContent:"space-around"},children:[a.jsx($u,{imageSrc:"https://images.evetech.net/types/14268/icon",title:"DDD Guide",subtitle:"get GUD & Read",slug:"guide/ddd"}),a.jsxs($u,{title:"Badges",subtitle:"Showing off u GUD",slug:"badges",children:[a.jsx(sn,{type:"DPS",height:"30px"}),a.jsx(sn,{type:"LOGI",height:"30px"}),a.jsx(sn,{type:"ALT",height:"30px"})]}),a.jsx($u,{imageSrc:"https://images.evetech.net/types/33400/icon",title:"Marauder Guide",subtitle:"Count to 2 and you gucci",slug:"guide/marauder"})]})]})}function Mv(){return a.jsx(uv,{})}const ox=["high","med","low","rig","other","drone","cargo"];var oc=null,Ai={};async function Ov(i){const r=i.split(",");oc||(oc=W("/incursions/api/module/preload",{}).catch(d=>oc=null));for(const[d,f]of Object.entries(await oc))Ai[d]=f;var o=[];for(const d of r)d in Ai||o.push(d);if(o&&o.length){const d=await W("/incursions/api/module/info",{json:{ids:o}});for(const[f,m]of Object.entries(d))Ai[f]=m}var u={};for(const d of r)u[d]=d in Ai?Ai[d]:null;return u}function zv(i){const[r,o]=b.useState(null),u=Array.from(i).sort().join(",");return b.useEffect(()=>{var d=!1;return Ov(u).then(f=>!d&&o(f)),()=>d=!0},[u,o]),r||{}}const Nv=C.div`
  display: flex;
  @media (max-width: 480px) {
    flex-wrap: wrap;
  }
`,je={};je.Ship=C.div`
  display: flex;
  align-items: center;
  font-size: 1.2em;
  font-weight: 600;
  margin-bottom: 0.5em;
  @media (max-width: 480px) {
    font-size: 1em;
  }
`;je.Ship.Image=C.img`
  height: 2em;
  width: 2em;
  margin-right: 2em;
  @media (max-width: 480px) {
    margin-right: 0.5em;
  }
`;je.Ship.Name=C.span`
  @media (max-width: 480px) {
    overflow-wrap: anywhere;
  }
`;je.Ship.Copy=C.div`
  margin-left: auto;
  margin-right: 2em;
  cursor: pointer;
  font-size: 0.8em;
`;je.Warning=C.div`
  margin: 1em 0;
`;je.Slot=C.div`
  margin-bottom: 1em;
`;je.Line=C.div`
  display: flex;
  ${i=>({have:"",missing:`
        background-color: ${i.theme.colors.danger.color};
        color: ${i.theme.colors.danger.text};
        text-decoration: line-through;
      `,extra:`
        background-color: ${i.theme.colors.success.color};
        color: ${i.theme.colors.success.text};
      `,downgraded_orig:`
        background-color: ${i.theme.colors.warning.color};
        color: ${i.theme.colors.warning.text};
        text-decoration: line-through;
      `,downgraded_new:`
        background-color: ${i.theme.colors.warning.color};
        color: ${i.theme.colors.warning.text};
      `})[i.group]}

  > * {
    margin-right: 0.5em;
  }
`;je.Line.Image=C.img`
  height: 1.5em;
  width: 1.5em;
`;je.Line.Count=C.span`
  min-width: 1em;
  @media (max-width: 480px) {
    font-size: 0.7em;
  }
`;je.Line.ModuleName=C.span`
  @media (max-width: 480px) {
    font-size: 0.8em;
  }
`;function Bv(i){const[r,...o]=i.split(/:/);var u=new Set,d={};u.add(parseInt(r));for(const m of o){if(!m)continue;const[x,p]=m.split(/;/);u.add(parseInt(x)),x in d||(d[x]=0),d[x]+=parseInt(p)}const f=Array.from(u).sort();return[r,f,d]}function Rv(i){if(!i)return[];var r=new Set;for(const o of["missing","extra","cargo_missing"])i[o]&&Object.keys(i[o]).forEach(u=>r.add(u));for(const o of["downgraded","upgraded"])i[o]&&Object.entries(i[o]).forEach(([u,d])=>{r.add(u),Object.keys(d).forEach(f=>r.add(f))});return Array.from(r).sort()}function dc(i,r){if(i.endsWith("_"))return"cargo";const o=r[parseInt(i)]||{};return o.slot?o.slot:"cargo"}function Aa(i,r,o){const u=parseInt(r);u in i?(i[u]+=o,i[u]||delete i[u]):i[u]=o}function Uv(i,r,o,u){const d=parseInt(r),f=parseInt(o);d in i||(i[d]={}),f in i[d]||(i[d][f]=0),i[d][f]+=u,i[d][f]||delete i[d][f],Z.isEmpty(i[d])&&delete i[d]}function Lv(i,r,o){if(!o)return null;var u={};ox.forEach(d=>u[d]={have:{},match:{},missing:{},extra:{},downgraded:{}});for(const[d,f]of Object.entries(i)){const m=dc(d,o);Aa(u[m].have,d,f),Aa(u[m].match,d,f)}if(r&&r.cargo_missing)for(const[d,f]of Object.entries(r.cargo_missing))Aa(u.cargo.missing,d,f);if(r&&r.missing)for(const[d,f]of Object.entries(r.missing)){const m=dc(d,o);Aa(u[m].missing,d,f)}if(r&&r.extra)for(const[d,f]of Object.entries(r.extra)){const m=dc(d,o);m!=="drone"&&(Aa(u[m].match,d,-f),Aa(u[m].extra,d,f))}if(r&&r.downgraded)for(const[d,f]of Object.entries(r.downgraded)){const m=dc(d,o);for(const[x,p]of Object.entries(f))Aa(u[m].match,x,-p),Uv(u[m].downgraded,d,x,p)}return u}function kv(i,r,o){var u=`[${o[i].name}, ${o[i].name}]
`;for(const f of ox){for(const[m,x]of Object.entries(r[f].have)){const p=m in o?o[m].name:m;if(f==="cargo"||f==="drone")u+=`${p} x${x}
`;else for(var d=0;d<x;d++)u+=`${p}
`}u+=`
`}return u}function Hv({isDiff:i,groups:r,moduleInfo:o}){const u=i?["match","missing","extra"]:["have"];return a.jsxs(je.Slot,{children:[u.map(d=>Object.entries(r[d]).map(([f,m])=>a.jsxs(je.Line,{group:d,children:[a.jsx(je.Line.Image,{src:`https://images.evetech.net/types/${f}/icon?size=64`,alt:(o[f]||{}).name||null}),a.jsx(je.Line.Count,{children:m}),a.jsx(je.Line.ModuleName,{children:(o[f]||{}).name||null})]},f))),i&&Object.entries(r.downgraded).map(([d,f])=>Object.entries(f).map(([m,x])=>a.jsxs(b.Fragment,{children:[a.jsxs(je.Line,{group:"downgraded_orig",children:[a.jsx(je.Line.Image,{src:`https://images.evetech.net/types/${d}/icon?size=64`,alt:(o[d]||{}).name||null}),a.jsx(je.Line.Count,{children:x}),a.jsx(je.Line.ModuleName,{children:(o[d]||{}).name||null})]}),a.jsxs(je.Line,{group:"downgraded_new",children:[a.jsx(je.Line.Image,{src:`https://images.evetech.net/types/${m}/icon?size=64`,alt:(o[m]||{}).name||null}),a.jsx(je.Line.Count,{children:x}),a.jsx(je.Line.ModuleName,{children:(o[m]||{}).name||null})]})]},`${d} ${m}`)))]})}function lo({dna:i,analysis:r=null,name:o=null}){const{t:u}=k(),d=b.useContext(ie),[f,m,x]=b.useMemo(()=>Bv(i),[i]),p=b.useMemo(()=>m.concat(Rv(r)),[m,r]),v=zv(p),j=b.useMemo(()=>Lv(x,r,v),[x,r,v]);if(!v||!v[f])return a.jsx("div",{children:a.jsx("em",{children:u("Loading fit info")})});let O=o||((r==null?void 0:r.name)??v[f].name);return a.jsxs("div",{children:[a.jsxs(je.Ship,{children:[a.jsx(je.Ship.Image,{src:`https://images.evetech.net/types/${f}/icon?size=64`,alt:v[f].name}),a.jsx(je.Ship.Name,{children:O}),a.jsx(je.Ship.Copy,{title:u("Copy to clipboard"),onClick:()=>{Xt(d,navigator.clipboard.writeText(kv(f,j,v)).then(D=>u("Copied to clipboard")))},children:a.jsx(ae,{fixedWidth:!0,icon:Km})})]}),r&&!r.name?a.jsx(je.Warning,{children:a.jsx(Yt,{$variant:"danger",children:u("Fit could not be automatically checked!")})}):null,Object.entries(j).map(([D,M])=>a.jsx(Hv,{isDiff:r!=null,groups:M,moduleInfo:v},D))]})}function dx({implants:i,...r}){const o=i.map(u=>`${u};1`).join(":");return a.jsx(lo,{dna:`670:${o}::`,...r})}function io({fit:i}){return a.jsxs(Nv,{children:[a.jsx("div",{style:{margin:"0 0.5em"},children:a.jsx(lo,{dna:i.dna,analysis:i.fit_analysis||{}})}),i.implants?a.jsx("div",{style:{margin:"0 0.5em"},children:a.jsx(dx,{implants:i.implants})}):null]})}function fx(i,r){Xt(i,navigator.clipboard.writeText(r).then(()=>"Copied to clipboard"))}function qv({type:i}){const r=b.useContext(ie),{t:o}=k();var u;switch(i){case"Amulet":u=["Mid-grade Amulet Alpha","Mid-grade Amulet Beta","Mid-grade Amulet Gamma","Mid-grade Amulet Delta","Mid-grade Amulet Epsilon"];break;case"Ascendancy":u=["High-grade Ascendancy Alpha","High-grade Ascendancy Beta","High-grade Ascendancy Gamma","High-grade Ascendancy Delta","High-grade Ascendancy Epsilon"];break;case"None":u=[];break;default:u=[]}return a.jsx(a.Fragment,{children:a.jsxs(Dn,{style:{width:"100%"},children:[a.jsx(Na,{children:a.jsxs(Re,{children:[a.jsx(fv,{}),a.jsx(Je,{children:o("DEFAULT")}),a.jsx(Je,{children:o("ALTERNATIVE (not required)")})]})}),a.jsxs(Mn,{children:[u.map((d,f)=>a.jsx($v,{toast:r,slot:f+1,implant:d},f)),a.jsxs(Re,{children:[a.jsx(I,{children:a.jsx("b",{children:o("Slot 6")})}),i==="Amulet"?a.jsx(I,{children:a.jsx(Fe,{toast:r,item:"Mid-Grade Amulet Omega"})}):i==="Ascendancy"?a.jsxs(I,{children:[a.jsx(Fe,{toast:r,item:"WS-518"})," ",o("+18% warp speed")]}):a.jsxs(I,{children:[a.jsx(Fe,{toast:r,item:"High-grade Ascendancy Omega"})," ",o("+21% warp speed")]})]}),a.jsx(Gv,{toastContext:r})]})]})})}function $v({toast:i,slot:r,implant:o}){const{t:u}=k();return a.jsxs(Re,{children:[a.jsx(I,{children:a.jsxs("b",{children:[u("Slot")," ",r]})}),a.jsx(I,{children:a.jsx(Fe,{toast:i,item:o})}),a.jsx(I,{})]})}function Fe({toast:i,item:r}){return a.jsx(iv,{onClick:o=>{fx(i,r)},children:r})}function Gv({toastContext:i}){const{t:r}=k();return a.jsxs(a.Fragment,{children:[a.jsxs(Re,{children:[a.jsx(I,{children:a.jsx("b",{children:r("Slot 7")})}),a.jsxs(I,{children:[a.jsx(Fe,{toast:i,item:"Ogdin's Eye Coordination Enhancer"})," ",r("+6% Tracking (Often Cheaper!)")]}),a.jsxs(I,{children:[a.jsx(Fe,{toast:i,item:"MR-705"})," ",r("+5% Tracking"),a.jsx("br",{}),a.jsx("b",{children:r("Logi:")}),a.jsx("br",{}),a.jsx(Fe,{toast:i,item:"RA-705"})," ",r("-5% Cap use for remote reps")]})]}),a.jsxs(Re,{children:[a.jsx(I,{children:a.jsx("b",{children:r("Slot 8")})}),a.jsxs(I,{children:[a.jsx(Fe,{toast:i,item:"EM-805"})," ",r("+5% Capacitor")]}),a.jsxs(I,{children:[a.jsx(Fe,{toast:i,item:"Zor's Custom Navigation Hyper-Link"})," ",r("+5% MWD/AB Speed"),a.jsx("br",{}),a.jsx("b",{children:r("Vindicator:")}),a.jsx("br",{}),a.jsx(Fe,{toast:i,item:"MR-805"})," ",r("+5% Web range")]})]}),a.jsxs(Re,{children:[a.jsx(I,{children:a.jsx("b",{children:r("Slot 9")})}),a.jsxs(I,{children:[a.jsx(Fe,{toast:i,item:"RF-905"})," ",r("+5% rate of fire for all turrets")]}),a.jsxs(I,{children:[a.jsx(Fe,{toast:i,item:"SS-905"})," ",r("+5% damage for all turrets"),a.jsx("br",{}),a.jsx(Fe,{toast:i,item:"Pashan's Turret Customization Mindlink"})," ",r("+7% rate of fire for all turrets")]})]}),a.jsxs(Re,{children:[a.jsx(I,{children:a.jsx("b",{children:r("Slot 10")})}),a.jsxs(I,{children:[a.jsx("b",{children:r("Kronos/Vindicator:")}),a.jsx("br",{}),a.jsx(Fe,{toast:i,item:"LH-1005"})," ",r("+5% Hybrid weapon damage"),a.jsx("br",{}),a.jsx("b",{children:r("Paladin:")}),a.jsx("br",{}),a.jsx(Fe,{toast:i,item:"LE-1005"})," ",r("+5% Energy weapon damage"),a.jsx("br",{}),a.jsx("b",{children:r("Vargur:")}),a.jsx("br",{}),a.jsx(Fe,{toast:i,item:"LP-1005"})," ",r("+5% Projectile weapon damage")]}),a.jsxs(I,{children:[a.jsx("b",{children:r("Paladin:")}),a.jsx("br",{}),a.jsx(Fe,{toast:i,item:"Pashan's Turret Handling Mindlink"})," ",r("+7% energy weapon damage"),a.jsx("br",{}),a.jsx("b",{children:r("Logi:")}),a.jsx("br",{}),a.jsx(Fe,{toast:i,item:"HG-1005"})," ",r("+5% Armor hitpoints"),a.jsx("br",{}),a.jsx(Fe,{toast:i,item:"HG-1008"})," ",r("+8% Armor hitpoints"),a.jsx("br",{})]})]})]})}const xc=C.div`
  margin: 0 0 0.5em;
  display: flex;
  background-color: ${i=>i.theme.colors[i.$variant].color};
  color: ${i=>(i.theme.colors[i.$variant]||{}).text||i.theme.colors.text};
  border-radius: 5px;
  width: ${i=>i.width};
  filter: drop-shadow(0px 4px 5px ${i=>i.theme.colors.shadow});
  padding: 0.1em 0.5em 0.2em;
  vertical-align: middle;
  word-break: break-word;
`,fc=C.div`
  background-color: ${i=>i.theme.colors.accent1};
  border-radius: 20px;
  border: solid 1px ${i=>i.theme.colors.accent2};
  padding: 0.4em;
  border-radius: 20px;
  font-size: min(calc(9px + 0.4vw), 14px);
`;function Yv({variant:i="secondary",width:r="fit-content",children:o}){return a.jsxs(xc,{$variant:i,width:r,children:[a.jsx("div",{style:{marginRight:"0.5em"},children:a.jsx(ae,{icon:Fm})}),o]})}const gm="/static/incursions/waitlist/media/w.png",Ni=C.div`
  border: solid 2px ${i=>i.theme.colors.accent2};
  background-color: ${i=>i.theme.colors.background};
  border-radius: 5px;
  font-size: 0.9em;
  filter: drop-shadow(0px 3px 4px ${i=>i.theme.colors.shadow});
  width: 380px;
  &:hover:not(:disabled):not(.static) {
    border-color: ${i=>i.theme.colors.accent3};
    cursor: pointer;
  }
  @media (max-width: 480px) {
    width: 100%;
  }
`;Ni.Content=C.div`
  display: flex;
  align-items: center;
  color: ${i=>i.theme.colors.text};
  p {
    @media (max-width: 480px) {
      font-size: 3.1vw;
    }
  }
  img {
    border-radius: 3px 0px 0px 3px;
    margin-right: 0.5em;
    align-self: flex-start;
  }
`;Ni.Content.Badges=C.div`
  margin-left: auto;
  display: flex;
  align-items: center;
  > *:last-child {
    margin-right: 0.5em;
  }
  img {
    height: 1.3em;
  }
  @media (max-width: 480px) {
    font-size: 1em;
    > *:last-child {
      margin-right: 0.4em;
    }
  }
`;const Bi=C.div`
  display: flex;
  flex-wrap: wrap;
  width: 100%;
  @media (max-width: 480px) {
    justify-content: center;
  }
`;function hc({data:i,tier:r}){const{t:o}=k();var u=[],d=[],f=[],m={},x,p;return r==="Antigank"?p=i.fittingdata:p=Z.sortBy(i.fittingdata,function(v){return v.name.indexOf("HYBRID")}),Z.forEach(i.logi_rules,v=>{f.push(v)}),Z.forEach(i.notes,v=>{m[v.name]=v.description}),p.forEach(v=>{if(v.dna&&v.name&&v.tier===r&&!(r!=="Antigank"&&v.name.toLowerCase().indexOf("antigank")!==-1)){const j=v.dna.split(":",1)[0];v.name in m?x=m[v.name]:x=null,f.includes(parseInt(j))?d.push(a.jsx(pm,{fit:v,id:j,note:x},v.name)):u.push(a.jsx(pm,{fit:v,id:j,note:x},v.name))}}),r==="Other"?a.jsx(a.Fragment,{children:a.jsxs("div",{children:[a.jsx("div",{style:{padding:"1em 0 0.4em"},children:a.jsx("p",{children:o("These ships are never used as main characters in fleet.")})}),a.jsx(_e,{children:o("Secondary Support Ships")}),a.jsx(Bi,{children:u})]})}):a.jsx(a.Fragment,{children:a.jsxs("div",{children:[a.jsx("div",{style:{padding:"1em 0 0.4em"},children:r in m?a.jsx(Hi,{children:m[r]}):a.jsx("br",{})}),u.length!==0&&a.jsxs(a.Fragment,{children:[a.jsx(_e,{children:o("DPS")}),a.jsx(Bi,{children:u})]}),a.jsx("br",{}),d.length!==0&&a.jsxs(a.Fragment,{children:[a.jsx(_e,{children:o("LOGISTICS")}),a.jsx(Bi,{children:d})]})]})})}function pm({fit:i,id:r,note:o}){const[u,d]=b.useState(!1),{t:f}=k();return a.jsxs(a.Fragment,{children:[u?a.jsx(ze,{open:!0,setOpen:d,children:a.jsxs(we,{style:{maxWidth:"500px"},children:[a.jsx("div",{style:{display:"flex"},children:a.jsx("div",{style:{margin:"0 0.5em"},children:a.jsx(lo,{dna:i.dna,name:i.name})})}),o?a.jsx(xc,{$variant:"secondary",children:a.jsx(Hi,{children:o})}):null,i.implant_set==="Amulet"?a.jsx(xc,{$variant:"danger",children:a.jsx("p",{children:f("HYBRID FIT! This fit requires at least Amulet 1 - 5. See implants above")})}):i.implant_set==="Ascendancy "?a.jsx(xc,{$variant:"danger",children:a.jsx("p",{children:f("ASCENDANCY FIT! This fit requires at least Ascendancy 1 - 5 & WS-618. See implants above")})}):null]})}):null,a.jsx(we,{mpadding:"0.2em",style:{margin:"0.5em 0"},children:a.jsx(Ni,{$variant:"input",children:a.jsx("a",{onClick:m=>d(!0),children:a.jsxs(Ni.Content,{children:[a.jsx("img",{style:{height:"64px"},src:`https://images.evetech.net/types/${r}/icon`,alt:i.name}),a.jsx("p",{children:i.name}),a.jsxs(Ni.Content.Badges,{children:[o?a.jsx(ae,{icon:Fm}):null,i.implant_set==="Amulet"?a.jsx(Ku,{color:"red",letter:"A",title:f("Amulet Implants")}):i.implant_set==="Ascendancy "?a.jsx(Ku,{color:"red",letter:"W",title:f("Ascendancy Implants")}):null]})]})})})})]})}function Xv(){return a.jsxs(a.Fragment,{children:[a.jsx(Bi,{style:{justifyContent:"initial"},children:a.jsx(vm,{name:"Amulet",img:gm})}),a.jsx(Bi,{style:{justifyContent:"initial"},children:a.jsx(vm,{name:"Ascendancy",img:gm})})]})}function vm({name:i,img:r}){const[o,u]=b.useState(!1),{t:d}=k();return a.jsxs(a.Fragment,{children:[o?a.jsx(ze,{open:!0,setOpen:u,children:a.jsxs(we,{style:{width:"100%"},children:[a.jsx(Ri,{style:{width:"100%"},children:a.jsxs(Ri.Title,{children:[a.jsx("div",{children:a.jsx("img",{src:r,alt:i,style:{width:"1.8em",marginRight:"0.5em"}})}),a.jsxs(_e,{children:[d(i),"  "]})]})}),a.jsx("br",{}),a.jsx("br",{}),a.jsx(qv,{type:i})]})}):null,a.jsx(sa,{children:a.jsx("a",{onClick:f=>u(!0),children:a.jsxs(sa.Content,{children:[a.jsx(sa.Icon,{children:a.jsx("img",{src:r,alt:i,style:{width:"1.5em"}})}),d(i)]})})})]})}function Qv(){const i=new URLSearchParams(un().search),r=vc(),o=i.get("Tier")||"Armor",u=d=>{i.set("Tier",d),r({search:`?${i.toString()}`})};return a.jsx(Vv,{tier:o,setTier:u})}function Vv({tier:i,setTier:r=null}){const{t:o}=k();qe(o(`${i} Fits`));const[u]=he("/incursions/api/fittings");return u===null?a.jsx("em",{children:o("Loading fits...")}):a.jsxs(a.Fragment,{children:[a.jsx(ra,{children:o("FITS")}),r!=null&&a.jsx(bt,{style:{marginBottom:"0.5em"},children:a.jsxs(Oe,{children:[a.jsx(q,{$active:i==="Basic",onClick:()=>r("Basic"),children:o("Basic")}),a.jsx(q,{$active:i==="Mainline",onClick:()=>r("Mainline"),children:o("Mainline")}),a.jsx(q,{$active:i==="Alt",onClick:()=>r("Alt"),children:o("Alt")}),a.jsx(q,{$active:i==="Other",onClick:()=>r("Other"),children:o("Other")})]})}),a.jsx(Xv,{}),i==="Basic"?a.jsx(hc,{data:u,tier:"Basic"}):i==="Mainline"?a.jsx(hc,{data:u,tier:"Mainline"}):i==="Alt"?a.jsx(hc,{data:u,tier:"Alt"}):i==="Other"?a.jsx(hc,{data:u,tier:"Other"}):null]})}const Di={},Zv=C(ct)`
  max-width: 800px;
`;function Kv(i){return i.split("/").pop()}function ym(){const i=b.useContext(ie),r=un(),o=Kv(r.pathname),[u,d]=b.useState(null),f=`./${o}`,m=`${f}/guide.md`,{t:x}=k();b.useEffect(()=>{if(d(null),!(m in Di))return;const v=document.title;return oe(i,fetch(Di[m]).then(j=>j.text()).then(j=>{d(j),no(cx(j))})),()=>document.title=v},[i,m]);const p=v=>{const j=`${f}/${v}`;return j in Di?Di[j].default:v};return Di[m]?u?a.jsx(Zv,{style:{maxWidth:"800px"},children:a.jsx(Hi,{transformImageUri:p,transformLinkUri:null,children:u})}):a.jsx(a.Fragment,{children:a.jsx("em",{children:x("Loading...")})}):a.jsx("div",{children:x("client : a{{loc}}a",{loc:o})})}function Da({icon:i,slug:r,name:o,children:u}){const{t:d}=k();return a.jsx(ao,{children:a.jsx(jt,{style:{textDecoration:"inherit",color:"inherit"},exact:!0,to:`/fc/${r}`,children:a.jsx(ux,{title:a.jsxs(a.Fragment,{children:[a.jsx(ae,{fixedWidth:!0,icon:i})," ",d(o)]}),children:a.jsx("p",{children:d(u)})})})})}function Fv(){const i=b.useContext(Te),{t:r}=k();return qe(r("FC Menu")),a.jsxs(a.Fragment,{children:[a.jsx(ra,{children:r("FC Dashboard")}),a.jsxs(rx,{children:[i&&i.access["incursions.waitlist_announcements_manage"]&&a.jsx(Da,{slug:"announcements",name:r("Announcements"),icon:Jm}),i&&i.access["incursions.waitlist_bans_view"]&&a.jsx(Da,{slug:"bans",name:r("Bans"),icon:bc}),i&&i.access["incursions.waitlist_bages_view"]&&a.jsx(Da,{slug:"badges",name:r("Badges"),icon:O0}),i&&i.access["incursions.waitlist_commanders_view"]&&a.jsx(Da,{slug:"commanders",name:r("Commanders"),icon:z0}),i&&i.access["incursions.waitlist_documentation_view"]&&a.jsx(Da,{slug:"documentation",name:r("FC Documentation"),icon:N0}),i&&i.access["incursions.waitlist_fleet_view"]&&a.jsx(Da,{slug:"trainee",name:r("FC Training"),icon:Pu}),i&&i.access["incursions.waitlist_stats_view"]&&a.jsx(Da,{slug:"stats",name:r("Statistics"),icon:B0})]})]})}function Jv(i){return i.waitlist.map(r=>{var o=[],u={};return r.character?(Z.forEach(r.fits,d=>{if(d.character){var f;d.character.character_id in u?f=u[d.character.character_id]:(f={character:d.character,fits:[]},o.push(f),u[d.character.character_id]=f),f.fits.push(d)}}),o.map(d=>{var f=`<a href="showinfo:1377//${d.character.character_id}">${d.character.name}</a>`,m=d.fits.map(x=>{const p=x.approved?"":", CHECK FIT";return`${x.ship.name[0]}${p}`});return f+" "+m.join(", ")}).join(" | ")):""}).join(`
`)}function Wv({waitlist:i}){const{t:r}=k();return a.jsxs(ct,{children:[a.jsx("h2",{children:r("Notepad waitlist")}),a.jsxs("p",{children:[a.jsx("strong",{children:r("What is this?!")})," ",r("When ESI is having trouble, the Invite button may not always work. To invite manually, or to switch to a channel-based waitlist, you can copy the existing waitlist into a notepad or channel MOTD by copying the code below. It will make the names linkable so that they can be invited by dragging into the fleet composition.")]}),a.jsx(Kt,{readOnly:!0,style:{width:"100%"},rows:"15",children:Jv(i)})]})}class Iv extends b.Component{constructor(r){super(r),this.state={time:Date.now()}}componentDidMount(){this.timer=setInterval(()=>{this.setState({time:Date.now()})},6e4)}componentWillUnmount(){clearInterval(this.timer)}render(){const r=this.state.time,o=new Date(this.props.relativeTo).getTime(),u=Math.round((r-o)/1e3/60);return this.props.isAlt?a.jsx("span",{title:`${u} min`,children:a.jsx(Yt,{variant:"danger",children:"ALT"})}):a.jsxs(Yt,{variant:"secondary",children:[u," min"]})}}const Tl=C(({xs:i,sm:r,md:o,lg:u,xl:d,offset:f,children:m,...x})=>a.jsx(n0,{xs:i,sm:r,md:o,lg:u,xl:d,offset:f,...x,children:m})).withConfig({shouldForwardProp:(i,r)=>!["xs","sm","md","lg","xl","offset"].includes(i)&&r(i)})``,wl={};wl.Table=C.div`
  margin-bottom: 2em;
`;wl.Table.Name=C.h3`
  border-bottom: solid 2px ${i=>i.theme.colors.accent2};
  font-weight: bolder;
  padding: 0.75em;
`;wl.Table.Row=C.div`
  display: flex;
  padding: 0.5em 0.75em 0.5em 0.75em;
  border-bottom: solid 1px ${i=>i.theme.colors.accent2};

  &:last-child {
    border-bottom: none;
  }
  &:nth-child(odd) {
    background-color: ${i=>i.theme.colors.accent1};
  }
  > :last-child {
    margin-left: auto;
  }
`;const Pv=C.div`
  height: 36px;
`,hx=["Armor","Shields","Gunnery","Missiles","Neural Enhancement","Spaceship Command","Drones","Rigging"],ey=new Set(hx),ty=({current:i,skill:r})=>{if(i===5)return a.jsx(Yt,{$variant:"success",children:i});var o=null;for(const[u,d]of[["gold","success"],["elite","primary"],["min","secondary"]])if(u in r){if(i>=r[u])return a.jsxs(Yt,{$variant:d,children:[i,o]});o=` / ${r[u]}`}for(const[u,d]of[["min","danger"],["elite","warning"],["gold","secondary"]])if(u in r)return a.jsxs(Yt,{$variant:d,children:[i,o]});return null};function ny({title:i,current:r,requirements:o,ids:u,category:d,filterMin:f}){var m=[];return d.forEach(x=>{if(!(x in o))return;const p=o[x];f&&(!p.min||p.min<=r[x])||m.push(a.jsxs(wl.Table.Row,{children:[u[x]," ",a.jsx(ty,{current:r[x],skill:p})]},x))}),m.length?a.jsx(Tl,{xs:4,sm:4,md:2,children:a.jsxs(wl.Table,{children:[a.jsx(wl.Table.Name,{children:i}),m]})}):null}function ay({mySkills:i,shipName:r,filterMin:o}){const{t:u}=k(),d=Z.invert(i.ids);if(!(r in i.requirements))return a.jsx("em",{children:u("No skill information found")});const f=[...hx];return Z.forEach(Z.keys(i.categories),m=>{ey.has(m)||f.push(m)}),a.jsx(yc,{children:f.map(m=>a.jsx(ny,{title:u(m),current:i.current,requirements:i.requirements[r],category:i.categories[m],ids:d,filterMin:o},m))})}function so({characterId:i,ship:r,setShip:o=null,filterMin:u=!1}){const{t:d}=k(),[f]=he(`/incursions/api/skills/${i}`);return a.jsxs(a.Fragment,{children:[o!=null&&a.jsxs(bt,{style:{marginBottom:"1em"},children:[a.jsxs(Oe,{children:[a.jsx(q,{$active:r==="Vindicator",onClick:()=>o("Vindicator"),children:d("Vindicator")}),a.jsx(q,{$active:r==="Kronos",onClick:()=>o("Kronos"),children:d("Kronos")}),a.jsx(q,{$active:r==="Paladin",onClick:()=>o("Paladin"),children:d("Paladin")})]}),a.jsxs(Oe,{children:[a.jsx(q,{$active:r==="Guardian",onClick:()=>o("Guardian"),children:d("Guardian")}),a.jsx(q,{$active:r==="Nestor",onClick:()=>o("Nestor"),children:d("Nestor")})]}),a.jsxs(Oe,{children:[a.jsx(q,{$active:r==="Eos",onClick:()=>o("Eos"),children:d("Eos")}),a.jsx(q,{$active:r==="Damnation",onClick:()=>o("Damnation"),children:d("Damnation")})]})]}),a.jsxs("div",{style:{marginBottom:"1em"},children:[d("Legend"),":",a.jsx(Yt,{$variant:"danger",children:d("Does Not Meet Requirements")}),a.jsx(Yt,{$variant:"secondary",children:d("Minimum")}),a.jsx(Yt,{$variant:"primary",children:d("Suggested")}),a.jsx(Yt,{$variant:"success",children:d("#Swag")})]}),a.jsx(Pv,{children:(r==="Nestor"||r==="Guardian"||r==="Oneiros")&&a.jsx(Yv,{children:d("Basic tier skills are required for logistics.")})}),f?a.jsx(ay,{mySkills:f,shipName:r,filterMin:u}):a.jsx("p",{children:d("Loading skill information")})]})}async function mx(i){return await W("/incursions/api/waitlist/approve",{json:{id:i}})}async function xx(i,r){return await W("/incursions/api/waitlist/reject",{json:{id:i,review_comment:r}})}async function ly(i){return await W("/incursions/api/waitlist/remove_fit",{json:{id:i}})}async function iy(i,r){return await W("/incursions/api/open_window",{json:{target_id:i,character_id:r}})}const Ve=C.div`
  border: solid 2px ${i=>i.theme.colors[i.$variant].color};
  background-color: ${i=>i.theme.colors[i.$variant].color};
  color: ${i=>i.theme.colors[i.$variant].text};
  border-radius: 5px;
  font-size: 0.9em;
  filter: drop-shadow(0px 4px 5px ${i=>i.theme.colors.shadow});
  min-width: 245px;

  a {
    color: inherit;
    text-decoration: none;
  }
`;Ve.Head=C.div`
  display: flex;
  padding: 0.2em 0.2em 0.3em 0.5em;
  align-items: center;
  a {
    font-weight: 600;
  }
`;Ve.Head.Badges=C.div`
  margin-left: auto;
  display: flex;
  flex-shrink: 0;
  align-items: center;
  > * {
    margin-left: 0.25em;
  }
  > *:last-child {
    margin-left: 0.5em;
  }
  > span {
    display: flex;
    align-items: center;
  }
  img {
    height: 1.3em;
  }
`;Ve.Content=C.div`
  display: flex;

  background-color: ${i=>i.theme.colors.background};
  align-items: center;
  color: ${i=>i.theme.colors.text};
  img {
    margin-right: 0.5em;
    align-self: flex-start;
  }
  a {
    align-items: center;
    display: flex;
    cursor: pointer;
    width: 100%;
  }
`;Ve.FooterGroup=C.div`
  > *:last-child {
    border-radius: 0 0 4px 4px;
  }
`;Ve.Footer=C.div`
  display: flex;
  background-color: ${i=>i.theme.colors.accent1};
  color: ${i=>i.theme.colors.text};
  text-align: center;
  a:hover {
    background-color: ${i=>i.theme.colors.accent2};
    cursor: pointer;
  }
  > * {
    flex-grow: 1;
    flex-basis: 0;
  }
`;Ve.ReviewComment=C.div`
  padding: 0.5em;
  margin: 0.5em;
  width: 100%;
  text-align: center;
  background-color: ${i=>i.theme.colors.secondary.color};
  border-radius: 5px;
  color: ${i=>i.theme.colors.secondary.text};
  word-break: break-word;
`;Ve.ReviewComment.Header=C.div`
  border-bottom: 1px solid;
  margin-bottom: 1em;
  font-weight: bold;
`;function sy({fit:i,onAction:r}){const o=b.useContext(Te),u=b.useContext(ie),[d,f]=b.useState(!1),m=i.character?`${i.character.character_name}'s `:"";return i.dna&&i.ship?a.jsxs(a.Fragment,{children:[d?a.jsx(ze,{open:!0,setOpen:f,children:a.jsxs(we,{children:[o.access["incursions.waitlist_manage_waitlist"]&&a.jsxs(bt,{style:{marginBlock:"1em",marginTop:"0px"},children:[a.jsx(q,{$variant:"success",style:{minWidth:"95px"},onClick:x=>{f(!1),oe(u,mx(i.id)).then(r)},children:"Approve"}),a.jsx(q,{$variant:"danger",style:{minWidth:"95px"},onClick:x=>{var p=prompt("Why is the fit being rejected? (Will be displayed to pilot)");p&&(f(!1),oe(u,xx(i.id,p)).then(r))},children:"Reject"})]}),a.jsx(io,{fit:i}),i.tags.includes("STARTER")?a.jsxs(a.Fragment,{children:[a.jsx(_e,{children:"Starter skills"}),a.jsx(so,{characterId:i.character.character_id,ship:i.ship.name,filterMin:!0})]}):null]})}):null,a.jsxs("a",{onClick:x=>f(!0),children:[a.jsx("img",{style:{height:"44px"},src:`https://images.evetech.net/types/${i.ship.id}/icon?size=64`,alt:i.ship.name}),a.jsxs("span",{style:{flexShrink:1},children:[m,i.ship.name]})]})]}):i.ship?a.jsxs(a.Fragment,{children:[a.jsx("img",{style:{height:"44px"},src:`https://images.evetech.net/types/${i.ship.id}/icon?size=64`,alt:i.ship.name}),a.jsxs("span",{children:[m,i.ship.name]})]}):a.jsxs(a.Fragment,{children:[a.jsx("img",{style:{height:"44px"},src:"https://images.evetech.net/types/28606/icon?size=64",alt:""}),a.jsxs("span",{children:[m,"Ship"]})]})}function cy({characterId:i,ship:r}){const[o,u]=b.useState(!1),[d,f]=b.useState(r);return a.jsxs(a.Fragment,{children:[a.jsx("a",{title:"Show skills",onClick:m=>u(!0),children:a.jsx(ae,{icon:L0})}),o&&a.jsx(ze,{open:!0,setOpen:u,children:a.jsx(we,{children:a.jsx(so,{characterId:i,ship:d,setShip:f})})})]})}function Ju({number:i}){const r=b.useContext(za);return a.jsx("span",{style:{verticalAlign:"middle"},children:a.jsx("svg",{style:{height:"1em"},viewBox:"0 0 50 50",xmlns:"http://www.w3.org/2000/svg",children:a.jsxs("g",{children:[a.jsx("circle",{style:{verticalAlign:"middle",fill:r.colors.text},cy:"25",cx:"25",r:"24"}),a.jsx("text",{style:{fontSize:"2.6em",fontWeight:"600",textAnchor:"middle",fill:r.colors.accent1,textRendering:"geometricPrecision"},x:"25",y:"38",children:i})]})})})}function ry({fitId:i,fcId:r,onAction:o}){var D,M,L,U;const u=b.useContext(za),d=b.useContext(ie),[f,m]=b.useState(void 0),[x,p]=ue.useReducer(H=>H+1,0),{t:v}=k(),j={success:(M=(D=u==null?void 0:u.colors)==null?void 0:D.success)==null?void 0:M.color,failed:(U=(L=u==null?void 0:u.colors)==null?void 0:L.danger)==null?void 0:U.color},O=async()=>{m("pending"),p(),oe(d,W("/incursions/api/waitlist/invite",{json:{id:i,character_id:r}}).then(()=>{m("success"),o()}).catch(H=>{throw m("failed"),H}))};return a.jsx("a",{title:v("Invite"),onClick:O,style:{cursor:f==="Pending"?"not-allowed":null,backgroundColor:j[f]??null,transition:"background-color 300ms linear"},children:x<2?a.jsx(ae,{fixedWidth:!0,icon:f!=="pending"?Im:k0,spin:f==="pending"}):a.jsx(Ju,{number:x})})}function jm({from:i,message:r}){return a.jsxs(a.Fragment,{children:[a.jsx(Ve.ReviewComment.Header,{children:i}),a.jsx("div",{children:r})]})}function uy({characterId:i,authContext:r,id:o}){const[u]=he(r.access["incursions.waitlist_notes_view"]?`/incursions/api/notes?character_id=${i}`:null),{t:d}=k();if(!u||!u.notes)return a.jsx(jt,{to:"/pilot?character_id="+o,children:a.jsx(Ju,{number:0})});var f=Object.keys(u.notes).length,m=d("Pilot information");return f=f>9?"9+":f.toString(),f>0&&(m+=`
`+d("Last Note:")+`
`+u.notes[f-1].note),a.jsx(jt,{title:m,to:"/pilot?character_id="+o,children:a.jsx(Ju,{number:f})})}function qi({entry:i,fit:r,onAction:o}){const u=b.useContext(Te),d=b.useContext(ie),f=r.is_alt,m=i.character?i.character.character_name:"Name hidden",x=Z.sortBy(r.tags,function(D){return to.indexOf(D)});var p=i.character&&i.character.character_id===u.account_id,v=[],j=[];x.forEach(D=>{D in _l?j.push(a.jsx(sn,{type:D},D)):v.push(D)});const O=r.approved?null:a.jsx("span",{title:"Pending approval",children:a.jsx(ae,{icon:R0})});return a.jsxs(Ve,{$variant:r.approved?p?"success":"secondary":r.approved?"secondary":r.review_comment?"danger":p||u.access["incursions.waitlist_context_a"]?"warning":"secondary",children:[a.jsxs(Ve.Head,{children:[a.jsx("span",{children:m}),a.jsxs(Ve.Head.Badges,{children:[j,O,a.jsx(Iv,{relativeTo:i.joined_at,isAlt:f})]})]}),a.jsx(Ve.Content,{children:a.jsx(sy,{fit:r,onAction:o})}),a.jsx(Ve.Content,{children:a.jsx("div",{style:{FlexWrap:"wrap"},children:v.map(D=>a.jsx(Yt,{children:D},D))})}),r.review_comment?a.jsx(Ve.Content,{children:a.jsx(Ve.ReviewComment,{children:a.jsx(jm,{from:"FC",message:r.review_comment})})}):null,r.messagexup?a.jsx(Ve.Content,{children:a.jsx(Ve.ReviewComment,{children:a.jsx(jm,{from:"Pilot",message:r.messagexup})})}):null,a.jsxs(Ve.FooterGroup,{children:[a.jsxs(Ve.Footer,{children:[i.can_remove?a.jsx("a",{title:"Remove x-up",onClick:D=>oe(d,ly(r.id)).then(o),children:a.jsx(ae,{icon:U0})}):null,u.access["incursions.waitlist_esi_show_info"]&&a.jsx("a",{title:"Open in-game profile",onClick:D=>oe(d,iy(r.character.character_id,u.current.character_id)),children:a.jsx(ae,{icon:Li})}),u.access["incursions.waitlist_context_a_skills"]&&a.jsx(cy,{characterId:r.character.character_id,ship:r.ship.name}),u.access["incursions.waitlist_context_a_pilot"]&&a.jsx(uy,{characterId:r.character.character_id,authContext:u,id:r.character.character_id}),Z.isFinite(r.hours_in_fleet)?a.jsxs("span",{title:"Hours in fleet",children:[r.hours_in_fleet,"h"]}):null,u.access["incursions.waitlist_manage_waitlist"]&&a.jsx("a",{title:"Reject",onClick:D=>{var M=prompt("Why is the fit being rejected? (Will be displayed to pilot)");M&&oe(d,xx(r.id,M)).then(o)},children:a.jsx(ae,{icon:eo})}),u.access["incursions.waitlist_manage_waitlist"]&&r.approved&&a.jsx(ry,{fitId:r.id,fcId:u.current.character_id,onAction:o}),u.access["incursions.waitlist_manage_waitlist"]&&!r.approved&&a.jsx("a",{title:"Approve",onClick:D=>oe(d,mx(r.id)).then(o),children:a.jsx(ae,{icon:Wm})})]}),!f&&Z.isFinite(r.hours_in_fleet)&&r.hours_in_fleet<1&&a.jsx(Ve.Footer,{children:a.jsx("span",{children:"NEW"})})]})]})}const gc=C.div`
  background-color: ${i=>i.theme.colors.accent1};
  display: flex;
  flex-wrap: wrap;
  align-items: center;
  justify-content: space-between;
  padding: 0 1em;
  border-radius: 10px;
  box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
  > h2 {
    font-size: 1.2em;
    font-weight: 600;
    padding: 0.2em;
  }
  > div {
    display: flex;
    opacity: 0.7;
    > span {
      flex: 1;
      display: inline-flex;
      align-items: center;
      padding: 0.2em;
      img {
        width: 1.5em;
        height: 1.5em;
        border-radius: 2px;
        margin-right: 0.2em;
      }
    }
  }

  box-shadow: 2px 2px 3px ${i=>i.theme.colors.shadow};
`,oy=C(gc)`
  border-radius: 5px;
  border: solid 1px ${i=>i.theme.colors.accent2};
  padding: 0em 0.2em;
  > h2 {
    font-size: initial;
    font-weight: initial;
  }
`;function co({name:i,fleetComposition:r,altCol:o=!0}){if(!(r&&r.members))return a.jsx(a.Fragment,{children:!o&&i==="Alts"?null:a.jsx(gc,{children:a.jsx("h2",{children:i})})});const u=Z.filter(r.members,x=>x.wl_category===i);if(!o&&i==="Alts"&&u.length===0)return null;var d={},f={};Z.forEach(u,x=>{d[x.ship.id]=x.ship,f[x.ship.id]||(f[x.ship.id]=0),f[x.ship.id]++});var m=Z.map(f,(x,p)=>[x,d[p]]);return m.sort((x,p)=>x[0]-p[0]),a.jsx(a.Fragment,{children:!o&&i==="Alts"?a.jsx(oy,{children:a.jsx(bm,{name:i,shipCountsArr:m})}):a.jsx(gc,{children:a.jsx(bm,{name:i,shipCountsArr:m})})})}function bm({name:i,shipCountsArr:r}){return a.jsxs(a.Fragment,{children:[a.jsx("h2",{children:i}),a.jsx("div",{children:r.map(([o,u])=>a.jsxs("span",{children:[a.jsx("img",{src:`https://images.evetech.net/types/${u.id}/icon?size=64`,alt:u.name}),o]},u.id))})]})}const pc=C.div`
  display: flex;
  @media (max-width: 480px) {
    flex-wrap: wrap;
    width: 100%;
  }
`;pc.Category=C.div`
  flex-grow: 1;
  flex-basis: 0;
  padding: 0.5em;

  > div {
    margin-bottom: 1.5em;
  }
  @media (max-width: 480px) {
    width: 100%;
    flex-basis: unset;
  }
`;function dy({waitlist:i,onAction:r,fleetComposition:o,altCol:u=!1,authContext:d}){var f=[],m={};return Z.forEach(i.categories,(x,p)=>{x==="Alts"&&!u||(f.push([x,[]]),m[x]=p)}),Z.forEach(i.waitlist,x=>{Z.forEach(x.fits,p=>{const v=m[u&&p.is_alt?"Alts":p.category];f[v][1].push(a.jsx("div",{children:a.jsx(qi,{entry:x,fit:p,onAction:r})},p.id))})}),a.jsx(a.Fragment,{children:a.jsx(pc,{children:f.map(x=>a.jsxs(pc.Category,{children:[a.jsx(co,{name:x[0],fleetComposition:o}),x[1]]},x[0]))})})}const fy=C.div`
  display: flex;
  flex-wrap: wrap;
  > div {
    padding: 0.5em;
  }
`;function hy({waitlist:i,onAction:r}){var o=[];return Z.forEach(i.waitlist,u=>{Z.forEach(u.fits,d=>{o.push(a.jsx("div",{children:a.jsx(qi,{entry:u,fit:d,onAction:r})},d.id))})}),a.jsx(fy,{children:o})}const Wu=C.div``;Wu.Entry=C.div`
  display: flex;
  flex-wrap: wrap;
  margin-bottom: 1em;
  > div {
    padding: 0.5em;
  }
`;function my({waitlist:i,onAction:r}){return a.jsx(Wu,{children:i.waitlist.map(o=>a.jsx(Wu.Entry,{children:o.fits.map(u=>a.jsx("div",{children:a.jsx(qi,{fit:u,entry:o,onAction:r})},u.id))},o.id))})}const xy=C.table`
  width: 100%;
  table-layout: fixed;
  text-align: left;

  > thead > tr > th {
    width: 1%;
  }
  th,
  td {
    padding: 0.5em;
  }
`;function gy({waitlist:i,onAction:r,fleetComposition:o}){var u=[],d={};return Z.forEach(i.categories,(f,m)=>{u.push([f,[]]),d[f]=m}),a.jsx(xy,{children:a.jsxs("thead",{children:[a.jsx("tr",{children:u.map(f=>a.jsx("th",{children:a.jsx(co,{name:f[0],fleetComposition:o})},f[0]))}),i.waitlist.map(f=>{var m=u.map(x=>[]);return Z.forEach(f.fits,x=>{m[d[x.is_alt?"Alts":x.category]].push(a.jsx("div",{children:a.jsx(qi,{fit:x,entry:f,onAction:r})},x.id))}),a.jsx("tr",{children:m.map((x,p)=>a.jsx("td",{children:x},p))},f.id)})]})})}const Iu=C.div`
  overflow-x: auto;
`;Iu.Category=C.div`
  padding: 0.5em 0.5em;
  display: flex;

  > div {
    margin: 0 0.75em;
  }
`;function py({waitlist:i,onAction:r,fleetComposition:o}){var u=[],d={};return Z.forEach(i.categories,(f,m)=>{u.push([f,[]]),d[f]=m}),Z.forEach(i.waitlist,f=>{Z.forEach(f.fits,m=>{const x=d[m.is_alt?"Alts":m.category];u[x][1].push(a.jsx("div",{children:a.jsx(qi,{entry:f,fit:m,onAction:r},m.id)},m.id))})}),a.jsx(a.Fragment,{children:a.jsx(Iu,{children:u.map(f=>a.jsxs("div",{children:[a.jsx(co,{name:f[0],fleetComposition:o}),a.jsx(Iu.Category,{children:f[1]})]},f[0]))})})}const vy=["Paladin","Kronos","Golem","Vargur"],gx=["Eos","Damnation","Claymore","Vulture","Sleipnir","Astarte"];function yy({characterId:i}){const[r]=he(`/incursions/api/pilot/info?character_id=${i}`);return a.jsx(sx,{tags:r&&r.tags,height:"14px"})}function jy({members:i,warnActive:r}){const{t:o}=k(),u=i.map(d=>d.ship.name).filter(d=>!gx.includes(d));return a.jsx(a.Fragment,{children:i.map(d=>a.jsxs(Re,{noAlternating:!0,children:[a.jsx(An,{}),a.jsx(hv,{warn:u.length>2&&r&&"yellow",children:d.role==="squad_commander"&&"★"}),a.jsx(An,{children:a.jsxs(jt,{to:"/pilot?character_id="+d.id,children:[d.name," "]})}),a.jsx(An,{children:o(d.ship.name)}),a.jsx(An,{children:a.jsx("div",{style:{display:"flex",justifyContent:"space-between"},children:a.jsx(yy,{characterId:d.id})})})]},d.id))})}function by({members:i,squadname:r,warnActive:o}){const{t:u}=k();return i.sort((d,f)=>d.role==="squad_commander"?-1:f.role==="squad_commander"?1:0),a.jsxs(b.Fragment,{children:[a.jsxs(Re,{style:{paddingLeft:"20px"},noAlternating:!0,children:[a.jsx(An,{}),a.jsxs(An,{children:[u(r),i.length>0&&` (${i.length})`]}),a.jsx(An,{}),a.jsx(An,{}),a.jsx(An,{})]},r),a.jsx(jy,{members:i,category:r,warnActive:o})]},r)}function Sm({characterId:i,memberlist:r,showFull:o=!0}){const{t:u}=k();var d={Marauder:0,Logiarmor:0,Logishield:0,Vindicator:0,Booster:0},f={};return r&&r.forEach(m=>{f[m.ship.name]||(f[m.ship.name]=0),f[m.ship.name]++,gx.includes(m.ship.name)&&d.Booster++,vy.includes(m.ship.name)&&d.Marauder++,m.ship.name==="Vindicator"&&d.Vindicator++,m.ship.name==="Loki"&&d.Logishield++,m.ship.name==="Nestor"&&d.Logiarmor++}),a.jsxs("div",{style:o?{}:{display:"flex",justifyContent:"center"},children:[o&&a.jsx(_e,{children:u("Fleet Summary")}),a.jsxs(Oe,{style:{marginBottom:"1em"},children:[a.jsxs(fc,{children:[u("Marauders"),": ",d.Marauder," "]}),a.jsxs(fc,{children:[u("Logi (N/L)"),": ",d.Logiarmor,"/",d.Logishield]}),a.jsxs(fc,{children:[u("Vindicators"),": ",d.Vindicator," "]}),a.jsxs(fc,{children:[u("Boosters"),": ",d.Booster," "]})]}),o&&a.jsxs(Dn,{children:[a.jsx(Na,{children:a.jsxs(Re,{children:[a.jsx(Je,{children:u("Ship")}),a.jsx(Je,{children:"#"})]})}),a.jsx(Mn,{children:Z.sortBy(Z.entries(f),[1]).map(([m,x])=>a.jsxs(Re,{children:[a.jsx(I,{children:u(m)}),a.jsx(I,{children:x})]},m))})]})]})}function Sy(i){let r=0;i.member&&(r+=1);for(let o of i.squads)r+=o.members.length;return r}function wm(i){let r=[];return i.member&&r.push(i.member),i.wings.forEach(o=>{o.member&&r.push(o.member),o.squads.forEach(u=>{u.members.forEach(d=>{r.push(d)})})}),r}function px({fleetpage:i=!0,setStatTempActive:r=null}){const{t:o}=k(),u=b.useContext(Te),d=b.useContext(ie),[f,m]=b.useState(null),[x,p]=b.useState(0),v=u.current.character_id;return b.useEffect(()=>{W("/incursions/api/fleet/fleetcomp?character_id="+v,{}).then(m).catch(j=>{m(null),i||r(!1)})},[v,i,r,o]),b.useEffect(()=>{if(!i){const j=setInterval(()=>{if(x>=4)return ca(d,{title:o("Error"),message:o("Consecutive Error Limit Exceeded, shutting down fleetstats"),variant:"danger"}),r(!1),null;W("/incursions/api/fleet/fleetcomp?character_id="+v,{}).then(O=>{m(O),p(0)}).catch(O=>{p(x+1),O.toLowerCase().includes("fleet".toLowerCase())&&r(!1)})},15e3);return()=>clearInterval(j)}},[v,x,i,r,d,o]),f?(f&&f.wings.forEach(j=>{j.squads.sort((O,D)=>O.id-D.id)}),a.jsxs(pc.Category,{children:[!i&&a.jsx(gc,{children:a.jsx("h2",{children:o("Members")})}),a.jsxs("div",{style:{display:"flex",flexWrap:"wrap"},children:[a.jsxs("div",{children:[i&&a.jsx(_e,{children:o("Members")}),!i&&a.jsx(Sm,{characterId:u.current.character_id,showFull:!1,memberlist:wm(f)}),a.jsx(Dn,{style:{fontSize:"12px"},fullWidth:i?void 0:!0,children:a.jsx(Mn,{children:f.wings.map((j,O)=>a.jsxs(b.Fragment,{children:[a.jsxs(Re,{background:!0,noAlternating:!0,children:[a.jsxs(I,{style:{fontWeight:"bold",width:"40px",overflow:"visible",whiteSpace:"nowrap"},children:[o(j.name.toUpperCase())," (",Sy(j),")"]}),a.jsx(I,{style:{width:"80px"}}),a.jsx(I,{}),a.jsx(I,{style:{width:"70px"}}),a.jsx(I,{style:{width:"75px"}})]}),j.squads.map((D,M)=>a.jsx(by,{squadname:D.name,members:D.members,warnActive:M>2&&O===0},D.name))]},j.name))})})]}),i&&a.jsx("div",{style:{marginLeft:"4em"},children:a.jsx(Sm,{characterId:u.current.character_id,showFull:!0,memberlist:wm(f)})})]})]})):null}const wy="/static/incursions/waitlist/static/img/fleetcomp-BQGhOhZ8.png";async function Cm(i,r){return await W("/incursions/api/waitlist/set_open",{json:{waitlist_id:i,open:r}})}async function Cy(i){return await W("/incursions/api/waitlist/empty",{json:{waitlist_id:i}})}async function _y(i){return await W("/incursions/api/fleet/close",{json:{character_id:i}})}function Ty(){const[i,r]=b.useState(!1),[o,u]=b.useState(!1),d=b.useContext(Te),f=b.useContext(ie),[m]=he("/incursions/api/fleet/status"),{t:x}=k();return b.useEffect(()=>{window.Notification&&Notification.permission==="default"&&Notification.requestPermission()},[]),qe(x("Fleet")),a.jsxs(a.Fragment,{children:[a.jsxs(bt,{children:[a.jsx(Oe,{children:a.jsx(ln,{to:"/fc/fleet/register",children:x("Configure fleet")})}),a.jsx(Oe,{children:a.jsx(ln,{as:"a",href:"/incursions/char/add_fc",children:x("ESI re-auth as FC")})}),a.jsxs(Oe,{children:[a.jsx(q,{$variant:"success",onClick:()=>Xt(f,Cm(1,!0)),children:x("Open waitlist")}),a.jsx(q,{onClick:()=>Xt(f,Cm(1,!1)),children:x("Close waitlist")}),a.jsx(q,{onClick:()=>u(!0),children:x("Empty waitlist")})]}),a.jsx(Oe,{children:a.jsx(q,{$variant:"danger",onClick:()=>r(!0),children:x("Kick everyone from fleet")})})]}),a.jsxs(ct,{children:[a.jsx("p",{children:x("Make sure you re-auth via ESI, then create an in-game fleet with your comp. Click the 'Configure fleet' button, and select the five squads that the tool will invite people into. Then open the waitlist, allowing people to X up.")}),a.jsx("p",{children:x("To hand over the fleet, transfer the star (Boss role). Then the new FC should go via 'Configure fleet' again, as if it was a new fleet.")}),((m==null?void 0:m.fleets)??[]).map(p=>a.jsxs("div",{children:["STATUS: Fleet ",p.id,", boss ",p.boss.character_name]},p.id))]}),d.access["incursions.waitlist_history_view"]&&a.jsx(bt,{children:a.jsx(Oe,{children:a.jsx(ln,{to:"/fc/fleet/history",children:x("Fleet comp history")})})}),a.jsx(px,{}),a.jsx(mm,{open:i,setOpen:r,title:x("Kick everyone from fleet"),onConfirm:p=>Xt(f,_y(d.current.character_id)).finally(()=>r(!1)),children:x("Are you sure?")}),a.jsx(mm,{open:o,setOpen:u,title:x("Empty waitlist"),onConfirm:p=>Xt(f,Cy(1)).finally(()=>u(!1)),children:x("Are you sure?")})]})}async function Ey({fleetInfo:i,categoryMatches:r,authContext:o}){return await W("/incursions/api/fleet/register",{json:{character_id:o.current.character_id,assignments:r,fleet_id:i.fleet_id}})}function Ay({matches:i,categories:r,wings:o}){var u={...i},d=!1;for(const f of r)if(!(f.id in i))for(const m of o)for(const x of m.squads)(x.name.toLowerCase().includes(f.name.toLowerCase())||x.name.toLowerCase().includes(String(f.id).toLowerCase()))&&(u[f.id]=[m.id,x.id],d=!0);return d?u:null}function Dy(){const i=b.useContext(Te),r=b.useContext(ie),[o,u]=b.useState(null),[d,f]=b.useState(null),[m,x]=b.useState({}),{t:p}=k(),v=i.current.character_id;return b.useEffect(()=>{u(null),oe(r,W("/incursions/api/fleet/info?character_id="+v,{}).then(u)),f(null),oe(r,W("/incursions/api/categories",{}).then(j=>f(j.categories)))},[v,r]),b.useEffect(()=>{if(!(!d||!o)){var j=Ay({matches:m,categories:d,wings:o.wings});j&&x(j)}},[o,d,m,x]),!o||!d?a.jsx("em",{children:p("Loading fleet information.., Please be patient, this can take up to a minute")}):a.jsxs(a.Fragment,{children:[a.jsx("div",{style:{marginBottom:"1em"},children:p("Will be automatically filled if the squad names in your fleet match.")}),a.jsxs("div",{style:{display:"flex"},children:[a.jsx(My,{categories:d,wings:o.wings,value:m,onChange:x}),a.jsx("img",{style:{marginLeft:"3em"},src:wy,alt:p("For auto filling, make sure the squad names match!")})]}),a.jsx(q,{$variant:"primary",onClick:j=>Xt(r,Ey({authContext:i,fleetInfo:o,categoryMatches:m})),children:p("Continue")})]})}function My({categories:i,wings:r,onChange:o,value:u}){const{t:d}=k();var f=[];r.forEach(p=>{p.squads.forEach(v=>{f.push({name:`${p.name} - ${v.name}`,id:`${p.id},${v.id}`})})});var m=[];for(const p of i){var x=f.map(v=>a.jsx("option",{value:v.id,children:v.name},v.id));m.push(a.jsxs("p",{children:[a.jsxs("label",{className:"label",children:[d(p.name),a.jsx("br",{})]}),a.jsxs(rn,{value:u[p.id],onChange:v=>o({...u,[p.id]:v.target.value.split(",").map(j=>parseInt(j))}),children:[a.jsx("option",{}),x]})]},p.id))}return a.jsx(ct,{children:m})}function ia(i){var r=[],o=Math.floor(i/3600);o>0&&r.push(`${o}h`);var u=Math.floor(i%3600/60);u>0&&r.push(`${u}min`);var d=i%60;return d>0&&r.push(`${d}s`),r?r.length>1?`${r[0]} ${r[1]}`:r[0]:"-"}function Ba(i){return i.toLocaleString("en-GB",{timeZone:"UTC"})}function Sc(i){const r=(f,m,x=!1)=>{f=Math.trunc(f),f>1&&(m+="s");let p="";return x||(p+="in "),p+=`${f.toLocaleString()} ${m}`,x&&(p+=" ago"),p};if(!(i instanceof Date))return`expected date saw ${typeof i}`;const o=new Date,u=i<o;var d=Math.abs(o-i)/1e3;return d<60?u?"just now":"less than one minute":(d=d/60,d<60?r(d,"minute",u):(d=d/60,d<24?r(d,"hour",u):(d=d/24,d<365?r(d,"day",u):i.toLocaleDateString("en-GB",{timeZone:"UTC"}))))}function Ui(i){return i.toLocaleString("en-GB",{timeZone:"UTC",dateStyle:"short"})}function Oy(){const[i,r]=b.useState(""),[o,u]=b.useState(""),{t:d}=k(),f=i&&o?new Date(`${i}T${o}Z`):null,m=f?f.getTime()/1e3:null,[x]=he(m?`/incursions/api/history/fleet-comp?time=${m}`:null);return qe(d("Fleet History")),a.jsxs(ct,{children:[a.jsx("h2",{children:d("Fleet history lookup")}),a.jsxs(Oe,{children:[a.jsx(cn,{type:"date",value:i,onChange:p=>r(p.target.value)}),a.jsx(cn,{type:"time",value:o,onChange:p=>u(p.target.value)})]}),f?a.jsx("div",{children:a.jsx("em",{children:f.toString()})}):null,x&&a.jsx("h2",{children:d("Results")}),x&&Z.map(x.fleets,(p,v)=>a.jsxs("div",{children:[a.jsxs("h3",{children:[d("Fleet")," ",v]}),a.jsxs(Dn,{fullWidth:!0,children:[a.jsx(Na,{children:a.jsxs(Re,{children:[a.jsx(Je,{children:d("Pilot")}),a.jsx(Je,{children:d("Ship")}),a.jsx(Je,{children:d("Time")})]})}),a.jsx(Mn,{children:p.map(j=>a.jsxs(Re,{children:[a.jsxs(I,{children:[j.character_name,j.is_boss&&a.jsxs(a.Fragment,{children:[" ",a.jsx(ae,{icon:H0})]})]}),a.jsx(I,{children:j.ship.name}),a.jsxs(I,{children:[Ba(new Date(j.logged_at))," (",ia(j.time_in_fleet),")"]})]},j.character_id))})]})]},v)),x&&Z.isEmpty(x.fleets)&&a.jsx("em",{children:d("Nothing found!")})]})}function aa(i,r={}){return i===null?null:i.toLocaleString(void 0,{maximumFractionDigits:2,...r})}function zy(i){var r=[];for(const d of i)Zu.encode(Math.round(d),r,r.length);var o=85;for(const d of r)o^=d;return r.push(o),r=Vm.Buffer.from(r),r.toString("base64").replaceAll("+","-").replaceAll("/","_").replaceAll("=","")}function Ny(i){var r=Vm.Buffer.from(i,"base64"),o=0,u=0;for(const f of r)u^=f;if(u!==85)throw new Error("Checksum mismatch!");for(var d=[];o<r.byteLength-1;)d.push(Zu.decode(r,o)),o+=Zu.decode.bytes;return d}function By(i){return"1"+zy([i.isk,i.lp,i.sites,i.startTime,i.endTime-i.startTime,i.minTime,i.maxTime,i.chars,i.firstSitePayout])}function Ry(i){if(i[0]==="1"){const r=Ny(i.slice(1));return{isk:r[0],lp:r[1],sites:r[2],startTime:r[3],endTime:r[3]+r[4],minTime:r[5],maxTime:r[6],chars:r[7],firstSitePayout:r[8]||315e5}}else throw new Error("Cannot decode input")}function Uy(){var i={};for(const[o,u,d,f]of[["Mothership (HS)",63e6,14e3,80],["Mothership (LS/NS)",9e7,2e4,120],["HQ (HS)",315e5,7e3,40],["HQ (LS/NS)",45e6,1e4,60],["AS (HS)",182e5,3500,20],["AS (LS/NS)",26e6,5e3,30],["VG (HS)",10395e3,1400,10],["VG (LS/NS)",15e6,2e3,15],["Scout",35e5,400,5]])for(var r=0;r<11;r++){const m=1-.0725*r-.0025*r**2,x=Math.round(u*m);if(i[x])throw new Error("Two sites give the same payout?!");i[x]={siteType:o,payout:x,lp:Math.round(d*m),normalPayout:u,normalLp:d,onGrid:r?f+r:null}}return i}const Ly=Uy();function ky(i){var r=[];for(const j of i.split(`
`)){var[o,u,d,,f]=j.split(/\t|\s{2,}/);if(!u||!f||!d||!d.match(/ISK/)||!(u.match(/reward payout/i)&&f.match(/concord/i)))continue;d=d.replace(/[.,]\d{2} /," "),d=d.replace(/\D/g,""),d=Math.round(parseFloat(d));const[O,D]=o.split(/ /),M=`${O.replaceAll(".","-")}T${D}Z`,L=new Date(M);r.push({time:L,value:d})}r=Z.sortBy(r,["time","value"]);var m=null,x=1,p=[],v={isk:0,lp:0,sites:0,chars:1,raw:[]};for(const j of r){m?m.getTime()!==j.time.getTime()?(p.push((j.time.getTime()-m.getTime())/1e3),m=j.time,x=1,v.sites+=1):(x+=1,v.chars<x&&(v.chars=x)):(m=j.time,v.sites+=1),v.isk+=j.value;const O=Ly[j.value];O&&(v.lp+=O.lp),v.raw.push({time:j.time.getTime()/1e3,isk:j.value,lp:O?O.lp:null,onGrid:O?O.onGrid:null})}return p.length<1?null:(v.minTime=Math.min(...p),v.maxTime=Math.max(...p),v.startTime=Math.min(...v.raw.map(j=>j.time)),v.endTime=Math.max(...v.raw.map(j=>j.time)),v.firstSitePayout=v.raw.find(j=>j.time===v.startTime).isk,v)}function Hy(){const[i,r]=b.useState(""),o=ky(i),u=o?By(o):null,{t:d}=k();return qe(d("ISK/h")),a.jsxs(a.Fragment,{children:[a.jsx(ra,{children:d("ISK/h calculator")}),a.jsxs("div",{style:{display:"flex"},children:[a.jsxs("div",{style:{flex:1,padding:"0.5em"},children:[a.jsx("em",{children:d("Go to your in-game wallet, select all incursion payouts, and hit Ctrl-C. Then, paste them here. Note: this calculator currently only works for English EVE clients.")}),a.jsx(Kt,{value:i,onChange:f=>r(f.target.value),rows:"10",style:{width:"100%"}}),a.jsx("div",{style:{padding:"1em"},children:a.jsx(vx,{dataStr:u})})]}),o&&a.jsx("div",{style:{flex:2,padding:"0.5em"},children:a.jsxs(Dn,{fullWidth:!0,children:[a.jsx(Na,{children:a.jsxs(Re,{children:[a.jsx(Je,{children:d("Time")}),a.jsx(Je,{children:d("ISK")}),a.jsx(Je,{children:d("LP")}),a.jsx(Je,{children:d("On grid")})]})}),a.jsx(Mn,{children:o.raw.map((f,m)=>a.jsxs(Re,{children:[a.jsx(I,{children:Ba(new Date(f.time*1e3))}),a.jsx(I,{children:aa(f.isk)}),a.jsx(I,{children:aa(f.lp)}),a.jsx(I,{children:aa(f.onGrid)})]},m))})]})})]})]})}function qy(){const r=new URLSearchParams(un().search).get("d")||"",{t:o}=k();return a.jsxs(a.Fragment,{children:[a.jsx("div",{children:a.jsx(ln,{exact:!0,to:"/isk-h/calc",children:o("Calculator")})}),a.jsx("div",{style:{display:"flex",justifyContent:"center"},children:a.jsx(vx,{dataStr:r})})]})}const $y=C.div`
  ${i=>`
    max-width: 500px;
    border-radius: 10px;
    text-align: center;
    border: solid 1px ${i.theme.colors.accent4};

    > h1 {
      margin-top: 0.5em;
      font-size: 2em;
      font-weight: 600;
      filter: drop-shadow(0px 1px 1px ${i.theme.colors.shadow});
    }
    > h2 {
      font-size: 1.5em;
      font-weight: 600;
    }
    > * {
      padding-left: 1em;
      padding-right: 1em;
    }

    hr {
      border: 0;
      margin-top: 0.75em;
    }
    p:last-child {
      border-top: solid 1px ${i.theme.colors.accent3};
      font-size: 0.8em;
      margin-top: 1em;
      margin-bottom: 0.3em;
    padding-top: 0.3em;
    &:hover:not(:disabled):not(.static) {
    color: ${i.theme.colors.accent4};
    cursor: pointer;
    }
    }
    a {
      color: ${i.theme.colors.text};
      text-decoration: none;
    }
  `}
`;function vx({dataStr:i}){const r=b.useContext(ie),{t:o}=k();if(!i)return null;var u;try{u=Ry(i)}catch{return a.jsx("em",{children:o("Failed to load results")})}const d=u.endTime-u.startTime,f=Math.round((u.isk-u.firstSitePayout)/(d/3600)),m=`${window.location.origin}/incursions/waitlist/isk-h?d=${encodeURIComponent(i)}`;return a.jsx(a.Fragment,{children:a.jsxs($y,{children:[a.jsxs("h1",{children:[aa(f)," ",o("ISK/h")]}),a.jsxs("h2",{children:[aa(u.isk)," ISK + ",aa(u.lp)," LP"]}),a.jsx("hr",{}),a.jsxs("p",{children:[aa(u.sites)," ",o("sites completed")]}),u.chars>1&&a.jsxs("p",{children:[aa(u.chars)," ",o("characters included in payout calculation")]}),a.jsx("hr",{}),a.jsxs("p",{children:[ia(u.minTime)," ~ ",ia(u.maxTime)," (",o("average")," ",ia(Math.round(d/(u.sites-1))),")"]}),a.jsxs("p",{children:[Ba(new Date(u.startTime*1e3))," ++ ",ia(d)]}),a.jsx("p",{onClick:x=>{fx(r,m)},children:m})]})})}function Gy(){return qe("Legal Notice"),a.jsxs(ct,{children:[a.jsx("h2",{children:"CCP Copyright Notice"}),a.jsx("p",{children:"EVE Online and the EVE logo are the registered trademarks of CCP hf. All rights are reserved worldwide. All other trademarks are the property of their respective owners. EVE Online, the EVE logo, EVE and all associated logos and designs are the intellectual property of CCP hf. All artwork, screenshots, characters, vehicles, storylines, world facts or other recognizable features of the intellectual property relating to these trademarks are likewise the intellectual property of CCP hf. CCP hf. has granted permission to zKillboard.com to use EVE Online and all associated logos and designs for promotional and information purposes on its website but does not endorse, and is not in any way affiliated with, zKillboard.com. CCP is in no way responsible for the content on or functioning of this website, nor can it be liable for any damage arising from the use of this website."}),a.jsxs("p",{children:["The source code for AA Incursions and this Waitlist Module is available under the MIT license. The source code and full text for this license can be found"," ",a.jsx("a",{href:"https://gitlab.com/tactical-supremacy/aa-incursions",children:"here"}),"."]}),a.jsxs("p",{children:["This Waitlist Module is a fork of TLA Waitlist, which is also available under the MIT license. The source code and full text for this license can be found"," ",a.jsx("a",{href:"https://github.com/luna-duclos/tla-waitlist",children:"here"}),"."]})]})}async function Yy(i,r){await W("/incursions/api/notes/add",{json:{character_id:i,note:r}})}function Xy(){const{t:i}=k();qe(i("Add Note"));const r=b.useContext(ie),[o,u]=b.useState(""),[d,f]=b.useState(!1),m=new URLSearchParams(un().search);var x=parseInt(m.get("character_id"));const p=vc(),[v]=he(x?`/incursions/api/pilot/info?character_id=${x}`:null);return x?a.jsxs(a.Fragment,{children:[a.jsxs(ra,{children:[i("Add note"),v&&`: ${v.name}`]}),a.jsx(Kt,{style:{width:"100%"},onChange:j=>u(j.target.value),value:o,rows:"5",cols:"60"}),a.jsx("p",{children:a.jsx("em",{children:i("Remember that notes cannot be removed!")})}),a.jsxs(Oe,{children:[a.jsx(q,{$variant:"success",disabled:o.length<20||o.length>5e3||d,onClick:j=>{f(!0),oe(r,Yy(x,o).then(O=>p(`/pilot?character_id=${x}`)).finally(O=>f(!1)))},children:i("Save")}),a.jsx(q,{onClick:()=>p(-1),children:i("Never mind")})]})]}):a.jsx("em",{children:i("Missing character ID")})}const ro=C.img`
  border-radius: 25%;
  margin-right: 10px;
  vertical-align: middle;

  @media (max-width: 450px) {
    display: none;
  }
`,yx=(i,r,o)=>{oe(o,W("/incursions/api/open_window",{method:"POST",json:{character_id:r.id,target_id:i}}))},He=({avatar:i,avatarSize:r,character_id:o,character_name:u,noLink:d})=>a.jsxs(a.Fragment,{children:[i&&a.jsx(ro,{src:`https://images.evetech.net/characters/${o}/portrait?size=${r}`,loading:"lazy"}),d?u:a.jsx(jc,{to:`/fc/search?query=${u}`,children:u})]}),$i=({avatar:i,avatarSize:r,id:o,name:u,noLink:d})=>{const f=b.useContext(ie),m=b.useContext(Te);return a.jsxs(a.Fragment,{children:[i&&a.jsx(ro,{src:`https://images.evetech.net/corporations/${o}/logo?size=${r}`,loading:"lazy"}),d?u:a.jsxs(a.Fragment,{children:[a.jsx(jc,{to:"#",onClick:()=>yx(o,m.current,f),children:u}),a.jsx(ae,{fixedWidth:!0,icon:Li})]})]})},Gi=({avatar:i,avatarSize:r,id:o,name:u,noLink:d})=>{const f=b.useContext(ie),m=b.useContext(Te);return a.jsxs(a.Fragment,{children:[i&&a.jsx(ro,{src:`https://images.evetech.net/alliances/${o}/logo?size=${r}`,loading:"lazy"}),d?u:a.jsxs(a.Fragment,{children:[a.jsx(jc,{to:"#",onClick:()=>yx(o,m.current,f),children:u}),a.jsx(ae,{fixedWidth:!0,icon:Li})]})]})};He.defaultProps={avatar:!0,avatarSize:32,character_id:1,noLink:!1};He.propTypes={avatar:De.bool,avatarSize:De.number,character_id:De.number,character_name:De.string.isRequired,noLink:De.bool};Gi.defaultProps={avatar:!0,avatarSize:32,alliance_id:1,noLink:!1};Gi.propTypes={avatar:De.bool,avatarSize:De.number,alliance_id:De.number,alliance_name:De.string.isRequired,noLink:De.bool};$i.defaultProps={avatar:!0,avatarSize:32,corporation_id:1,noLink:!1};$i.propTypes={avatar:De.bool,avatarSize:De.number,corporation_id:De.number,corporation_name:De.string.isRequired,noLink:De.bool};const _m=C.div`
  margin-left: 40px;
  margin-bottom: 5px;

  &:first-of-type {
    min-height: 50px;
  }

  &:nth-of-type(2) {
    min-height: 100px;
  }

  @media (min-width: 400px) {
    min-width: 310px;
  }

  @media (max-width: 451px) {
    margin-left: 3px;

    span {
      display: block;
    }

    br {
      display: none;
    }
  }
`;async function Qy(i,r){return await W(`/incursions/api/badges/${i}/members`,{method:"POST",json:{character_id:r}})}async function Vy(i,r){return await W(`/incursions/api/badges/${i}/members/${r}`,{method:"DELETE"})}const jx=({character:i,refreshData:r})=>{const[o,u]=b.useState();return a.jsxs(a.Fragment,{children:[a.jsx(q,{onClick:()=>u(!0),children:"Badges"}),o&&a.jsx(Zy,{character:i,isOpen:o,setOpen:u,refreshData:r})]})},Zy=({character:i,isOpen:r,setOpen:o,refreshData:u})=>{const[d,f]=he("/incursions/api/badges"),[m,x]=b.useState(void 0),[p,v]=b.useState(!1),j=b.useContext(ie);ue.useEffect(()=>{d&&oe(j,W(`/incursions/api/pilot/info?character_id=${i==null?void 0:i.character_id}`,{}).then(U=>{if(!U.tags)return;const H=U.tags,$=d;for(let J=0;J<($==null?void 0:$.length);J++)$[J].default=H.includes($[J].name),$[J].checked=H.includes($[J].name);x($??[])}))},[d,j,i==null?void 0:i.character_id]);const O=()=>{v(!0);let U=[];m.forEach(H=>{H.default&&!H.checked&&U.push(new Promise($=>{Xt(j,Vy(H.id,i.character_id)).then($)}))}),Promise.all(U).then(()=>{let H=[];m.forEach($=>{!$.default&&$.checked&&H.push(new Promise(J=>{Xt(j,Qy($.id,i.character_id)).then(J)}))}),Promise.all(H).then(()=>{f(),v(!1),u&&u()})})},D=(U,H,$)=>{$.checked=U.target.checked;let J=m;J[H]=$,x([...J])};if(m){var M=[];m.forEach(H=>{H.default&&M.push(H.name)});const U=Z.sortBy(M,function(H){return to.indexOf(H)});var L=[];Z.forEach(U,H=>{H in _l&&L.push(a.jsx("span",{style:{marginRight:"5px",display:"inline-block"},children:a.jsx(sn,{type:H})},H))})}return a.jsx(ze,{open:r,setOpen:o,children:a.jsxs(we,{children:[a.jsx(_e,{style:{marginBottom:"5px"},children:a.jsx(He,{...i,avatarSize:32,noLink:!0})}),a.jsx(_m,{children:m?a.jsxs(a.Fragment,{children:[a.jsx("p",{children:"Current Badges:"}),a.jsx("span",{children:L})]}):a.jsx("small",{style:{fontStyle:"italic",fontSize:"smaller"},children:"Loading..."})}),a.jsx(_m,{children:m==null?void 0:m.map((U,H)=>a.jsxs("span",{children:[H%3?null:a.jsx("br",{}),a.jsxs("label",{style:{marginRight:"20px",marginBottom:"15px",display:"inline-block"},htmlFor:H,children:[a.jsx("input",{id:H,type:"checkbox",checked:U.checked,onChange:$=>D($,H,U)}),U.name]})]},H))}),a.jsxs(El,{children:[a.jsx(q,{$variant:"success",onClick:O,disabled:p,children:"Confirm"}),a.jsx(q,{onClick:()=>o(!1),children:"Close"})]})]})})},Ky=C.a`
  cursor: pointer;
  text-decoration: underline;
`,Ma=C.div`
  display: flex;

  border-bottom: solid 1px ${i=>i.theme.colors.accent2};
  &:first-child {
    border-top: solid 1px ${i=>i.theme.colors.accent2};
  }
  &:nth-child(odd) {
    background-color: ${i=>i.theme.colors.accent1};
  }
`;Ma.Time=C.div`
  flex: 0 0 200px;
  padding: 0.5em;
  @media (max-width: 480px) {
    width: 40%;
    flex: unset;
  }
`;Ma.Icon=C.div`
  flex: 0 0 auto;
  padding: 0.5em;
`;Ma.Content=C.div`
  flex: 1;
  padding: 0.5em;
`;function Yi({time:i,icon:r,children:o}){return a.jsxs(Ma,{children:[a.jsx(Ma.Icon,{children:r&&a.jsx(ae,{fixedWidth:!0,icon:r})}),a.jsx(Ma.Time,{children:Ba(new Date(i*1e3))}),a.jsx(Ma.Content,{children:o})]})}function Fy({issued_at:i,issued_by:r,reason:o,public_reason:u,revoked_at:d,revoked_by:f}){const{t:m}=k(),x=!d;return a.jsx(Yi,{time:i,icon:bc,children:a.jsxs(ct,{children:[a.jsxs("p",{children:[m(x?"Permanent":"Temporary")," ",m("ban"),", ",m("issued by"),": ",a.jsx(He,{...r,avatar:!1}),"."]}),!x&&!f&&a.jsxs("p",{children:[m("Expires"),": ",Sc(new Date(d*1e3)),"."]}),!x&&f&&a.jsxs("p",{children:[m("Revoked by"),": ",a.jsx(He,{...f,avatar:!1})," ",m("on the")," ",Ui(new Date(d*1e3)),"."]}),a.jsxs("p",{style:{marginBottom:"2px",fontWeight:"600"},children:[m("Reason"),":"]}),a.jsx("p",{children:o}),u&&a.jsxs(a.Fragment,{children:[a.jsx("p",{style:{marginBottom:"2px",fontWeight:"600"},children:m("Public Reason")}),a.jsx("p",{children:u})]})]})})}function Jy({logged_at:i,ship:r,dna:o,implants:u}){const[d,f]=b.useState(!1);return a.jsxs(Yi,{time:i,icon:Pm,children:[d&&a.jsx(ze,{open:!0,setOpen:f,children:a.jsx(we,{style:{display:"flex"},children:a.jsx(io,{fit:{dna:o,implants:u,fit_analysis:{name:r.name}}})})}),a.jsx(Ky,{onClick:m=>f(!0),children:r.name})]})}function Wy({logged_at:i,ship:r,time_in_fleet:o}){return a.jsxs(Yi,{time:i,icon:ex,children:[a.jsx("span",{style:{display:"inline-block",minWidth:"40%",marginRight:"0.5em"},children:r.name}),a.jsx("span",{children:ia(o)})]})}function Iy({logged_at:i,name:r,old_level:o,new_level:u}){const{t:d}=k();var f=o>u?"danger":o===u?"":"success";return a.jsxs(Yi,{time:i,icon:Pu,children:[a.jsx("span",{style:{display:"inline-block",minWidth:"40%",marginRight:"0.5em"},children:d(r)}),a.jsxs(Yt,{$variant:f,children:[o," -> ",u]})]})}function Py({logged_at:i,author:r,note:o}){const{t:u}=k();return a.jsx(Yi,{time:i,icon:tx,children:a.jsxs(ct,{children:[a.jsxs("p",{children:[u("Note written by")," ",a.jsx("strong",{children:r.name})]}),a.jsx(Xm,{children:o})]})})}const ej=C.div`
  margin-bottom: 2em;
`;function tj({filter:i,banHistory:r,fleetHistory:o,skillHistory:u,xupHistory:d,notes:f}){const{t:m}=k();var x=[],p=0;for(const M of r||[])p++,x.push({key:`ban-${p}`,entry:M,time:M.issued_at,type:"ban"});p=0;for(const M of d||[])p++,x.push({time:M.logged_at,type:"fit",entry:M,key:`fit-${p}`});p=0;for(const M of o||[])p++,x.push({time:M.logged_at,endTime:M.logged_at+M.time_in_fleet,type:"fleet",entry:M,key:`fleet-${p}`});p=0;for(const M of u||[])p++,x.push({time:M.logged_at,type:"skill",entry:M,key:`skill-${p}`});p=0;for(const M of f||[])p++,x.push({time:M.logged_at,type:"note",entry:M,key:`note-${p}`});i!==null&&(x=x.filter(M=>i(M.type))),x=Z.sortBy(x,["time"]);var v=[],j=null,O=null;for(const{time:M,entry:L,type:U,endTime:H,key:$}of x)(j===null||O<M)&&(j=[],v.push({key:M,group:j})),O=(H||M)+3*3600,U==="ban"?j.push(a.jsx(Fy,{...L},$)):U==="fit"?j.push(a.jsx(Jy,{...L},$)):U==="fleet"?j.push(a.jsx(Wy,{...L},$)):U==="skill"?j.push(a.jsx(Iy,{...L},$)):U==="note"&&j.push(a.jsx(Py,{...L},$));var D=[];v.reverse();for(const{group:M,key:L}of v)M.reverse(),D.push(a.jsx(ej,{children:M},L));return D.length?a.jsx("div",{children:D}):a.jsx("div",{children:a.jsx("em",{children:m("No logged history")})})}function nj({filter:i,banHistory:r,fleetHistory:o,skillHistory:u,xupHistory:d,notes:f}){return a.jsx(tj,{filter:i,banHistory:r,fleetHistory:o,skillHistory:u,xupHistory:d,notes:f})}function aj({summary:i}){const{t:r}=k();if(!i)return null;if(!i.length)return a.jsx("em",{children:r("Never seen before")});const o=Z.sum(i.map(({time_in_fleet:u})=>u));return a.jsx(Dn,{fullWidth:!0,edgeLine:!0,style:{marginBottom:"2em"},children:a.jsxs(Mn,{children:[a.jsxs(Re,{children:[a.jsx(Je,{children:r("Total")}),a.jsx(Je,{children:ia(o)})]}),i.map(({ship:u,time_in_fleet:d})=>a.jsxs(Re,{children:[a.jsx(I,{children:r(u.name)}),a.jsx(I,{children:ia(d)})]},u.id))]})})}const lj=C.div`
  margin: 15px 0px;
`;async function ij(i,r){return await W("/incursions/api/commanders",{method:"POST",json:{character_id:i,role:r}})}async function Tm(i){return await W(`/incursions/api/commanders/${i}`,{method:"DELETE"})}const uo=({character:i,children:r="ACL",currentRole:o,isRevokeable:u,handleRefresh:d})=>{const[f,m]=b.useState(!1),[x,p]=b.useState(void 0),[v,j]=b.useState(0),O=b.useContext(Te);ue.useEffect(()=>{o?p(o):i!=null&&i.character_id&&W(`/incursions/api/commanders/${i.character_id}`,{}).then(L=>p(L)).catch(L=>{var U;(U=L==null?void 0:L.detail)!=null&&U.includes("No CharacterRoles")?p(null):console.error("Failed to fetch current role:",L)})},[i==null?void 0:i.character_id,o,v]);let D=O.access[`commanders-manage:${x}`];const M=()=>{j(v+1),d&&d()};return a.jsxs(a.Fragment,{children:[a.jsx(q,{onClick:()=>m(!0),disabled:!(!x||D),children:r}),f?a.jsx(sj,{character:i,currentRole:x,isOpen:f,setOpen:m,isRevokeable:u,handleRefresh:M}):null]})},sj=({character:i,currentRole:r,isRevokeable:o,isOpen:u,handleRefresh:d,setOpen:f})=>{const{t:m}=k(),[x]=he("/incursions/api/commanders/roles"),[p,v]=b.useState(!1),[j,O]=b.useState(void 0),D=b.useContext(ie),M=()=>{p||(v(!0),oe(D,Tm(i==null?void 0:i.character_id)).then(()=>{Xt(D,ij(i==null?void 0:i.character_id,j)).then(()=>{d(),O(void 0)})}).finally(()=>v(!1)))},L=()=>{p||(v(!0),Xt(D,Tm(i==null?void 0:i.character_id)).then(()=>{d(),O(void 0),v(!1)}).finally(()=>f(!1)))};return ue.useEffect(()=>{r?O(r):(x==null?void 0:x.length)>=0&&O(x[0])},[x,r]),a.jsx(ze,{open:u,setOpen:f,children:a.jsxs(we,{children:[a.jsx(_e,{style:{marginBottom:"10px"},children:a.jsx(He,{...i,avatarSize:32,noLink:!0})}),a.jsxs(lj,{children:[a.jsx(ke,{htmlFor:`role-select-${i==null?void 0:i.character_id}`,required:!0,children:m("Select Role")}),x?a.jsx(rn,{id:`role-select-${i==null?void 0:i.character_id}`,value:j??r,onChange:U=>O(U.target.value),style:{width:"100%",appearance:"auto"},required:!0,children:x.map((U,H)=>a.jsx("option",{value:U,children:m(U)},H))}):a.jsx("small",{style:{fontStyle:"italic",fontSize:"smaller"},children:m("Loading...")})]}),a.jsxs(El,{children:[a.jsx(q,{$variant:"success",onClick:M,disabled:!x||p,children:m("Confirm")}),o&&a.jsx(q,{$variant:"danger",onClick:L,disabled:!x||p,children:m("Revoke FC")})]})]})})},cj="/static/incursions/waitlist/media/dead.jpg",rj=C.div`
  margin: 0 0 0.5em;
  display: flex;
  background-color: ${i=>i.theme.colors.secondary.color};
  color: ${i=>i.theme.colors.secondary.text};
  width: 100%;
  filter: drop-shadow(0px 4px 5px ${i=>i.theme.colors.shadow});
  padding: 0.1em 0.5em 0.5em;
  align-items: center;
  word-break: break-word;

  svg {
    font-size: 32px;
    margin: 5px 5px 5px 5px;
    flex-shrink: 1;
  }

  div {
    flex-grow: 3;

    h3 {
      font-size: 1.5em;
      font-weight: 600;
    }
  }

  a {
    color: white;
  }
`;C.div`
  svg:first-of-type {
    font-size: 50px;
    display: block;
    margin: 10vh auto 20px auto;
  }
  h1 {
    font-size: 1.6em;
    text-align: center;
    margin-bottom: 12px;
  }
  p {
    display: block;
    margin: 0 auto 15px auto;
    margin-left: auto;
    margin-right: auto;
    width: auto;
    max-width: 500px;
    text-align: center;
  }
`;C.div`
  position: absolute;
  height: 100vh;
  width: 100vw;
  top: 0;
  left: 0;
  z-index: 10;
  background: url(${cj}) no-repeat;
  background-size: cover;
  color: #d5d5d5;
  h1 {
    text-align: center;
    margin-top: 30vh;
    font-size: revert;
    font-weight: bolder;
  }
  p {
    text-align: center;
    max-width: 300px;
    margin-left: auto;
    margin-right: auto;
  }
`;const uj=({bans:i})=>{var d,f;const{t:r}=k(),o=b.useContext(Te),u=i==null?void 0:i.find(m=>m.revoked_at===null||m.revoked_at>new Date);return o.access["incursions.waitlist_bans_manage"]&&u?a.jsxs(rj,{children:[a.jsx(ae,{fixedWidth:!0,icon:bc}),a.jsxs("div",{children:[a.jsx("h3",{children:r("{{category}} Suspended",{category:(d=u==null?void 0:u.entity)==null?void 0:d.category})}),a.jsx("p",{children:r("Issued on: {{date}} by {{issuer}}.",{date:Ui(new Date(u.issued_at)),issuer:(f=u==null?void 0:u.issued_by)==null?void 0:f.name})}),(u==null?void 0:u.revoked_at)&&a.jsx("p",{children:r("Expires in {{time}}.",{time:Sc(new Date(u.revoked_at))})}),a.jsx("p",{children:u==null?void 0:u.reason})]})]}):null},oj=C.div`
  span {
    display: none;
  }
  div {
    display: inline-block;
    height: 2rem;
    width: 2rem !important;
    vertical-align: text-bottom;
    margin: 15px auto 15px auto;

    background-color: ${i=>i.theme.colors.accent3};
    border-radius: 50%;
    opacity: 0;
    animation: spinner-grow 0.75s linear infinite;
    -webkit-animation: spinner-grow 0.75s linear infinite;

    @keyframes spinner-grow {
      0% {
        transform: scale(0);
      }
      50% {
        opacity: 1;
        transform: none;
      }
    }
  }
`,dj=()=>a.jsxs(oj,{children:[a.jsx("div",{}),a.jsx("span",{children:"Loading..."})]}),Em=C.div`
  margin-bottom: 25px;

  div {
    padding: 5px;
    width: 100%;
  }

  button {
    padding: 5px;
    font-size: 10px;
    margin-left: 5px;
  }
`;async function fj(i,r){return await W("/incursions/api/open_window",{json:{target_id:i,character_id:r}})}const hj=i=>{const r=ue.useContext(Te);return r!=null&&r.access["incursions.waitlist_alts_view"]?a.jsx(mj,{characterId:i.character}):null},mj=({characterId:i=0})=>{const r=ue.useContext(Te),{t:o}=k(),u=i!==0?`/incursions/api/pilot/alts?character_id=${i}`:null,[d]=he(u);return i===0?a.jsxs(Em,{children:[a.jsx(_e,{children:o("Known Alt Characters")}),a.jsx("em",{style:{fontSize:"smaller"},children:o("No character selected.")})]}):a.jsxs(Em,{children:[a.jsxs(_e,{children:[o("Known Alt Characters"),a.jsx(ae,{fixedWidth:!0,icon:q0,style:{marginLeft:"5px"},title:o("Only characters that the pilot has linked are shown below. Characters are unlinked when the user clicks logout.")})]}),d?d.length>0?d.map((f,m)=>a.jsxs("div",{children:[a.jsx(He,{...f}),a.jsx(q,{title:o("Open Show Info Window"),onClick:x=>oe(ie,fj(f.character_id,r.current.character_id)),children:a.jsx(ae,{fixedWidth:!0,icon:Li})})]},m)):a.jsx("em",{style:{fontSize:"smaller"},children:o("Pilot has no known alts.")}):a.jsx(dj,{})]})},xj=C.span`
  font-size: 0.75em;
  margin-left: 2em;

  a {
    cursor: pointer;
    padding: 0 0.2em;
  }
`;async function gj(i,r){return await W("/incursions/api/open_window",{json:{target_id:i,character_id:r}})}function pj(){const i=b.useContext(Te),{t:r}=k();return i?a.jsx(yj,{authContext:i}):a.jsxs(ct,{children:[a.jsx("b",{children:r("Login Required!")}),a.jsx("p",{children:r("This page will show you your own Fleet statistics like x-up's, fleet times and skill changes.")})]})}const vj=C.div`
  display: flex;
  align-items: center;
  padding-bottom: 30px;

  @media (max-width: 400px) {
    flex-direction: column;
  }

  img {
    border-radius: 50%;
    height: 100px;
    width: 100px;
    margin-right: 10px;
    vertical-align: bottom;

    @media (max-width: 400px) {
      margin-right: 0px;
    }
  }

  div:first-of-type {
    display: flex;
    flex-direction: column;

    div:first-of-type {
      display: flex;
      flex-direction: row;

      @media (max-width: 400px) {
        flex-direction: column;
        padding-bottom: 15px;

        h1 {
          text-align: center;
        }
      }

      h1 {
        font-size: 1.9em;
        margin-right: 10px;
      }
    }
  }
`;function yj({authContext:i}){const{t:r}=k();var u=new URLSearchParams(un().search).get("character_id")||i.current.character_id;const[d,f]=b.useState(null),[m,x]=he(`/incursions/api/pilot/info?character_id=${u}`),[p]=he(`/incursions/api/history/fleet?character_id=${u}`),[v]=he(i.access["incursions.waitlist_bans_view"]?`/incursions/api/bans/${u}`:null),[j]=he(`/incursions/api/history/xup?character_id=${u}`),[O]=he(`/incursions/api/history/skills?character_id=${u}`),[D]=he(i.access["incursions.waitlist_notes_view"]?`/incursions/api/notes?character_id=${u}`:null);return qe(r("Pilot")),a.jsxs(a.Fragment,{children:[i.access["incursions.waitlist_bans_view"]&&a.jsx(uj,{bans:v}),a.jsxs(vj,{children:[(m==null?void 0:m.character.character_id)!==1&&a.jsx("img",{src:`https://images.evetech.net/characters/${m==null?void 0:m.character.character_id}/portrait?size=128`,alt:r("Character Portrait")}),a.jsxs("div",{children:[a.jsx("div",{children:a.jsx("h1",{children:m==null?void 0:m.character.character_name})}),a.jsx(sx,{style:{flexWrap:"flex"},tags:m==null?void 0:m.tags})]})]}),i.account_id!==u&&a.jsxs(Oe,{style:{marginBottom:"20px"},children:[i.access["incursions.waitlist_notes_manage"]&&a.jsx(ln,{to:`/fc/notes/add?character_id=${u}`,children:r("Write note")}),i.access["incursions.waitlist_commanders_manage"]&&a.jsx(uo,{character:m??{id:parseInt(u),name:""},isRevokeable:!0,handleRefresh:x}),i.access["incursions.waitlist_badges_manage"]&&a.jsx(jx,{character:m??{id:parseInt(u),name:""},refreshData:x}),i.access["incursion.waitlist_esi_show_info"]&&a.jsxs(q,{title:r("Open Show Info Window"),onClick:()=>oe(ie,gj(m.id,i.current.character_id)),children:[r("Show Info")," ",a.jsx(ae,{fixedWidth:!0,icon:Li})]})]}),a.jsxs(yc,{children:[a.jsxs(Tl,{xs:4,md:6,children:[a.jsxs(_e,{children:[r("History"),a.jsxs(xj,{children:[a.jsx("a",{onClick:()=>f(null),style:{marginRight:"0.5em"},title:r("Clear Filters"),children:a.jsx(ae,{fixedWidth:!0,icon:eo})}),a.jsx("a",{onClick:()=>f("skill"),title:r("Skill History"),children:a.jsx(ae,{fixedWidth:!0,icon:Pu})}),a.jsx("a",{onClick:()=>f("fit"),title:r("X-UP History"),children:a.jsx(ae,{fixedWidth:!0,icon:Pm})}),a.jsx("a",{onClick:()=>f("fleet"),title:r("Fleet History"),children:a.jsx(ae,{fixedWidth:!0,icon:ex})}),i.access["incursion.waitlist_notes_view"]&&a.jsx("a",{onClick:()=>f("note"),title:r("Pilot Notes"),children:a.jsx(ae,{fixedWidth:!0,icon:tx})}),i.access["incursion.waitlist_bans_view"]&&a.jsx("a",{onClick:()=>f("ban"),title:r("Character Ban History"),children:a.jsx(ae,{fixedWidth:!0,icon:bc})})]})]}),a.jsx(nj,{filter:d?M=>M===d:null,banHistory:v,fleetHistory:p&&p.activity,skillHistory:O&&O.history,xupHistory:j&&j.xups,notes:D&&D.notes})]}),a.jsxs(Tl,{xs:4,md:2,children:[a.jsx(_e,{children:r("Time in fleet")}),a.jsx(aj,{summary:p&&p.summary}),a.jsx(hj,{character:m==null?void 0:m.character.character_id})]})]})]})}function oo(){const i=un(),r=vc(),o=i.search,u=b.useMemo(()=>{const f=new URLSearchParams(o);var m={};for(const[x,p]of f)m[x]=p;return m},[o]),d=b.useCallback((f,m,x)=>{const p=new URLSearchParams(o);m===null?p.delete(f):p.set(f,m),r({search:`?${p.toString()}`},{replace:!!x})},[o,r]);return[u,d]}const jj="/static/incursions/waitlist/media/skillqueue.png";function bj(){const i=b.useContext(Te),{t:r}=k();return i?a.jsx(Sj,{authContext:i}):a.jsxs(ct,{children:[a.jsx("b",{children:r("Login Required!")}),a.jsx("p",{children:r("This page will show copyable skill plan tables comparing to your current skills with checkmarks next to already completed skills.")})]})}function Sj({authContext:i}){const[{plan:r}]=oo(),[o]=he("/incursions/api/skills/plans"),[u]=he(`/incursions/api/skills/${i.current.character_id}`),{t:d}=k();if(!o||!u)return a.jsx("em",{children:d("Loading...")});if(r){const f=Z.find(o.plans,m=>m.source.name===r);return f?a.jsx(Cj,{plan:f,mySkills:u}):a.jsx("em",{children:d("Plan not found")})}return a.jsx(Tj,{plans:o.plans,mySkills:u})}function bx(i){if(i===1)return"I";if(i===2)return"II";if(i===3)return"III";if(i===4)return"IV";if(i===5)return"V";throw new Error("Unlikely skill numeral")}function wj(i,r){return i.map(([o,u])=>`${r[o]||"MISSING SKILL"} ${bx(u)}`).join(`
`)}function Cj({plan:i,mySkills:r}){const o=b.useContext(ie),[u,d]=b.useState(!1),{t:f}=k();var m=[],x=Z.invert(r.ids);return Z.forEach(i.levels,([p,v])=>{const j=x[p],O=r.current[p];m.push(a.jsxs(Re,{children:[a.jsxs(I,{children:[j||f("MISSING SKILL")," ",bx(v)]}),a.jsx(I,{children:O>=v?a.jsx(ae,{icon:Wm}):null})]},`${p} ${v}`))}),qe(cv(i.source.name)),a.jsxs(yc,{children:[a.jsxs(Tl,{xs:4,md:4,children:[a.jsx(bt,{children:a.jsx(jt,{exact:!0,to:"/skills/plans",style:{textDecoration:"inherit",color:"inherit"},children:a.jsx(q,{children:f("Back")})})}),a.jsxs(ct,{children:[a.jsx("h2",{children:i.source.name}),a.jsx("p",{children:i.source.description}),a.jsx("div",{style:{marginTop:"2em"},children:i.ships.map(p=>a.jsx("img",{src:`https://images.evetech.net/types/${p.id}/render?size=128`,style:{maxWidth:"128px",margin:"0.5em"},alt:p.name,title:p.name},p.id))})]})]}),a.jsxs(Tl,{xs:4,md:4,children:[a.jsxs("p",{style:{marginBottom:"1em"},children:[a.jsx(q,{onClick:()=>{Xt(o,navigator.clipboard.writeText(wj(i.levels,x)).then(()=>f("Copied to clipboard")))},children:a.jsx(ae,{icon:Km})})," ",a.jsx("a",{style:{textDecoration:"underline",cursor:"pointer"},onClick:()=>d(!0),children:f("How do I use this?")})]}),a.jsxs(Dn,{children:[a.jsx(Na,{children:a.jsxs(Re,{children:[a.jsx(Je,{children:f("Skill")}),a.jsx(Je,{})]})}),a.jsx(Mn,{children:m})]})]}),a.jsx(ze,{open:u,setOpen:d,children:a.jsx("img",{alt:f("Explanation for using the skill queue"),src:jj})})]})}const _j=C.div`
  border: solid 2px ${i=>i.theme.colors.secondary.color};
  line-height: 0;
  padding: 0.1em;
  justify-content: center;
  border-radius: 5px;
  max-width: fit-content;
  img {
    margin: 1px;
    border-radius: 3px;
    max-width: 31px;
  }
`;function Tj({plans:i,mySkills:r}){const{t:o}=k();return qe(o("Skill Plans")),a.jsxs(a.Fragment,{children:[a.jsx(ra,{children:o("Skill plans")}),a.jsx(rx,{children:i.map(u=>a.jsx(ao,{children:a.jsx(jt,{exact:!0,to:`/skills/plans?plan=${u.source.name}`,style:{textDecoration:"inherit",color:"inherit"},children:a.jsxs(ux,{title:u.source.name,children:[a.jsx(_j,{children:u.ships.map(d=>a.jsx("img",{src:`https://images.evetech.net/types/${d.id}/icon?size=64`,alt:d.name,title:d.name},d.id))}),a.jsx("p",{children:u.source.description})]})})},u.source.name))})]})}function Ej(){const i=b.useContext(Te),{t:r}=k();var[{query:o},u]=oo();const d=m=>{u("query",m||null,!0)},[f]=he(o&&o.length>=3?"/incursions/api/search?"+new URLSearchParams({query:o}):null);return qe(r("Search")),a.jsxs(a.Fragment,{children:[a.jsx("div",{style:{marginBottom:"1em"},children:a.jsxs("label",{children:[a.jsx("strong",{children:r("Search term:")}),a.jsx("br",{}),a.jsx(cn,{value:o??"",onChange:m=>d(m.target.value)})]})}),f==null?null:f.results.length?a.jsxs(Dn,{fullWidth:!0,children:[a.jsx(Na,{children:a.jsxs(Re,{children:[a.jsx(Je,{children:r("Name")}),a.jsx(Je,{children:r("Character ID")}),a.jsx(Je,{style:{width:"50%"}})]})}),a.jsx(Mn,{children:f.results.map(m=>a.jsxs(Re,{children:[a.jsx(I,{children:m.character_name}),a.jsx(I,{children:m.character_id}),a.jsx(I,{children:a.jsxs(bt,{marginb:"0em",children:[a.jsxs(Oe,{children:[a.jsx(ln,{to:"/skills?character_id="+m.character_id,children:r("Skills")}),a.jsx(ln,{to:"/pilot?character_id="+m.character_id,children:r("Information")})]}),a.jsxs(Oe,{children:[i.access["incursions.waitlist_commanders_manage"]&&a.jsx(uo,{character:m,isRevokeable:!0}),i.access["incursions.waitlist_badges_manage"]&&a.jsx(jx,{character:m})]})]})})]},m.character_id))})]}):a.jsx("em",{children:r("No results")})]})}function Aj(){const{t:i}=k(),r=b.useContext(Te);return r?a.jsx(Dj,{authContext:r}):a.jsxs(ct,{children:[a.jsx("b",{children:i("Login Required!")}),a.jsx("p",{children:i("This page will show tables with TDF related skills comparing to your current skills with a color indicating the progres tier that skill is at.")})]})}function Dj({authContext:i}){const{t:r}=k(),o=new URLSearchParams(un().search),u=vc();var d=o.get("character_id")||i.current.character_id,f=o.get("ship")||"Vindicator";const[m]=he(`/incursions/api/pilot/info?character_id=${d}`),x=p=>{o.set("ship",p),u({search:`?${o.toString()}`})};return qe(r("{{ship}} Skills",{ship:f})),a.jsxs(a.Fragment,{children:[a.jsx(ra,{children:m?r("Skills for {{name}}",{name:m.character.character_name}):r("Skills")}),a.jsx(so,{characterId:d,ship:f,setShip:x})]})}Zm.register(d0,f0,h0,m0,x0,g0,p0,v0,y0);Zm.register(...j0);const na=C(Tl).attrs({md:4})`
  max-height: 350px;
`;function Am(i,r){let o=1546047137;for(let m=0;m<r.length;m++)o=r.charCodeAt(m)+((o<<5)-o);o=o&2147483647;const u=o%360,d=(o>>10)%60+30,f=Math.round(i.colors.lumFactor*50);return`hsla(${u}, ${d}%, ${f}%, 1)`}function fo(i,r){return Z.merge({},{maintainAspectRatio:!1,animation:!1,color:i.colors.text,backgroundColor:i.colors.accent1,borderColor:i.colors.accent2,plugins:{title:{color:i.colors.text}},scales:{x:{ticks:{color:i.colors.text},grid:{color:i.colors.accent2}},y:{ticks:{color:i.colors.text},grid:{color:i.colors.accent2}}}},r||{})}function ho(i,r,o){const u=Z.cloneDeep(r);if(u.datasets)for(const d of u.datasets){for(const f of["backgroundColor","borderColor"])d[f]||(o?d[f]=u.labels.map(m=>Am(i,m)):d[f]=Am(i,d.label||""));d.fill===void 0&&(d.fill=!0)}return u}function mo({options:i,data:r,...o}){const u=b.useContext(za);return a.jsx(S0,{options:fo(u,i),data:ho(u,r,!1),...o})}function xo({options:i,data:r,...o}){const u=b.useContext(za);return a.jsx(b0,{options:fo(u,i),data:ho(u,r,!1),...o})}function Sx({options:i,data:r,...o}){const u=b.useContext(za);return a.jsx(w0,{options:fo(u,i),data:ho(u,r,!0),...o})}function Xi(i){const r=Object.keys(i).sort(),o=r.map(u=>i[u]);return{labels:r,data:o}}function wc(i){const r=Xi(i),o={};for(let u=0;u<r.labels.length;u++)for(const[d,f]of Object.entries(r.data[u]))o[d]||(o[d]=new Array(r.labels.length).fill(null)),o[d][u]=f;return{labels:r.labels,series:o}}function Mj({data:i}){const{t:r}=k(),o=Xi(i);return a.jsx(xo,{data:{labels:o.labels,datasets:[{label:r("Hours"),data:o.data.map(u=>Math.round(u/3600))}]},options:{plugins:{title:{display:!0,text:r("Total fleet time")}}}})}function Oj({data:i}){const{t:r}=k(),o=Xi(i);return a.jsx(xo,{data:{labels:o.labels,datasets:[{label:r("Pilots"),data:o.data}]},options:{plugins:{title:{display:!0,text:r("Pilots seen in fleet")}}}})}function zj({data:i}){const{t:r}=k(),o=wc(i);return a.jsx(mo,{data:{labels:o.labels,datasets:Object.entries(o.series).map(([u,d])=>({label:r(u),data:d.map(f=>Math.round(f/3600))}))},options:{scales:{x:{stacked:!0},y:{stacked:!0}},plugins:{title:{display:!0,text:r("Time in fleet by ship")}}}})}function Nj({data:i}){const{t:r}=k(),o=wc(i);return a.jsx(xo,{data:{labels:o.labels,datasets:Object.entries(o.series).map(([u,d])=>({label:r(u),data:d.map(f=>f||0)}))},options:{plugins:{title:{display:!0,text:r("X'es by ship")}}}})}function Bj({data:i}){const{t:r}=k(),o=wc(i);return a.jsx(mo,{data:{labels:o.labels,datasets:Object.entries(o.series).map(([u,d])=>({label:r(u),data:d.map(f=>f||0)}))},options:{plugins:{title:{display:!0,text:r("Distribution of time in fleet")}}}})}function Rj({data:i}){const{t:r}=k(),o=wc(i);return a.jsx(mo,{data:{labels:o.labels,datasets:Object.entries(o.series).map(([u,d])=>({label:r(u),data:d.map(f=>Math.round((f||0)*1e3)/10)}))},options:{plugins:{title:{display:!0,text:r("Time vs X'es in percentages (28d)")}}}})}function Uj({data:i}){const{t:r}=k(),o=Xi(i);return a.jsx(Sx,{data:{labels:o.labels.map(u=>r(u)),datasets:[{data:o.data}]},options:{plugins:{title:{display:!0,text:r("X'es by ship (28d)")}}}})}function Lj({data:i}){const{t:r}=k(),o=Xi(i);return a.jsx(Sx,{data:{labels:o.labels.map(u=>r(u)),datasets:[{data:o.data.map(u=>Math.round((u||0)/3600))}]},options:{plugins:{title:{display:!0,text:r("Time in fleet by ship (28d)")}}}})}function kj(){const{t:i}=k();qe(i("Statistics"));const[r]=he("/incursions/api/stats");return r?a.jsxs(yc,{children:[a.jsx(na,{children:a.jsx(Mj,{data:r.fleet_seconds_by_month})}),a.jsx(na,{children:a.jsx(Oj,{data:r.pilots_by_month})}),a.jsx(na,{children:a.jsx(zj,{data:r.fleet_seconds_by_ship_by_month})}),a.jsx(na,{children:a.jsx(Nj,{data:r.xes_by_ship_by_month})}),a.jsx(na,{children:a.jsx(Bj,{data:r.time_spent_in_fleet_by_month})}),a.jsx(na,{children:a.jsx(Rj,{data:r.x_vs_time_by_ship_28d})}),a.jsx(na,{children:a.jsx(Uj,{data:r.xes_by_ship_28d})}),a.jsx(na,{children:a.jsx(Lj,{data:r.fleet_seconds_by_ship_28d})})]}):a.jsx("em",{children:i("Loading statistics...")})}class Oa extends ue.Component{constructor(r){super(r),this.state={hasError:!1,message:"",trace:""}}static getDerivedStateFromError(r){return{hasError:!0}}componentDidCatch(r,o){console.error("ErrorBoundary caught an error:",r,o),this.setState({message:r.message,trace:String(o.componentStack)})}render(){return this.state.hasError?a.jsxs(a.Fragment,{children:[a.jsx("p",{className:"text-center",children:"You should not be seeing this message, please report this error to your Administrators."}),a.jsx("div",{style:{justifyContent:"center"},className:"d-flex",children:a.jsx("pre",{style:{maxWidth:"1000px"},className:"border",children:this.state.trace})})]}):this.props.children}}const Hj=C0`
  to {
    transform: rotate(360deg);
  }
`,qj=C.div`
  display: flex;
  justify-content: center;
  align-items: center;
  height: 100%;
`,$j=C.div`
  width: 4rem;
  height: 4rem;
  border-radius: 50%;
  border: 0.2rem solid ${i=>i.theme.colors.accent1};
  border-top-color: ${i=>i.theme.colors.text};
  animation: ${Hj} 1.5s linear infinite;
  box-shadow: 0px -12px 8px -5px ${i=>i.theme.colors.text}40;
`;function Gj(){const[i,r]=b.useState(!1),{t:o}=k();return a.jsxs(an,{style:{width:"100%"},children:[a.jsx(an.Head,{style:{marginBottom:"1em"},children:o("We apologize, the waitlist is currently closed.")}),a.jsx(an.Paragraph,{style:{width:"50%"},children:o("Thank you for your patience. A fleet commander will be available shortly. Please stand by...")}),a.jsxs(an.Paragraph,{style:{width:"50%"},children:[a.jsx(qj,{children:a.jsx($j,{})}),a.jsx("div",{style:{display:"flex",alignItems:"center",justifyContent:"center",marginTop:"1.5em"},children:a.jsx(Oe,{children:a.jsx(q,{onClick:u=>r(!0),children:o("Click here to Ping FC's for Fleet")})})})]}),i&&a.jsx("iframe",{title:"Never Gonna Give You Up",width:"560",height:"315",src:"https://www.youtube-nocookie.com/embed/dQw4w9WgXcQ?autoplay=1&controls=0",frameBorder:"0",allow:"autoplay; encrypted-media; picture-in-picture",allowFullScreen:!0})]})}const Yj=String.raw`[Paladin, Paladin]
Imperial Navy Heat Sink
Imperial Navy Heat Sink
Imperial Navy Heat Sink
Imperial Navy 1600mm Steel Plates
Imperial Navy 1600mm Steel Plates
Imperial Navy Multispectrum Energized Membrane
Imperial Navy Multispectrum Energized Membrane

Shadow Serpentis 500MN Microwarpdrive
Tracking Computer II
Tracking Computer II
Large Micro Jump Drive

Large Coaxial Compact Remote Armor Repairer
Mega Pulse Laser II
Mega Pulse Laser II
Mega Pulse Laser II
Mega Pulse Laser II
Heavy Energy Neutralizer II
Bastion Module I
Small Tractor Beam I

Large Energy Burst Aerator II
Large Trimark Armor Pump II



Hobgoblin II x6
Hammerhead II x2
Wasp II x1`.trim(),Xj=String.raw`bringing 1 alt`.trim(),Qj=C.div`
  display: flex;
  @media (max-width: 1100px) {
    display: block;
  }
`;async function Vj({character:i,eft:r,toastContext:o,waitlist_id:u,alt:d,messagexup:f}){await W("/incursions/api/waitlist/xup",{json:{eft:r,character_id:i,waitlist_id:parseInt(u),is_alt:d,messagexup:f}}),ca(o,{title:"Added to waitlist.",message:"Your X has been added to the waitlist!",variant:"success"}),window.Notification&&Notification.requestPermission()}function wx({setXupOpen:i}){qe("X-up");const r=b.useContext(ie),o=b.useContext(Te),u=new URLSearchParams(un().search),[d,f]=b.useState(""),[m,x]=b.useState(""),[p,v]=b.useState(!1),[j,O]=b.useState(!1),[D]=b.useState(!1),[M]=he(`/incursions/api/implants?character_id=${o.current.character_id}`),{t:L}=k(),U=u.get("wl");return U?a.jsx(a.Fragment,{children:j?a.jsx(Zj,{waitlistId:U,setOpen:O,setXupOpen:i}):a.jsxs(Qj,{children:[a.jsxs(ct,{style:{flex:1},children:[a.jsx("h2",{children:L("X-up with fit(s)")}),a.jsx(Kt,{placeholder:Yj,rows:15,onChange:H=>f(H.target.value),value:d,style:{width:"100%",marginBottom:"1em"}}),a.jsxs("div",{style:{marginBottom:"1em"},children:[a.jsx("h2",{children:L("X-up message (optional)")}),a.jsx(Kt,{placeholder:Xj,rows:1,onChange:H=>x(H.target.value),value:m,style:{width:"100%"}}),L("Characters left"),": ",m.length<101?100-m.length:L("Too long")]}),a.jsxs(Oe,{children:[a.jsx(q,{static:!0,children:o.current.character_name}),a.jsx(q,{$variant:"success",onClick:()=>{v(!0),oe(r,Vj({character:o.current.character_id,eft:d,toastContext:r,waitlist_id:U,alt:D,messagexup:m}).then(()=>O(!0))).finally(()=>v(!1))},disabled:d.trim().length<50||!d.startsWith("[")||p||m.length>100,children:L("X-up")})]})]}),a.jsx(we,{style:{flex:1,marginTop:"1em"},children:M?a.jsx(dx,{implants:M.implants,name:`${o.current.character_name}'s capsule`}):null})]})}):a.jsx("em",{children:L("Missing waitlist information")})}function Zj({waitlistId:i,setOpen:r,setXupOpen:o}){const u=b.useContext(Te),[d]=he("/incursions/api/waitlist"),{t:f}=k();if(!d)return a.jsx("em",{children:f("Loading")});const m=Z.find(d.waitlist,x=>x.character&&x.character.character_id===u.account_id);return a.jsxs(a.Fragment,{children:[a.jsx(ra,{children:f("Fit review")}),a.jsx("em",{children:f("You are now on the waitlist! These are the fits you x-ed up with, please check to make sure you have everything and adjust your fit if needed.")}),m.fits.map(x=>a.jsx(we,{children:a.jsx(io,{fit:x})},x.id)),a.jsxs(bt,{children:[a.jsx(q,{$variant:"primary",onClick:x=>o(!1),children:f("Yes, looks good")}),a.jsx(q,{$variant:"secondary",onClick:x=>r(!1),children:f("No, go back to update my fit")})]})]})}const Kj=C.div`
  width: 100%;
`,Fj=C.div`
  display: flex;
  width: 100%;
  justify-content: center;
  margin-top: 1em;
  @media (max-width: 1100px) {
    flex-wrap: wrap;
  }
`,Jj=C.div`
  width: 70%;
  @media (max-width: 970px) {
    width: 100%;
  }
`;function Cx(i,r){var o=null,u=null;const d=function(){if(u=setTimeout(d,r),o){const[f,m]=o;o=null,i.apply(f,m)}};return u=setTimeout(d,r*Math.random()),[function(){o=[this,arguments]},function(){clearTimeout(u)}]}async function Wj(i){return await W("/incursions/api/waitlist/remove_x",{json:{id:i}})}function Ij(i){const r=b.useContext(ki),[o,u]=he("/incursions/api/waitlist");return b.useEffect(()=>{if(!r)return;const[d,f]=Cx(u,2e3),m=function(x){var p=JSON.parse(x.data);p.waitlist_id===i&&d()};return r.addEventListener("waitlist_update",m),r.addEventListener("open",d),function(){f(),r.removeEventListener("waitlist_update",m),r.removeEventListener("open",d)}},[u,r,i]),[o,u]}function Pj(){const i=b.useContext(Te),r=b.useContext(ki),[o,u]=b.useState(null),d=b.useCallback(()=>{if(!i.access["incursions.waitlist_fleet_view"]){u(null);return}W(`/incursions/api/fleet/members/${i.current.character_id}`,{}).then(u,()=>u(null))},[i,u]);return b.useEffect(()=>{d()},[d]),b.useEffect(()=>{if(!r)return;const[f,m]=Cx(d,2e3);return r.addEventListener("comp_update",f),r.addEventListener("open",f),function(){m(),r.removeEventListener("comp_update",f),r.removeEventListener("open",f)}},[d,r]),o}function e1(){const{t:i}=k(),r=b.useContext(Te),o=b.useContext(ie),[u,d]=oo(),[f,m]=b.useState(window.localStorage&&window.localStorage.getItem("FleetStat")?window.localStorage.getItem("FleetStat")==="true":!1),[x,p]=b.useState(!0),[v,j]=b.useState(!1),O=parseInt(u.wl),[D,M]=Ij(O),L=Pj(),U=u.mode||"columns";qe(i("Waitlist"));const H=se=>{d("mode",se)};if(b.useEffect(()=>{if(!O){d("wl",1);return}},[O,d]),b.useEffect(()=>{p(!0)},[r.current.character_id]),!O)return null;if(D===null)return a.jsx("em",{children:i("Loading waitlist information.")});if(!D.open)return a.jsx(Gj,{});const $=()=>{m(!f),window.localStorage&&window.localStorage.setItem("FleetStat",!f)};var J=Z.find(D.waitlist,se=>se.character&&se.character.character_id===r.account_id);return a.jsxs(a.Fragment,{children:[a.jsx(Oa,{children:a.jsxs(bt,{children:[a.jsxs(Oe,{children:[v&&a.jsx(ze,{open:!0,setOpen:j,fill:"true",children:a.jsx(Kj,{children:a.jsx(we,{children:a.jsx(wx,{setXupOpen:j})})})}),a.jsx(lx,{$variant:J?null:"primary",onClick:()=>j(!0),children:i(J?"Update fit(s)":"Join waitlist")}),a.jsx(q,{$variant:J?"danger":null,onClick:()=>oe(o,Wj(J.id)),disabled:!J,children:i("Leave waitlist")})]}),r.access["incursion.waitlist_context_a"]&&a.jsxs(a.Fragment,{children:[a.jsxs(Oe,{children:[a.jsx(q,{active:U==="columns",onClick:()=>H("columns"),children:i("Columns")}),a.jsx(q,{active:U==="matrix",onClick:()=>H("matrix"),children:i("Matrix")}),a.jsx(q,{active:U==="compact",onClick:()=>H("compact"),children:i("Compact")}),a.jsx(q,{active:U==="linear",onClick:()=>H("linear"),children:i("Linear")}),a.jsx(q,{active:U==="rows",onClick:()=>H("rows"),children:i("Rows")})]}),a.jsx(Oe,{children:a.jsx(q,{active:U==="notepad",onClick:()=>H("notepad"),children:i("Notepad")})}),U==="columns"&&a.jsx(Oe,{children:a.jsx(q,{onClick:$,children:i(f?"Disable Fleet Stats":"Enable Fleet Stats")})})]})]})}),a.jsx(Oa,{children:a.jsxs(Fj,{children:[a.jsx(Jj,{children:U==="columns"?a.jsx(dy,{waitlist:D,onAction:M,fleetComposition:L,authContext:r,showMembers:f}):U==="compact"?a.jsx(hy,{waitlist:D,onAction:M}):U==="linear"?a.jsx(my,{waitlist:D,onAction:M}):U==="matrix"?a.jsx(gy,{waitlist:D,onAction:M,fleetComposition:L}):U==="rows"?a.jsx(py,{waitlist:D,onAction:M,fleetComposition:L}):U==="notepad"?a.jsx(Wv,{waitlist:D,onAction:M}):null}),f&&x&&r.access["incursions.waitlist_context_a"]&&a.jsx(px,{fleetpage:!1,setStatTempActive:p})]})})]})}function t1(){return a.jsxs(a.Fragment,{children:[a.jsx(Oe,{style:{marginTop:"5em"},children:a.jsx(ln,{to:"/legal",children:"Legal"})}),a.jsx(ct,{children:a.jsxs(an,{children:[a.jsx(an.Head,{style:{marginBottom:"1em"},children:"Welcome to a fork of TLA Waitlist, embedded into Alliance Auth. This App is still a work in progress and not every API call is implemented yet."}),a.jsx(an.Paragraph,{})]})})]})}const Dm={font:{family:'-apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',monospaceFamily:'SFMono-Regular, Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace'},logo:{}},st={Light:Z.merge({},Dm,{base:"light",colors:{background:"#ffffff",text:"#4a4a4a",active:"#000000",lumFactor:1,outline:"hsla(213, 100%, 40%, 0.2)",modal:"hsla(0, 0%, 0%, 0.80)",shadow:"hsla(0, 0%, 0%, 0.2)",input:{color:"#2020200d",text:"#4a4a4a",accent:"2020200d",disabled:"#cccccc"},success:{color:"#48c774",text:"white",accent:"#3ec46d",disabled:"#92ddac"},warning:{color:"#ffdd57",text:"#4a4a4a",accent:"#ffda47",disabled:"#cccccc"},danger:{color:"#f14668",text:"white",accent:"#f03a5f",disabled:"#f8a5b6"},primary:{color:"#47afff",text:"white",accent:"#38a9ff",disabled:"#addcff"},secondary:{color:"#e6e6e6",text:"#4a4a4a",accent:"#dbdbdb",disabled:"#cccccc"},highlight:{text:"#fc9936",active:"#ffad5c"},accent1:"#fafafa",accent2:"#dbdbdb",accent3:"#999999",accent4:"#666666",tdfShields:{red:"#d60015",green:"#19b915",blue:"#0076c2",yellow:"#d2bd00",purple:"#820082",neutral:"#4b4b4b",cyan:"#1eabaa",text:"#ffffff"}}}),Dark:Z.merge({},Dm,{base:"dark",logo:{filter:"invert(1)"},colors:{background:"#1f1f1f",text:"#cccccc",active:"#eeeeee",lumFactor:.6,outline:"hsla(213, 100%, 40%, 0.2)",modal:"hsla(0, 0%, 0%, 0.80)",shadow:"hsla(0, 0%, 0%, 0.5)",input:{color:"#ffffff0a",text:"#cccccc",accent:"#ffffff0a",disabled:"#999999"},success:{color:"#1f6538",text:"white",accent:"#226d3c",disabled:"#133e22"},warning:{color:"#977c0b",text:"white",accent:"#b89300",disabled:"#574500"},danger:{color:"#661425",text:"white",accent:"#6f1628",disabled:"#330a12"},primary:{color:"#005ca3",text:"white",disabled:"#cccccc",accent:"#002e52"},secondary:{color:"#404040",text:"white",accent:"#454545",disabled:"#202020"},highlight:{text:"#fc9936",active:"#ffad5c"},accent1:"#2e2e2e",accent2:"#454545",accent3:"#757575",accent4:"#ababab",tdfShields:{red:"#9a121f",green:"#21861e",blue:"#105b8b",yellow:"#968912",purple:"#820082",neutral:"#777777",cyan:"#1c9493",text:"#cccccc"}}})};st.AMOLED=Z.merge({},st.Dark,{colors:{text:"#f0f0f0",background:"#000000",modal:"hsla(55, 0%, 13%, 0.83)"}});st["Midnight Blue"]=Z.merge({},st.Dark,{colors:{background:"#0a0a2c",accent1:"#1e1e40"}});st.Specialist=Z.merge({},st.Light,{colors:{text:"#666666",background:"#fdf3f9",accent1:"#ffcbe9",accent2:"#ffbcdf",accent3:"#d55f9d",active:"#e11891",outline:"hsla(306, 100%, 75%, 0.2)",modal:"hsla(0, 0%, 0%, 0.50)",shadow:"hsla(315, 100%, 90%, 0.4)",input:{color:"#ffc3e536",text:"#4a4a4a",accent:"#ffc3e536",disabled:"#757575"},primary:{color:"#d36ab9",text:"white",accent:"#b64a9b",disabled:"#e8e8e8"},secondary:{color:"#f1abd6",text:"white",accent:"#e58ac2",disabled:"#e8e8e8"},warning:{color:"#ffeb9f",text:"#363636",accent:"#ffda47",disabled:"#e8e8e8"},danger:{color:"#ff889f",text:"white",accent:"#f35e7b",disabled:"#f35e7b"},success:{color:"#d673af",text:"white",accent:"#c15496",disabled:"#e8e8e8"},tdfShields:{red:"#ff5676",yellow:"#f2d56d",green:"#50df4d",blue:"#2e91d1"}},logo:{filter:"hue-rotate(-55deg) drop-shadow(1px 2px 0.5px #ff8fc9) contrast(90%)"}});st.Chocola=Z.merge({},st.Dark,{colors:{background:"#30292c",active:"#FF357C",shadow:"hsla(0, 0%, 0%, 0.2)",outline:"hsla(339, 100%, 60%, 0.2)",secondary:{color:"#AE3F69",text:"white",accent:"#bc577d",disabled:"#e8e8e8"},input:{color:"#4f3d44",text:"#cccccc",accent:"#4f3d44",disabled:"#999999"},success:{color:"#1f6538",text:"white",accent:"#226d3c",disabled:"#133e22"},danger:{color:"#711818",text:"white",accent:"#6f1628",disabled:"#330a12"},accent1:"#4f3d44",accent2:"#5b4453",accent3:"#d15886"},logo:{filter:"invert(1) drop-shadow(1px 2px 0.5px #80173E)"},sticker:"https://i.imgur.com/ohDedR4.png"});st.Vanilla=Z.merge({},st.Dark,{colors:{background:"#2d2f43",active:"#9bf8ff",shadow:"rgba(0, 0, 0, .2)",outline:"hsla(203, 69%, 25%, 0.2)",text:"#6a96e9",secondary:{color:"#4b598a",text:"#e6e6e6",accent:"#5e6faa",disabled:"#b0a17f"},success:{color:"#1f6538",text:"#e4eff9 ",accent:"#226d3c",disabled:"#cccccc"},input:{color:"#3a425e",text:"#b0a17f",accent:"#3a425e",disabled:"#999999"},warning:{color:"#b79718",text:"white",accent:"#c8a51c",disabled:"#cccccc"},danger:{color:"#752626",text:"#cdcdcd ",accent:"#842c2c",disabled:"#330a12"},accent1:"#333557",accent2:"#3d5d86",accent3:"#9bf8ff",accent4:"#b0a17f",highlight:{text:"#fc9936",active:"#ffad5c"}},logo:{filter:"invert(62%) sepia(28%) saturate(325%) hue-rotate(4deg) brightness(100%) contrast(84%) drop-shadow(1px 1px 0.3px #000000)"},sticker:"https://i.imgur.com/8JN6udB.png"});Object.keys(st).forEach(i=>{st[i].name=i});const Al=i=>{const r=b.useContext(za);return Object.entries(st).forEach(o=>{const[u,d]=o;a0(`TDF-${u}`,{text:{primary:d.colors.primary,secondary:d.colors.secondary},background:{default:d.colors.background}},d.base??"dark")}),a.jsx(l0,{...i,theme:`TDF-${r.name}`})};Al.propTypes={columns:De.arrayOf(De.object).isRequired,customStyles:De.object,data:De.array,pagination:De.bool,paginationPerPage:De.number,paginationRowsPerPageOptions:De.arrayOf(De.number),persistTableHead:De.bool};Al.defaultProps={customStyles:{head:{style:{fontSize:"unset"}},subHeader:{style:{paddingLeft:"12px"}},rows:{style:{fontSize:"15px"}}},pagination:!0,paginationPerPage:50,paginationRowsPerPageOptions:[10,25,50,75,100],persistTableHead:!0};const n1=(i,r)=>i.localeCompare(r,{sensitivity:"base"}),Mm=new Date(864e13),a1=(i,r)=>(i||(i=Mm),r||(r=Mm),i instanceof Date||(i=new Date(i)),r instanceof Date||(r=new Date(r)),i.getTime()-r.getTime()),mc=["Character","Corporation","Alliance"],l1=(i,r)=>mc.indexOf(i.category)>mc.indexOf(r.category)?1:mc.indexOf(i.category)<mc.indexOf(r.category)?-1:0,_x=[{name:"Fits",value:"/fits"},{name:"Guides",value:"/guide"},{name:"Skills",value:"/skills"},{name:"Profile",value:"/pilot"},{name:"Waitlist",value:"/waitlist"}],Cl=C.div`
  margin: 15px 0px;
  padding: 5px 10px;
  flex-grow: 2;
`,Tx=C.div`
  font-style: italic;
`,Om={"Use in game channel":{content:"Join the TLA Incursions channel to x-up for the fleet.",alert:!1},"Gankers in Focus":{content:"GANKERS ARE IN FOCUS! Stay docked and read the fleet MOTD for instructions.",alert:!0}},i1={marginRight:"20px",marginBottom:"15px",display:"inline-block"},Ex=({idPrefix:i="",selectedFilters:r,onChange:o})=>{const[u,d]=b.useState([]);ue.useEffect(()=>{r!==u&&d(r??[])},[r,u]);const f=m=>{const x=m.target;let p=u;if(x.checked&&!p.includes(x.id)&&p.push(x.id),!x.checked&&p.includes(x.id)){let v=p.indexOf(x.id);p.splice(v,1)}d([...p]),o(p)};return a.jsxs(Cl,{children:[a.jsx(ke,{children:"Display on: (leave blank for site-wide)"}),_x.map((m,x)=>{const p=m.name.toLowerCase(),v=u.includes(p);return a.jsxs("label",{htmlFor:p,style:i1,children:[a.jsx("input",{id:p,type:"checkbox",checked:v,onChange:j=>f(j)})," ",m.name]},x)})]})},s1=({isOpen:i,setOpen:r,refreshFunction:o})=>{const u=b.useContext(ie),[d,f]=b.useState(!1),[m,x]=b.useState(void 0),[p,v]=b.useState([]),[j,O]=b.useState(!1),D=()=>{f(!1),x(void 0)},M=U=>{if(U.preventDefault(),j)return;O(!0);let H=null;p.length>0&&(H=JSON.stringify(p)),oe(u,W("/incursions/api/announcements",{method:"POST",json:{message:m,is_alert:d,pages:H}}).then(()=>{r(!1),o(),D()}).finally(()=>O(!1)))},L=U=>{const H=Om[U.target.value];f(H==null?void 0:H.alert),x(H==null?void 0:H.content)};return a.jsx(ze,{open:i,setOpen:r,children:a.jsxs(we,{children:[a.jsx(_e,{children:"New Announcement"}),a.jsxs("form",{onSubmit:M,children:[a.jsxs(Cl,{children:[a.jsx(ke,{htmlFor:"content",required:!0,children:"Content:"}),a.jsx(Kt,{id:"content",value:m??"",style:{maxWidth:"450px",width:"80vw",height:"250px",resize:"vertical"},onChange:U=>x(U.target.value),required:!0,minLength:"0",maxLength:"512"}),a.jsx(Tx,{children:"Maximum 512 characters."})]}),a.jsxs(Cl,{children:[a.jsx("input",{id:"important",type:"checkbox",checked:d,onChange:()=>f(!d)}),a.jsxs("label",{htmlFor:"important",title:"Banner has a red background.",children:["This is a"," ",a.jsx("b",{children:a.jsx("u",{children:"REALLY"})})," ","important announcement!"]})]}),a.jsx(Ex,{onChange:U=>v(U)}),a.jsxs(Cl,{children:[a.jsx(ke,{children:"or select a template"}),a.jsxs(rn,{style:{width:"100%",appearance:"auto"},onChange:L,children:[a.jsx("option",{children:"Select..."}),Object.entries(Om).map((U,H)=>{const[$]=U;return a.jsx("option",{value:$,children:$},H)})]})]}),a.jsxs(bt,{style:{paddingLeft:"8px"},children:[a.jsx(q,{$variant:"danger",type:"submit",disabled:j,children:"Confirm"}),a.jsx(q,{$variant:"secondary",onClick:()=>r(!1),children:"Cancel"})]})]})]})})},c1=({data:i,refreshFunction:r})=>{const[o,u]=b.useState(!1),d=({data:f,refreshFunction:m,isOpen:x,setOpen:p})=>{const v=b.useContext(ie),[j,O]=b.useState(void 0),[D,M]=b.useState(!1),[L,U]=b.useState([]),[H,$]=b.useState(!1),J=se=>{if(se.preventDefault(),H)return;$(!0);let We=null;L.length>0&&(We=JSON.stringify(L)),oe(v,W(`/incursions/api/announcements/${f.id}`,{method:"put",json:{message:j,is_alert:D,pages:We}}).then(()=>{p(!1),m()}).finally(()=>$(!1)))};return ue.useEffect(()=>{O(f==null?void 0:f.message),M(f==null?void 0:f.is_alert)},[f==null?void 0:f.message,f==null?void 0:f.is_alert]),a.jsx(ze,{open:x,setOpen:p,children:a.jsxs(we,{children:[a.jsxs(_e,{children:["Update Announcement #",f.id]}),a.jsxs("form",{onSubmit:J,children:[a.jsxs(Cl,{children:[a.jsx(ke,{htmlFor:`content-${f.id}`,required:!0,children:"Content:"}),a.jsx(Kt,{id:`content-${f.id}`,value:j??"",style:{maxWidth:"450px",width:"80vw",height:"250px",resize:"vertical"},onChange:se=>O(se.target.value),required:!0,minLength:"0",maxLength:"512"}),a.jsx(Tx,{children:"Maximum 512 characters."})]}),a.jsxs(Cl,{children:[a.jsx("input",{id:`important-${f.id}`,type:"checkbox",checked:D,onChange:()=>M(!D)}),a.jsxs("label",{htmlFor:`important-${f.id}`,title:"Banner has a red background.",children:["This is a"," ",a.jsx("b",{children:a.jsx("u",{children:"REALLY"})})," ","important announcement!"]})]}),a.jsx(Ex,{idPrefix:f.id,selectedFilters:f!=null&&f.pages?JSON.parse(f.pages):[],onChange:se=>U(se)}),a.jsxs(bt,{style:{paddingLeft:"8px"},children:[a.jsx(q,{$variant:"danger",type:"submit",disabled:H,children:"Confirm"}),a.jsx(q,{$variant:"secondary",onClick:()=>p(!1),children:"Cancel"})]})]})]})})};return a.jsxs(a.Fragment,{children:[a.jsx(q,{onClick:()=>u(!0),children:"Update"}),a.jsx(d,{isOpen:o,setOpen:u,data:i,refreshFunction:r})]})},r1=C.div`
  padding-bottom: 10px;
  display: flex;
  flex-wrap: wrap;
  justify-content: space-between;
  align-content: space-between;

  h1 {
    font-size: 32px;
  }
`;async function u1(i){return await W(`/incursions/api/announcements/${i}`,{method:"DELETE"})}const o1=()=>{const[i,r]=he("/incursions/api/announcements"),[o,u]=b.useState(!1),d=b.useContext(ie),{t:f}=k(),m=[{name:f("Content"),grow:5,selector:x=>x.message,wrap:!0},{name:f("Pages"),selector:x=>{const p=x.pages;return p?JSON.parse(p).map(v=>f(`pages.${v}`,v)).join(", "):f("table.pages.all","All")},wrap:!0},{name:f("Created By"),selector:x=>a.jsx(He,{...x.created_by})},{name:"",maxWidth:"115px",selector:x=>a.jsx(c1,{data:x,refreshFunction:r})},{name:"",maxWidth:"110px",selector:x=>a.jsx(q,{$variant:"danger",onClick:()=>oe(d,u1(x.id).then(r)),children:f("Delete")})}];return qe(f("Announcements")),a.jsxs(a.Fragment,{children:[a.jsxs(r1,{children:[a.jsx("h1",{children:f("Announcements")}),a.jsxs(q,{$variant:"primary",onClick:()=>u(!0),style:{marginTop:"15px"},children:[a.jsx(ae,{fixedWidth:!0,icon:Jm,style:{marginRight:"10px"}}),f("New")]})]}),a.jsx(Al,{columns:m,data:i??[],pagination:!1,progressPending:!i}),a.jsx(s1,{isOpen:o,setOpen:u,refreshFunction:r})]})},d1=C.ul`
  position: absolute;
  width: 100%;
  background: ${i=>{var r;return(r=i.theme.colors)==null?void 0:r.accent1}};
  z-index: 500;
  border: 1px solid #999;
  border-top-width: 0;
  list-style: none;
  margin-top: 0;
  overflow-y: auto;
  padding-left: 0;

  & > li {
    padding: 0.5rem;

    &.active,
    &:hover {
      color: ${i=>{var r;return(r=i.theme.active)==null?void 0:r.text}};
      cursor: pointer;
      font-weight: 700;
    }
  }
`,f1=C.div`
  color: ${i=>{var r,o;return(o=(r=i.theme.colors)==null?void 0:r.secondary)==null?void 0:o.text}};
  padding: 0.5rem;
  font-style: italic;
`,Ax=({id:i,onChange:r,style:o,resetSearch:u,hideNotFound:d})=>{const{t:f}=k(),[m,x]=b.useState(0),[p,v]=b.useState(!1),[j,O]=b.useState([]),[D,M]=b.useState(""),[L,U]=b.useState(""),H=de=>{U(de),M(de)},[$]=he(L&&L.length>=3?`/incursions/api/search?${new URLSearchParams({query:L})}`:null);ue.useEffect(()=>{let de=!1;O($==null?void 0:$.results.filter(fe=>(fe.character_name.toLowerCase()===D.toLocaleLowerCase()&&(r(fe),M(fe.character_name),x(0),de=!0),fe.character_name.toLowerCase().indexOf(D.toLowerCase())>-1))),v(!de)},[$,D,r]),ue.useEffect(()=>{M(""),O([]),v(!1),x(0)},[u]);const J=de=>{x(0),v(!1),M(de.currentTarget.innerText);for(let fe=0;fe<j.length;fe++){const mt=j[fe];if(mt.character_name.toLowerCase()===de.currentTarget.innerText.toLowerCase()){r(mt);break}}},se=de=>{let fe=m;if(de.keyCode===13)de.preventDefault(),r(j[fe]),M(j[fe].character_name),x(0),v(!1);else if(de.keyCode===38){if(de.preventDefault(),m===0)return;x(fe-1)}else if(de.keyCode===40){if(de.preventDefault(),m===($==null?void 0:$.results.length)-1)return;x(fe+1)}};let We;return p&&D&&(j!=null&&j.length?We=a.jsx(d1,{children:j.map((de,fe)=>a.jsx("li",{className:fe===m?"active":null,onClick:J,children:de.character_name},fe))}):We=d?null:a.jsx(f1,{children:f("Could not find {{character_name}} in the database, sorry.",{name:D})})),a.jsxs("div",{style:{position:"relative"},children:[a.jsx(cn,{id:i??"pilot-search",type:"text",value:D,onChange:de=>H(de.target.value),onKeyDown:se,style:o,autoComplete:"off"}),We]})},zm=C.div`
  margin: 15px 0px;
`,h1=C.p`
  margin-bottom: 20px;
`,m1=({badgeOptions:i=[],isOpen:r,setOpen:o,refreshFunction:u})=>{const{t:d}=k(),[f,m]=b.useState(void 0),[x,p]=b.useState(void 0),v=b.useContext(ie),[j,O]=b.useState(0),D=M=>{if(M.preventDefault(),isNaN(x))return ca(v,{title:d("Error:"),message:d("You need to search for a pilot..."),variant:"danger"});oe(v,W(`/incursions/api/badges/${f}/members`,{method:"POST",json:{id:parseInt(x)}}).then(()=>{u()})),m(""),p(""),o(!1),O(L=>L+1)};return ue.useEffect(()=>{!f&&(i??[]).length>0&&m(i[0].id)},[i,f]),a.jsx(ze,{open:r,setOpen:o,children:a.jsxs(we,{style:{overflowY:"hidden"},children:[a.jsx(_e,{children:d("Assign a Specialist Badge")}),a.jsxs("form",{onSubmit:D,children:[a.jsxs(zm,{children:[a.jsx(ke,{htmlFor:"pilot-search",required:!0,children:d("Search for a pilot:")}),a.jsx(Ax,{required:!0,resetSearch:j,style:{width:"100%"},onChange:M=>p(M.id),hideNotFound:!0})]}),a.jsxs(zm,{children:[a.jsx(ke,{htmlFor:"badge-select",required:!0,children:d("Select badge type:")}),a.jsx(rn,{id:"badge-select",value:f,onChange:M=>m(M.target.value),style:{width:"100%",appearance:"auto"},required:!0,children:i==null?void 0:i.map((M,L)=>a.jsx("option",{value:M.id,children:M.name},L))})]}),a.jsx(q,{$variant:"success",children:d("Confirm")})]})]})})},x1=i=>{const{t:r}=k(),[o,u]=b.useState(!1);return a.jsxs(a.Fragment,{children:[a.jsx(q,{$variant:"danger",onClick:()=>u(!0),children:r("Revoke")}),a.jsx(g1,{isOpen:o,setOpen:u,...i})]})},g1=({badge:i,character:r,isOpen:o,setOpen:u,refreshFunction:d})=>{const{t:f}=k(),[m,x]=b.useState(!1),p=b.useContext(ie),v=()=>{m||(x(!0),oe(p,W(`/incursions/api/badges/${i.id}/members/${r.character_id}`,{method:"DELETE"}).then(()=>{x(!1),u(!1),d()}).catch(j=>{throw x(!1),j})))};return a.jsx(ze,{open:o,setOpen:u,children:a.jsxs(we,{children:[a.jsx(_e,{children:f("Revoke {{badge}}",{badge:i.name})}),a.jsxs(h1,{children:[f("From"),": ",a.jsx(He,{...r,noLink:!0,avatar:!1})]}),a.jsxs(El,{size:"90px",children:[a.jsx(q,{$variant:"secondary",onClick:()=>u(!1),children:f("Cancel")}),a.jsx(q,{$variant:"danger",onClick:v,children:f("Confirm")})]})]})})},p1=C.div`
  padding-bottom: 10px;
  display: flex;
  flex-wrap: wrap;
  justify-content: space-between;
  align-content: space-between;

  h1 {
    font-size: 32px;
  }
`,v1=C.div`
  align-content: space-between;
  display: flex;
  width: 100%;
  flex-wrap: wrap;

  > button {
    @media (max-width: 800px) {
      width: 100%;
    }
  }

  #filters {
    flex-grow: 1;

    span:first-of-type {
      font-style: italic;
      margin-right: 10px;

      @media (max-width: 800px) {
        display: block;
        margin-bottom: 5px;
      }
    }

    @media (max-width: 800px) {
      input,
      select {
        width: calc(calc(100vw - 158px) / 2);
      }
    }

    @media (max-width: 500px) {
      input,
      select {
        width: 100%;
      }
      button {
        display: block;
        width: 100%;
      }
    }
  }
`,Gu=(i,r)=>{const o=i.character_name.toLowerCase(),u=r.character_name.toLowerCase();return o.localeCompare(u)},y1=({badgeOptions:i,filters:r,onChange:o,onClear:u})=>{const{t:d}=k(),f=x=>{let p={...r};p.type=x.target.value==="-1"?null:x.target.value,o(p)},m=x=>{let p={...r};p.name=x.target.value,o(p)};return a.jsxs("div",{id:"filters",children:[a.jsx("span",{children:d("Filter results by...")}),a.jsxs(rn,{value:(r==null?void 0:r.type)??"",onChange:f,style:{marginRight:"10px",marginBottom:"10px",appearance:"auto"},children:[a.jsx("option",{value:-1,children:d("any type...")}),i==null?void 0:i.map((x,p)=>{var v;return a.jsxs("option",{value:x.id,children:[x.name," (",(v=x==null?void 0:x.member_count)==null?void 0:v.toLocaleString(),")"]},p)})]}),a.jsx(cn,{value:(r==null?void 0:r.name)??"",onChange:m,placeholder:d("pilot name"),style:{marginRight:"10px",marginBottom:"10px"}}),a.jsx(q,{$variant:"primary",onClick:u,style:{marginBottom:"10px"},children:d("Clear")})]})},j1=()=>{const[i,r]=he("/incursions/api/badges"),[o,u]=b.useState(null),[d,f]=b.useState(!1),[m,x]=b.useState({type:null,name:""}),{t:p}=k();ue.useEffect(()=>{i&&Promise.all(i.map(D=>W(`/incursions/api/badges/${D.id}/members`,{}).catch(()=>[]))).then(D=>{const M=D.flat().filter(Boolean);u(M)})},[i]);const v=[{name:p("Pilot Name"),sortable:!0,sortFunction:(D,M)=>Gu(D.character,M.character),grow:2,selector:D=>a.jsx(He,{...D.character})},{name:p("Badge"),sortable:!0,sortFunction:(D,M)=>Gu(D.badge,M.badge),grow:1,selector:D=>a.jsx(sn,{type:D.badge.name,height:"1.8em"})},{name:p("Granted By"),sortable:!0,sortFunction:(D,M)=>Gu(D.granted_by,M.granted_by),hide:"md",grow:2,selector:D=>a.jsx(He,{...D.granted_by})},{name:p("Granted At"),hide:"sm",grow:2,selector:D=>Ba(new Date(D.granted_at))},{name:"",grow:1,minWidth:"95",selector:D=>a.jsx(x1,{badge:D.badge,character:D.character,refreshFunction:r})}],j=b.useMemo(()=>{const D=()=>x({type:null,name:""});return a.jsxs(v1,{children:[a.jsx(y1,{badgeOptions:i,filters:m,onChange:M=>x({...M}),onClear:D}),a.jsxs(q,{$variant:"primary",onClick:()=>f(!0),style:{marginBottom:"10px"},children:[a.jsx(ae,{fixedWidth:!0,icon:Im,style:{marginRight:"10px"}}),p("Assign Badge")]})]})},[m,i,p]),O=(o??[]).filter(D=>D&&D.character&&(!m.type||D.badge.id===m.type)&&D.character.character_name.toLowerCase().includes(m==null?void 0:m.name.toLowerCase()));return qe(p("Specialist Badges")),a.jsxs(a.Fragment,{children:[a.jsx(p1,{children:a.jsx("h1",{children:p("Specialist Badges")})}),a.jsxs("p",{style:{marginBottom:"10px"},children:[p("You can find the badge guide")," ",a.jsx(jc,{to:"/badges",children:p("here")}),"."]}),a.jsx(Al,{columns:v,data:O,defaultSortFieldId:1,subHeader:!0,subHeaderComponent:j,progressPending:!o}),a.jsx(m1,{badgeOptions:i,isOpen:d,setOpen:f,refreshFunction:r})]})},Nm={width:"100%",resize:"vertical",minWidth:"250px"},Mi=C.div`
  margin: 15px 0px;
  padding: 5px 10px;
  flex-grow: 2;
`,b1=C.form`
  display: flex;
  flex-wrap: wrap;
  justify-content: space-between;

  & label::selection,
  div::selection,
  button::selection {
    background: none;
  }
`,Bm=C.div`
  font-style: italic;
`,S1=i=>{switch(i.entity_type){case"Character":return a.jsx(He,{...i.entity_character,noLink:!0});case"Corporation":return a.jsx($i,{...i.entity_corporation,noLink:!0});case"Alliance":return a.jsx(Gi,{...i.entity_alliance,noLink:!0});default:return i.entity_name}},w1=({isOpen:i,setOpen:r,refreshFunction:o})=>{const{t:u}=k(),d=b.useContext(ie),[f,m]=b.useState(!1),[x,p]=b.useState(!1),[v,j]=b.useState(void 0),[O,D]=b.useState("Character"),[M,L]=b.useState({id:null,name:""}),[U,H]=b.useState(""),[$,J]=b.useState(!1),[se,We]=b.useState(void 0),[de,fe]=b.useState(void 0),mt=$e=>{if($e.preventDefault(),!f){if(m(!0),!M.id){ca(d,{variant:"danger",message:u("You need to provide a {{category}} name.",{category:O.toLowerCase()})}),m(!1);return}oe(d,W("/incursions/api/bans",{method:"POST",json:{entity:{...M,category:O},reason:se,public_reason:de,revoked_at:x?null:v}}).then(()=>{r(!1),o(),St()}).finally(()=>m(!1)))}},St=()=>{p(!1),j(void 0),D("Character"),L({id:null,name:""}),H(""),J(!1),We(void 0),fe(void 0)};return ue.useEffect(()=>{const $e=()=>L({id:null,name:""});if(U.length<3)return $e();J(!0),oe(d,W("/incursions/api/search",{method:"POST",json:{search:U,category:O.toLowerCase(),strict:!0}}).then(ua=>{J(!1),ua.length>0?L({id:ua[0],name:U}):$e()}))},[U,O,d]),a.jsx(ze,{open:i,setOpen:r,children:a.jsxs(we,{children:[a.jsx(_e,{children:u("Issue a Ban")}),a.jsxs(b1,{onSubmit:mt,children:[a.jsxs("div",{children:[a.jsxs(Mi,{style:{paddingBottom:"40px"},children:[a.jsx(ke,{htmlFor:"select-type",required:!0,children:u("Type:")}),a.jsxs(rn,{id:"select-type",value:O,onChange:$e=>{H(""),D($e.target.value)},style:{width:"100%",appearance:"auto"},children:[a.jsx("option",{disabled:!0,children:u("Account")}),a.jsx("option",{children:u("Character")}),a.jsx("option",{children:u("Corporation")}),a.jsx("option",{children:u("Alliance")})]})]}),a.jsxs(Mi,{children:[a.jsx(ke,{htmlFor:"entity-name",required:!0,children:u("{{category}} Name:",{category:O})}),a.jsx(cn,{id:"entity-name",type:"text",value:U,required:!0,tabIndex:2,onChange:$e=>H($e.target.value)}),a.jsx("div",{style:{paddingTop:"10px"},children:$?u("Searching..."):(M==null?void 0:M.id)&&a.jsx(S1,{category:O,...M})})]})]}),a.jsxs("div",{children:[a.jsxs(Mi,{children:[a.jsx(ke,{htmlFor:"expires_at",required:!0,children:u("Expires:")}),a.jsx(cn,{id:"expires_at",type:"date",value:v?new Date(v).toISOString().substring(0,10):"",onChange:$e=>j(new Date($e.target.value).getTime()/1e3),min:new Date(Date.now()+3600*1e3*24).toISOString().substring(0,10),required:!0,disabled:x}),a.jsx("span",{style:{margin:"0 5px"},children:u("or")}),a.jsxs("label",{style:{marginRight:"20px",marginBottom:"15px",display:"inline-block"},children:[a.jsx("input",{type:"checkbox",checked:x,onChange:()=>p(!x)}),u("Permanent")]}),a.jsx(Bm,{children:u("Bans expire at downtime")})]}),a.jsxs(Mi,{children:[a.jsx(ke,{htmlFor:"reason",required:!0,children:u("Reason:")}),a.jsx(Kt,{id:"reason",value:se??"",style:Nm,required:!0,onChange:$e=>We($e.target.value)})]}),a.jsxs(Mi,{children:[a.jsx(ke,{htmlFor:"public_reason",children:u("Public Reason:")}),a.jsx(Kt,{id:"public_reason",value:de??"",style:Nm,onChange:$e=>fe($e.target.value)}),a.jsx(Bm,{children:u("This reason will be shown to the pilot on the ban page.")})]}),a.jsxs(bt,{style:{paddingLeft:"8px"},children:[a.jsx(q,{$variant:"secondary",onClick:()=>r(!1),children:u("Cancel")}),a.jsx(q,{$variant:"danger",type:"submit",disabled:f,children:u("Confirm")})]})]})]})]})})},Rm={width:"100%",resize:"vertical",minWidth:"250px"},la=C.div`
  margin: 15px 0px;
  padding: 5px 10px;
  flex-grow: 2;
`,C1=C.div`
  font-style: italic;
`,Dx=i=>{switch(i.entity_type){case"Character":return a.jsx(He,{...i.entity_character});case"Corporation":return a.jsx($i,{...i.entity_corporation});case"Alliance":return a.jsx(Gi,{...i.entity_alliance});default:return i.entity_name}},_1=({ban:i,isOpen:r,setOpen:o,refreshFunction:u})=>{const{t:d}=k(),[f,m]=b.useState(!1),x=b.useContext(ie),p=()=>{f||(m(!0),oe(x,W(`/incursions/api/bans/${i.id}`,{method:"DELETE"}).then(()=>{m(!1),o(!1),u()}).catch(v=>{throw m(!1),v})))};return a.jsx(ze,{open:r,setOpen:o,children:a.jsxs(we,{children:[a.jsx(_e,{children:d("Revoke {{type}} Ban?",{type:i==null?void 0:i.entity_type})}),a.jsxs("div",{style:{maxWidth:"500px",display:"flex"},children:[a.jsxs(la,{children:[a.jsx(ke,{children:d("{{type}}:",{type:i==null?void 0:i.entity_type})}),a.jsx(Dx,{...i})]}),a.jsxs(la,{children:[a.jsx(ke,{children:d("Issued By:")}),a.jsx(He,{...i.issued_by})]})]}),a.jsxs(la,{children:[a.jsx(ke,{children:d("Reason:")}),a.jsx("p",{style:{maxWidth:"500px"},children:i.reason})]}),a.jsxs(El,{size:"90px",children:[a.jsx(q,{$variant:"secondary",onClick:()=>o(!1),children:d("Cancel")}),a.jsx(q,{$variant:"danger",onClick:p,disabled:f,children:d("Confirm")})]})]})})},T1=({ban:i,isOpen:r,setOpen:o,refreshFunction:u})=>{const{t:d}=k(),[f,m]=b.useState(void 0),[x,p]=b.useState(void 0),[v,j]=b.useState(void 0),[O,D]=b.useState(!1),[M,L]=b.useState(!1),U=b.useContext(ie),H=$=>{$.preventDefault(),!M&&(L(!0),oe(U,W(`/incursions/api/bans/${i.id}`,{method:"PATCH",json:{reason:x,public_reason:v,revoked_at:O?null:f}}).then(()=>{L(!1),o(!1),u()}).catch(J=>{throw L(!1),J})))};return ue.useEffect(()=>{m(i==null?void 0:i.revoked_at),i!=null&&i.revoked_at||D(!0),p(i==null?void 0:i.reason),j(i==null?void 0:i.public_reason)},[i==null?void 0:i.revoked_at,i==null?void 0:i.reason,i==null?void 0:i.public_reason]),a.jsx(ze,{open:r,setOpen:o,children:a.jsxs(we,{children:[a.jsx(_e,{children:d("Update {{type}} Ban:",{type:i==null?void 0:i.entity_type})}),a.jsxs("div",{style:{maxWidth:"500px",display:"flex"},children:[a.jsxs(la,{children:[a.jsx(ke,{children:d("{{type}}:",{type:i==null?void 0:i.entity_type})}),a.jsx(Dx,{...i})]}),a.jsxs(la,{children:[a.jsx(ke,{children:d("Issued By:")}),a.jsx(He,{...i.issued_by})]})]}),a.jsxs("form",{onSubmit:H,children:[a.jsxs(la,{children:[a.jsx(ke,{required:!0,children:d("Expires:")}),a.jsx(cn,{type:"date",value:f?new Date(f).toISOString().substring(0,10):"",onChange:$=>m(new Date($.target.value).getTime()/1e3),min:new Date(Date.now()+3600*1e3*24).toISOString().substring(0,10),disabled:O,required:!0}),a.jsx("span",{style:{margin:"0 5px"},children:d("or")}),a.jsxs("label",{style:{marginRight:"20px",marginBottom:"15px",display:"inline-block"},children:[a.jsx("input",{type:"checkbox",checked:O,onChange:()=>D(!O)}),d("Permanent")]})]}),a.jsxs(la,{children:[a.jsx(ke,{htmlFor:`reason-${i.id}`,required:!0,children:d("Reason:")}),a.jsx(Kt,{id:`reason-${i.id}`,value:x,onChange:$=>p($.target.value),style:Rm,required:!0})]}),a.jsxs(la,{children:[a.jsx(ke,{htmlFor:`public_reason-${i.id}`,children:d("Public Reason:")}),a.jsx(Kt,{id:`public_reason-${i.id}`,value:v??"",onChange:$=>j($.target.value),style:Rm}),a.jsx(C1,{children:d("This reason will be shown to the pilot on the ban page.")})]}),a.jsxs(El,{size:"90px",children:[a.jsx(q,{$variant:"secondary",type:"button",onClick:()=>o(!1),children:d("Cancel")}),a.jsx(q,{$variant:"danger",type:"submit",disabled:M,children:d("Confirm")})]})]})]})})},Um={marginRight:"10px",marginBottom:"10px",appearance:"auto"},E1=({filters:i,onChange:r,onClear:o})=>{const{t:u}=k(),d={type:[{text:u("any duration"),value:-1},{text:u("permanent")},{text:u("temporary")}],entity_type:[{text:u("any type"),value:-1},{text:u("account")},{text:u("alliance")},{text:u("character")},{text:u("corporation")}]},f=(x,p)=>{r({...i,[p]:x.target.value==="-1"?null:x.target.value})},m=x=>{r({...i,name:x.target.value})};return a.jsxs("div",{id:"filters",children:[a.jsx("span",{children:u("Filter results by...")}),a.jsx(rn,{value:(i==null?void 0:i.entity_type)??"",onChange:x=>f(x,"entity_type"),style:Um,children:d.entity_type.map((x,p)=>a.jsx("option",{value:x.value??x.text,disabled:x.text===u("account"),children:x.text},p))}),a.jsx(rn,{value:(i==null?void 0:i.type)??"",onChange:x=>f(x,"type"),style:Um,children:d.type.map((x,p)=>a.jsx("option",{value:x.value??x.text,children:x.text},p))}),a.jsx(cn,{value:(i==null?void 0:i.name)??"",onChange:m,placeholder:u("name"),style:{marginRight:"10px",marginBottom:"10px"}}),a.jsx(q,{$variant:"primary",onClick:o,style:{marginBottom:"10px"},children:u("Clear")})]})},A1=i=>{const{t:r}=k(),[o,u]=b.useState(!1);return a.jsxs(a.Fragment,{children:[a.jsxs(q,{$variant:"primary",onClick:()=>u(!0),children:[a.jsx(ae,{fixedWidth:!0,icon:$0,style:{marginRight:"10px"}}),r("Issue Ban")]}),a.jsx(w1,{isOpen:o,setOpen:u,...i})]})},D1=i=>{const{t:r}=k(),[o,u]=b.useState(!1);return a.jsxs(a.Fragment,{children:[a.jsx(q,{$variant:"danger",onClick:()=>u(!0),children:r("Revoke")}),a.jsx(_1,{isOpen:o,setOpen:u,...i})]})},M1=i=>{const{t:r}=k(),[o,u]=b.useState(!1);return a.jsxs(a.Fragment,{children:[a.jsx(q,{onClick:()=>u(!0),children:r("Update")}),a.jsx(T1,{isOpen:o,setOpen:u,...i})]})},O1=C.div`
  display: flex;
  flex-flow: column wrap;
  justify-content: space-around;
  padding-top: 10px;
  padding-bottom: 15px;

  p {
    padding-bottom: 5px;
    font-weight: bold;

    span {
      font-weight: normal;
      font-style: italic;
      font-size: small;
      color: ${i=>i.theme.colors.active};
    }
  }

  div {
    padding-bottom: 20px;

    &[mode="wide"] {
      display: flex;
      flex-flow: row wrap;
      div {
        min-width: 120px;
        width: 20vw;
      }
    }
  }
`,z1=({data:i,refreshFunction:r})=>{const{t:o}=k();return a.jsxs(O1,{children:[a.jsxs("div",{style:{paddingBottom:"0"},children:[a.jsxs("div",{children:[a.jsx("p",{children:o("Issued by:")}),a.jsx(He,{...i.issued_by})]}),i.revoked_by&&a.jsxs("div",{children:[a.jsx("p",{children:o("Revoked by:")}),a.jsx(He,{...i.revoked_by})]})]}),a.jsxs("div",{style:{paddingBottom:"0"},children:[a.jsxs("div",{children:[a.jsx("p",{children:o("Issued at:")}),Ba(new Date(i.issued_at))]}),i.revoked_at&&new Date(i.revoked_at)<new Date&&a.jsxs("div",{children:[a.jsx("p",{children:o("Revoked at:")}),Ui(new Date(i.revoked_at))]})]}),i.revoked_at&&new Date(i.revoked_at)>new Date&&a.jsxs("div",{children:[a.jsx("p",{children:o("Expires In:")}),a.jsx("span",{title:Ui(new Date(i.revoked_at)),children:Sc(new Date(i.revoked_at))})]}),a.jsxs("div",{style:{wordWrap:"break-word",maxWidth:"70vw"},children:[a.jsxs("p",{children:[o("Reason:")," ",a.jsx("span",{children:o("(this reason can ONLY be seen by the FC team)")})]}),i.reason]}),i.public_reason&&a.jsxs("div",{style:{wordWrap:"break-word",maxWidth:"70vw"},children:[a.jsxs("p",{children:[o("Public Reason:")," ",a.jsx("span",{children:o("(this reason can be seen by the pilot)")})]}),i.public_reason]}),a.jsxs(bt,{children:[a.jsx(M1,{ban:i,refreshFunction:r}),a.jsx(D1,{ban:i,refreshFunction:r})]})]})},N1=C.div`
  padding-bottom: 10px;
  display: flex;
  flex-wrap: wrap;
  justify-content: space-between;
  align-content: space-between;

  h1 {
    font-size: 32px;
  }
`,B1=C.div`
  align-content: space-between;
  display: flex;
  width: 100%;
  flex-wrap: wrap;

  > button {
    @media (max-width: 800px) {
      width: 100%;
    }
  }

  #filters {
    flex-grow: 1;

    span:first-of-type {
      font-style: italic;
      margin-right: 10px;

      @media (max-width: 800px) {
        display: block;
        margin-bottom: 5px;
      }
    }

    @media (max-width: 800px) {
      input,
      select {
        width: calc(calc(100vw - 158px) / 2);
      }
    }

    @media (max-width: 500px) {
      input,
      select {
        width: 100%;
      }
      button {
        display: block;
        width: 100%;
      }
    }
  }
`,R1=()=>{const[i,r]=he("/incursions/api/bans"),[o,u]=b.useState({type:null,name:"",entity_type:""}),d=[{name:"Name",sortable:!0,sortFunction:(x,p)=>n1(x.entity_name,p.entity_name),grow:3,selector:x=>{switch(x.entity_type){case"Character":return a.jsx(He,{...x.entity_character});case"Corporation":return a.jsx($i,{...x.entity_corporation});case"Alliance":return a.jsx(Gi,{...x.entity_alliance});default:return x.entity_name}}},{name:"Entity Type",sortable:!0,sortFunction:(x,p)=>l1(x.entity,p.entity),grow:1,selector:x=>x.entity_type},{name:"Expires",sortable:!0,hide:"sm",sortFunction:(x,p)=>a1(x.revoked_at,p.revoked_at),grow:1,selector:x=>x.revoked_at?Ui(new Date(x.revoked_at)):"Never"},{name:"Reason",hide:"sm",grow:6,wrap:!0,selector:x=>x.reason}],f=(i??[]).filter(x=>(!o.entity_type||x.entity_type.toLowerCase()==o.entity_type)&&(!o.type||o.type==="permanent"&&!x.revoked_at||o.type==="temporary"&&x.revoked_at)&&x.entity_name.toLowerCase().includes(o==null?void 0:o.name.toLowerCase())),m=b.useMemo(()=>a.jsxs(B1,{children:[a.jsx(E1,{filters:o,onChange:x=>{u({...x})},onClear:()=>u({type:null,name:"",entity_type:""})}),a.jsx(A1,{refreshFunction:r})]}),[o,r]);return qe("Bans"),a.jsxs(a.Fragment,{children:[a.jsx(N1,{children:a.jsx("h1",{children:"System Bans"})}),a.jsx("p",{style:{marginBottom:"10px"},children:"Players who are banned or are in a banned corporation or alliance will be prevented from authenticating or joining the waitlist."}),a.jsx(Al,{textAlign:"center",verticalAlign:"middle",columns:d,data:f,defaultSortFieldId:1,expandableRows:!0,expandableRowsComponent:z1,expandableRowsComponentProps:{refreshFunction:r},subHeader:!0,subHeaderComponent:m,progressPending:!i})]})},Lm=C.div`
  margin: 15px 0px;
`,U1=C.p`
  margin-bottom: 20px;
`,L1=C.span`
  [data-icon] {
    display: none;
  }
  @media (max-width: 450px) {
    [data-icon] {
      display: block !important;
    }
    span {
      display: none;
    }
  }
`,k1=({refreshData:i})=>{const[r,o]=b.useState(!1),{t:u}=k(),d=({isOpen:f,setOpen:m,refreshData:x})=>{const[p,v]=b.useState(void 0),[j]=he("/incursions/api/commanders/roles"),[O,D]=b.useState(void 0),[M,L]=b.useState(0),U=b.useContext(ie),H=$=>{if($.preventDefault(),isNaN(O))return ca(U,{title:u("error"),message:u("You need to search for a pilot..."),variant:"danger"});oe(U,W("/incursions/api/commanders",{method:"POST",json:{character_id:O,role:p}}).then(()=>x())),v(""),D(""),m(!1),L(J=>J+1)};return ue.useEffect(()=>{!p&&(j==null?void 0:j.length)>0&&v(j[0])},[p,j]),a.jsx(ze,{open:f,setOpen:m,children:a.jsxs(we,{children:[a.jsx(_e,{children:u("Add an FC")}),a.jsxs("form",{onSubmit:H,children:[a.jsxs(Lm,{children:[a.jsx(ke,{htmlFor:"pilot-search",required:!0,children:u("Search for a pilot:")}),a.jsx(Ax,{required:!0,resetSearch:M,style:{width:"100%"},onChange:$=>D($.id),hideNotFound:!0})]}),a.jsxs(Lm,{children:[a.jsx(ke,{htmlFor:"role-select",required:!0,children:u("Select role:")}),a.jsx(rn,{id:"role-select",value:p,onChange:$=>v($.target.value),style:{width:"100%",appearance:"auto"},required:!0,children:j==null?void 0:j.map(($,J)=>a.jsx("option",{value:$,children:u(`roles.${$}`,$)},J))})]}),a.jsx(q,{$variant:"success",children:u("Confirm")})]})]})})};return a.jsxs(a.Fragment,{children:[a.jsxs(q,{$variant:"primary",onClick:()=>o(!0),style:{marginBottom:"10px"},children:[a.jsx(ae,{fixedWidth:!0,icon:G0,style:{marginRight:"10px"}}),u("Add an FC")]}),a.jsx(d,{isOpen:r,setOpen:o,refreshData:i})]})},H1=({filters:i,filterOptions:r,onChange:o,onClear:u})=>{const{t:d}=k();return a.jsxs("div",{id:"filters",children:[a.jsx("span",{children:d("Filter results by...")}),a.jsxs(rn,{value:(i==null?void 0:i.role)??"",onChange:f=>o({...i,role:f.target.value==="-1"?null:f.target.value}),style:{marginRight:"10px",marginBottom:"10px",appearance:"auto"},children:[a.jsx("option",{value:-1,children:d("any role...")}),r==null?void 0:r.map((f,m)=>{var x;return a.jsxs("option",{value:f.name,children:[d(`roles.${f.name}`,f.name)," (",(x=f==null?void 0:f.member_count)==null?void 0:x.toLocaleString(),")"]},m)})]}),a.jsx(cn,{value:(i==null?void 0:i.name)??"",onChange:f=>o({...i,name:f.target.value}),placeholder:d("pilot name"),style:{marginRight:"10px",marginBottom:"10px"}}),a.jsx(q,{$variant:"primary",onClick:u,style:{marginBottom:"10px"},children:d("Clear")})]})},q1=i=>{var p;const[r,o]=b.useState(!1),u=b.useContext(Te),{t:d}=k(),f=`commanders-manage:${i.role}`,m=(p=u==null?void 0:u.access)==null?void 0:p[f],x=({character:v,role:j,isOpen:O,setOpen:D,refreshData:M})=>{const[L,U]=b.useState(!1),H=b.useContext(ie),$=()=>{L||(U(!0),oe(H,W(`/incursions/api/commanders/${v.character_id}`,{method:"DELETE"}).then(()=>{U(!1),D(!1),M()}).catch(J=>{throw U(!1),J})))};return a.jsx(ze,{open:O,setOpen:D,children:a.jsxs(we,{children:[a.jsx(_e,{children:d("Revoke {{role}}",{role:j})}),a.jsxs(U1,{children:[d("From:")," ",a.jsx(He,{...v,noLink:!0,avatar:!1})]}),a.jsxs(El,{size:"90px",children:[a.jsx(q,{$variant:"secondary",onClick:()=>D(!1),children:d("Cancel")}),a.jsx(q,{$variant:"danger",onClick:$,children:d("Confirm")})]})]})})};return a.jsxs(a.Fragment,{children:[a.jsx(q,{$variant:"danger",onClick:()=>o(!0),disabled:!m,children:a.jsxs(L1,{children:[a.jsx(ae,{fixedWidth:!0,icon:Y0}),a.jsx("span",{children:d("Revoke")})]})}),a.jsx(x,{isOpen:r,setOpen:o,...i})]})},$1=C.div`
  padding-bottom: 10px;
  display: flex;
  flex-wrap: wrap;
  justify-content: space-between;
  align-content: space-between;

  h1 {
    font-size: 32px;
  }
`,G1=C.div`
  align-content: space-between;
  display: flex;
  width: 100%;
  flex-wrap: wrap;

  > button {
    @media (max-width: 800px) {
      width: 100%;
    }
  }

  #filters {
    flex-grow: 1;

    span:first-of-type {
      font-style: italic;
      margin-right: 10px;

      @media (max-width: 800px) {
        display: block;
        margin-bottom: 5px;
      }
    }

    @media (max-width: 800px) {
      input,
      select {
        width: calc(calc(100vw - 158px) / 2);
      }
    }

    @media (max-width: 500px) {
      input,
      select {
        width: 100%;
      }
      button {
        display: block;
        width: 100%;
      }
    }
  }
`,Y1=C.span`
  [data-icon] {
    display: none;
  }
  @media (max-width: 450px) {
    [data-icon] {
      display: block !important;
    }
    span {
      display: none;
    }
  }
`,km=(i,r)=>{const o=i.character_name.toLowerCase(),u=r.character_name.toLowerCase();return o>u?1:u>o?-1:0},X1=()=>{const i=ue.useContext(Te),[r,o]=he("/incursions/api/commanders"),[u,d]=b.useState({role:null,name:""}),f=[{name:"Pilot Name",sortable:!0,sortFunction:(p,v)=>km(p.character,v.character),grow:2,selector:p=>a.jsx(He,{...p.character})},{name:"Role",sortable:!0,grow:2,selector:p=>p.role.name},{name:"Granted By",sortable:!0,sortFunction:(p,v)=>km(p.granted_by,v.granted_by),hide:"md",grow:1,selector:p=>a.jsx(He,{...p.granted_by})},{name:"Granted At",hide:"sm",grow:1,selector:p=>Ba(new Date(p.granted_at))},{name:"",compact:!0,grow:1,minWidth:"46",selector:p=>i&&i.access["incursions.waitlist_commanders_manage"]&&a.jsxs(bt,{children:[a.jsx(uo,{character:p.character,current:p.role,handleRefresh:o,children:a.jsxs(Y1,{children:[a.jsx(ae,{fixedWidth:!0,icon:X0}),a.jsx("span",{children:"Update"})]})}),a.jsx(q1,{character:p.character,role:p.role,refreshData:o})]})}],m=((r==null?void 0:r.commanders)??[]).filter(p=>p&&p.character&&(!u.role||p.role===u.role)&&p.character.character_name.toLowerCase().includes(u==null?void 0:u.name.toLowerCase())),x=b.useMemo(()=>{const p=()=>d({role:null,name:""});return a.jsxs(G1,{children:[a.jsx(H1,{filterOptions:r==null?void 0:r.filters,filters:u,onChange:v=>d({...v}),onClear:p}),i&&i.access["incursions.waitlist_commanders_manage"]&&a.jsx(k1,{refreshData:o})]})},[u,r,o,i]);return qe("Commanders"),a.jsxs(a.Fragment,{children:[a.jsxs($1,{children:[a.jsx("h1",{children:"Fleet Commanders"}),a.jsx("h2",{children:"Reminder this is purely COSMETIC, PERMISSIONS are controlled via Alliance Auth"})]}),a.jsx(Al,{columns:f,data:m,defaultSortFieldId:1,subHeader:!0,subHeaderComponent:x,progressPending:!(r!=null&&r.commanders)})]})},Q1=C.a`
  color: ${i=>i.theme.colors.highlight.text};
  text-decoration: none;
  &:hover {
    cursor: pointer;
    color: ${i=>i.theme.colors.highlight.active};
    transition: ease-in-out 0.15s;
  }

  & + svg {
    margin-left: 5px;
    font-size: small;
  }
`,V1=C.div`
  padding: 10px 20px 10px 20px;
  font-weight: 600;

  h1 {
    font-size: 30px;
  }
`,go=({children:i,title:r})=>(qe(r),a.jsx(V1,{children:i})),Z1=()=>{const{t:i}=k();return a.jsx(go,{title:i("Login Required"),children:a.jsxs("p",{children:[i("You must")," ",a.jsx(Q1,{href:"/incursions/char/add",children:i("Login")})," ",i("to view this page.")]})})},K1=()=>{const{t:i}=k();return a.jsxs(go,{title:i("Forbidden"),children:[a.jsx("h1",{children:i("403 Error")}),i("You are not allowed to view this page. Contact leadership to request access.")]})},F1=()=>{const{t:i}=k();return a.jsxs(go,{title:i("Page Not Found"),children:[a.jsx("h1",{children:i("404 Error")}),i("I warped to the FC twice, and all I got was this '404: page not found' error.")]})},ht=({component:i,loginRequired:r=!1,access:o=null})=>{const u=ue.useContext(Te);return!r&&!o?i:u?o&&!u.access[o]?a.jsx(K1,{}):i:a.jsx(Z1,{})};function J1(){return a.jsxs(i0,{children:[a.jsx(Se,{path:"/",element:a.jsx(t1,{})}),a.jsx(Se,{path:"/fits",element:a.jsx(Qv,{})}),a.jsx(Se,{path:"/isk-h",element:a.jsx(qy,{})}),a.jsx(Se,{path:"/isk-h/calc",element:a.jsx(Hy,{})}),a.jsx(Se,{path:"/pilot",element:a.jsx(pj,{})}),a.jsx(Se,{path:"/skills",element:a.jsx(Aj,{})}),a.jsx(Se,{path:"/skills/plans",element:a.jsx(bj,{})}),a.jsx(Se,{path:"/badges",element:a.jsx(Mv,{})}),a.jsx(Se,{path:"/guide",element:a.jsx(Dv,{})}),a.jsx(Se,{path:"/guide/:guideName",element:a.jsx(Av,{})}),a.jsx(Se,{path:"/legal",element:a.jsx(Gy,{})}),a.jsx(Se,{path:"/waitlist",element:a.jsx(ht,{component:a.jsx(e1,{}),loginRequired:!0})}),a.jsx(Se,{path:"/xup",element:a.jsx(ht,{component:a.jsx(wx,{}),loginRequired:!0})}),a.jsx(Se,{path:"/fc",element:a.jsx(ht,{component:a.jsx(Fv,{}),access:"incursions.waitlist_fleet_view"})}),a.jsx(Se,{path:"/fc/announcements",element:a.jsx(ht,{component:a.jsx(o1,{}),access:"incursions.waitlist_announcements_manage"})}),a.jsx(Se,{path:"/fc/badges",element:a.jsx(ht,{component:a.jsx(j1,{}),access:"incursions.waitlist_badges_manage"})}),a.jsx(Se,{path:"/fc/bans",element:a.jsx(ht,{component:a.jsx(R1,{}),access:"incursions.waitlist_bans_manage"})}),a.jsx(Se,{path:"/fc/commanders",element:a.jsx(ht,{component:a.jsx(X1,{}),access:"incursions.waitlist_commanders_view"})}),a.jsx(Se,{path:"/fc/documentation",element:a.jsx(ht,{component:a.jsx(ym,{}),access:"incursions.waitlist_documentation_view"})}),a.jsx(Se,{path:"/fc/fleet",element:a.jsx(ht,{component:a.jsx(Ty,{}),access:"incursions.waitlist_fleet_view"})}),a.jsx(Se,{path:"/fc/fleet/register",element:a.jsx(ht,{component:a.jsx(Dy,{}),access:"incursions.waitlist_fleet_view"})}),a.jsx(Se,{path:"/fc/fleet/history",element:a.jsx(ht,{component:a.jsx(Oy,{}),access:"incursions.waitlist_history_view"})}),a.jsx(Se,{path:"/fc/notes/add",element:a.jsx(ht,{component:a.jsx(Xy,{}),access:"incursions.waitlist_notes_manage"})}),a.jsx(Se,{path:"/fc/search",element:a.jsx(ht,{component:a.jsx(Ej,{}),access:"incursions.waitlist_search"})}),a.jsx(Se,{path:"/fc/stats",element:a.jsx(ht,{component:a.jsx(kj,{}),access:"incursions.waitlist_stats_view"})}),a.jsx(Se,{path:"/fc/trainee",element:a.jsx(ht,{component:a.jsx(ym,{}),access:"incursions.waitlist_documentation_view"})}),a.jsx(Se,{path:"*",element:a.jsx(F1,{})})]})}const W1="/static/incursions/waitlist/notification-icon.png",I1="/static/incursions/waitlist/bell-ringing-04.mp3",Yu="EventNotifierSettings";function Hm(i){const r=JSON.parse(i.data);window.Notification&&Notification.permission==="granted"?new Notification(r.message,{silent:!0}):window.Notification&&Notification.permission==="default"&&Notification.requestPermission()}function P1(){const{t:i}=k(),[r,o]=b.useState(!1),[u,d]=b.useState(!1),f=b.useContext(ki),m=b.useRef(null),[x,p]=b.useState(()=>window.localStorage&&window.localStorage.getItem(Yu)?JSON.parse(window.localStorage.getItem(Yu)):{});b.useEffect(()=>{window.localStorage&&window.localStorage.setItem(Yu,JSON.stringify(x))},[x]),b.useEffect(()=>{m&&(u?m.current.play():m.current.pause())},[u,m]);const v=b.useCallback(j=>{window.Notification&&Notification.permission==="granted"?new Notification("TLA",{body:j.data,icon:W1,tag:j.data,renotify:!0,timestamp:Math.floor(Date.now())}):window.Notification&&Notification.permission==="default"&&Notification.requestPermission(),x.enableSound&&m.current&&d(j.data)},[x]);return b.useEffect(()=>{if(f!=null)return f.addEventListener("wakeup",v),f.addEventListener("message",Hm),()=>{f.removeEventListener("wakeup",v),f.removeEventListener("message",Hm)}},[v,f]),a.jsxs(a.Fragment,{children:[a.jsx(ze,{open:r,setOpen:o,children:a.jsxs(we,{children:[a.jsx("p",{children:a.jsxs("label",{children:[a.jsx("input",{checked:x.enableSound,onChange:j=>p({...x,enableSound:!!j.target.checked}),type:"checkbox"})," ",i("Enable sound notifications")]})}),a.jsx(q,{onClick:()=>v({data:i("This is a test alert")}),children:i("Send test notification")})]})}),a.jsx(ze,{open:u,setOpen:d,children:a.jsxs(we,{style:{minHeight:"50px",height:"auto"},children:[a.jsx("p",{style:{marginBottom:"20px"},children:u}),a.jsx(q,{onClick:()=>d(!1),$variant:"success",children:i("OK")}),a.jsx("audio",{ref:m,loop:!0,children:a.jsx("source",{src:I1,type:"audio/mp3"})})]})}),a.jsx(ix,{onClick:()=>o(!0),title:x.enableSound?i("Sound alerts are currently enabled"):i("Sound alerts are currently disabled"),children:a.jsx(ae,{fixedWidth:!0,icon:x.enableSound?Q0:V0})})]})}const eb=Object.keys(st);function tb({theme:i,setTheme:r,sticker:o,setSticker:u}){const{t:d}=k(),[f,m]=b.useState(!1),x=()=>{u(!o)};return a.jsxs(a.Fragment,{children:[a.jsx(ze,{open:f,setOpen:m,children:a.jsxs(we,{children:[a.jsx(_e,{children:d("Theme select")}),eb.map(p=>a.jsx("div",{children:a.jsxs("label",{children:[a.jsx(av,{value:p,checked:i===p,onChange:v=>r(v.target.value)})," ",d(p)]})},p)),st[i].sticker&&a.jsx(q,{style:{marginTop:"0.5em"},onClick:x,children:d(o?"Disable Sticker":"Enable Sticker")})]})}),a.jsx(ix,{onClick:()=>m(!0),children:a.jsx(ae,{fixedWidth:!0,icon:["dark","AMOLED"].includes(i)?Z0:i==="Specialist"?K0:F0})})]})}const Tn=C(jt)`
  padding: 0 1em;
  color: #bbb;
  text-decoration: none;
  text-shadow: 2px 2px 5px rgba(0, 0, 0, 0.5);
  &:hover {
    color: #cccccc;
    border-radius: 2px;
  }
  &.active {
    color: #eeeeee;
    text-shadow: 0px 0px 5px rgba(255, 255, 255, 0.5);
  }
  @media (max-width: 480px) {
    padding: 1em;
    &.active {
      background-color: #454545;
      border-radius: 4px;
    }
  }
`,nb=C.div`
  * {
    display: ${i=>i.open?"flex":"none"};
    flex-wrap: wrap;
    flex-direction: column;
  }
`,ab=C.div`
  padding: 0.3em;
  width: 100%;
  transition-delay: 2s;
  opacity: ${i=>i.open?"1":"0"};
  height: ${i=>i.open?"100%":"0"};
  transition: all 0.3s;
  background-color: #2e2e2e;
  border-radius: 0 0 5px 5px;
`;function lb({isOpen:i,whoami:r}){return a.jsx(ab,{open:i,children:a.jsx(nb,{open:i,children:a.jsx(Mx,{whoami:r})})})}function ib({isOpen:i,setIsOpen:r}){const o=un();return b.useEffect(()=>{r(!1)},[o,r]),a.jsx(a.Fragment,{children:i?a.jsx(fm,{onClick:()=>r(!1),children:a.jsx(ae,{icon:eo})}):a.jsx(fm,{onClick:()=>r(!0),children:a.jsx(ae,{icon:J0})})})}function Mx({whoami:i}){var o,u;const{t:r}=k();return a.jsxs(a.Fragment,{children:[a.jsx(Tn,{to:"/",end:!0,className:({isActive:d})=>d?"active":"",children:r("Home")}),i&&a.jsx(Tn,{to:"/waitlist",end:!0,className:({isActive:d})=>d?"active":"",children:r("Waitlist")}),a.jsx(Tn,{to:"/guide",end:!0,className:({isActive:d})=>d?"active":"",children:r("Guides")}),a.jsx(Tn,{to:"/fits?Tier=Mainline",end:!0,className:({isActive:d})=>d?"active":"",children:r("Fits")}),a.jsx(Tn,{to:"/skills?ship=Paladin",end:!0,className:({isActive:d})=>d?"active":"",children:r("Skills")}),a.jsx(Tn,{to:"/isk-h/calc",end:!0,className:({isActive:d})=>d?"active":"",children:r("ISK/h")}),((o=i==null?void 0:i.access)==null?void 0:o["incursions.waitlist_fleet_view"])&&a.jsxs(a.Fragment,{children:[a.jsx(Tn,{to:"/fc/fleet",end:!0,className:({isActive:d})=>d?"active":"",children:r("Fleet")}),a.jsx(Tn,{to:"/fc",end:!0,className:({isActive:d})=>d?"active":"",children:r("FC")})]}),((u=i==null?void 0:i.access)==null?void 0:u["incursions.waitlist_search"])&&a.jsx(Tn,{to:"/fc/search",end:!0,className:({isActive:d})=>d?"active":"",children:r("Search")})]})}const sb="/static/incursions/waitlist/banner.png",cb=C.div`
  background-image: url(${sb});
  background-size: 100% auto;
  background-repeat: no-repeat;
  padding: 0.5em;
  border-radius: 0 0 20px 20px;
  box-shadow: 2px 2px 10px rgba(0, 0, 0, 0.3);
  transition: border-radius 0.1s ease-in-out;
  padding-top: 6.5em;

  @media (max-width: 700px) {
    background-size: auto 100%;
    border-radius: ${i=>i.$mobileopen?"unset":"0 0 20px 20px"};
  }
`,rb=C(jt)`
  height: 2.5em;

  img {
    &:hover {
      opacity: 0.7;
    }
  }

  &.active {
    font-weight: bold;
  }
`,Gt=C.div`
  margin-bottom: 2em;
`;Gt.LogoLink=C(jt)`
  margin-right: 2em;
  flex-grow: 0;
  line-height: 0;

  @media (max-width: 480px) {
    margin-right: unset;
    margin-left: auto;
  }

  &.active {
    font-weight: bold;
  }
`;Gt.Logo=C.img`
  width: 150px;
  filter: ${i=>i.theme.logo.filter};
`;Gt.Menu=C.div`
  display: flex;
  flex-wrap: wrap;
  align-items: center;
  flex-grow: 1;
`;Gt.Link=C(jt)`
  padding: 1em;
  color: ${i=>i.theme.colors.accent4};
  text-decoration: none;

  &.active {
    color: ${i=>i.theme.colors.active};
    font-weight: bold;
  }
`;Gt.End=C.div`
  margin-left: auto;
  display: flex;
  flex-wrap: wrap;
  align-items: center;

  > :not(:last-child) {
    @media (max-width: 480px) {
      margin-bottom: 0.4em;
    }
  }
`;Gt.Main=C.div`
  display: flex;
  flex-wrap: wrap;

  @media (max-width: 480px) {
    display: none;
  }
`;Gt.Name=C.div`
  margin-right: 2em;

  @media (max-width: 480px) {
    margin-right: 0em;
    width: 100%;
  }
`;function ub({onChangeCharacter:i,theme:r,setTheme:o,sticker:u,setSticker:d}){const[f,m]=ue.useState(!1),[x,p]=ue.useState(window.innerWidth),{t:v}=k();return ue.useEffect(()=>{const j=()=>p(window.innerWidth);return window.addEventListener("resize",j),()=>window.removeEventListener("resize",j)},[]),a.jsx(Te.Consumer,{children:j=>a.jsxs(Gt,{children:[a.jsx(cb,{$mobileopen:f,children:a.jsxs(Gt.Menu,{children:[a.jsx(Gt.Main,{children:a.jsx(Mx,{whoami:j})}),a.jsxs(Gt.End,{children:[j&&a.jsx(Gt.Name,{children:a.jsxs(hm,{$fixed:!0,children:[a.jsx(rb,{to:"/pilot",end:!0,className:({isActive:O})=>O?"active":"",children:a.jsx("img",{style:{maxHeight:"100%",borderRadius:"20px 0 0 20px"},src:`https://images.evetech.net/characters/${j.current.character_id??1}/portrait?size=128`,alt:"Character Portrait"})}),a.jsx(lv,{value:j.current.character_id,onChange:O=>i&&i(parseInt(O.target.value)),style:{flexGrow:"1",border:"unset"},children:j.characters.map(O=>a.jsx("option",{value:O.character_id,children:O.character_name},O.character_id))}),a.jsx(ln,{as:"a",href:"/incursions/char/add",children:"+"})]})}),a.jsxs(hm,{children:[x<481&&a.jsx(ib,{isOpen:f,setIsOpen:m}),a.jsx(P1,{}),a.jsx(tb,{theme:r,setTheme:o,sticker:u,setSticker:d}),j?a.jsx(nv,{as:"button",onClick:()=>window.location.href="/incursions/waitlist/auth/logout",children:v("Logout")}):a.jsx(ln,{as:"a",href:"/incursions/char/add",$variant:"primary",children:v("Login")})]})]})]})}),a.jsx(lb,{isOpen:f,whoami:j})]})})}const ob=C.div`
  background: ${i=>i.theme.colors.secondary.color};
  box-shadow: 0px 3px ${i=>i.theme.colors.shadow};
  color: ${i=>i.theme.colors.text};
  margin-bottom: 3.5px;
  padding: 12px;
  position: relative;

  &[data-alert="true"] {
    background: ${i=>i.theme.colors.danger.color};
    color: ${i=>i.theme.colors.danger.text};
  }

  small {
    font-style: italic;
    font-size: small;
  }

  .close {
    position: absolute;
    right: 15px;
    top: 15px;
    width: 32px;
    height: 32px;
    opacity: 0.6;
  }
  .close:hover {
    opacity: 1;
    transition: ease-in-out 0.2s;
    cursor: pointer;
  }
  .close:before,
  .close:after {
    position: absolute;
    left: 15px;
    content: " ";
    height: 15px;
    width: 2px;
    background-color: ${i=>i.theme.colors.secondary.text};
  }
  .close:before {
    transform: rotate(45deg);
  }
  .close:after {
    transform: rotate(-45deg);
  }
`,db=C(ct)`
  padding-left: 42px;
  p {
    margin-bottom: 0em;
  }
  h1,
  h2,
  h3,
  h4 {
    margin-top: 0em;
  }
`,fb=(i,r)=>{const o=ue.useRef();ue.useEffect(()=>{o.current=i},[i]),ue.useEffect(()=>{function u(){o.current()}{const d=setInterval(u,r);return()=>clearInterval(d)}},[r])},hb=()=>{const i=b.useContext(Te),r=b.useContext(ki),[,o]=ue.useReducer(M=>M+1,0),{t:u}=k(),[d,f]=b.useState([]),[m,x]=b.useState([]),[p,v]=b.useState(window.location.pathname),j=un();ue.useEffect(()=>{v(j.pathname)},[j]);const O=M=>{f(JSON.parse(M.data)??[])};ue.useEffect(()=>{if(r)return r.addEventListener("announcement;new",O),r.addEventListener("announcement;updated",O),()=>{r.removeEventListener("announcement;new",O),r.removeEventListener("announcement;updated",O)}},[r]);const D=M=>{let L=JSON.parse(window.localStorage.getItem("ignore-announcements"))??{};for(const[U,H]in L)H<new Date&&delete L[U];M in L||(L[M]=new Date().setDate(new Date().getDate()+30)),window.localStorage.setItem("ignore-announcements",JSON.stringify(L)),x(L)};return ue.useEffect(()=>{async function M(){x(JSON.parse(window.localStorage.getItem("ignore-announcements"))??{});const L=await W("/incursions/api/announcements",{});f(Array.isArray(L)?L:[])}M()},[]),fb(()=>o(),1e3*60),d.length===0?null:a.jsx("div",{style:{marginBottom:"10px"},children:d==null?void 0:d.map((M,L)=>{if(M.id in m)return null;const U=M!=null&&M.pages?JSON.parse(M.pages):[];if(U.length>0){let $=_x.filter(se=>U.includes(se.name.toLowerCase())),J=!1;if($.forEach(se=>{p.startsWith(se.value.toLowerCase())&&(J=!0)}),!J)return null}const H=new Date(M.created_at);return a.jsxs(ob,{"data-alert":M.is_alert,children:[a.jsx(He,{...M.created_by,noLink:!(i!=null&&i.access["incursions.waitlist_announcements_manage"])}),", ",u("{{time}} ago",{time:Sc(H)}),a.jsx("span",{className:"close",onClick:()=>D(M.id)}),a.jsx(db,{children:a.jsx(Hi,{children:M.message})}),(i==null?void 0:i.access["incursions.waitlist_announcements_manage"])&&a.jsxs("small",{style:{paddingLeft:"42px"},children:[u("Displayed on"),": ",U.length>0?U.join(", "):u("all pages"),"."]})]},L)})})};E0.use(A0).use(D0).use(M0).init({detection:{order:["htmlTag","querystring","cookie","localStorage","sessionStorage","navigator","path","subdomain"],htmlTag:document.getElementById("root")},fallbackLng:"en",interpolation:{escapeValue:!1},react:{useSuspense:!1},backend:{loadPath:"/static/incursions/waitlist/i18n/{{lng}}/{{ns}}.json"}});const mb=_0`
  html {
    // overflow-y: scroll;
    text-rendering: optimizeLegibility;
    font-size: 16px;
    min-width: 300px;
  }
  body {
    min-height: 100vh;
    background-color: ${i=>i.theme.colors.background};
    color: ${i=>i.theme.colors.text};
    font-family: ${i=>i.theme.font.family};
    line-height: 1.5;
    font-weight: 400;
  overflow-y: scroll;
  ${i=>i.sticker&&i.theme.sticker&&`
    &:before {
      content:'';
      pointer-events:none;
      position:fixed;
      z-index:100;
      width:100%;
      height:100%;
      background-position:100% 100%;
      background-repeat: no-repeat;
      opacity:1;
      background-size: 18%;
        background-image: url(${i.theme.sticker});
    }
  `}
  }
  em, i {
    font-style: italic;
  }
  strong, b {
    font-weight: bold;
  }
`;class xb extends b.Component{constructor(o){super(o);Hu(this,"addToast",o=>{this.setState({toasts:[...this.state.toasts,o]})});Hu(this,"changeCharacter",o=>{var u={...this.state.auth},d=this.state.auth.characters.filter(f=>f.character_id===o)[0];u.current=d,this.setState({auth:u}),localStorage.setItem("selectedCharacter",o)});this.state={auth:null,toasts:[],events:null,eventErrors:0,theme:window.localStorage&&window.localStorage.getItem("theme")in st&&window.localStorage.getItem("theme")||"Light",sticker:(window.localStorage&&window.localStorage.getItem("Sticker")&&window.localStorage.getItem("Sticker")||"true")==="true"}}componentDidUpdate(){if(this.state.auth&&!this.state.events){var o=new EventSource("/incursions/api/sse/stream");o.addEventListener("open",u=>{this.setState({eventErrors:0})}),o.addEventListener("error",u=>{o.close(),setTimeout(()=>{this.setState({events:null,eventErrors:this.state.eventErrors+1})},this.state.eventErrors*5e3+Math.random()*1e4)}),this.setState({events:o})}}componentDidMount(){W0(o=>this.setState({auth:o}))}render(){return a.jsx(b.StrictMode,{children:a.jsxs(T0,{theme:st[this.state.theme],children:[a.jsx(mb,{sticker:this.state.sticker}),a.jsx(ie.Provider,{value:this.addToast,children:a.jsx(ki.Provider,{value:this.state.events,children:a.jsx(Te.Provider,{value:this.state.auth,children:a.jsx(s0,{basename:"/incursions/waitlist",children:a.jsxs(c0,{children:[a.jsx(Oa,{children:a.jsx(ub,{onChangeCharacter:o=>this.changeCharacter(o),theme:this.state.theme,setTheme:o=>{this.setState({theme:o}),window.localStorage&&window.localStorage.setItem("theme",o)},sticker:this.state.sticker,setSticker:o=>{this.setState({sticker:o}),window.localStorage&&window.localStorage.setItem("Sticker",o)}})}),a.jsx(Oa,{children:a.jsx(hb,{})}),a.jsx(Oa,{children:a.jsx(J1,{})}),a.jsx(Oa,{children:a.jsx(tv,{toasts:this.state.toasts,setToasts:o=>this.setState({toasts:o})})})]})})})})})]})})}}var Xu={exports:{}},Oi={},Qu={exports:{}},Vu={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var qm;function gb(){return qm||(qm=1,function(i){function r(B,G){var F=B.length;B.push(G);e:for(;0<F;){var Ee=F-1>>>1,Ae=B[Ee];if(0<d(Ae,G))B[Ee]=G,B[F]=Ae,F=Ee;else break e}}function o(B){return B.length===0?null:B[0]}function u(B){if(B.length===0)return null;var G=B[0],F=B.pop();if(F!==G){B[0]=F;e:for(var Ee=0,Ae=B.length,dt=Ae>>>1;Ee<dt;){var Ne=2*(Ee+1)-1,ge=B[Ne],Ie=Ne+1,Jt=B[Ie];if(0>d(ge,F))Ie<Ae&&0>d(Jt,ge)?(B[Ee]=Jt,B[Ie]=F,Ee=Ie):(B[Ee]=ge,B[Ne]=F,Ee=Ne);else if(Ie<Ae&&0>d(Jt,F))B[Ee]=Jt,B[Ie]=F,Ee=Ie;else break e}}return G}function d(B,G){var F=B.sortIndex-G.sortIndex;return F!==0?F:B.id-G.id}if(i.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var f=performance;i.unstable_now=function(){return f.now()}}else{var m=Date,x=m.now();i.unstable_now=function(){return m.now()-x}}var p=[],v=[],j=1,O=null,D=3,M=!1,L=!1,U=!1,H=!1,$=typeof setTimeout=="function"?setTimeout:null,J=typeof clearTimeout=="function"?clearTimeout:null,se=typeof setImmediate<"u"?setImmediate:null;function We(B){for(var G=o(v);G!==null;){if(G.callback===null)u(v);else if(G.startTime<=B)u(v),G.sortIndex=G.expirationTime,r(p,G);else break;G=o(v)}}function de(B){if(U=!1,We(B),!L)if(o(p)!==null)L=!0,fe||(fe=!0,zt());else{var G=o(v);G!==null&&on(de,G.startTime-B)}}var fe=!1,mt=-1,St=5,$e=-1;function ua(){return H?!0:!(i.unstable_now()-$e<St)}function Ra(){if(H=!1,fe){var B=i.unstable_now();$e=B;var G=!0;try{e:{L=!1,U&&(U=!1,J(mt),mt=-1),M=!0;var F=D;try{t:{for(We(B),O=o(p);O!==null&&!(O.expirationTime>B&&ua());){var Ee=O.callback;if(typeof Ee=="function"){O.callback=null,D=O.priorityLevel;var Ae=Ee(O.expirationTime<=B);if(B=i.unstable_now(),typeof Ae=="function"){O.callback=Ae,We(B),G=!0;break t}O===o(p)&&u(p),We(B)}else u(p);O=o(p)}if(O!==null)G=!0;else{var dt=o(v);dt!==null&&on(de,dt.startTime-B),G=!1}}break e}finally{O=null,D=F,M=!1}G=void 0}}finally{G?zt():fe=!1}}}var zt;if(typeof se=="function")zt=function(){se(Ra)};else if(typeof MessageChannel<"u"){var Qi=new MessageChannel,Dl=Qi.port2;Qi.port1.onmessage=Ra,zt=function(){Dl.postMessage(null)}}else zt=function(){$(Ra,0)};function on(B,G){mt=$(function(){B(i.unstable_now())},G)}i.unstable_IdlePriority=5,i.unstable_ImmediatePriority=1,i.unstable_LowPriority=4,i.unstable_NormalPriority=3,i.unstable_Profiling=null,i.unstable_UserBlockingPriority=2,i.unstable_cancelCallback=function(B){B.callback=null},i.unstable_forceFrameRate=function(B){0>B||125<B?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):St=0<B?Math.floor(1e3/B):5},i.unstable_getCurrentPriorityLevel=function(){return D},i.unstable_next=function(B){switch(D){case 1:case 2:case 3:var G=3;break;default:G=D}var F=D;D=G;try{return B()}finally{D=F}},i.unstable_requestPaint=function(){H=!0},i.unstable_runWithPriority=function(B,G){switch(B){case 1:case 2:case 3:case 4:case 5:break;default:B=3}var F=D;D=B;try{return G()}finally{D=F}},i.unstable_scheduleCallback=function(B,G,F){var Ee=i.unstable_now();switch(typeof F=="object"&&F!==null?(F=F.delay,F=typeof F=="number"&&0<F?Ee+F:Ee):F=Ee,B){case 1:var Ae=-1;break;case 2:Ae=250;break;case 5:Ae=1073741823;break;case 4:Ae=1e4;break;default:Ae=5e3}return Ae=F+Ae,B={id:j++,callback:G,priorityLevel:B,startTime:F,expirationTime:Ae,sortIndex:-1},F>Ee?(B.sortIndex=F,r(v,B),o(p)===null&&B===o(v)&&(U?(J(mt),mt=-1):U=!0,on(de,F-Ee))):(B.sortIndex=Ae,r(p,B),L||M||(L=!0,fe||(fe=!0,zt()))),B},i.unstable_shouldYield=ua,i.unstable_wrapCallback=function(B){var G=D;return function(){var F=D;D=G;try{return B.apply(this,arguments)}finally{D=F}}}}(Vu)),Vu}var $m;function pb(){return $m||($m=1,Qu.exports=gb()),Qu.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Gm;function vb(){if(Gm)return Oi;Gm=1;var i=pb(),r=Qm(),o=nx();function u(e){var t="https://react.dev/errors/"+e;if(1<arguments.length){t+="?args[]="+encodeURIComponent(arguments[1]);for(var n=2;n<arguments.length;n++)t+="&args[]="+encodeURIComponent(arguments[n])}return"Minified React error #"+e+"; visit "+t+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function d(e){return!(!e||e.nodeType!==1&&e.nodeType!==9&&e.nodeType!==11)}function f(e){var t=e,n=e;if(e.alternate)for(;t.return;)t=t.return;else{e=t;do t=e,(t.flags&4098)!==0&&(n=t.return),e=t.return;while(e)}return t.tag===3?n:null}function m(e){if(e.tag===13){var t=e.memoizedState;if(t===null&&(e=e.alternate,e!==null&&(t=e.memoizedState)),t!==null)return t.dehydrated}return null}function x(e){if(f(e)!==e)throw Error(u(188))}function p(e){var t=e.alternate;if(!t){if(t=f(e),t===null)throw Error(u(188));return t!==e?null:e}for(var n=e,l=t;;){var s=n.return;if(s===null)break;var c=s.alternate;if(c===null){if(l=s.return,l!==null){n=l;continue}break}if(s.child===c.child){for(c=s.child;c;){if(c===n)return x(s),e;if(c===l)return x(s),t;c=c.sibling}throw Error(u(188))}if(n.return!==l.return)n=s,l=c;else{for(var h=!1,g=s.child;g;){if(g===n){h=!0,n=s,l=c;break}if(g===l){h=!0,l=s,n=c;break}g=g.sibling}if(!h){for(g=c.child;g;){if(g===n){h=!0,n=c,l=s;break}if(g===l){h=!0,l=c,n=s;break}g=g.sibling}if(!h)throw Error(u(189))}}if(n.alternate!==l)throw Error(u(190))}if(n.tag!==3)throw Error(u(188));return n.stateNode.current===n?e:t}function v(e){var t=e.tag;if(t===5||t===26||t===27||t===6)return e;for(e=e.child;e!==null;){if(t=v(e),t!==null)return t;e=e.sibling}return null}var j=Object.assign,O=Symbol.for("react.element"),D=Symbol.for("react.transitional.element"),M=Symbol.for("react.portal"),L=Symbol.for("react.fragment"),U=Symbol.for("react.strict_mode"),H=Symbol.for("react.profiler"),$=Symbol.for("react.provider"),J=Symbol.for("react.consumer"),se=Symbol.for("react.context"),We=Symbol.for("react.forward_ref"),de=Symbol.for("react.suspense"),fe=Symbol.for("react.suspense_list"),mt=Symbol.for("react.memo"),St=Symbol.for("react.lazy"),$e=Symbol.for("react.activity"),ua=Symbol.for("react.memo_cache_sentinel"),Ra=Symbol.iterator;function zt(e){return e===null||typeof e!="object"?null:(e=Ra&&e[Ra]||e["@@iterator"],typeof e=="function"?e:null)}var Qi=Symbol.for("react.client.reference");function Dl(e){if(e==null)return null;if(typeof e=="function")return e.$$typeof===Qi?null:e.displayName||e.name||null;if(typeof e=="string")return e;switch(e){case L:return"Fragment";case H:return"Profiler";case U:return"StrictMode";case de:return"Suspense";case fe:return"SuspenseList";case $e:return"Activity"}if(typeof e=="object")switch(e.$$typeof){case M:return"Portal";case se:return(e.displayName||"Context")+".Provider";case J:return(e._context.displayName||"Context")+".Consumer";case We:var t=e.render;return e=e.displayName,e||(e=t.displayName||t.name||"",e=e!==""?"ForwardRef("+e+")":"ForwardRef"),e;case mt:return t=e.displayName||null,t!==null?t:Dl(e.type)||"Memo";case St:t=e._payload,e=e._init;try{return Dl(e(t))}catch{}}return null}var on=Array.isArray,B=r.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,G=o.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,F={pending:!1,data:null,method:null,action:null},Ee=[],Ae=-1;function dt(e){return{current:e}}function Ne(e){0>Ae||(e.current=Ee[Ae],Ee[Ae]=null,Ae--)}function ge(e,t){Ae++,Ee[Ae]=e.current,e.current=t}var Ie=dt(null),Jt=dt(null),On=dt(null),Vi=dt(null);function Zi(e,t){switch(ge(On,t),ge(Jt,e),ge(Ie,null),t.nodeType){case 9:case 11:e=(e=t.documentElement)&&(e=e.namespaceURI)?kh(e):0;break;default:if(e=t.tagName,t=t.namespaceURI)t=kh(t),e=Hh(t,e);else switch(e){case"svg":e=1;break;case"math":e=2;break;default:e=0}}Ne(Ie),ge(Ie,e)}function Ua(){Ne(Ie),Ne(Jt),Ne(On)}function Cc(e){e.memoizedState!==null&&ge(Vi,e);var t=Ie.current,n=Hh(t,e.type);t!==n&&(ge(Jt,e),ge(Ie,n))}function Ki(e){Jt.current===e&&(Ne(Ie),Ne(Jt)),Vi.current===e&&(Ne(Vi),Si._currentValue=F)}var _c=Object.prototype.hasOwnProperty,Tc=i.unstable_scheduleCallback,Ec=i.unstable_cancelCallback,Ox=i.unstable_shouldYield,zx=i.unstable_requestPaint,Wt=i.unstable_now,Nx=i.unstable_getCurrentPriorityLevel,po=i.unstable_ImmediatePriority,vo=i.unstable_UserBlockingPriority,Fi=i.unstable_NormalPriority,Bx=i.unstable_LowPriority,yo=i.unstable_IdlePriority,Rx=i.log,Ux=i.unstable_setDisableYieldValue,Ml=null,wt=null;function zn(e){if(typeof Rx=="function"&&Ux(e),wt&&typeof wt.setStrictMode=="function")try{wt.setStrictMode(Ml,e)}catch{}}var Ct=Math.clz32?Math.clz32:Hx,Lx=Math.log,kx=Math.LN2;function Hx(e){return e>>>=0,e===0?32:31-(Lx(e)/kx|0)|0}var Ji=256,Wi=4194304;function oa(e){var t=e&42;if(t!==0)return t;switch(e&-e){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return e&4194048;case 4194304:case 8388608:case 16777216:case 33554432:return e&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return e}}function Ii(e,t,n){var l=e.pendingLanes;if(l===0)return 0;var s=0,c=e.suspendedLanes,h=e.pingedLanes;e=e.warmLanes;var g=l&134217727;return g!==0?(l=g&~c,l!==0?s=oa(l):(h&=g,h!==0?s=oa(h):n||(n=g&~e,n!==0&&(s=oa(n))))):(g=l&~c,g!==0?s=oa(g):h!==0?s=oa(h):n||(n=l&~e,n!==0&&(s=oa(n)))),s===0?0:t!==0&&t!==s&&(t&c)===0&&(c=s&-s,n=t&-t,c>=n||c===32&&(n&4194048)!==0)?t:s}function Ol(e,t){return(e.pendingLanes&~(e.suspendedLanes&~e.pingedLanes)&t)===0}function qx(e,t){switch(e){case 1:case 2:case 4:case 8:case 64:return t+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return t+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function jo(){var e=Ji;return Ji<<=1,(Ji&4194048)===0&&(Ji=256),e}function bo(){var e=Wi;return Wi<<=1,(Wi&62914560)===0&&(Wi=4194304),e}function Ac(e){for(var t=[],n=0;31>n;n++)t.push(e);return t}function zl(e,t){e.pendingLanes|=t,t!==268435456&&(e.suspendedLanes=0,e.pingedLanes=0,e.warmLanes=0)}function $x(e,t,n,l,s,c){var h=e.pendingLanes;e.pendingLanes=n,e.suspendedLanes=0,e.pingedLanes=0,e.warmLanes=0,e.expiredLanes&=n,e.entangledLanes&=n,e.errorRecoveryDisabledLanes&=n,e.shellSuspendCounter=0;var g=e.entanglements,y=e.expirationTimes,T=e.hiddenUpdates;for(n=h&~n;0<n;){var z=31-Ct(n),R=1<<z;g[z]=0,y[z]=-1;var E=T[z];if(E!==null)for(T[z]=null,z=0;z<E.length;z++){var A=E[z];A!==null&&(A.lane&=-536870913)}n&=~R}l!==0&&So(e,l,0),c!==0&&s===0&&e.tag!==0&&(e.suspendedLanes|=c&~(h&~t))}function So(e,t,n){e.pendingLanes|=t,e.suspendedLanes&=~t;var l=31-Ct(t);e.entangledLanes|=t,e.entanglements[l]=e.entanglements[l]|1073741824|n&4194090}function wo(e,t){var n=e.entangledLanes|=t;for(e=e.entanglements;n;){var l=31-Ct(n),s=1<<l;s&t|e[l]&t&&(e[l]|=t),n&=~s}}function Dc(e){switch(e){case 2:e=1;break;case 8:e=4;break;case 32:e=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:e=128;break;case 268435456:e=134217728;break;default:e=0}return e}function Mc(e){return e&=-e,2<e?8<e?(e&134217727)!==0?32:268435456:8:2}function Co(){var e=G.p;return e!==0?e:(e=window.event,e===void 0?32:lm(e.type))}function Gx(e,t){var n=G.p;try{return G.p=e,t()}finally{G.p=n}}var Nn=Math.random().toString(36).slice(2),rt="__reactFiber$"+Nn,xt="__reactProps$"+Nn,La="__reactContainer$"+Nn,Oc="__reactEvents$"+Nn,Yx="__reactListeners$"+Nn,Xx="__reactHandles$"+Nn,_o="__reactResources$"+Nn,Nl="__reactMarker$"+Nn;function zc(e){delete e[rt],delete e[xt],delete e[Oc],delete e[Yx],delete e[Xx]}function ka(e){var t=e[rt];if(t)return t;for(var n=e.parentNode;n;){if(t=n[La]||n[rt]){if(n=t.alternate,t.child!==null||n!==null&&n.child!==null)for(e=Yh(e);e!==null;){if(n=e[rt])return n;e=Yh(e)}return t}e=n,n=e.parentNode}return null}function Ha(e){if(e=e[rt]||e[La]){var t=e.tag;if(t===5||t===6||t===13||t===26||t===27||t===3)return e}return null}function Bl(e){var t=e.tag;if(t===5||t===26||t===27||t===6)return e.stateNode;throw Error(u(33))}function qa(e){var t=e[_o];return t||(t=e[_o]={hoistableStyles:new Map,hoistableScripts:new Map}),t}function Pe(e){e[Nl]=!0}var To=new Set,Eo={};function da(e,t){$a(e,t),$a(e+"Capture",t)}function $a(e,t){for(Eo[e]=t,e=0;e<t.length;e++)To.add(t[e])}var Qx=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),Ao={},Do={};function Vx(e){return _c.call(Do,e)?!0:_c.call(Ao,e)?!1:Qx.test(e)?Do[e]=!0:(Ao[e]=!0,!1)}function Pi(e,t,n){if(Vx(t))if(n===null)e.removeAttribute(t);else{switch(typeof n){case"undefined":case"function":case"symbol":e.removeAttribute(t);return;case"boolean":var l=t.toLowerCase().slice(0,5);if(l!=="data-"&&l!=="aria-"){e.removeAttribute(t);return}}e.setAttribute(t,""+n)}}function es(e,t,n){if(n===null)e.removeAttribute(t);else{switch(typeof n){case"undefined":case"function":case"symbol":case"boolean":e.removeAttribute(t);return}e.setAttribute(t,""+n)}}function dn(e,t,n,l){if(l===null)e.removeAttribute(n);else{switch(typeof l){case"undefined":case"function":case"symbol":case"boolean":e.removeAttribute(n);return}e.setAttributeNS(t,n,""+l)}}var Nc,Mo;function Ga(e){if(Nc===void 0)try{throw Error()}catch(n){var t=n.stack.trim().match(/\n( *(at )?)/);Nc=t&&t[1]||"",Mo=-1<n.stack.indexOf(`
    at`)?" (<anonymous>)":-1<n.stack.indexOf("@")?"@unknown:0:0":""}return`
`+Nc+e+Mo}var Bc=!1;function Rc(e,t){if(!e||Bc)return"";Bc=!0;var n=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var l={DetermineComponentFrameRoot:function(){try{if(t){var R=function(){throw Error()};if(Object.defineProperty(R.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(R,[])}catch(A){var E=A}Reflect.construct(e,[],R)}else{try{R.call()}catch(A){E=A}e.call(R.prototype)}}else{try{throw Error()}catch(A){E=A}(R=e())&&typeof R.catch=="function"&&R.catch(function(){})}}catch(A){if(A&&E&&typeof A.stack=="string")return[A.stack,E.stack]}return[null,null]}};l.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var s=Object.getOwnPropertyDescriptor(l.DetermineComponentFrameRoot,"name");s&&s.configurable&&Object.defineProperty(l.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var c=l.DetermineComponentFrameRoot(),h=c[0],g=c[1];if(h&&g){var y=h.split(`
`),T=g.split(`
`);for(s=l=0;l<y.length&&!y[l].includes("DetermineComponentFrameRoot");)l++;for(;s<T.length&&!T[s].includes("DetermineComponentFrameRoot");)s++;if(l===y.length||s===T.length)for(l=y.length-1,s=T.length-1;1<=l&&0<=s&&y[l]!==T[s];)s--;for(;1<=l&&0<=s;l--,s--)if(y[l]!==T[s]){if(l!==1||s!==1)do if(l--,s--,0>s||y[l]!==T[s]){var z=`
`+y[l].replace(" at new "," at ");return e.displayName&&z.includes("<anonymous>")&&(z=z.replace("<anonymous>",e.displayName)),z}while(1<=l&&0<=s);break}}}finally{Bc=!1,Error.prepareStackTrace=n}return(n=e?e.displayName||e.name:"")?Ga(n):""}function Zx(e){switch(e.tag){case 26:case 27:case 5:return Ga(e.type);case 16:return Ga("Lazy");case 13:return Ga("Suspense");case 19:return Ga("SuspenseList");case 0:case 15:return Rc(e.type,!1);case 11:return Rc(e.type.render,!1);case 1:return Rc(e.type,!0);case 31:return Ga("Activity");default:return""}}function Oo(e){try{var t="";do t+=Zx(e),e=e.return;while(e);return t}catch(n){return`
Error generating stack: `+n.message+`
`+n.stack}}function Nt(e){switch(typeof e){case"bigint":case"boolean":case"number":case"string":case"undefined":return e;case"object":return e;default:return""}}function zo(e){var t=e.type;return(e=e.nodeName)&&e.toLowerCase()==="input"&&(t==="checkbox"||t==="radio")}function Kx(e){var t=zo(e)?"checked":"value",n=Object.getOwnPropertyDescriptor(e.constructor.prototype,t),l=""+e[t];if(!e.hasOwnProperty(t)&&typeof n<"u"&&typeof n.get=="function"&&typeof n.set=="function"){var s=n.get,c=n.set;return Object.defineProperty(e,t,{configurable:!0,get:function(){return s.call(this)},set:function(h){l=""+h,c.call(this,h)}}),Object.defineProperty(e,t,{enumerable:n.enumerable}),{getValue:function(){return l},setValue:function(h){l=""+h},stopTracking:function(){e._valueTracker=null,delete e[t]}}}}function ts(e){e._valueTracker||(e._valueTracker=Kx(e))}function No(e){if(!e)return!1;var t=e._valueTracker;if(!t)return!0;var n=t.getValue(),l="";return e&&(l=zo(e)?e.checked?"true":"false":e.value),e=l,e!==n?(t.setValue(e),!0):!1}function ns(e){if(e=e||(typeof document<"u"?document:void 0),typeof e>"u")return null;try{return e.activeElement||e.body}catch{return e.body}}var Fx=/[\n"\\]/g;function Bt(e){return e.replace(Fx,function(t){return"\\"+t.charCodeAt(0).toString(16)+" "})}function Uc(e,t,n,l,s,c,h,g){e.name="",h!=null&&typeof h!="function"&&typeof h!="symbol"&&typeof h!="boolean"?e.type=h:e.removeAttribute("type"),t!=null?h==="number"?(t===0&&e.value===""||e.value!=t)&&(e.value=""+Nt(t)):e.value!==""+Nt(t)&&(e.value=""+Nt(t)):h!=="submit"&&h!=="reset"||e.removeAttribute("value"),t!=null?Lc(e,h,Nt(t)):n!=null?Lc(e,h,Nt(n)):l!=null&&e.removeAttribute("value"),s==null&&c!=null&&(e.defaultChecked=!!c),s!=null&&(e.checked=s&&typeof s!="function"&&typeof s!="symbol"),g!=null&&typeof g!="function"&&typeof g!="symbol"&&typeof g!="boolean"?e.name=""+Nt(g):e.removeAttribute("name")}function Bo(e,t,n,l,s,c,h,g){if(c!=null&&typeof c!="function"&&typeof c!="symbol"&&typeof c!="boolean"&&(e.type=c),t!=null||n!=null){if(!(c!=="submit"&&c!=="reset"||t!=null))return;n=n!=null?""+Nt(n):"",t=t!=null?""+Nt(t):n,g||t===e.value||(e.value=t),e.defaultValue=t}l=l??s,l=typeof l!="function"&&typeof l!="symbol"&&!!l,e.checked=g?e.checked:!!l,e.defaultChecked=!!l,h!=null&&typeof h!="function"&&typeof h!="symbol"&&typeof h!="boolean"&&(e.name=h)}function Lc(e,t,n){t==="number"&&ns(e.ownerDocument)===e||e.defaultValue===""+n||(e.defaultValue=""+n)}function Ya(e,t,n,l){if(e=e.options,t){t={};for(var s=0;s<n.length;s++)t["$"+n[s]]=!0;for(n=0;n<e.length;n++)s=t.hasOwnProperty("$"+e[n].value),e[n].selected!==s&&(e[n].selected=s),s&&l&&(e[n].defaultSelected=!0)}else{for(n=""+Nt(n),t=null,s=0;s<e.length;s++){if(e[s].value===n){e[s].selected=!0,l&&(e[s].defaultSelected=!0);return}t!==null||e[s].disabled||(t=e[s])}t!==null&&(t.selected=!0)}}function Ro(e,t,n){if(t!=null&&(t=""+Nt(t),t!==e.value&&(e.value=t),n==null)){e.defaultValue!==t&&(e.defaultValue=t);return}e.defaultValue=n!=null?""+Nt(n):""}function Uo(e,t,n,l){if(t==null){if(l!=null){if(n!=null)throw Error(u(92));if(on(l)){if(1<l.length)throw Error(u(93));l=l[0]}n=l}n==null&&(n=""),t=n}n=Nt(t),e.defaultValue=n,l=e.textContent,l===n&&l!==""&&l!==null&&(e.value=l)}function Xa(e,t){if(t){var n=e.firstChild;if(n&&n===e.lastChild&&n.nodeType===3){n.nodeValue=t;return}}e.textContent=t}var Jx=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function Lo(e,t,n){var l=t.indexOf("--")===0;n==null||typeof n=="boolean"||n===""?l?e.setProperty(t,""):t==="float"?e.cssFloat="":e[t]="":l?e.setProperty(t,n):typeof n!="number"||n===0||Jx.has(t)?t==="float"?e.cssFloat=n:e[t]=(""+n).trim():e[t]=n+"px"}function ko(e,t,n){if(t!=null&&typeof t!="object")throw Error(u(62));if(e=e.style,n!=null){for(var l in n)!n.hasOwnProperty(l)||t!=null&&t.hasOwnProperty(l)||(l.indexOf("--")===0?e.setProperty(l,""):l==="float"?e.cssFloat="":e[l]="");for(var s in t)l=t[s],t.hasOwnProperty(s)&&n[s]!==l&&Lo(e,s,l)}else for(var c in t)t.hasOwnProperty(c)&&Lo(e,c,t[c])}function kc(e){if(e.indexOf("-")===-1)return!1;switch(e){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var Wx=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),Ix=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function as(e){return Ix.test(""+e)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":e}var Hc=null;function qc(e){return e=e.target||e.srcElement||window,e.correspondingUseElement&&(e=e.correspondingUseElement),e.nodeType===3?e.parentNode:e}var Qa=null,Va=null;function Ho(e){var t=Ha(e);if(t&&(e=t.stateNode)){var n=e[xt]||null;e:switch(e=t.stateNode,t.type){case"input":if(Uc(e,n.value,n.defaultValue,n.defaultValue,n.checked,n.defaultChecked,n.type,n.name),t=n.name,n.type==="radio"&&t!=null){for(n=e;n.parentNode;)n=n.parentNode;for(n=n.querySelectorAll('input[name="'+Bt(""+t)+'"][type="radio"]'),t=0;t<n.length;t++){var l=n[t];if(l!==e&&l.form===e.form){var s=l[xt]||null;if(!s)throw Error(u(90));Uc(l,s.value,s.defaultValue,s.defaultValue,s.checked,s.defaultChecked,s.type,s.name)}}for(t=0;t<n.length;t++)l=n[t],l.form===e.form&&No(l)}break e;case"textarea":Ro(e,n.value,n.defaultValue);break e;case"select":t=n.value,t!=null&&Ya(e,!!n.multiple,t,!1)}}}var $c=!1;function qo(e,t,n){if($c)return e(t,n);$c=!0;try{var l=e(t);return l}finally{if($c=!1,(Qa!==null||Va!==null)&&(Gs(),Qa&&(t=Qa,e=Va,Va=Qa=null,Ho(t),e)))for(t=0;t<e.length;t++)Ho(e[t])}}function Rl(e,t){var n=e.stateNode;if(n===null)return null;var l=n[xt]||null;if(l===null)return null;n=l[t];e:switch(t){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(l=!l.disabled)||(e=e.type,l=!(e==="button"||e==="input"||e==="select"||e==="textarea")),e=!l;break e;default:e=!1}if(e)return null;if(n&&typeof n!="function")throw Error(u(231,t,typeof n));return n}var fn=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),Gc=!1;if(fn)try{var Ul={};Object.defineProperty(Ul,"passive",{get:function(){Gc=!0}}),window.addEventListener("test",Ul,Ul),window.removeEventListener("test",Ul,Ul)}catch{Gc=!1}var Bn=null,Yc=null,ls=null;function $o(){if(ls)return ls;var e,t=Yc,n=t.length,l,s="value"in Bn?Bn.value:Bn.textContent,c=s.length;for(e=0;e<n&&t[e]===s[e];e++);var h=n-e;for(l=1;l<=h&&t[n-l]===s[c-l];l++);return ls=s.slice(e,1<l?1-l:void 0)}function is(e){var t=e.keyCode;return"charCode"in e?(e=e.charCode,e===0&&t===13&&(e=13)):e=t,e===10&&(e=13),32<=e||e===13?e:0}function ss(){return!0}function Go(){return!1}function gt(e){function t(n,l,s,c,h){this._reactName=n,this._targetInst=s,this.type=l,this.nativeEvent=c,this.target=h,this.currentTarget=null;for(var g in e)e.hasOwnProperty(g)&&(n=e[g],this[g]=n?n(c):c[g]);return this.isDefaultPrevented=(c.defaultPrevented!=null?c.defaultPrevented:c.returnValue===!1)?ss:Go,this.isPropagationStopped=Go,this}return j(t.prototype,{preventDefault:function(){this.defaultPrevented=!0;var n=this.nativeEvent;n&&(n.preventDefault?n.preventDefault():typeof n.returnValue!="unknown"&&(n.returnValue=!1),this.isDefaultPrevented=ss)},stopPropagation:function(){var n=this.nativeEvent;n&&(n.stopPropagation?n.stopPropagation():typeof n.cancelBubble!="unknown"&&(n.cancelBubble=!0),this.isPropagationStopped=ss)},persist:function(){},isPersistent:ss}),t}var fa={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(e){return e.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},cs=gt(fa),Ll=j({},fa,{view:0,detail:0}),Px=gt(Ll),Xc,Qc,kl,rs=j({},Ll,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:Zc,button:0,buttons:0,relatedTarget:function(e){return e.relatedTarget===void 0?e.fromElement===e.srcElement?e.toElement:e.fromElement:e.relatedTarget},movementX:function(e){return"movementX"in e?e.movementX:(e!==kl&&(kl&&e.type==="mousemove"?(Xc=e.screenX-kl.screenX,Qc=e.screenY-kl.screenY):Qc=Xc=0,kl=e),Xc)},movementY:function(e){return"movementY"in e?e.movementY:Qc}}),Yo=gt(rs),eg=j({},rs,{dataTransfer:0}),tg=gt(eg),ng=j({},Ll,{relatedTarget:0}),Vc=gt(ng),ag=j({},fa,{animationName:0,elapsedTime:0,pseudoElement:0}),lg=gt(ag),ig=j({},fa,{clipboardData:function(e){return"clipboardData"in e?e.clipboardData:window.clipboardData}}),sg=gt(ig),cg=j({},fa,{data:0}),Xo=gt(cg),rg={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},ug={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},og={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function dg(e){var t=this.nativeEvent;return t.getModifierState?t.getModifierState(e):(e=og[e])?!!t[e]:!1}function Zc(){return dg}var fg=j({},Ll,{key:function(e){if(e.key){var t=rg[e.key]||e.key;if(t!=="Unidentified")return t}return e.type==="keypress"?(e=is(e),e===13?"Enter":String.fromCharCode(e)):e.type==="keydown"||e.type==="keyup"?ug[e.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:Zc,charCode:function(e){return e.type==="keypress"?is(e):0},keyCode:function(e){return e.type==="keydown"||e.type==="keyup"?e.keyCode:0},which:function(e){return e.type==="keypress"?is(e):e.type==="keydown"||e.type==="keyup"?e.keyCode:0}}),hg=gt(fg),mg=j({},rs,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),Qo=gt(mg),xg=j({},Ll,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:Zc}),gg=gt(xg),pg=j({},fa,{propertyName:0,elapsedTime:0,pseudoElement:0}),vg=gt(pg),yg=j({},rs,{deltaX:function(e){return"deltaX"in e?e.deltaX:"wheelDeltaX"in e?-e.wheelDeltaX:0},deltaY:function(e){return"deltaY"in e?e.deltaY:"wheelDeltaY"in e?-e.wheelDeltaY:"wheelDelta"in e?-e.wheelDelta:0},deltaZ:0,deltaMode:0}),jg=gt(yg),bg=j({},fa,{newState:0,oldState:0}),Sg=gt(bg),wg=[9,13,27,32],Kc=fn&&"CompositionEvent"in window,Hl=null;fn&&"documentMode"in document&&(Hl=document.documentMode);var Cg=fn&&"TextEvent"in window&&!Hl,Vo=fn&&(!Kc||Hl&&8<Hl&&11>=Hl),Zo=" ",Ko=!1;function Fo(e,t){switch(e){case"keyup":return wg.indexOf(t.keyCode)!==-1;case"keydown":return t.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function Jo(e){return e=e.detail,typeof e=="object"&&"data"in e?e.data:null}var Za=!1;function _g(e,t){switch(e){case"compositionend":return Jo(t);case"keypress":return t.which!==32?null:(Ko=!0,Zo);case"textInput":return e=t.data,e===Zo&&Ko?null:e;default:return null}}function Tg(e,t){if(Za)return e==="compositionend"||!Kc&&Fo(e,t)?(e=$o(),ls=Yc=Bn=null,Za=!1,e):null;switch(e){case"paste":return null;case"keypress":if(!(t.ctrlKey||t.altKey||t.metaKey)||t.ctrlKey&&t.altKey){if(t.char&&1<t.char.length)return t.char;if(t.which)return String.fromCharCode(t.which)}return null;case"compositionend":return Vo&&t.locale!=="ko"?null:t.data;default:return null}}var Eg={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function Wo(e){var t=e&&e.nodeName&&e.nodeName.toLowerCase();return t==="input"?!!Eg[e.type]:t==="textarea"}function Io(e,t,n,l){Qa?Va?Va.push(l):Va=[l]:Qa=l,t=Ks(t,"onChange"),0<t.length&&(n=new cs("onChange","change",null,n,l),e.push({event:n,listeners:t}))}var ql=null,$l=null;function Ag(e){Nh(e,0)}function us(e){var t=Bl(e);if(No(t))return e}function Po(e,t){if(e==="change")return t}var ed=!1;if(fn){var Fc;if(fn){var Jc="oninput"in document;if(!Jc){var td=document.createElement("div");td.setAttribute("oninput","return;"),Jc=typeof td.oninput=="function"}Fc=Jc}else Fc=!1;ed=Fc&&(!document.documentMode||9<document.documentMode)}function nd(){ql&&(ql.detachEvent("onpropertychange",ad),$l=ql=null)}function ad(e){if(e.propertyName==="value"&&us($l)){var t=[];Io(t,$l,e,qc(e)),qo(Ag,t)}}function Dg(e,t,n){e==="focusin"?(nd(),ql=t,$l=n,ql.attachEvent("onpropertychange",ad)):e==="focusout"&&nd()}function Mg(e){if(e==="selectionchange"||e==="keyup"||e==="keydown")return us($l)}function Og(e,t){if(e==="click")return us(t)}function zg(e,t){if(e==="input"||e==="change")return us(t)}function Ng(e,t){return e===t&&(e!==0||1/e===1/t)||e!==e&&t!==t}var _t=typeof Object.is=="function"?Object.is:Ng;function Gl(e,t){if(_t(e,t))return!0;if(typeof e!="object"||e===null||typeof t!="object"||t===null)return!1;var n=Object.keys(e),l=Object.keys(t);if(n.length!==l.length)return!1;for(l=0;l<n.length;l++){var s=n[l];if(!_c.call(t,s)||!_t(e[s],t[s]))return!1}return!0}function ld(e){for(;e&&e.firstChild;)e=e.firstChild;return e}function id(e,t){var n=ld(e);e=0;for(var l;n;){if(n.nodeType===3){if(l=e+n.textContent.length,e<=t&&l>=t)return{node:n,offset:t-e};e=l}e:{for(;n;){if(n.nextSibling){n=n.nextSibling;break e}n=n.parentNode}n=void 0}n=ld(n)}}function sd(e,t){return e&&t?e===t?!0:e&&e.nodeType===3?!1:t&&t.nodeType===3?sd(e,t.parentNode):"contains"in e?e.contains(t):e.compareDocumentPosition?!!(e.compareDocumentPosition(t)&16):!1:!1}function cd(e){e=e!=null&&e.ownerDocument!=null&&e.ownerDocument.defaultView!=null?e.ownerDocument.defaultView:window;for(var t=ns(e.document);t instanceof e.HTMLIFrameElement;){try{var n=typeof t.contentWindow.location.href=="string"}catch{n=!1}if(n)e=t.contentWindow;else break;t=ns(e.document)}return t}function Wc(e){var t=e&&e.nodeName&&e.nodeName.toLowerCase();return t&&(t==="input"&&(e.type==="text"||e.type==="search"||e.type==="tel"||e.type==="url"||e.type==="password")||t==="textarea"||e.contentEditable==="true")}var Bg=fn&&"documentMode"in document&&11>=document.documentMode,Ka=null,Ic=null,Yl=null,Pc=!1;function rd(e,t,n){var l=n.window===n?n.document:n.nodeType===9?n:n.ownerDocument;Pc||Ka==null||Ka!==ns(l)||(l=Ka,"selectionStart"in l&&Wc(l)?l={start:l.selectionStart,end:l.selectionEnd}:(l=(l.ownerDocument&&l.ownerDocument.defaultView||window).getSelection(),l={anchorNode:l.anchorNode,anchorOffset:l.anchorOffset,focusNode:l.focusNode,focusOffset:l.focusOffset}),Yl&&Gl(Yl,l)||(Yl=l,l=Ks(Ic,"onSelect"),0<l.length&&(t=new cs("onSelect","select",null,t,n),e.push({event:t,listeners:l}),t.target=Ka)))}function ha(e,t){var n={};return n[e.toLowerCase()]=t.toLowerCase(),n["Webkit"+e]="webkit"+t,n["Moz"+e]="moz"+t,n}var Fa={animationend:ha("Animation","AnimationEnd"),animationiteration:ha("Animation","AnimationIteration"),animationstart:ha("Animation","AnimationStart"),transitionrun:ha("Transition","TransitionRun"),transitionstart:ha("Transition","TransitionStart"),transitioncancel:ha("Transition","TransitionCancel"),transitionend:ha("Transition","TransitionEnd")},er={},ud={};fn&&(ud=document.createElement("div").style,"AnimationEvent"in window||(delete Fa.animationend.animation,delete Fa.animationiteration.animation,delete Fa.animationstart.animation),"TransitionEvent"in window||delete Fa.transitionend.transition);function ma(e){if(er[e])return er[e];if(!Fa[e])return e;var t=Fa[e],n;for(n in t)if(t.hasOwnProperty(n)&&n in ud)return er[e]=t[n];return e}var od=ma("animationend"),dd=ma("animationiteration"),fd=ma("animationstart"),Rg=ma("transitionrun"),Ug=ma("transitionstart"),Lg=ma("transitioncancel"),hd=ma("transitionend"),md=new Map,tr="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");tr.push("scrollEnd");function Qt(e,t){md.set(e,t),da(t,[e])}var xd=new WeakMap;function Rt(e,t){if(typeof e=="object"&&e!==null){var n=xd.get(e);return n!==void 0?n:(t={value:e,source:t,stack:Oo(t)},xd.set(e,t),t)}return{value:e,source:t,stack:Oo(t)}}var Ut=[],Ja=0,nr=0;function os(){for(var e=Ja,t=nr=Ja=0;t<e;){var n=Ut[t];Ut[t++]=null;var l=Ut[t];Ut[t++]=null;var s=Ut[t];Ut[t++]=null;var c=Ut[t];if(Ut[t++]=null,l!==null&&s!==null){var h=l.pending;h===null?s.next=s:(s.next=h.next,h.next=s),l.pending=s}c!==0&&gd(n,s,c)}}function ds(e,t,n,l){Ut[Ja++]=e,Ut[Ja++]=t,Ut[Ja++]=n,Ut[Ja++]=l,nr|=l,e.lanes|=l,e=e.alternate,e!==null&&(e.lanes|=l)}function ar(e,t,n,l){return ds(e,t,n,l),fs(e)}function Wa(e,t){return ds(e,null,null,t),fs(e)}function gd(e,t,n){e.lanes|=n;var l=e.alternate;l!==null&&(l.lanes|=n);for(var s=!1,c=e.return;c!==null;)c.childLanes|=n,l=c.alternate,l!==null&&(l.childLanes|=n),c.tag===22&&(e=c.stateNode,e===null||e._visibility&1||(s=!0)),e=c,c=c.return;return e.tag===3?(c=e.stateNode,s&&t!==null&&(s=31-Ct(n),e=c.hiddenUpdates,l=e[s],l===null?e[s]=[t]:l.push(t),t.lane=n|536870912),c):null}function fs(e){if(50<mi)throw mi=0,uu=null,Error(u(185));for(var t=e.return;t!==null;)e=t,t=e.return;return e.tag===3?e.stateNode:null}var Ia={};function kg(e,t,n,l){this.tag=e,this.key=n,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=t,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=l,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function Tt(e,t,n,l){return new kg(e,t,n,l)}function lr(e){return e=e.prototype,!(!e||!e.isReactComponent)}function hn(e,t){var n=e.alternate;return n===null?(n=Tt(e.tag,t,e.key,e.mode),n.elementType=e.elementType,n.type=e.type,n.stateNode=e.stateNode,n.alternate=e,e.alternate=n):(n.pendingProps=t,n.type=e.type,n.flags=0,n.subtreeFlags=0,n.deletions=null),n.flags=e.flags&65011712,n.childLanes=e.childLanes,n.lanes=e.lanes,n.child=e.child,n.memoizedProps=e.memoizedProps,n.memoizedState=e.memoizedState,n.updateQueue=e.updateQueue,t=e.dependencies,n.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext},n.sibling=e.sibling,n.index=e.index,n.ref=e.ref,n.refCleanup=e.refCleanup,n}function pd(e,t){e.flags&=65011714;var n=e.alternate;return n===null?(e.childLanes=0,e.lanes=t,e.child=null,e.subtreeFlags=0,e.memoizedProps=null,e.memoizedState=null,e.updateQueue=null,e.dependencies=null,e.stateNode=null):(e.childLanes=n.childLanes,e.lanes=n.lanes,e.child=n.child,e.subtreeFlags=0,e.deletions=null,e.memoizedProps=n.memoizedProps,e.memoizedState=n.memoizedState,e.updateQueue=n.updateQueue,e.type=n.type,t=n.dependencies,e.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext}),e}function hs(e,t,n,l,s,c){var h=0;if(l=e,typeof e=="function")lr(e)&&(h=1);else if(typeof e=="string")h=qp(e,n,Ie.current)?26:e==="html"||e==="head"||e==="body"?27:5;else e:switch(e){case $e:return e=Tt(31,n,t,s),e.elementType=$e,e.lanes=c,e;case L:return xa(n.children,s,c,t);case U:h=8,s|=24;break;case H:return e=Tt(12,n,t,s|2),e.elementType=H,e.lanes=c,e;case de:return e=Tt(13,n,t,s),e.elementType=de,e.lanes=c,e;case fe:return e=Tt(19,n,t,s),e.elementType=fe,e.lanes=c,e;default:if(typeof e=="object"&&e!==null)switch(e.$$typeof){case $:case se:h=10;break e;case J:h=9;break e;case We:h=11;break e;case mt:h=14;break e;case St:h=16,l=null;break e}h=29,n=Error(u(130,e===null?"null":typeof e,"")),l=null}return t=Tt(h,n,t,s),t.elementType=e,t.type=l,t.lanes=c,t}function xa(e,t,n,l){return e=Tt(7,e,l,t),e.lanes=n,e}function ir(e,t,n){return e=Tt(6,e,null,t),e.lanes=n,e}function sr(e,t,n){return t=Tt(4,e.children!==null?e.children:[],e.key,t),t.lanes=n,t.stateNode={containerInfo:e.containerInfo,pendingChildren:null,implementation:e.implementation},t}var Pa=[],el=0,ms=null,xs=0,Lt=[],kt=0,ga=null,mn=1,xn="";function pa(e,t){Pa[el++]=xs,Pa[el++]=ms,ms=e,xs=t}function vd(e,t,n){Lt[kt++]=mn,Lt[kt++]=xn,Lt[kt++]=ga,ga=e;var l=mn;e=xn;var s=32-Ct(l)-1;l&=~(1<<s),n+=1;var c=32-Ct(t)+s;if(30<c){var h=s-s%5;c=(l&(1<<h)-1).toString(32),l>>=h,s-=h,mn=1<<32-Ct(t)+s|n<<s|l,xn=c+e}else mn=1<<c|n<<s|l,xn=e}function cr(e){e.return!==null&&(pa(e,1),vd(e,1,0))}function rr(e){for(;e===ms;)ms=Pa[--el],Pa[el]=null,xs=Pa[--el],Pa[el]=null;for(;e===ga;)ga=Lt[--kt],Lt[kt]=null,xn=Lt[--kt],Lt[kt]=null,mn=Lt[--kt],Lt[kt]=null}var ft=null,Ue=null,re=!1,va=null,It=!1,ur=Error(u(519));function ya(e){var t=Error(u(418,""));throw Vl(Rt(t,e)),ur}function yd(e){var t=e.stateNode,n=e.type,l=e.memoizedProps;switch(t[rt]=e,t[xt]=l,n){case"dialog":ne("cancel",t),ne("close",t);break;case"iframe":case"object":case"embed":ne("load",t);break;case"video":case"audio":for(n=0;n<gi.length;n++)ne(gi[n],t);break;case"source":ne("error",t);break;case"img":case"image":case"link":ne("error",t),ne("load",t);break;case"details":ne("toggle",t);break;case"input":ne("invalid",t),Bo(t,l.value,l.defaultValue,l.checked,l.defaultChecked,l.type,l.name,!0),ts(t);break;case"select":ne("invalid",t);break;case"textarea":ne("invalid",t),Uo(t,l.value,l.defaultValue,l.children),ts(t)}n=l.children,typeof n!="string"&&typeof n!="number"&&typeof n!="bigint"||t.textContent===""+n||l.suppressHydrationWarning===!0||Lh(t.textContent,n)?(l.popover!=null&&(ne("beforetoggle",t),ne("toggle",t)),l.onScroll!=null&&ne("scroll",t),l.onScrollEnd!=null&&ne("scrollend",t),l.onClick!=null&&(t.onclick=Fs),t=!0):t=!1,t||ya(e)}function jd(e){for(ft=e.return;ft;)switch(ft.tag){case 5:case 13:It=!1;return;case 27:case 3:It=!0;return;default:ft=ft.return}}function Xl(e){if(e!==ft)return!1;if(!re)return jd(e),re=!0,!1;var t=e.tag,n;if((n=t!==3&&t!==27)&&((n=t===5)&&(n=e.type,n=!(n!=="form"&&n!=="button")||_u(e.type,e.memoizedProps)),n=!n),n&&Ue&&ya(e),jd(e),t===13){if(e=e.memoizedState,e=e!==null?e.dehydrated:null,!e)throw Error(u(317));e:{for(e=e.nextSibling,t=0;e;){if(e.nodeType===8)if(n=e.data,n==="/$"){if(t===0){Ue=Zt(e.nextSibling);break e}t--}else n!=="$"&&n!=="$!"&&n!=="$?"||t++;e=e.nextSibling}Ue=null}}else t===27?(t=Ue,Jn(e.type)?(e=Du,Du=null,Ue=e):Ue=t):Ue=ft?Zt(e.stateNode.nextSibling):null;return!0}function Ql(){Ue=ft=null,re=!1}function bd(){var e=va;return e!==null&&(yt===null?yt=e:yt.push.apply(yt,e),va=null),e}function Vl(e){va===null?va=[e]:va.push(e)}var or=dt(null),ja=null,gn=null;function Rn(e,t,n){ge(or,t._currentValue),t._currentValue=n}function pn(e){e._currentValue=or.current,Ne(or)}function dr(e,t,n){for(;e!==null;){var l=e.alternate;if((e.childLanes&t)!==t?(e.childLanes|=t,l!==null&&(l.childLanes|=t)):l!==null&&(l.childLanes&t)!==t&&(l.childLanes|=t),e===n)break;e=e.return}}function fr(e,t,n,l){var s=e.child;for(s!==null&&(s.return=e);s!==null;){var c=s.dependencies;if(c!==null){var h=s.child;c=c.firstContext;e:for(;c!==null;){var g=c;c=s;for(var y=0;y<t.length;y++)if(g.context===t[y]){c.lanes|=n,g=c.alternate,g!==null&&(g.lanes|=n),dr(c.return,n,e),l||(h=null);break e}c=g.next}}else if(s.tag===18){if(h=s.return,h===null)throw Error(u(341));h.lanes|=n,c=h.alternate,c!==null&&(c.lanes|=n),dr(h,n,e),h=null}else h=s.child;if(h!==null)h.return=s;else for(h=s;h!==null;){if(h===e){h=null;break}if(s=h.sibling,s!==null){s.return=h.return,h=s;break}h=h.return}s=h}}function Zl(e,t,n,l){e=null;for(var s=t,c=!1;s!==null;){if(!c){if((s.flags&524288)!==0)c=!0;else if((s.flags&262144)!==0)break}if(s.tag===10){var h=s.alternate;if(h===null)throw Error(u(387));if(h=h.memoizedProps,h!==null){var g=s.type;_t(s.pendingProps.value,h.value)||(e!==null?e.push(g):e=[g])}}else if(s===Vi.current){if(h=s.alternate,h===null)throw Error(u(387));h.memoizedState.memoizedState!==s.memoizedState.memoizedState&&(e!==null?e.push(Si):e=[Si])}s=s.return}e!==null&&fr(t,e,n,l),t.flags|=262144}function gs(e){for(e=e.firstContext;e!==null;){if(!_t(e.context._currentValue,e.memoizedValue))return!0;e=e.next}return!1}function ba(e){ja=e,gn=null,e=e.dependencies,e!==null&&(e.firstContext=null)}function ut(e){return Sd(ja,e)}function ps(e,t){return ja===null&&ba(e),Sd(e,t)}function Sd(e,t){var n=t._currentValue;if(t={context:t,memoizedValue:n,next:null},gn===null){if(e===null)throw Error(u(308));gn=t,e.dependencies={lanes:0,firstContext:t},e.flags|=524288}else gn=gn.next=t;return n}var Hg=typeof AbortController<"u"?AbortController:function(){var e=[],t=this.signal={aborted:!1,addEventListener:function(n,l){e.push(l)}};this.abort=function(){t.aborted=!0,e.forEach(function(n){return n()})}},qg=i.unstable_scheduleCallback,$g=i.unstable_NormalPriority,Ze={$$typeof:se,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function hr(){return{controller:new Hg,data:new Map,refCount:0}}function Kl(e){e.refCount--,e.refCount===0&&qg($g,function(){e.controller.abort()})}var Fl=null,mr=0,tl=0,nl=null;function Gg(e,t){if(Fl===null){var n=Fl=[];mr=0,tl=gu(),nl={status:"pending",value:void 0,then:function(l){n.push(l)}}}return mr++,t.then(wd,wd),t}function wd(){if(--mr===0&&Fl!==null){nl!==null&&(nl.status="fulfilled");var e=Fl;Fl=null,tl=0,nl=null;for(var t=0;t<e.length;t++)(0,e[t])()}}function Yg(e,t){var n=[],l={status:"pending",value:null,reason:null,then:function(s){n.push(s)}};return e.then(function(){l.status="fulfilled",l.value=t;for(var s=0;s<n.length;s++)(0,n[s])(t)},function(s){for(l.status="rejected",l.reason=s,s=0;s<n.length;s++)(0,n[s])(void 0)}),l}var Cd=B.S;B.S=function(e,t){typeof t=="object"&&t!==null&&typeof t.then=="function"&&Gg(e,t),Cd!==null&&Cd(e,t)};var Sa=dt(null);function xr(){var e=Sa.current;return e!==null?e:Ce.pooledCache}function vs(e,t){t===null?ge(Sa,Sa.current):ge(Sa,t.pool)}function _d(){var e=xr();return e===null?null:{parent:Ze._currentValue,pool:e}}var Jl=Error(u(460)),Td=Error(u(474)),ys=Error(u(542)),gr={then:function(){}};function Ed(e){return e=e.status,e==="fulfilled"||e==="rejected"}function js(){}function Ad(e,t,n){switch(n=e[n],n===void 0?e.push(t):n!==t&&(t.then(js,js),t=n),t.status){case"fulfilled":return t.value;case"rejected":throw e=t.reason,Md(e),e;default:if(typeof t.status=="string")t.then(js,js);else{if(e=Ce,e!==null&&100<e.shellSuspendCounter)throw Error(u(482));e=t,e.status="pending",e.then(function(l){if(t.status==="pending"){var s=t;s.status="fulfilled",s.value=l}},function(l){if(t.status==="pending"){var s=t;s.status="rejected",s.reason=l}})}switch(t.status){case"fulfilled":return t.value;case"rejected":throw e=t.reason,Md(e),e}throw Wl=t,Jl}}var Wl=null;function Dd(){if(Wl===null)throw Error(u(459));var e=Wl;return Wl=null,e}function Md(e){if(e===Jl||e===ys)throw Error(u(483))}var Un=!1;function pr(e){e.updateQueue={baseState:e.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function vr(e,t){e=e.updateQueue,t.updateQueue===e&&(t.updateQueue={baseState:e.baseState,firstBaseUpdate:e.firstBaseUpdate,lastBaseUpdate:e.lastBaseUpdate,shared:e.shared,callbacks:null})}function Ln(e){return{lane:e,tag:0,payload:null,callback:null,next:null}}function kn(e,t,n){var l=e.updateQueue;if(l===null)return null;if(l=l.shared,(me&2)!==0){var s=l.pending;return s===null?t.next=t:(t.next=s.next,s.next=t),l.pending=t,t=fs(e),gd(e,null,n),t}return ds(e,l,t,n),fs(e)}function Il(e,t,n){if(t=t.updateQueue,t!==null&&(t=t.shared,(n&4194048)!==0)){var l=t.lanes;l&=e.pendingLanes,n|=l,t.lanes=n,wo(e,n)}}function yr(e,t){var n=e.updateQueue,l=e.alternate;if(l!==null&&(l=l.updateQueue,n===l)){var s=null,c=null;if(n=n.firstBaseUpdate,n!==null){do{var h={lane:n.lane,tag:n.tag,payload:n.payload,callback:null,next:null};c===null?s=c=h:c=c.next=h,n=n.next}while(n!==null);c===null?s=c=t:c=c.next=t}else s=c=t;n={baseState:l.baseState,firstBaseUpdate:s,lastBaseUpdate:c,shared:l.shared,callbacks:l.callbacks},e.updateQueue=n;return}e=n.lastBaseUpdate,e===null?n.firstBaseUpdate=t:e.next=t,n.lastBaseUpdate=t}var jr=!1;function Pl(){if(jr){var e=nl;if(e!==null)throw e}}function ei(e,t,n,l){jr=!1;var s=e.updateQueue;Un=!1;var c=s.firstBaseUpdate,h=s.lastBaseUpdate,g=s.shared.pending;if(g!==null){s.shared.pending=null;var y=g,T=y.next;y.next=null,h===null?c=T:h.next=T,h=y;var z=e.alternate;z!==null&&(z=z.updateQueue,g=z.lastBaseUpdate,g!==h&&(g===null?z.firstBaseUpdate=T:g.next=T,z.lastBaseUpdate=y))}if(c!==null){var R=s.baseState;h=0,z=T=y=null,g=c;do{var E=g.lane&-536870913,A=E!==g.lane;if(A?(le&E)===E:(l&E)===E){E!==0&&E===tl&&(jr=!0),z!==null&&(z=z.next={lane:0,tag:g.tag,payload:g.payload,callback:null,next:null});e:{var K=e,Q=g;E=t;var ye=n;switch(Q.tag){case 1:if(K=Q.payload,typeof K=="function"){R=K.call(ye,R,E);break e}R=K;break e;case 3:K.flags=K.flags&-65537|128;case 0:if(K=Q.payload,E=typeof K=="function"?K.call(ye,R,E):K,E==null)break e;R=j({},R,E);break e;case 2:Un=!0}}E=g.callback,E!==null&&(e.flags|=64,A&&(e.flags|=8192),A=s.callbacks,A===null?s.callbacks=[E]:A.push(E))}else A={lane:E,tag:g.tag,payload:g.payload,callback:g.callback,next:null},z===null?(T=z=A,y=R):z=z.next=A,h|=E;if(g=g.next,g===null){if(g=s.shared.pending,g===null)break;A=g,g=A.next,A.next=null,s.lastBaseUpdate=A,s.shared.pending=null}}while(!0);z===null&&(y=R),s.baseState=y,s.firstBaseUpdate=T,s.lastBaseUpdate=z,c===null&&(s.shared.lanes=0),Vn|=h,e.lanes=h,e.memoizedState=R}}function Od(e,t){if(typeof e!="function")throw Error(u(191,e));e.call(t)}function zd(e,t){var n=e.callbacks;if(n!==null)for(e.callbacks=null,e=0;e<n.length;e++)Od(n[e],t)}var al=dt(null),bs=dt(0);function Nd(e,t){e=Cn,ge(bs,e),ge(al,t),Cn=e|t.baseLanes}function br(){ge(bs,Cn),ge(al,al.current)}function Sr(){Cn=bs.current,Ne(al),Ne(bs)}var Hn=0,P=null,pe=null,Xe=null,Ss=!1,ll=!1,wa=!1,ws=0,ti=0,il=null,Xg=0;function Ge(){throw Error(u(321))}function wr(e,t){if(t===null)return!1;for(var n=0;n<t.length&&n<e.length;n++)if(!_t(e[n],t[n]))return!1;return!0}function Cr(e,t,n,l,s,c){return Hn=c,P=t,t.memoizedState=null,t.updateQueue=null,t.lanes=0,B.H=e===null||e.memoizedState===null?pf:vf,wa=!1,c=n(l,s),wa=!1,ll&&(c=Rd(t,n,l,s)),Bd(e),c}function Bd(e){B.H=Ds;var t=pe!==null&&pe.next!==null;if(Hn=0,Xe=pe=P=null,Ss=!1,ti=0,il=null,t)throw Error(u(300));e===null||et||(e=e.dependencies,e!==null&&gs(e)&&(et=!0))}function Rd(e,t,n,l){P=e;var s=0;do{if(ll&&(il=null),ti=0,ll=!1,25<=s)throw Error(u(301));if(s+=1,Xe=pe=null,e.updateQueue!=null){var c=e.updateQueue;c.lastEffect=null,c.events=null,c.stores=null,c.memoCache!=null&&(c.memoCache.index=0)}B.H=Wg,c=t(n,l)}while(ll);return c}function Qg(){var e=B.H,t=e.useState()[0];return t=typeof t.then=="function"?ni(t):t,e=e.useState()[0],(pe!==null?pe.memoizedState:null)!==e&&(P.flags|=1024),t}function _r(){var e=ws!==0;return ws=0,e}function Tr(e,t,n){t.updateQueue=e.updateQueue,t.flags&=-2053,e.lanes&=~n}function Er(e){if(Ss){for(e=e.memoizedState;e!==null;){var t=e.queue;t!==null&&(t.pending=null),e=e.next}Ss=!1}Hn=0,Xe=pe=P=null,ll=!1,ti=ws=0,il=null}function pt(){var e={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return Xe===null?P.memoizedState=Xe=e:Xe=Xe.next=e,Xe}function Qe(){if(pe===null){var e=P.alternate;e=e!==null?e.memoizedState:null}else e=pe.next;var t=Xe===null?P.memoizedState:Xe.next;if(t!==null)Xe=t,pe=e;else{if(e===null)throw P.alternate===null?Error(u(467)):Error(u(310));pe=e,e={memoizedState:pe.memoizedState,baseState:pe.baseState,baseQueue:pe.baseQueue,queue:pe.queue,next:null},Xe===null?P.memoizedState=Xe=e:Xe=Xe.next=e}return Xe}function Ar(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function ni(e){var t=ti;return ti+=1,il===null&&(il=[]),e=Ad(il,e,t),t=P,(Xe===null?t.memoizedState:Xe.next)===null&&(t=t.alternate,B.H=t===null||t.memoizedState===null?pf:vf),e}function Cs(e){if(e!==null&&typeof e=="object"){if(typeof e.then=="function")return ni(e);if(e.$$typeof===se)return ut(e)}throw Error(u(438,String(e)))}function Dr(e){var t=null,n=P.updateQueue;if(n!==null&&(t=n.memoCache),t==null){var l=P.alternate;l!==null&&(l=l.updateQueue,l!==null&&(l=l.memoCache,l!=null&&(t={data:l.data.map(function(s){return s.slice()}),index:0})))}if(t==null&&(t={data:[],index:0}),n===null&&(n=Ar(),P.updateQueue=n),n.memoCache=t,n=t.data[t.index],n===void 0)for(n=t.data[t.index]=Array(e),l=0;l<e;l++)n[l]=ua;return t.index++,n}function vn(e,t){return typeof t=="function"?t(e):t}function _s(e){var t=Qe();return Mr(t,pe,e)}function Mr(e,t,n){var l=e.queue;if(l===null)throw Error(u(311));l.lastRenderedReducer=n;var s=e.baseQueue,c=l.pending;if(c!==null){if(s!==null){var h=s.next;s.next=c.next,c.next=h}t.baseQueue=s=c,l.pending=null}if(c=e.baseState,s===null)e.memoizedState=c;else{t=s.next;var g=h=null,y=null,T=t,z=!1;do{var R=T.lane&-536870913;if(R!==T.lane?(le&R)===R:(Hn&R)===R){var E=T.revertLane;if(E===0)y!==null&&(y=y.next={lane:0,revertLane:0,action:T.action,hasEagerState:T.hasEagerState,eagerState:T.eagerState,next:null}),R===tl&&(z=!0);else if((Hn&E)===E){T=T.next,E===tl&&(z=!0);continue}else R={lane:0,revertLane:T.revertLane,action:T.action,hasEagerState:T.hasEagerState,eagerState:T.eagerState,next:null},y===null?(g=y=R,h=c):y=y.next=R,P.lanes|=E,Vn|=E;R=T.action,wa&&n(c,R),c=T.hasEagerState?T.eagerState:n(c,R)}else E={lane:R,revertLane:T.revertLane,action:T.action,hasEagerState:T.hasEagerState,eagerState:T.eagerState,next:null},y===null?(g=y=E,h=c):y=y.next=E,P.lanes|=R,Vn|=R;T=T.next}while(T!==null&&T!==t);if(y===null?h=c:y.next=g,!_t(c,e.memoizedState)&&(et=!0,z&&(n=nl,n!==null)))throw n;e.memoizedState=c,e.baseState=h,e.baseQueue=y,l.lastRenderedState=c}return s===null&&(l.lanes=0),[e.memoizedState,l.dispatch]}function Or(e){var t=Qe(),n=t.queue;if(n===null)throw Error(u(311));n.lastRenderedReducer=e;var l=n.dispatch,s=n.pending,c=t.memoizedState;if(s!==null){n.pending=null;var h=s=s.next;do c=e(c,h.action),h=h.next;while(h!==s);_t(c,t.memoizedState)||(et=!0),t.memoizedState=c,t.baseQueue===null&&(t.baseState=c),n.lastRenderedState=c}return[c,l]}function Ud(e,t,n){var l=P,s=Qe(),c=re;if(c){if(n===void 0)throw Error(u(407));n=n()}else n=t();var h=!_t((pe||s).memoizedState,n);h&&(s.memoizedState=n,et=!0),s=s.queue;var g=Hd.bind(null,l,s,e);if(ai(2048,8,g,[e]),s.getSnapshot!==t||h||Xe!==null&&Xe.memoizedState.tag&1){if(l.flags|=2048,sl(9,Ts(),kd.bind(null,l,s,n,t),null),Ce===null)throw Error(u(349));c||(Hn&124)!==0||Ld(l,t,n)}return n}function Ld(e,t,n){e.flags|=16384,e={getSnapshot:t,value:n},t=P.updateQueue,t===null?(t=Ar(),P.updateQueue=t,t.stores=[e]):(n=t.stores,n===null?t.stores=[e]:n.push(e))}function kd(e,t,n,l){t.value=n,t.getSnapshot=l,qd(t)&&$d(e)}function Hd(e,t,n){return n(function(){qd(t)&&$d(e)})}function qd(e){var t=e.getSnapshot;e=e.value;try{var n=t();return!_t(e,n)}catch{return!0}}function $d(e){var t=Wa(e,2);t!==null&&Ot(t,e,2)}function zr(e){var t=pt();if(typeof e=="function"){var n=e;if(e=n(),wa){zn(!0);try{n()}finally{zn(!1)}}}return t.memoizedState=t.baseState=e,t.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:vn,lastRenderedState:e},t}function Gd(e,t,n,l){return e.baseState=n,Mr(e,pe,typeof l=="function"?l:vn)}function Vg(e,t,n,l,s){if(As(e))throw Error(u(485));if(e=t.action,e!==null){var c={payload:s,action:e,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(h){c.listeners.push(h)}};B.T!==null?n(!0):c.isTransition=!1,l(c),n=t.pending,n===null?(c.next=t.pending=c,Yd(t,c)):(c.next=n.next,t.pending=n.next=c)}}function Yd(e,t){var n=t.action,l=t.payload,s=e.state;if(t.isTransition){var c=B.T,h={};B.T=h;try{var g=n(s,l),y=B.S;y!==null&&y(h,g),Xd(e,t,g)}catch(T){Nr(e,t,T)}finally{B.T=c}}else try{c=n(s,l),Xd(e,t,c)}catch(T){Nr(e,t,T)}}function Xd(e,t,n){n!==null&&typeof n=="object"&&typeof n.then=="function"?n.then(function(l){Qd(e,t,l)},function(l){return Nr(e,t,l)}):Qd(e,t,n)}function Qd(e,t,n){t.status="fulfilled",t.value=n,Vd(t),e.state=n,t=e.pending,t!==null&&(n=t.next,n===t?e.pending=null:(n=n.next,t.next=n,Yd(e,n)))}function Nr(e,t,n){var l=e.pending;if(e.pending=null,l!==null){l=l.next;do t.status="rejected",t.reason=n,Vd(t),t=t.next;while(t!==l)}e.action=null}function Vd(e){e=e.listeners;for(var t=0;t<e.length;t++)(0,e[t])()}function Zd(e,t){return t}function Kd(e,t){if(re){var n=Ce.formState;if(n!==null){e:{var l=P;if(re){if(Ue){t:{for(var s=Ue,c=It;s.nodeType!==8;){if(!c){s=null;break t}if(s=Zt(s.nextSibling),s===null){s=null;break t}}c=s.data,s=c==="F!"||c==="F"?s:null}if(s){Ue=Zt(s.nextSibling),l=s.data==="F!";break e}}ya(l)}l=!1}l&&(t=n[0])}}return n=pt(),n.memoizedState=n.baseState=t,l={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Zd,lastRenderedState:t},n.queue=l,n=mf.bind(null,P,l),l.dispatch=n,l=zr(!1),c=kr.bind(null,P,!1,l.queue),l=pt(),s={state:t,dispatch:null,action:e,pending:null},l.queue=s,n=Vg.bind(null,P,s,c,n),s.dispatch=n,l.memoizedState=e,[t,n,!1]}function Fd(e){var t=Qe();return Jd(t,pe,e)}function Jd(e,t,n){if(t=Mr(e,t,Zd)[0],e=_s(vn)[0],typeof t=="object"&&t!==null&&typeof t.then=="function")try{var l=ni(t)}catch(h){throw h===Jl?ys:h}else l=t;t=Qe();var s=t.queue,c=s.dispatch;return n!==t.memoizedState&&(P.flags|=2048,sl(9,Ts(),Zg.bind(null,s,n),null)),[l,c,e]}function Zg(e,t){e.action=t}function Wd(e){var t=Qe(),n=pe;if(n!==null)return Jd(t,n,e);Qe(),t=t.memoizedState,n=Qe();var l=n.queue.dispatch;return n.memoizedState=e,[t,l,!1]}function sl(e,t,n,l){return e={tag:e,create:n,deps:l,inst:t,next:null},t=P.updateQueue,t===null&&(t=Ar(),P.updateQueue=t),n=t.lastEffect,n===null?t.lastEffect=e.next=e:(l=n.next,n.next=e,e.next=l,t.lastEffect=e),e}function Ts(){return{destroy:void 0,resource:void 0}}function Id(){return Qe().memoizedState}function Es(e,t,n,l){var s=pt();l=l===void 0?null:l,P.flags|=e,s.memoizedState=sl(1|t,Ts(),n,l)}function ai(e,t,n,l){var s=Qe();l=l===void 0?null:l;var c=s.memoizedState.inst;pe!==null&&l!==null&&wr(l,pe.memoizedState.deps)?s.memoizedState=sl(t,c,n,l):(P.flags|=e,s.memoizedState=sl(1|t,c,n,l))}function Pd(e,t){Es(8390656,8,e,t)}function ef(e,t){ai(2048,8,e,t)}function tf(e,t){return ai(4,2,e,t)}function nf(e,t){return ai(4,4,e,t)}function af(e,t){if(typeof t=="function"){e=e();var n=t(e);return function(){typeof n=="function"?n():t(null)}}if(t!=null)return e=e(),t.current=e,function(){t.current=null}}function lf(e,t,n){n=n!=null?n.concat([e]):null,ai(4,4,af.bind(null,t,e),n)}function Br(){}function sf(e,t){var n=Qe();t=t===void 0?null:t;var l=n.memoizedState;return t!==null&&wr(t,l[1])?l[0]:(n.memoizedState=[e,t],e)}function cf(e,t){var n=Qe();t=t===void 0?null:t;var l=n.memoizedState;if(t!==null&&wr(t,l[1]))return l[0];if(l=e(),wa){zn(!0);try{e()}finally{zn(!1)}}return n.memoizedState=[l,t],l}function Rr(e,t,n){return n===void 0||(Hn&1073741824)!==0?e.memoizedState=t:(e.memoizedState=n,e=oh(),P.lanes|=e,Vn|=e,n)}function rf(e,t,n,l){return _t(n,t)?n:al.current!==null?(e=Rr(e,n,l),_t(e,t)||(et=!0),e):(Hn&42)===0?(et=!0,e.memoizedState=n):(e=oh(),P.lanes|=e,Vn|=e,t)}function uf(e,t,n,l,s){var c=G.p;G.p=c!==0&&8>c?c:8;var h=B.T,g={};B.T=g,kr(e,!1,t,n);try{var y=s(),T=B.S;if(T!==null&&T(g,y),y!==null&&typeof y=="object"&&typeof y.then=="function"){var z=Yg(y,l);li(e,t,z,Mt(e))}else li(e,t,l,Mt(e))}catch(R){li(e,t,{then:function(){},status:"rejected",reason:R},Mt())}finally{G.p=c,B.T=h}}function Kg(){}function Ur(e,t,n,l){if(e.tag!==5)throw Error(u(476));var s=of(e).queue;uf(e,s,t,F,n===null?Kg:function(){return df(e),n(l)})}function of(e){var t=e.memoizedState;if(t!==null)return t;t={memoizedState:F,baseState:F,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:vn,lastRenderedState:F},next:null};var n={};return t.next={memoizedState:n,baseState:n,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:vn,lastRenderedState:n},next:null},e.memoizedState=t,e=e.alternate,e!==null&&(e.memoizedState=t),t}function df(e){var t=of(e).next.queue;li(e,t,{},Mt())}function Lr(){return ut(Si)}function ff(){return Qe().memoizedState}function hf(){return Qe().memoizedState}function Fg(e){for(var t=e.return;t!==null;){switch(t.tag){case 24:case 3:var n=Mt();e=Ln(n);var l=kn(t,e,n);l!==null&&(Ot(l,t,n),Il(l,t,n)),t={cache:hr()},e.payload=t;return}t=t.return}}function Jg(e,t,n){var l=Mt();n={lane:l,revertLane:0,action:n,hasEagerState:!1,eagerState:null,next:null},As(e)?xf(t,n):(n=ar(e,t,n,l),n!==null&&(Ot(n,e,l),gf(n,t,l)))}function mf(e,t,n){var l=Mt();li(e,t,n,l)}function li(e,t,n,l){var s={lane:l,revertLane:0,action:n,hasEagerState:!1,eagerState:null,next:null};if(As(e))xf(t,s);else{var c=e.alternate;if(e.lanes===0&&(c===null||c.lanes===0)&&(c=t.lastRenderedReducer,c!==null))try{var h=t.lastRenderedState,g=c(h,n);if(s.hasEagerState=!0,s.eagerState=g,_t(g,h))return ds(e,t,s,0),Ce===null&&os(),!1}catch{}finally{}if(n=ar(e,t,s,l),n!==null)return Ot(n,e,l),gf(n,t,l),!0}return!1}function kr(e,t,n,l){if(l={lane:2,revertLane:gu(),action:l,hasEagerState:!1,eagerState:null,next:null},As(e)){if(t)throw Error(u(479))}else t=ar(e,n,l,2),t!==null&&Ot(t,e,2)}function As(e){var t=e.alternate;return e===P||t!==null&&t===P}function xf(e,t){ll=Ss=!0;var n=e.pending;n===null?t.next=t:(t.next=n.next,n.next=t),e.pending=t}function gf(e,t,n){if((n&4194048)!==0){var l=t.lanes;l&=e.pendingLanes,n|=l,t.lanes=n,wo(e,n)}}var Ds={readContext:ut,use:Cs,useCallback:Ge,useContext:Ge,useEffect:Ge,useImperativeHandle:Ge,useLayoutEffect:Ge,useInsertionEffect:Ge,useMemo:Ge,useReducer:Ge,useRef:Ge,useState:Ge,useDebugValue:Ge,useDeferredValue:Ge,useTransition:Ge,useSyncExternalStore:Ge,useId:Ge,useHostTransitionStatus:Ge,useFormState:Ge,useActionState:Ge,useOptimistic:Ge,useMemoCache:Ge,useCacheRefresh:Ge},pf={readContext:ut,use:Cs,useCallback:function(e,t){return pt().memoizedState=[e,t===void 0?null:t],e},useContext:ut,useEffect:Pd,useImperativeHandle:function(e,t,n){n=n!=null?n.concat([e]):null,Es(4194308,4,af.bind(null,t,e),n)},useLayoutEffect:function(e,t){return Es(4194308,4,e,t)},useInsertionEffect:function(e,t){Es(4,2,e,t)},useMemo:function(e,t){var n=pt();t=t===void 0?null:t;var l=e();if(wa){zn(!0);try{e()}finally{zn(!1)}}return n.memoizedState=[l,t],l},useReducer:function(e,t,n){var l=pt();if(n!==void 0){var s=n(t);if(wa){zn(!0);try{n(t)}finally{zn(!1)}}}else s=t;return l.memoizedState=l.baseState=s,e={pending:null,lanes:0,dispatch:null,lastRenderedReducer:e,lastRenderedState:s},l.queue=e,e=e.dispatch=Jg.bind(null,P,e),[l.memoizedState,e]},useRef:function(e){var t=pt();return e={current:e},t.memoizedState=e},useState:function(e){e=zr(e);var t=e.queue,n=mf.bind(null,P,t);return t.dispatch=n,[e.memoizedState,n]},useDebugValue:Br,useDeferredValue:function(e,t){var n=pt();return Rr(n,e,t)},useTransition:function(){var e=zr(!1);return e=uf.bind(null,P,e.queue,!0,!1),pt().memoizedState=e,[!1,e]},useSyncExternalStore:function(e,t,n){var l=P,s=pt();if(re){if(n===void 0)throw Error(u(407));n=n()}else{if(n=t(),Ce===null)throw Error(u(349));(le&124)!==0||Ld(l,t,n)}s.memoizedState=n;var c={value:n,getSnapshot:t};return s.queue=c,Pd(Hd.bind(null,l,c,e),[e]),l.flags|=2048,sl(9,Ts(),kd.bind(null,l,c,n,t),null),n},useId:function(){var e=pt(),t=Ce.identifierPrefix;if(re){var n=xn,l=mn;n=(l&~(1<<32-Ct(l)-1)).toString(32)+n,t="«"+t+"R"+n,n=ws++,0<n&&(t+="H"+n.toString(32)),t+="»"}else n=Xg++,t="«"+t+"r"+n.toString(32)+"»";return e.memoizedState=t},useHostTransitionStatus:Lr,useFormState:Kd,useActionState:Kd,useOptimistic:function(e){var t=pt();t.memoizedState=t.baseState=e;var n={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return t.queue=n,t=kr.bind(null,P,!0,n),n.dispatch=t,[e,t]},useMemoCache:Dr,useCacheRefresh:function(){return pt().memoizedState=Fg.bind(null,P)}},vf={readContext:ut,use:Cs,useCallback:sf,useContext:ut,useEffect:ef,useImperativeHandle:lf,useInsertionEffect:tf,useLayoutEffect:nf,useMemo:cf,useReducer:_s,useRef:Id,useState:function(){return _s(vn)},useDebugValue:Br,useDeferredValue:function(e,t){var n=Qe();return rf(n,pe.memoizedState,e,t)},useTransition:function(){var e=_s(vn)[0],t=Qe().memoizedState;return[typeof e=="boolean"?e:ni(e),t]},useSyncExternalStore:Ud,useId:ff,useHostTransitionStatus:Lr,useFormState:Fd,useActionState:Fd,useOptimistic:function(e,t){var n=Qe();return Gd(n,pe,e,t)},useMemoCache:Dr,useCacheRefresh:hf},Wg={readContext:ut,use:Cs,useCallback:sf,useContext:ut,useEffect:ef,useImperativeHandle:lf,useInsertionEffect:tf,useLayoutEffect:nf,useMemo:cf,useReducer:Or,useRef:Id,useState:function(){return Or(vn)},useDebugValue:Br,useDeferredValue:function(e,t){var n=Qe();return pe===null?Rr(n,e,t):rf(n,pe.memoizedState,e,t)},useTransition:function(){var e=Or(vn)[0],t=Qe().memoizedState;return[typeof e=="boolean"?e:ni(e),t]},useSyncExternalStore:Ud,useId:ff,useHostTransitionStatus:Lr,useFormState:Wd,useActionState:Wd,useOptimistic:function(e,t){var n=Qe();return pe!==null?Gd(n,pe,e,t):(n.baseState=e,[e,n.queue.dispatch])},useMemoCache:Dr,useCacheRefresh:hf},cl=null,ii=0;function Ms(e){var t=ii;return ii+=1,cl===null&&(cl=[]),Ad(cl,e,t)}function si(e,t){t=t.props.ref,e.ref=t!==void 0?t:null}function Os(e,t){throw t.$$typeof===O?Error(u(525)):(e=Object.prototype.toString.call(t),Error(u(31,e==="[object Object]"?"object with keys {"+Object.keys(t).join(", ")+"}":e)))}function yf(e){var t=e._init;return t(e._payload)}function jf(e){function t(w,S){if(e){var _=w.deletions;_===null?(w.deletions=[S],w.flags|=16):_.push(S)}}function n(w,S){if(!e)return null;for(;S!==null;)t(w,S),S=S.sibling;return null}function l(w){for(var S=new Map;w!==null;)w.key!==null?S.set(w.key,w):S.set(w.index,w),w=w.sibling;return S}function s(w,S){return w=hn(w,S),w.index=0,w.sibling=null,w}function c(w,S,_){return w.index=_,e?(_=w.alternate,_!==null?(_=_.index,_<S?(w.flags|=67108866,S):_):(w.flags|=67108866,S)):(w.flags|=1048576,S)}function h(w){return e&&w.alternate===null&&(w.flags|=67108866),w}function g(w,S,_,N){return S===null||S.tag!==6?(S=ir(_,w.mode,N),S.return=w,S):(S=s(S,_),S.return=w,S)}function y(w,S,_,N){var Y=_.type;return Y===L?z(w,S,_.props.children,N,_.key):S!==null&&(S.elementType===Y||typeof Y=="object"&&Y!==null&&Y.$$typeof===St&&yf(Y)===S.type)?(S=s(S,_.props),si(S,_),S.return=w,S):(S=hs(_.type,_.key,_.props,null,w.mode,N),si(S,_),S.return=w,S)}function T(w,S,_,N){return S===null||S.tag!==4||S.stateNode.containerInfo!==_.containerInfo||S.stateNode.implementation!==_.implementation?(S=sr(_,w.mode,N),S.return=w,S):(S=s(S,_.children||[]),S.return=w,S)}function z(w,S,_,N,Y){return S===null||S.tag!==7?(S=xa(_,w.mode,N,Y),S.return=w,S):(S=s(S,_),S.return=w,S)}function R(w,S,_){if(typeof S=="string"&&S!==""||typeof S=="number"||typeof S=="bigint")return S=ir(""+S,w.mode,_),S.return=w,S;if(typeof S=="object"&&S!==null){switch(S.$$typeof){case D:return _=hs(S.type,S.key,S.props,null,w.mode,_),si(_,S),_.return=w,_;case M:return S=sr(S,w.mode,_),S.return=w,S;case St:var N=S._init;return S=N(S._payload),R(w,S,_)}if(on(S)||zt(S))return S=xa(S,w.mode,_,null),S.return=w,S;if(typeof S.then=="function")return R(w,Ms(S),_);if(S.$$typeof===se)return R(w,ps(w,S),_);Os(w,S)}return null}function E(w,S,_,N){var Y=S!==null?S.key:null;if(typeof _=="string"&&_!==""||typeof _=="number"||typeof _=="bigint")return Y!==null?null:g(w,S,""+_,N);if(typeof _=="object"&&_!==null){switch(_.$$typeof){case D:return _.key===Y?y(w,S,_,N):null;case M:return _.key===Y?T(w,S,_,N):null;case St:return Y=_._init,_=Y(_._payload),E(w,S,_,N)}if(on(_)||zt(_))return Y!==null?null:z(w,S,_,N,null);if(typeof _.then=="function")return E(w,S,Ms(_),N);if(_.$$typeof===se)return E(w,S,ps(w,_),N);Os(w,_)}return null}function A(w,S,_,N,Y){if(typeof N=="string"&&N!==""||typeof N=="number"||typeof N=="bigint")return w=w.get(_)||null,g(S,w,""+N,Y);if(typeof N=="object"&&N!==null){switch(N.$$typeof){case D:return w=w.get(N.key===null?_:N.key)||null,y(S,w,N,Y);case M:return w=w.get(N.key===null?_:N.key)||null,T(S,w,N,Y);case St:var ee=N._init;return N=ee(N._payload),A(w,S,_,N,Y)}if(on(N)||zt(N))return w=w.get(_)||null,z(S,w,N,Y,null);if(typeof N.then=="function")return A(w,S,_,Ms(N),Y);if(N.$$typeof===se)return A(w,S,_,ps(S,N),Y);Os(S,N)}return null}function K(w,S,_,N){for(var Y=null,ee=null,X=S,V=S=0,nt=null;X!==null&&V<_.length;V++){X.index>V?(nt=X,X=null):nt=X.sibling;var ce=E(w,X,_[V],N);if(ce===null){X===null&&(X=nt);break}e&&X&&ce.alternate===null&&t(w,X),S=c(ce,S,V),ee===null?Y=ce:ee.sibling=ce,ee=ce,X=nt}if(V===_.length)return n(w,X),re&&pa(w,V),Y;if(X===null){for(;V<_.length;V++)X=R(w,_[V],N),X!==null&&(S=c(X,S,V),ee===null?Y=X:ee.sibling=X,ee=X);return re&&pa(w,V),Y}for(X=l(X);V<_.length;V++)nt=A(X,w,V,_[V],N),nt!==null&&(e&&nt.alternate!==null&&X.delete(nt.key===null?V:nt.key),S=c(nt,S,V),ee===null?Y=nt:ee.sibling=nt,ee=nt);return e&&X.forEach(function(ta){return t(w,ta)}),re&&pa(w,V),Y}function Q(w,S,_,N){if(_==null)throw Error(u(151));for(var Y=null,ee=null,X=S,V=S=0,nt=null,ce=_.next();X!==null&&!ce.done;V++,ce=_.next()){X.index>V?(nt=X,X=null):nt=X.sibling;var ta=E(w,X,ce.value,N);if(ta===null){X===null&&(X=nt);break}e&&X&&ta.alternate===null&&t(w,X),S=c(ta,S,V),ee===null?Y=ta:ee.sibling=ta,ee=ta,X=nt}if(ce.done)return n(w,X),re&&pa(w,V),Y;if(X===null){for(;!ce.done;V++,ce=_.next())ce=R(w,ce.value,N),ce!==null&&(S=c(ce,S,V),ee===null?Y=ce:ee.sibling=ce,ee=ce);return re&&pa(w,V),Y}for(X=l(X);!ce.done;V++,ce=_.next())ce=A(X,w,V,ce.value,N),ce!==null&&(e&&ce.alternate!==null&&X.delete(ce.key===null?V:ce.key),S=c(ce,S,V),ee===null?Y=ce:ee.sibling=ce,ee=ce);return e&&X.forEach(function(Ip){return t(w,Ip)}),re&&pa(w,V),Y}function ye(w,S,_,N){if(typeof _=="object"&&_!==null&&_.type===L&&_.key===null&&(_=_.props.children),typeof _=="object"&&_!==null){switch(_.$$typeof){case D:e:{for(var Y=_.key;S!==null;){if(S.key===Y){if(Y=_.type,Y===L){if(S.tag===7){n(w,S.sibling),N=s(S,_.props.children),N.return=w,w=N;break e}}else if(S.elementType===Y||typeof Y=="object"&&Y!==null&&Y.$$typeof===St&&yf(Y)===S.type){n(w,S.sibling),N=s(S,_.props),si(N,_),N.return=w,w=N;break e}n(w,S);break}else t(w,S);S=S.sibling}_.type===L?(N=xa(_.props.children,w.mode,N,_.key),N.return=w,w=N):(N=hs(_.type,_.key,_.props,null,w.mode,N),si(N,_),N.return=w,w=N)}return h(w);case M:e:{for(Y=_.key;S!==null;){if(S.key===Y)if(S.tag===4&&S.stateNode.containerInfo===_.containerInfo&&S.stateNode.implementation===_.implementation){n(w,S.sibling),N=s(S,_.children||[]),N.return=w,w=N;break e}else{n(w,S);break}else t(w,S);S=S.sibling}N=sr(_,w.mode,N),N.return=w,w=N}return h(w);case St:return Y=_._init,_=Y(_._payload),ye(w,S,_,N)}if(on(_))return K(w,S,_,N);if(zt(_)){if(Y=zt(_),typeof Y!="function")throw Error(u(150));return _=Y.call(_),Q(w,S,_,N)}if(typeof _.then=="function")return ye(w,S,Ms(_),N);if(_.$$typeof===se)return ye(w,S,ps(w,_),N);Os(w,_)}return typeof _=="string"&&_!==""||typeof _=="number"||typeof _=="bigint"?(_=""+_,S!==null&&S.tag===6?(n(w,S.sibling),N=s(S,_),N.return=w,w=N):(n(w,S),N=ir(_,w.mode,N),N.return=w,w=N),h(w)):n(w,S)}return function(w,S,_,N){try{ii=0;var Y=ye(w,S,_,N);return cl=null,Y}catch(X){if(X===Jl||X===ys)throw X;var ee=Tt(29,X,null,w.mode);return ee.lanes=N,ee.return=w,ee}finally{}}}var rl=jf(!0),bf=jf(!1),Ht=dt(null),Pt=null;function qn(e){var t=e.alternate;ge(Ke,Ke.current&1),ge(Ht,e),Pt===null&&(t===null||al.current!==null||t.memoizedState!==null)&&(Pt=e)}function Sf(e){if(e.tag===22){if(ge(Ke,Ke.current),ge(Ht,e),Pt===null){var t=e.alternate;t!==null&&t.memoizedState!==null&&(Pt=e)}}else $n()}function $n(){ge(Ke,Ke.current),ge(Ht,Ht.current)}function yn(e){Ne(Ht),Pt===e&&(Pt=null),Ne(Ke)}var Ke=dt(0);function zs(e){for(var t=e;t!==null;){if(t.tag===13){var n=t.memoizedState;if(n!==null&&(n=n.dehydrated,n===null||n.data==="$?"||Au(n)))return t}else if(t.tag===19&&t.memoizedProps.revealOrder!==void 0){if((t.flags&128)!==0)return t}else if(t.child!==null){t.child.return=t,t=t.child;continue}if(t===e)break;for(;t.sibling===null;){if(t.return===null||t.return===e)return null;t=t.return}t.sibling.return=t.return,t=t.sibling}return null}function Hr(e,t,n,l){t=e.memoizedState,n=n(l,t),n=n==null?t:j({},t,n),e.memoizedState=n,e.lanes===0&&(e.updateQueue.baseState=n)}var qr={enqueueSetState:function(e,t,n){e=e._reactInternals;var l=Mt(),s=Ln(l);s.payload=t,n!=null&&(s.callback=n),t=kn(e,s,l),t!==null&&(Ot(t,e,l),Il(t,e,l))},enqueueReplaceState:function(e,t,n){e=e._reactInternals;var l=Mt(),s=Ln(l);s.tag=1,s.payload=t,n!=null&&(s.callback=n),t=kn(e,s,l),t!==null&&(Ot(t,e,l),Il(t,e,l))},enqueueForceUpdate:function(e,t){e=e._reactInternals;var n=Mt(),l=Ln(n);l.tag=2,t!=null&&(l.callback=t),t=kn(e,l,n),t!==null&&(Ot(t,e,n),Il(t,e,n))}};function wf(e,t,n,l,s,c,h){return e=e.stateNode,typeof e.shouldComponentUpdate=="function"?e.shouldComponentUpdate(l,c,h):t.prototype&&t.prototype.isPureReactComponent?!Gl(n,l)||!Gl(s,c):!0}function Cf(e,t,n,l){e=t.state,typeof t.componentWillReceiveProps=="function"&&t.componentWillReceiveProps(n,l),typeof t.UNSAFE_componentWillReceiveProps=="function"&&t.UNSAFE_componentWillReceiveProps(n,l),t.state!==e&&qr.enqueueReplaceState(t,t.state,null)}function Ca(e,t){var n=t;if("ref"in t){n={};for(var l in t)l!=="ref"&&(n[l]=t[l])}if(e=e.defaultProps){n===t&&(n=j({},n));for(var s in e)n[s]===void 0&&(n[s]=e[s])}return n}var Ns=typeof reportError=="function"?reportError:function(e){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var t=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof e=="object"&&e!==null&&typeof e.message=="string"?String(e.message):String(e),error:e});if(!window.dispatchEvent(t))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",e);return}console.error(e)};function _f(e){Ns(e)}function Tf(e){console.error(e)}function Ef(e){Ns(e)}function Bs(e,t){try{var n=e.onUncaughtError;n(t.value,{componentStack:t.stack})}catch(l){setTimeout(function(){throw l})}}function Af(e,t,n){try{var l=e.onCaughtError;l(n.value,{componentStack:n.stack,errorBoundary:t.tag===1?t.stateNode:null})}catch(s){setTimeout(function(){throw s})}}function $r(e,t,n){return n=Ln(n),n.tag=3,n.payload={element:null},n.callback=function(){Bs(e,t)},n}function Df(e){return e=Ln(e),e.tag=3,e}function Mf(e,t,n,l){var s=n.type.getDerivedStateFromError;if(typeof s=="function"){var c=l.value;e.payload=function(){return s(c)},e.callback=function(){Af(t,n,l)}}var h=n.stateNode;h!==null&&typeof h.componentDidCatch=="function"&&(e.callback=function(){Af(t,n,l),typeof s!="function"&&(Zn===null?Zn=new Set([this]):Zn.add(this));var g=l.stack;this.componentDidCatch(l.value,{componentStack:g!==null?g:""})})}function Ig(e,t,n,l,s){if(n.flags|=32768,l!==null&&typeof l=="object"&&typeof l.then=="function"){if(t=n.alternate,t!==null&&Zl(t,n,s,!0),n=Ht.current,n!==null){switch(n.tag){case 13:return Pt===null?du():n.alternate===null&&Le===0&&(Le=3),n.flags&=-257,n.flags|=65536,n.lanes=s,l===gr?n.flags|=16384:(t=n.updateQueue,t===null?n.updateQueue=new Set([l]):t.add(l),hu(e,l,s)),!1;case 22:return n.flags|=65536,l===gr?n.flags|=16384:(t=n.updateQueue,t===null?(t={transitions:null,markerInstances:null,retryQueue:new Set([l])},n.updateQueue=t):(n=t.retryQueue,n===null?t.retryQueue=new Set([l]):n.add(l)),hu(e,l,s)),!1}throw Error(u(435,n.tag))}return hu(e,l,s),du(),!1}if(re)return t=Ht.current,t!==null?((t.flags&65536)===0&&(t.flags|=256),t.flags|=65536,t.lanes=s,l!==ur&&(e=Error(u(422),{cause:l}),Vl(Rt(e,n)))):(l!==ur&&(t=Error(u(423),{cause:l}),Vl(Rt(t,n))),e=e.current.alternate,e.flags|=65536,s&=-s,e.lanes|=s,l=Rt(l,n),s=$r(e.stateNode,l,s),yr(e,s),Le!==4&&(Le=2)),!1;var c=Error(u(520),{cause:l});if(c=Rt(c,n),hi===null?hi=[c]:hi.push(c),Le!==4&&(Le=2),t===null)return!0;l=Rt(l,n),n=t;do{switch(n.tag){case 3:return n.flags|=65536,e=s&-s,n.lanes|=e,e=$r(n.stateNode,l,e),yr(n,e),!1;case 1:if(t=n.type,c=n.stateNode,(n.flags&128)===0&&(typeof t.getDerivedStateFromError=="function"||c!==null&&typeof c.componentDidCatch=="function"&&(Zn===null||!Zn.has(c))))return n.flags|=65536,s&=-s,n.lanes|=s,s=Df(s),Mf(s,e,n,l),yr(n,s),!1}n=n.return}while(n!==null);return!1}var Of=Error(u(461)),et=!1;function at(e,t,n,l){t.child=e===null?bf(t,null,n,l):rl(t,e.child,n,l)}function zf(e,t,n,l,s){n=n.render;var c=t.ref;if("ref"in l){var h={};for(var g in l)g!=="ref"&&(h[g]=l[g])}else h=l;return ba(t),l=Cr(e,t,n,h,c,s),g=_r(),e!==null&&!et?(Tr(e,t,s),jn(e,t,s)):(re&&g&&cr(t),t.flags|=1,at(e,t,l,s),t.child)}function Nf(e,t,n,l,s){if(e===null){var c=n.type;return typeof c=="function"&&!lr(c)&&c.defaultProps===void 0&&n.compare===null?(t.tag=15,t.type=c,Bf(e,t,c,l,s)):(e=hs(n.type,null,l,t,t.mode,s),e.ref=t.ref,e.return=t,t.child=e)}if(c=e.child,!Fr(e,s)){var h=c.memoizedProps;if(n=n.compare,n=n!==null?n:Gl,n(h,l)&&e.ref===t.ref)return jn(e,t,s)}return t.flags|=1,e=hn(c,l),e.ref=t.ref,e.return=t,t.child=e}function Bf(e,t,n,l,s){if(e!==null){var c=e.memoizedProps;if(Gl(c,l)&&e.ref===t.ref)if(et=!1,t.pendingProps=l=c,Fr(e,s))(e.flags&131072)!==0&&(et=!0);else return t.lanes=e.lanes,jn(e,t,s)}return Gr(e,t,n,l,s)}function Rf(e,t,n){var l=t.pendingProps,s=l.children,c=e!==null?e.memoizedState:null;if(l.mode==="hidden"){if((t.flags&128)!==0){if(l=c!==null?c.baseLanes|n:n,e!==null){for(s=t.child=e.child,c=0;s!==null;)c=c|s.lanes|s.childLanes,s=s.sibling;t.childLanes=c&~l}else t.childLanes=0,t.child=null;return Uf(e,t,l,n)}if((n&536870912)!==0)t.memoizedState={baseLanes:0,cachePool:null},e!==null&&vs(t,c!==null?c.cachePool:null),c!==null?Nd(t,c):br(),Sf(t);else return t.lanes=t.childLanes=536870912,Uf(e,t,c!==null?c.baseLanes|n:n,n)}else c!==null?(vs(t,c.cachePool),Nd(t,c),$n(),t.memoizedState=null):(e!==null&&vs(t,null),br(),$n());return at(e,t,s,n),t.child}function Uf(e,t,n,l){var s=xr();return s=s===null?null:{parent:Ze._currentValue,pool:s},t.memoizedState={baseLanes:n,cachePool:s},e!==null&&vs(t,null),br(),Sf(t),e!==null&&Zl(e,t,l,!0),null}function Rs(e,t){var n=t.ref;if(n===null)e!==null&&e.ref!==null&&(t.flags|=4194816);else{if(typeof n!="function"&&typeof n!="object")throw Error(u(284));(e===null||e.ref!==n)&&(t.flags|=4194816)}}function Gr(e,t,n,l,s){return ba(t),n=Cr(e,t,n,l,void 0,s),l=_r(),e!==null&&!et?(Tr(e,t,s),jn(e,t,s)):(re&&l&&cr(t),t.flags|=1,at(e,t,n,s),t.child)}function Lf(e,t,n,l,s,c){return ba(t),t.updateQueue=null,n=Rd(t,l,n,s),Bd(e),l=_r(),e!==null&&!et?(Tr(e,t,c),jn(e,t,c)):(re&&l&&cr(t),t.flags|=1,at(e,t,n,c),t.child)}function kf(e,t,n,l,s){if(ba(t),t.stateNode===null){var c=Ia,h=n.contextType;typeof h=="object"&&h!==null&&(c=ut(h)),c=new n(l,c),t.memoizedState=c.state!==null&&c.state!==void 0?c.state:null,c.updater=qr,t.stateNode=c,c._reactInternals=t,c=t.stateNode,c.props=l,c.state=t.memoizedState,c.refs={},pr(t),h=n.contextType,c.context=typeof h=="object"&&h!==null?ut(h):Ia,c.state=t.memoizedState,h=n.getDerivedStateFromProps,typeof h=="function"&&(Hr(t,n,h,l),c.state=t.memoizedState),typeof n.getDerivedStateFromProps=="function"||typeof c.getSnapshotBeforeUpdate=="function"||typeof c.UNSAFE_componentWillMount!="function"&&typeof c.componentWillMount!="function"||(h=c.state,typeof c.componentWillMount=="function"&&c.componentWillMount(),typeof c.UNSAFE_componentWillMount=="function"&&c.UNSAFE_componentWillMount(),h!==c.state&&qr.enqueueReplaceState(c,c.state,null),ei(t,l,c,s),Pl(),c.state=t.memoizedState),typeof c.componentDidMount=="function"&&(t.flags|=4194308),l=!0}else if(e===null){c=t.stateNode;var g=t.memoizedProps,y=Ca(n,g);c.props=y;var T=c.context,z=n.contextType;h=Ia,typeof z=="object"&&z!==null&&(h=ut(z));var R=n.getDerivedStateFromProps;z=typeof R=="function"||typeof c.getSnapshotBeforeUpdate=="function",g=t.pendingProps!==g,z||typeof c.UNSAFE_componentWillReceiveProps!="function"&&typeof c.componentWillReceiveProps!="function"||(g||T!==h)&&Cf(t,c,l,h),Un=!1;var E=t.memoizedState;c.state=E,ei(t,l,c,s),Pl(),T=t.memoizedState,g||E!==T||Un?(typeof R=="function"&&(Hr(t,n,R,l),T=t.memoizedState),(y=Un||wf(t,n,y,l,E,T,h))?(z||typeof c.UNSAFE_componentWillMount!="function"&&typeof c.componentWillMount!="function"||(typeof c.componentWillMount=="function"&&c.componentWillMount(),typeof c.UNSAFE_componentWillMount=="function"&&c.UNSAFE_componentWillMount()),typeof c.componentDidMount=="function"&&(t.flags|=4194308)):(typeof c.componentDidMount=="function"&&(t.flags|=4194308),t.memoizedProps=l,t.memoizedState=T),c.props=l,c.state=T,c.context=h,l=y):(typeof c.componentDidMount=="function"&&(t.flags|=4194308),l=!1)}else{c=t.stateNode,vr(e,t),h=t.memoizedProps,z=Ca(n,h),c.props=z,R=t.pendingProps,E=c.context,T=n.contextType,y=Ia,typeof T=="object"&&T!==null&&(y=ut(T)),g=n.getDerivedStateFromProps,(T=typeof g=="function"||typeof c.getSnapshotBeforeUpdate=="function")||typeof c.UNSAFE_componentWillReceiveProps!="function"&&typeof c.componentWillReceiveProps!="function"||(h!==R||E!==y)&&Cf(t,c,l,y),Un=!1,E=t.memoizedState,c.state=E,ei(t,l,c,s),Pl();var A=t.memoizedState;h!==R||E!==A||Un||e!==null&&e.dependencies!==null&&gs(e.dependencies)?(typeof g=="function"&&(Hr(t,n,g,l),A=t.memoizedState),(z=Un||wf(t,n,z,l,E,A,y)||e!==null&&e.dependencies!==null&&gs(e.dependencies))?(T||typeof c.UNSAFE_componentWillUpdate!="function"&&typeof c.componentWillUpdate!="function"||(typeof c.componentWillUpdate=="function"&&c.componentWillUpdate(l,A,y),typeof c.UNSAFE_componentWillUpdate=="function"&&c.UNSAFE_componentWillUpdate(l,A,y)),typeof c.componentDidUpdate=="function"&&(t.flags|=4),typeof c.getSnapshotBeforeUpdate=="function"&&(t.flags|=1024)):(typeof c.componentDidUpdate!="function"||h===e.memoizedProps&&E===e.memoizedState||(t.flags|=4),typeof c.getSnapshotBeforeUpdate!="function"||h===e.memoizedProps&&E===e.memoizedState||(t.flags|=1024),t.memoizedProps=l,t.memoizedState=A),c.props=l,c.state=A,c.context=y,l=z):(typeof c.componentDidUpdate!="function"||h===e.memoizedProps&&E===e.memoizedState||(t.flags|=4),typeof c.getSnapshotBeforeUpdate!="function"||h===e.memoizedProps&&E===e.memoizedState||(t.flags|=1024),l=!1)}return c=l,Rs(e,t),l=(t.flags&128)!==0,c||l?(c=t.stateNode,n=l&&typeof n.getDerivedStateFromError!="function"?null:c.render(),t.flags|=1,e!==null&&l?(t.child=rl(t,e.child,null,s),t.child=rl(t,null,n,s)):at(e,t,n,s),t.memoizedState=c.state,e=t.child):e=jn(e,t,s),e}function Hf(e,t,n,l){return Ql(),t.flags|=256,at(e,t,n,l),t.child}var Yr={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function Xr(e){return{baseLanes:e,cachePool:_d()}}function Qr(e,t,n){return e=e!==null?e.childLanes&~n:0,t&&(e|=qt),e}function qf(e,t,n){var l=t.pendingProps,s=!1,c=(t.flags&128)!==0,h;if((h=c)||(h=e!==null&&e.memoizedState===null?!1:(Ke.current&2)!==0),h&&(s=!0,t.flags&=-129),h=(t.flags&32)!==0,t.flags&=-33,e===null){if(re){if(s?qn(t):$n(),re){var g=Ue,y;if(y=g){e:{for(y=g,g=It;y.nodeType!==8;){if(!g){g=null;break e}if(y=Zt(y.nextSibling),y===null){g=null;break e}}g=y}g!==null?(t.memoizedState={dehydrated:g,treeContext:ga!==null?{id:mn,overflow:xn}:null,retryLane:536870912,hydrationErrors:null},y=Tt(18,null,null,0),y.stateNode=g,y.return=t,t.child=y,ft=t,Ue=null,y=!0):y=!1}y||ya(t)}if(g=t.memoizedState,g!==null&&(g=g.dehydrated,g!==null))return Au(g)?t.lanes=32:t.lanes=536870912,null;yn(t)}return g=l.children,l=l.fallback,s?($n(),s=t.mode,g=Us({mode:"hidden",children:g},s),l=xa(l,s,n,null),g.return=t,l.return=t,g.sibling=l,t.child=g,s=t.child,s.memoizedState=Xr(n),s.childLanes=Qr(e,h,n),t.memoizedState=Yr,l):(qn(t),Vr(t,g))}if(y=e.memoizedState,y!==null&&(g=y.dehydrated,g!==null)){if(c)t.flags&256?(qn(t),t.flags&=-257,t=Zr(e,t,n)):t.memoizedState!==null?($n(),t.child=e.child,t.flags|=128,t=null):($n(),s=l.fallback,g=t.mode,l=Us({mode:"visible",children:l.children},g),s=xa(s,g,n,null),s.flags|=2,l.return=t,s.return=t,l.sibling=s,t.child=l,rl(t,e.child,null,n),l=t.child,l.memoizedState=Xr(n),l.childLanes=Qr(e,h,n),t.memoizedState=Yr,t=s);else if(qn(t),Au(g)){if(h=g.nextSibling&&g.nextSibling.dataset,h)var T=h.dgst;h=T,l=Error(u(419)),l.stack="",l.digest=h,Vl({value:l,source:null,stack:null}),t=Zr(e,t,n)}else if(et||Zl(e,t,n,!1),h=(n&e.childLanes)!==0,et||h){if(h=Ce,h!==null&&(l=n&-n,l=(l&42)!==0?1:Dc(l),l=(l&(h.suspendedLanes|n))!==0?0:l,l!==0&&l!==y.retryLane))throw y.retryLane=l,Wa(e,l),Ot(h,e,l),Of;g.data==="$?"||du(),t=Zr(e,t,n)}else g.data==="$?"?(t.flags|=192,t.child=e.child,t=null):(e=y.treeContext,Ue=Zt(g.nextSibling),ft=t,re=!0,va=null,It=!1,e!==null&&(Lt[kt++]=mn,Lt[kt++]=xn,Lt[kt++]=ga,mn=e.id,xn=e.overflow,ga=t),t=Vr(t,l.children),t.flags|=4096);return t}return s?($n(),s=l.fallback,g=t.mode,y=e.child,T=y.sibling,l=hn(y,{mode:"hidden",children:l.children}),l.subtreeFlags=y.subtreeFlags&65011712,T!==null?s=hn(T,s):(s=xa(s,g,n,null),s.flags|=2),s.return=t,l.return=t,l.sibling=s,t.child=l,l=s,s=t.child,g=e.child.memoizedState,g===null?g=Xr(n):(y=g.cachePool,y!==null?(T=Ze._currentValue,y=y.parent!==T?{parent:T,pool:T}:y):y=_d(),g={baseLanes:g.baseLanes|n,cachePool:y}),s.memoizedState=g,s.childLanes=Qr(e,h,n),t.memoizedState=Yr,l):(qn(t),n=e.child,e=n.sibling,n=hn(n,{mode:"visible",children:l.children}),n.return=t,n.sibling=null,e!==null&&(h=t.deletions,h===null?(t.deletions=[e],t.flags|=16):h.push(e)),t.child=n,t.memoizedState=null,n)}function Vr(e,t){return t=Us({mode:"visible",children:t},e.mode),t.return=e,e.child=t}function Us(e,t){return e=Tt(22,e,null,t),e.lanes=0,e.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null},e}function Zr(e,t,n){return rl(t,e.child,null,n),e=Vr(t,t.pendingProps.children),e.flags|=2,t.memoizedState=null,e}function $f(e,t,n){e.lanes|=t;var l=e.alternate;l!==null&&(l.lanes|=t),dr(e.return,t,n)}function Kr(e,t,n,l,s){var c=e.memoizedState;c===null?e.memoizedState={isBackwards:t,rendering:null,renderingStartTime:0,last:l,tail:n,tailMode:s}:(c.isBackwards=t,c.rendering=null,c.renderingStartTime=0,c.last=l,c.tail=n,c.tailMode=s)}function Gf(e,t,n){var l=t.pendingProps,s=l.revealOrder,c=l.tail;if(at(e,t,l.children,n),l=Ke.current,(l&2)!==0)l=l&1|2,t.flags|=128;else{if(e!==null&&(e.flags&128)!==0)e:for(e=t.child;e!==null;){if(e.tag===13)e.memoizedState!==null&&$f(e,n,t);else if(e.tag===19)$f(e,n,t);else if(e.child!==null){e.child.return=e,e=e.child;continue}if(e===t)break e;for(;e.sibling===null;){if(e.return===null||e.return===t)break e;e=e.return}e.sibling.return=e.return,e=e.sibling}l&=1}switch(ge(Ke,l),s){case"forwards":for(n=t.child,s=null;n!==null;)e=n.alternate,e!==null&&zs(e)===null&&(s=n),n=n.sibling;n=s,n===null?(s=t.child,t.child=null):(s=n.sibling,n.sibling=null),Kr(t,!1,s,n,c);break;case"backwards":for(n=null,s=t.child,t.child=null;s!==null;){if(e=s.alternate,e!==null&&zs(e)===null){t.child=s;break}e=s.sibling,s.sibling=n,n=s,s=e}Kr(t,!0,n,null,c);break;case"together":Kr(t,!1,null,null,void 0);break;default:t.memoizedState=null}return t.child}function jn(e,t,n){if(e!==null&&(t.dependencies=e.dependencies),Vn|=t.lanes,(n&t.childLanes)===0)if(e!==null){if(Zl(e,t,n,!1),(n&t.childLanes)===0)return null}else return null;if(e!==null&&t.child!==e.child)throw Error(u(153));if(t.child!==null){for(e=t.child,n=hn(e,e.pendingProps),t.child=n,n.return=t;e.sibling!==null;)e=e.sibling,n=n.sibling=hn(e,e.pendingProps),n.return=t;n.sibling=null}return t.child}function Fr(e,t){return(e.lanes&t)!==0?!0:(e=e.dependencies,!!(e!==null&&gs(e)))}function Pg(e,t,n){switch(t.tag){case 3:Zi(t,t.stateNode.containerInfo),Rn(t,Ze,e.memoizedState.cache),Ql();break;case 27:case 5:Cc(t);break;case 4:Zi(t,t.stateNode.containerInfo);break;case 10:Rn(t,t.type,t.memoizedProps.value);break;case 13:var l=t.memoizedState;if(l!==null)return l.dehydrated!==null?(qn(t),t.flags|=128,null):(n&t.child.childLanes)!==0?qf(e,t,n):(qn(t),e=jn(e,t,n),e!==null?e.sibling:null);qn(t);break;case 19:var s=(e.flags&128)!==0;if(l=(n&t.childLanes)!==0,l||(Zl(e,t,n,!1),l=(n&t.childLanes)!==0),s){if(l)return Gf(e,t,n);t.flags|=128}if(s=t.memoizedState,s!==null&&(s.rendering=null,s.tail=null,s.lastEffect=null),ge(Ke,Ke.current),l)break;return null;case 22:case 23:return t.lanes=0,Rf(e,t,n);case 24:Rn(t,Ze,e.memoizedState.cache)}return jn(e,t,n)}function Yf(e,t,n){if(e!==null)if(e.memoizedProps!==t.pendingProps)et=!0;else{if(!Fr(e,n)&&(t.flags&128)===0)return et=!1,Pg(e,t,n);et=(e.flags&131072)!==0}else et=!1,re&&(t.flags&1048576)!==0&&vd(t,xs,t.index);switch(t.lanes=0,t.tag){case 16:e:{e=t.pendingProps;var l=t.elementType,s=l._init;if(l=s(l._payload),t.type=l,typeof l=="function")lr(l)?(e=Ca(l,e),t.tag=1,t=kf(null,t,l,e,n)):(t.tag=0,t=Gr(null,t,l,e,n));else{if(l!=null){if(s=l.$$typeof,s===We){t.tag=11,t=zf(null,t,l,e,n);break e}else if(s===mt){t.tag=14,t=Nf(null,t,l,e,n);break e}}throw t=Dl(l)||l,Error(u(306,t,""))}}return t;case 0:return Gr(e,t,t.type,t.pendingProps,n);case 1:return l=t.type,s=Ca(l,t.pendingProps),kf(e,t,l,s,n);case 3:e:{if(Zi(t,t.stateNode.containerInfo),e===null)throw Error(u(387));l=t.pendingProps;var c=t.memoizedState;s=c.element,vr(e,t),ei(t,l,null,n);var h=t.memoizedState;if(l=h.cache,Rn(t,Ze,l),l!==c.cache&&fr(t,[Ze],n,!0),Pl(),l=h.element,c.isDehydrated)if(c={element:l,isDehydrated:!1,cache:h.cache},t.updateQueue.baseState=c,t.memoizedState=c,t.flags&256){t=Hf(e,t,l,n);break e}else if(l!==s){s=Rt(Error(u(424)),t),Vl(s),t=Hf(e,t,l,n);break e}else{switch(e=t.stateNode.containerInfo,e.nodeType){case 9:e=e.body;break;default:e=e.nodeName==="HTML"?e.ownerDocument.body:e}for(Ue=Zt(e.firstChild),ft=t,re=!0,va=null,It=!0,n=bf(t,null,l,n),t.child=n;n;)n.flags=n.flags&-3|4096,n=n.sibling}else{if(Ql(),l===s){t=jn(e,t,n);break e}at(e,t,l,n)}t=t.child}return t;case 26:return Rs(e,t),e===null?(n=Zh(t.type,null,t.pendingProps,null))?t.memoizedState=n:re||(n=t.type,e=t.pendingProps,l=Js(On.current).createElement(n),l[rt]=t,l[xt]=e,it(l,n,e),Pe(l),t.stateNode=l):t.memoizedState=Zh(t.type,e.memoizedProps,t.pendingProps,e.memoizedState),null;case 27:return Cc(t),e===null&&re&&(l=t.stateNode=Xh(t.type,t.pendingProps,On.current),ft=t,It=!0,s=Ue,Jn(t.type)?(Du=s,Ue=Zt(l.firstChild)):Ue=s),at(e,t,t.pendingProps.children,n),Rs(e,t),e===null&&(t.flags|=4194304),t.child;case 5:return e===null&&re&&((s=l=Ue)&&(l=Ep(l,t.type,t.pendingProps,It),l!==null?(t.stateNode=l,ft=t,Ue=Zt(l.firstChild),It=!1,s=!0):s=!1),s||ya(t)),Cc(t),s=t.type,c=t.pendingProps,h=e!==null?e.memoizedProps:null,l=c.children,_u(s,c)?l=null:h!==null&&_u(s,h)&&(t.flags|=32),t.memoizedState!==null&&(s=Cr(e,t,Qg,null,null,n),Si._currentValue=s),Rs(e,t),at(e,t,l,n),t.child;case 6:return e===null&&re&&((e=n=Ue)&&(n=Ap(n,t.pendingProps,It),n!==null?(t.stateNode=n,ft=t,Ue=null,e=!0):e=!1),e||ya(t)),null;case 13:return qf(e,t,n);case 4:return Zi(t,t.stateNode.containerInfo),l=t.pendingProps,e===null?t.child=rl(t,null,l,n):at(e,t,l,n),t.child;case 11:return zf(e,t,t.type,t.pendingProps,n);case 7:return at(e,t,t.pendingProps,n),t.child;case 8:return at(e,t,t.pendingProps.children,n),t.child;case 12:return at(e,t,t.pendingProps.children,n),t.child;case 10:return l=t.pendingProps,Rn(t,t.type,l.value),at(e,t,l.children,n),t.child;case 9:return s=t.type._context,l=t.pendingProps.children,ba(t),s=ut(s),l=l(s),t.flags|=1,at(e,t,l,n),t.child;case 14:return Nf(e,t,t.type,t.pendingProps,n);case 15:return Bf(e,t,t.type,t.pendingProps,n);case 19:return Gf(e,t,n);case 31:return l=t.pendingProps,n=t.mode,l={mode:l.mode,children:l.children},e===null?(n=Us(l,n),n.ref=t.ref,t.child=n,n.return=t,t=n):(n=hn(e.child,l),n.ref=t.ref,t.child=n,n.return=t,t=n),t;case 22:return Rf(e,t,n);case 24:return ba(t),l=ut(Ze),e===null?(s=xr(),s===null&&(s=Ce,c=hr(),s.pooledCache=c,c.refCount++,c!==null&&(s.pooledCacheLanes|=n),s=c),t.memoizedState={parent:l,cache:s},pr(t),Rn(t,Ze,s)):((e.lanes&n)!==0&&(vr(e,t),ei(t,null,null,n),Pl()),s=e.memoizedState,c=t.memoizedState,s.parent!==l?(s={parent:l,cache:l},t.memoizedState=s,t.lanes===0&&(t.memoizedState=t.updateQueue.baseState=s),Rn(t,Ze,l)):(l=c.cache,Rn(t,Ze,l),l!==s.cache&&fr(t,[Ze],n,!0))),at(e,t,t.pendingProps.children,n),t.child;case 29:throw t.pendingProps}throw Error(u(156,t.tag))}function bn(e){e.flags|=4}function Xf(e,t){if(t.type!=="stylesheet"||(t.state.loading&4)!==0)e.flags&=-16777217;else if(e.flags|=16777216,!Ih(t)){if(t=Ht.current,t!==null&&((le&4194048)===le?Pt!==null:(le&62914560)!==le&&(le&536870912)===0||t!==Pt))throw Wl=gr,Td;e.flags|=8192}}function Ls(e,t){t!==null&&(e.flags|=4),e.flags&16384&&(t=e.tag!==22?bo():536870912,e.lanes|=t,fl|=t)}function ci(e,t){if(!re)switch(e.tailMode){case"hidden":t=e.tail;for(var n=null;t!==null;)t.alternate!==null&&(n=t),t=t.sibling;n===null?e.tail=null:n.sibling=null;break;case"collapsed":n=e.tail;for(var l=null;n!==null;)n.alternate!==null&&(l=n),n=n.sibling;l===null?t||e.tail===null?e.tail=null:e.tail.sibling=null:l.sibling=null}}function Be(e){var t=e.alternate!==null&&e.alternate.child===e.child,n=0,l=0;if(t)for(var s=e.child;s!==null;)n|=s.lanes|s.childLanes,l|=s.subtreeFlags&65011712,l|=s.flags&65011712,s.return=e,s=s.sibling;else for(s=e.child;s!==null;)n|=s.lanes|s.childLanes,l|=s.subtreeFlags,l|=s.flags,s.return=e,s=s.sibling;return e.subtreeFlags|=l,e.childLanes=n,t}function ep(e,t,n){var l=t.pendingProps;switch(rr(t),t.tag){case 31:case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return Be(t),null;case 1:return Be(t),null;case 3:return n=t.stateNode,l=null,e!==null&&(l=e.memoizedState.cache),t.memoizedState.cache!==l&&(t.flags|=2048),pn(Ze),Ua(),n.pendingContext&&(n.context=n.pendingContext,n.pendingContext=null),(e===null||e.child===null)&&(Xl(t)?bn(t):e===null||e.memoizedState.isDehydrated&&(t.flags&256)===0||(t.flags|=1024,bd())),Be(t),null;case 26:return n=t.memoizedState,e===null?(bn(t),n!==null?(Be(t),Xf(t,n)):(Be(t),t.flags&=-16777217)):n?n!==e.memoizedState?(bn(t),Be(t),Xf(t,n)):(Be(t),t.flags&=-16777217):(e.memoizedProps!==l&&bn(t),Be(t),t.flags&=-16777217),null;case 27:Ki(t),n=On.current;var s=t.type;if(e!==null&&t.stateNode!=null)e.memoizedProps!==l&&bn(t);else{if(!l){if(t.stateNode===null)throw Error(u(166));return Be(t),null}e=Ie.current,Xl(t)?yd(t):(e=Xh(s,l,n),t.stateNode=e,bn(t))}return Be(t),null;case 5:if(Ki(t),n=t.type,e!==null&&t.stateNode!=null)e.memoizedProps!==l&&bn(t);else{if(!l){if(t.stateNode===null)throw Error(u(166));return Be(t),null}if(e=Ie.current,Xl(t))yd(t);else{switch(s=Js(On.current),e){case 1:e=s.createElementNS("http://www.w3.org/2000/svg",n);break;case 2:e=s.createElementNS("http://www.w3.org/1998/Math/MathML",n);break;default:switch(n){case"svg":e=s.createElementNS("http://www.w3.org/2000/svg",n);break;case"math":e=s.createElementNS("http://www.w3.org/1998/Math/MathML",n);break;case"script":e=s.createElement("div"),e.innerHTML="<script><\/script>",e=e.removeChild(e.firstChild);break;case"select":e=typeof l.is=="string"?s.createElement("select",{is:l.is}):s.createElement("select"),l.multiple?e.multiple=!0:l.size&&(e.size=l.size);break;default:e=typeof l.is=="string"?s.createElement(n,{is:l.is}):s.createElement(n)}}e[rt]=t,e[xt]=l;e:for(s=t.child;s!==null;){if(s.tag===5||s.tag===6)e.appendChild(s.stateNode);else if(s.tag!==4&&s.tag!==27&&s.child!==null){s.child.return=s,s=s.child;continue}if(s===t)break e;for(;s.sibling===null;){if(s.return===null||s.return===t)break e;s=s.return}s.sibling.return=s.return,s=s.sibling}t.stateNode=e;e:switch(it(e,n,l),n){case"button":case"input":case"select":case"textarea":e=!!l.autoFocus;break e;case"img":e=!0;break e;default:e=!1}e&&bn(t)}}return Be(t),t.flags&=-16777217,null;case 6:if(e&&t.stateNode!=null)e.memoizedProps!==l&&bn(t);else{if(typeof l!="string"&&t.stateNode===null)throw Error(u(166));if(e=On.current,Xl(t)){if(e=t.stateNode,n=t.memoizedProps,l=null,s=ft,s!==null)switch(s.tag){case 27:case 5:l=s.memoizedProps}e[rt]=t,e=!!(e.nodeValue===n||l!==null&&l.suppressHydrationWarning===!0||Lh(e.nodeValue,n)),e||ya(t)}else e=Js(e).createTextNode(l),e[rt]=t,t.stateNode=e}return Be(t),null;case 13:if(l=t.memoizedState,e===null||e.memoizedState!==null&&e.memoizedState.dehydrated!==null){if(s=Xl(t),l!==null&&l.dehydrated!==null){if(e===null){if(!s)throw Error(u(318));if(s=t.memoizedState,s=s!==null?s.dehydrated:null,!s)throw Error(u(317));s[rt]=t}else Ql(),(t.flags&128)===0&&(t.memoizedState=null),t.flags|=4;Be(t),s=!1}else s=bd(),e!==null&&e.memoizedState!==null&&(e.memoizedState.hydrationErrors=s),s=!0;if(!s)return t.flags&256?(yn(t),t):(yn(t),null)}if(yn(t),(t.flags&128)!==0)return t.lanes=n,t;if(n=l!==null,e=e!==null&&e.memoizedState!==null,n){l=t.child,s=null,l.alternate!==null&&l.alternate.memoizedState!==null&&l.alternate.memoizedState.cachePool!==null&&(s=l.alternate.memoizedState.cachePool.pool);var c=null;l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(c=l.memoizedState.cachePool.pool),c!==s&&(l.flags|=2048)}return n!==e&&n&&(t.child.flags|=8192),Ls(t,t.updateQueue),Be(t),null;case 4:return Ua(),e===null&&ju(t.stateNode.containerInfo),Be(t),null;case 10:return pn(t.type),Be(t),null;case 19:if(Ne(Ke),s=t.memoizedState,s===null)return Be(t),null;if(l=(t.flags&128)!==0,c=s.rendering,c===null)if(l)ci(s,!1);else{if(Le!==0||e!==null&&(e.flags&128)!==0)for(e=t.child;e!==null;){if(c=zs(e),c!==null){for(t.flags|=128,ci(s,!1),e=c.updateQueue,t.updateQueue=e,Ls(t,e),t.subtreeFlags=0,e=n,n=t.child;n!==null;)pd(n,e),n=n.sibling;return ge(Ke,Ke.current&1|2),t.child}e=e.sibling}s.tail!==null&&Wt()>qs&&(t.flags|=128,l=!0,ci(s,!1),t.lanes=4194304)}else{if(!l)if(e=zs(c),e!==null){if(t.flags|=128,l=!0,e=e.updateQueue,t.updateQueue=e,Ls(t,e),ci(s,!0),s.tail===null&&s.tailMode==="hidden"&&!c.alternate&&!re)return Be(t),null}else 2*Wt()-s.renderingStartTime>qs&&n!==536870912&&(t.flags|=128,l=!0,ci(s,!1),t.lanes=4194304);s.isBackwards?(c.sibling=t.child,t.child=c):(e=s.last,e!==null?e.sibling=c:t.child=c,s.last=c)}return s.tail!==null?(t=s.tail,s.rendering=t,s.tail=t.sibling,s.renderingStartTime=Wt(),t.sibling=null,e=Ke.current,ge(Ke,l?e&1|2:e&1),t):(Be(t),null);case 22:case 23:return yn(t),Sr(),l=t.memoizedState!==null,e!==null?e.memoizedState!==null!==l&&(t.flags|=8192):l&&(t.flags|=8192),l?(n&536870912)!==0&&(t.flags&128)===0&&(Be(t),t.subtreeFlags&6&&(t.flags|=8192)):Be(t),n=t.updateQueue,n!==null&&Ls(t,n.retryQueue),n=null,e!==null&&e.memoizedState!==null&&e.memoizedState.cachePool!==null&&(n=e.memoizedState.cachePool.pool),l=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(l=t.memoizedState.cachePool.pool),l!==n&&(t.flags|=2048),e!==null&&Ne(Sa),null;case 24:return n=null,e!==null&&(n=e.memoizedState.cache),t.memoizedState.cache!==n&&(t.flags|=2048),pn(Ze),Be(t),null;case 25:return null;case 30:return null}throw Error(u(156,t.tag))}function tp(e,t){switch(rr(t),t.tag){case 1:return e=t.flags,e&65536?(t.flags=e&-65537|128,t):null;case 3:return pn(Ze),Ua(),e=t.flags,(e&65536)!==0&&(e&128)===0?(t.flags=e&-65537|128,t):null;case 26:case 27:case 5:return Ki(t),null;case 13:if(yn(t),e=t.memoizedState,e!==null&&e.dehydrated!==null){if(t.alternate===null)throw Error(u(340));Ql()}return e=t.flags,e&65536?(t.flags=e&-65537|128,t):null;case 19:return Ne(Ke),null;case 4:return Ua(),null;case 10:return pn(t.type),null;case 22:case 23:return yn(t),Sr(),e!==null&&Ne(Sa),e=t.flags,e&65536?(t.flags=e&-65537|128,t):null;case 24:return pn(Ze),null;case 25:return null;default:return null}}function Qf(e,t){switch(rr(t),t.tag){case 3:pn(Ze),Ua();break;case 26:case 27:case 5:Ki(t);break;case 4:Ua();break;case 13:yn(t);break;case 19:Ne(Ke);break;case 10:pn(t.type);break;case 22:case 23:yn(t),Sr(),e!==null&&Ne(Sa);break;case 24:pn(Ze)}}function ri(e,t){try{var n=t.updateQueue,l=n!==null?n.lastEffect:null;if(l!==null){var s=l.next;n=s;do{if((n.tag&e)===e){l=void 0;var c=n.create,h=n.inst;l=c(),h.destroy=l}n=n.next}while(n!==s)}}catch(g){be(t,t.return,g)}}function Gn(e,t,n){try{var l=t.updateQueue,s=l!==null?l.lastEffect:null;if(s!==null){var c=s.next;l=c;do{if((l.tag&e)===e){var h=l.inst,g=h.destroy;if(g!==void 0){h.destroy=void 0,s=t;var y=n,T=g;try{T()}catch(z){be(s,y,z)}}}l=l.next}while(l!==c)}}catch(z){be(t,t.return,z)}}function Vf(e){var t=e.updateQueue;if(t!==null){var n=e.stateNode;try{zd(t,n)}catch(l){be(e,e.return,l)}}}function Zf(e,t,n){n.props=Ca(e.type,e.memoizedProps),n.state=e.memoizedState;try{n.componentWillUnmount()}catch(l){be(e,t,l)}}function ui(e,t){try{var n=e.ref;if(n!==null){switch(e.tag){case 26:case 27:case 5:var l=e.stateNode;break;case 30:l=e.stateNode;break;default:l=e.stateNode}typeof n=="function"?e.refCleanup=n(l):n.current=l}}catch(s){be(e,t,s)}}function en(e,t){var n=e.ref,l=e.refCleanup;if(n!==null)if(typeof l=="function")try{l()}catch(s){be(e,t,s)}finally{e.refCleanup=null,e=e.alternate,e!=null&&(e.refCleanup=null)}else if(typeof n=="function")try{n(null)}catch(s){be(e,t,s)}else n.current=null}function Kf(e){var t=e.type,n=e.memoizedProps,l=e.stateNode;try{e:switch(t){case"button":case"input":case"select":case"textarea":n.autoFocus&&l.focus();break e;case"img":n.src?l.src=n.src:n.srcSet&&(l.srcset=n.srcSet)}}catch(s){be(e,e.return,s)}}function Jr(e,t,n){try{var l=e.stateNode;Sp(l,e.type,n,t),l[xt]=t}catch(s){be(e,e.return,s)}}function Ff(e){return e.tag===5||e.tag===3||e.tag===26||e.tag===27&&Jn(e.type)||e.tag===4}function Wr(e){e:for(;;){for(;e.sibling===null;){if(e.return===null||Ff(e.return))return null;e=e.return}for(e.sibling.return=e.return,e=e.sibling;e.tag!==5&&e.tag!==6&&e.tag!==18;){if(e.tag===27&&Jn(e.type)||e.flags&2||e.child===null||e.tag===4)continue e;e.child.return=e,e=e.child}if(!(e.flags&2))return e.stateNode}}function Ir(e,t,n){var l=e.tag;if(l===5||l===6)e=e.stateNode,t?(n.nodeType===9?n.body:n.nodeName==="HTML"?n.ownerDocument.body:n).insertBefore(e,t):(t=n.nodeType===9?n.body:n.nodeName==="HTML"?n.ownerDocument.body:n,t.appendChild(e),n=n._reactRootContainer,n!=null||t.onclick!==null||(t.onclick=Fs));else if(l!==4&&(l===27&&Jn(e.type)&&(n=e.stateNode,t=null),e=e.child,e!==null))for(Ir(e,t,n),e=e.sibling;e!==null;)Ir(e,t,n),e=e.sibling}function ks(e,t,n){var l=e.tag;if(l===5||l===6)e=e.stateNode,t?n.insertBefore(e,t):n.appendChild(e);else if(l!==4&&(l===27&&Jn(e.type)&&(n=e.stateNode),e=e.child,e!==null))for(ks(e,t,n),e=e.sibling;e!==null;)ks(e,t,n),e=e.sibling}function Jf(e){var t=e.stateNode,n=e.memoizedProps;try{for(var l=e.type,s=t.attributes;s.length;)t.removeAttributeNode(s[0]);it(t,l,n),t[rt]=e,t[xt]=n}catch(c){be(e,e.return,c)}}var Sn=!1,Ye=!1,Pr=!1,Wf=typeof WeakSet=="function"?WeakSet:Set,tt=null;function np(e,t){if(e=e.containerInfo,wu=nc,e=cd(e),Wc(e)){if("selectionStart"in e)var n={start:e.selectionStart,end:e.selectionEnd};else e:{n=(n=e.ownerDocument)&&n.defaultView||window;var l=n.getSelection&&n.getSelection();if(l&&l.rangeCount!==0){n=l.anchorNode;var s=l.anchorOffset,c=l.focusNode;l=l.focusOffset;try{n.nodeType,c.nodeType}catch{n=null;break e}var h=0,g=-1,y=-1,T=0,z=0,R=e,E=null;t:for(;;){for(var A;R!==n||s!==0&&R.nodeType!==3||(g=h+s),R!==c||l!==0&&R.nodeType!==3||(y=h+l),R.nodeType===3&&(h+=R.nodeValue.length),(A=R.firstChild)!==null;)E=R,R=A;for(;;){if(R===e)break t;if(E===n&&++T===s&&(g=h),E===c&&++z===l&&(y=h),(A=R.nextSibling)!==null)break;R=E,E=R.parentNode}R=A}n=g===-1||y===-1?null:{start:g,end:y}}else n=null}n=n||{start:0,end:0}}else n=null;for(Cu={focusedElem:e,selectionRange:n},nc=!1,tt=t;tt!==null;)if(t=tt,e=t.child,(t.subtreeFlags&1024)!==0&&e!==null)e.return=t,tt=e;else for(;tt!==null;){switch(t=tt,c=t.alternate,e=t.flags,t.tag){case 0:break;case 11:case 15:break;case 1:if((e&1024)!==0&&c!==null){e=void 0,n=t,s=c.memoizedProps,c=c.memoizedState,l=n.stateNode;try{var K=Ca(n.type,s,n.elementType===n.type);e=l.getSnapshotBeforeUpdate(K,c),l.__reactInternalSnapshotBeforeUpdate=e}catch(Q){be(n,n.return,Q)}}break;case 3:if((e&1024)!==0){if(e=t.stateNode.containerInfo,n=e.nodeType,n===9)Eu(e);else if(n===1)switch(e.nodeName){case"HEAD":case"HTML":case"BODY":Eu(e);break;default:e.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((e&1024)!==0)throw Error(u(163))}if(e=t.sibling,e!==null){e.return=t.return,tt=e;break}tt=t.return}}function If(e,t,n){var l=n.flags;switch(n.tag){case 0:case 11:case 15:Yn(e,n),l&4&&ri(5,n);break;case 1:if(Yn(e,n),l&4)if(e=n.stateNode,t===null)try{e.componentDidMount()}catch(h){be(n,n.return,h)}else{var s=Ca(n.type,t.memoizedProps);t=t.memoizedState;try{e.componentDidUpdate(s,t,e.__reactInternalSnapshotBeforeUpdate)}catch(h){be(n,n.return,h)}}l&64&&Vf(n),l&512&&ui(n,n.return);break;case 3:if(Yn(e,n),l&64&&(e=n.updateQueue,e!==null)){if(t=null,n.child!==null)switch(n.child.tag){case 27:case 5:t=n.child.stateNode;break;case 1:t=n.child.stateNode}try{zd(e,t)}catch(h){be(n,n.return,h)}}break;case 27:t===null&&l&4&&Jf(n);case 26:case 5:Yn(e,n),t===null&&l&4&&Kf(n),l&512&&ui(n,n.return);break;case 12:Yn(e,n);break;case 13:Yn(e,n),l&4&&th(e,n),l&64&&(e=n.memoizedState,e!==null&&(e=e.dehydrated,e!==null&&(n=dp.bind(null,n),Dp(e,n))));break;case 22:if(l=n.memoizedState!==null||Sn,!l){t=t!==null&&t.memoizedState!==null||Ye,s=Sn;var c=Ye;Sn=l,(Ye=t)&&!c?Xn(e,n,(n.subtreeFlags&8772)!==0):Yn(e,n),Sn=s,Ye=c}break;case 30:break;default:Yn(e,n)}}function Pf(e){var t=e.alternate;t!==null&&(e.alternate=null,Pf(t)),e.child=null,e.deletions=null,e.sibling=null,e.tag===5&&(t=e.stateNode,t!==null&&zc(t)),e.stateNode=null,e.return=null,e.dependencies=null,e.memoizedProps=null,e.memoizedState=null,e.pendingProps=null,e.stateNode=null,e.updateQueue=null}var Me=null,vt=!1;function wn(e,t,n){for(n=n.child;n!==null;)eh(e,t,n),n=n.sibling}function eh(e,t,n){if(wt&&typeof wt.onCommitFiberUnmount=="function")try{wt.onCommitFiberUnmount(Ml,n)}catch{}switch(n.tag){case 26:Ye||en(n,t),wn(e,t,n),n.memoizedState?n.memoizedState.count--:n.stateNode&&(n=n.stateNode,n.parentNode.removeChild(n));break;case 27:Ye||en(n,t);var l=Me,s=vt;Jn(n.type)&&(Me=n.stateNode,vt=!1),wn(e,t,n),vi(n.stateNode),Me=l,vt=s;break;case 5:Ye||en(n,t);case 6:if(l=Me,s=vt,Me=null,wn(e,t,n),Me=l,vt=s,Me!==null)if(vt)try{(Me.nodeType===9?Me.body:Me.nodeName==="HTML"?Me.ownerDocument.body:Me).removeChild(n.stateNode)}catch(c){be(n,t,c)}else try{Me.removeChild(n.stateNode)}catch(c){be(n,t,c)}break;case 18:Me!==null&&(vt?(e=Me,Gh(e.nodeType===9?e.body:e.nodeName==="HTML"?e.ownerDocument.body:e,n.stateNode),Ti(e)):Gh(Me,n.stateNode));break;case 4:l=Me,s=vt,Me=n.stateNode.containerInfo,vt=!0,wn(e,t,n),Me=l,vt=s;break;case 0:case 11:case 14:case 15:Ye||Gn(2,n,t),Ye||Gn(4,n,t),wn(e,t,n);break;case 1:Ye||(en(n,t),l=n.stateNode,typeof l.componentWillUnmount=="function"&&Zf(n,t,l)),wn(e,t,n);break;case 21:wn(e,t,n);break;case 22:Ye=(l=Ye)||n.memoizedState!==null,wn(e,t,n),Ye=l;break;default:wn(e,t,n)}}function th(e,t){if(t.memoizedState===null&&(e=t.alternate,e!==null&&(e=e.memoizedState,e!==null&&(e=e.dehydrated,e!==null))))try{Ti(e)}catch(n){be(t,t.return,n)}}function ap(e){switch(e.tag){case 13:case 19:var t=e.stateNode;return t===null&&(t=e.stateNode=new Wf),t;case 22:return e=e.stateNode,t=e._retryCache,t===null&&(t=e._retryCache=new Wf),t;default:throw Error(u(435,e.tag))}}function eu(e,t){var n=ap(e);t.forEach(function(l){var s=fp.bind(null,e,l);n.has(l)||(n.add(l),l.then(s,s))})}function Et(e,t){var n=t.deletions;if(n!==null)for(var l=0;l<n.length;l++){var s=n[l],c=e,h=t,g=h;e:for(;g!==null;){switch(g.tag){case 27:if(Jn(g.type)){Me=g.stateNode,vt=!1;break e}break;case 5:Me=g.stateNode,vt=!1;break e;case 3:case 4:Me=g.stateNode.containerInfo,vt=!0;break e}g=g.return}if(Me===null)throw Error(u(160));eh(c,h,s),Me=null,vt=!1,c=s.alternate,c!==null&&(c.return=null),s.return=null}if(t.subtreeFlags&13878)for(t=t.child;t!==null;)nh(t,e),t=t.sibling}var Vt=null;function nh(e,t){var n=e.alternate,l=e.flags;switch(e.tag){case 0:case 11:case 14:case 15:Et(t,e),At(e),l&4&&(Gn(3,e,e.return),ri(3,e),Gn(5,e,e.return));break;case 1:Et(t,e),At(e),l&512&&(Ye||n===null||en(n,n.return)),l&64&&Sn&&(e=e.updateQueue,e!==null&&(l=e.callbacks,l!==null&&(n=e.shared.hiddenCallbacks,e.shared.hiddenCallbacks=n===null?l:n.concat(l))));break;case 26:var s=Vt;if(Et(t,e),At(e),l&512&&(Ye||n===null||en(n,n.return)),l&4){var c=n!==null?n.memoizedState:null;if(l=e.memoizedState,n===null)if(l===null)if(e.stateNode===null){e:{l=e.type,n=e.memoizedProps,s=s.ownerDocument||s;t:switch(l){case"title":c=s.getElementsByTagName("title")[0],(!c||c[Nl]||c[rt]||c.namespaceURI==="http://www.w3.org/2000/svg"||c.hasAttribute("itemprop"))&&(c=s.createElement(l),s.head.insertBefore(c,s.querySelector("head > title"))),it(c,l,n),c[rt]=e,Pe(c),l=c;break e;case"link":var h=Jh("link","href",s).get(l+(n.href||""));if(h){for(var g=0;g<h.length;g++)if(c=h[g],c.getAttribute("href")===(n.href==null||n.href===""?null:n.href)&&c.getAttribute("rel")===(n.rel==null?null:n.rel)&&c.getAttribute("title")===(n.title==null?null:n.title)&&c.getAttribute("crossorigin")===(n.crossOrigin==null?null:n.crossOrigin)){h.splice(g,1);break t}}c=s.createElement(l),it(c,l,n),s.head.appendChild(c);break;case"meta":if(h=Jh("meta","content",s).get(l+(n.content||""))){for(g=0;g<h.length;g++)if(c=h[g],c.getAttribute("content")===(n.content==null?null:""+n.content)&&c.getAttribute("name")===(n.name==null?null:n.name)&&c.getAttribute("property")===(n.property==null?null:n.property)&&c.getAttribute("http-equiv")===(n.httpEquiv==null?null:n.httpEquiv)&&c.getAttribute("charset")===(n.charSet==null?null:n.charSet)){h.splice(g,1);break t}}c=s.createElement(l),it(c,l,n),s.head.appendChild(c);break;default:throw Error(u(468,l))}c[rt]=e,Pe(c),l=c}e.stateNode=l}else Wh(s,e.type,e.stateNode);else e.stateNode=Fh(s,l,e.memoizedProps);else c!==l?(c===null?n.stateNode!==null&&(n=n.stateNode,n.parentNode.removeChild(n)):c.count--,l===null?Wh(s,e.type,e.stateNode):Fh(s,l,e.memoizedProps)):l===null&&e.stateNode!==null&&Jr(e,e.memoizedProps,n.memoizedProps)}break;case 27:Et(t,e),At(e),l&512&&(Ye||n===null||en(n,n.return)),n!==null&&l&4&&Jr(e,e.memoizedProps,n.memoizedProps);break;case 5:if(Et(t,e),At(e),l&512&&(Ye||n===null||en(n,n.return)),e.flags&32){s=e.stateNode;try{Xa(s,"")}catch(A){be(e,e.return,A)}}l&4&&e.stateNode!=null&&(s=e.memoizedProps,Jr(e,s,n!==null?n.memoizedProps:s)),l&1024&&(Pr=!0);break;case 6:if(Et(t,e),At(e),l&4){if(e.stateNode===null)throw Error(u(162));l=e.memoizedProps,n=e.stateNode;try{n.nodeValue=l}catch(A){be(e,e.return,A)}}break;case 3:if(Ps=null,s=Vt,Vt=Ws(t.containerInfo),Et(t,e),Vt=s,At(e),l&4&&n!==null&&n.memoizedState.isDehydrated)try{Ti(t.containerInfo)}catch(A){be(e,e.return,A)}Pr&&(Pr=!1,ah(e));break;case 4:l=Vt,Vt=Ws(e.stateNode.containerInfo),Et(t,e),At(e),Vt=l;break;case 12:Et(t,e),At(e);break;case 13:Et(t,e),At(e),e.child.flags&8192&&e.memoizedState!==null!=(n!==null&&n.memoizedState!==null)&&(su=Wt()),l&4&&(l=e.updateQueue,l!==null&&(e.updateQueue=null,eu(e,l)));break;case 22:s=e.memoizedState!==null;var y=n!==null&&n.memoizedState!==null,T=Sn,z=Ye;if(Sn=T||s,Ye=z||y,Et(t,e),Ye=z,Sn=T,At(e),l&8192)e:for(t=e.stateNode,t._visibility=s?t._visibility&-2:t._visibility|1,s&&(n===null||y||Sn||Ye||_a(e)),n=null,t=e;;){if(t.tag===5||t.tag===26){if(n===null){y=n=t;try{if(c=y.stateNode,s)h=c.style,typeof h.setProperty=="function"?h.setProperty("display","none","important"):h.display="none";else{g=y.stateNode;var R=y.memoizedProps.style,E=R!=null&&R.hasOwnProperty("display")?R.display:null;g.style.display=E==null||typeof E=="boolean"?"":(""+E).trim()}}catch(A){be(y,y.return,A)}}}else if(t.tag===6){if(n===null){y=t;try{y.stateNode.nodeValue=s?"":y.memoizedProps}catch(A){be(y,y.return,A)}}}else if((t.tag!==22&&t.tag!==23||t.memoizedState===null||t===e)&&t.child!==null){t.child.return=t,t=t.child;continue}if(t===e)break e;for(;t.sibling===null;){if(t.return===null||t.return===e)break e;n===t&&(n=null),t=t.return}n===t&&(n=null),t.sibling.return=t.return,t=t.sibling}l&4&&(l=e.updateQueue,l!==null&&(n=l.retryQueue,n!==null&&(l.retryQueue=null,eu(e,n))));break;case 19:Et(t,e),At(e),l&4&&(l=e.updateQueue,l!==null&&(e.updateQueue=null,eu(e,l)));break;case 30:break;case 21:break;default:Et(t,e),At(e)}}function At(e){var t=e.flags;if(t&2){try{for(var n,l=e.return;l!==null;){if(Ff(l)){n=l;break}l=l.return}if(n==null)throw Error(u(160));switch(n.tag){case 27:var s=n.stateNode,c=Wr(e);ks(e,c,s);break;case 5:var h=n.stateNode;n.flags&32&&(Xa(h,""),n.flags&=-33);var g=Wr(e);ks(e,g,h);break;case 3:case 4:var y=n.stateNode.containerInfo,T=Wr(e);Ir(e,T,y);break;default:throw Error(u(161))}}catch(z){be(e,e.return,z)}e.flags&=-3}t&4096&&(e.flags&=-4097)}function ah(e){if(e.subtreeFlags&1024)for(e=e.child;e!==null;){var t=e;ah(t),t.tag===5&&t.flags&1024&&t.stateNode.reset(),e=e.sibling}}function Yn(e,t){if(t.subtreeFlags&8772)for(t=t.child;t!==null;)If(e,t.alternate,t),t=t.sibling}function _a(e){for(e=e.child;e!==null;){var t=e;switch(t.tag){case 0:case 11:case 14:case 15:Gn(4,t,t.return),_a(t);break;case 1:en(t,t.return);var n=t.stateNode;typeof n.componentWillUnmount=="function"&&Zf(t,t.return,n),_a(t);break;case 27:vi(t.stateNode);case 26:case 5:en(t,t.return),_a(t);break;case 22:t.memoizedState===null&&_a(t);break;case 30:_a(t);break;default:_a(t)}e=e.sibling}}function Xn(e,t,n){for(n=n&&(t.subtreeFlags&8772)!==0,t=t.child;t!==null;){var l=t.alternate,s=e,c=t,h=c.flags;switch(c.tag){case 0:case 11:case 15:Xn(s,c,n),ri(4,c);break;case 1:if(Xn(s,c,n),l=c,s=l.stateNode,typeof s.componentDidMount=="function")try{s.componentDidMount()}catch(T){be(l,l.return,T)}if(l=c,s=l.updateQueue,s!==null){var g=l.stateNode;try{var y=s.shared.hiddenCallbacks;if(y!==null)for(s.shared.hiddenCallbacks=null,s=0;s<y.length;s++)Od(y[s],g)}catch(T){be(l,l.return,T)}}n&&h&64&&Vf(c),ui(c,c.return);break;case 27:Jf(c);case 26:case 5:Xn(s,c,n),n&&l===null&&h&4&&Kf(c),ui(c,c.return);break;case 12:Xn(s,c,n);break;case 13:Xn(s,c,n),n&&h&4&&th(s,c);break;case 22:c.memoizedState===null&&Xn(s,c,n),ui(c,c.return);break;case 30:break;default:Xn(s,c,n)}t=t.sibling}}function tu(e,t){var n=null;e!==null&&e.memoizedState!==null&&e.memoizedState.cachePool!==null&&(n=e.memoizedState.cachePool.pool),e=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(e=t.memoizedState.cachePool.pool),e!==n&&(e!=null&&e.refCount++,n!=null&&Kl(n))}function nu(e,t){e=null,t.alternate!==null&&(e=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==e&&(t.refCount++,e!=null&&Kl(e))}function tn(e,t,n,l){if(t.subtreeFlags&10256)for(t=t.child;t!==null;)lh(e,t,n,l),t=t.sibling}function lh(e,t,n,l){var s=t.flags;switch(t.tag){case 0:case 11:case 15:tn(e,t,n,l),s&2048&&ri(9,t);break;case 1:tn(e,t,n,l);break;case 3:tn(e,t,n,l),s&2048&&(e=null,t.alternate!==null&&(e=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==e&&(t.refCount++,e!=null&&Kl(e)));break;case 12:if(s&2048){tn(e,t,n,l),e=t.stateNode;try{var c=t.memoizedProps,h=c.id,g=c.onPostCommit;typeof g=="function"&&g(h,t.alternate===null?"mount":"update",e.passiveEffectDuration,-0)}catch(y){be(t,t.return,y)}}else tn(e,t,n,l);break;case 13:tn(e,t,n,l);break;case 23:break;case 22:c=t.stateNode,h=t.alternate,t.memoizedState!==null?c._visibility&2?tn(e,t,n,l):oi(e,t):c._visibility&2?tn(e,t,n,l):(c._visibility|=2,ul(e,t,n,l,(t.subtreeFlags&10256)!==0)),s&2048&&tu(h,t);break;case 24:tn(e,t,n,l),s&2048&&nu(t.alternate,t);break;default:tn(e,t,n,l)}}function ul(e,t,n,l,s){for(s=s&&(t.subtreeFlags&10256)!==0,t=t.child;t!==null;){var c=e,h=t,g=n,y=l,T=h.flags;switch(h.tag){case 0:case 11:case 15:ul(c,h,g,y,s),ri(8,h);break;case 23:break;case 22:var z=h.stateNode;h.memoizedState!==null?z._visibility&2?ul(c,h,g,y,s):oi(c,h):(z._visibility|=2,ul(c,h,g,y,s)),s&&T&2048&&tu(h.alternate,h);break;case 24:ul(c,h,g,y,s),s&&T&2048&&nu(h.alternate,h);break;default:ul(c,h,g,y,s)}t=t.sibling}}function oi(e,t){if(t.subtreeFlags&10256)for(t=t.child;t!==null;){var n=e,l=t,s=l.flags;switch(l.tag){case 22:oi(n,l),s&2048&&tu(l.alternate,l);break;case 24:oi(n,l),s&2048&&nu(l.alternate,l);break;default:oi(n,l)}t=t.sibling}}var di=8192;function ol(e){if(e.subtreeFlags&di)for(e=e.child;e!==null;)ih(e),e=e.sibling}function ih(e){switch(e.tag){case 26:ol(e),e.flags&di&&e.memoizedState!==null&&Gp(Vt,e.memoizedState,e.memoizedProps);break;case 5:ol(e);break;case 3:case 4:var t=Vt;Vt=Ws(e.stateNode.containerInfo),ol(e),Vt=t;break;case 22:e.memoizedState===null&&(t=e.alternate,t!==null&&t.memoizedState!==null?(t=di,di=16777216,ol(e),di=t):ol(e));break;default:ol(e)}}function sh(e){var t=e.alternate;if(t!==null&&(e=t.child,e!==null)){t.child=null;do t=e.sibling,e.sibling=null,e=t;while(e!==null)}}function fi(e){var t=e.deletions;if((e.flags&16)!==0){if(t!==null)for(var n=0;n<t.length;n++){var l=t[n];tt=l,rh(l,e)}sh(e)}if(e.subtreeFlags&10256)for(e=e.child;e!==null;)ch(e),e=e.sibling}function ch(e){switch(e.tag){case 0:case 11:case 15:fi(e),e.flags&2048&&Gn(9,e,e.return);break;case 3:fi(e);break;case 12:fi(e);break;case 22:var t=e.stateNode;e.memoizedState!==null&&t._visibility&2&&(e.return===null||e.return.tag!==13)?(t._visibility&=-3,Hs(e)):fi(e);break;default:fi(e)}}function Hs(e){var t=e.deletions;if((e.flags&16)!==0){if(t!==null)for(var n=0;n<t.length;n++){var l=t[n];tt=l,rh(l,e)}sh(e)}for(e=e.child;e!==null;){switch(t=e,t.tag){case 0:case 11:case 15:Gn(8,t,t.return),Hs(t);break;case 22:n=t.stateNode,n._visibility&2&&(n._visibility&=-3,Hs(t));break;default:Hs(t)}e=e.sibling}}function rh(e,t){for(;tt!==null;){var n=tt;switch(n.tag){case 0:case 11:case 15:Gn(8,n,t);break;case 23:case 22:if(n.memoizedState!==null&&n.memoizedState.cachePool!==null){var l=n.memoizedState.cachePool.pool;l!=null&&l.refCount++}break;case 24:Kl(n.memoizedState.cache)}if(l=n.child,l!==null)l.return=n,tt=l;else e:for(n=e;tt!==null;){l=tt;var s=l.sibling,c=l.return;if(Pf(l),l===n){tt=null;break e}if(s!==null){s.return=c,tt=s;break e}tt=c}}}var lp={getCacheForType:function(e){var t=ut(Ze),n=t.data.get(e);return n===void 0&&(n=e(),t.data.set(e,n)),n}},ip=typeof WeakMap=="function"?WeakMap:Map,me=0,Ce=null,te=null,le=0,xe=0,Dt=null,Qn=!1,dl=!1,au=!1,Cn=0,Le=0,Vn=0,Ta=0,lu=0,qt=0,fl=0,hi=null,yt=null,iu=!1,su=0,qs=1/0,$s=null,Zn=null,lt=0,Kn=null,hl=null,ml=0,cu=0,ru=null,uh=null,mi=0,uu=null;function Mt(){if((me&2)!==0&&le!==0)return le&-le;if(B.T!==null){var e=tl;return e!==0?e:gu()}return Co()}function oh(){qt===0&&(qt=(le&536870912)===0||re?jo():536870912);var e=Ht.current;return e!==null&&(e.flags|=32),qt}function Ot(e,t,n){(e===Ce&&(xe===2||xe===9)||e.cancelPendingCommit!==null)&&(xl(e,0),Fn(e,le,qt,!1)),zl(e,n),((me&2)===0||e!==Ce)&&(e===Ce&&((me&2)===0&&(Ta|=n),Le===4&&Fn(e,le,qt,!1)),nn(e))}function dh(e,t,n){if((me&6)!==0)throw Error(u(327));var l=!n&&(t&124)===0&&(t&e.expiredLanes)===0||Ol(e,t),s=l?rp(e,t):fu(e,t,!0),c=l;do{if(s===0){dl&&!l&&Fn(e,t,0,!1);break}else{if(n=e.current.alternate,c&&!sp(n)){s=fu(e,t,!1),c=!1;continue}if(s===2){if(c=t,e.errorRecoveryDisabledLanes&c)var h=0;else h=e.pendingLanes&-536870913,h=h!==0?h:h&536870912?536870912:0;if(h!==0){t=h;e:{var g=e;s=hi;var y=g.current.memoizedState.isDehydrated;if(y&&(xl(g,h).flags|=256),h=fu(g,h,!1),h!==2){if(au&&!y){g.errorRecoveryDisabledLanes|=c,Ta|=c,s=4;break e}c=yt,yt=s,c!==null&&(yt===null?yt=c:yt.push.apply(yt,c))}s=h}if(c=!1,s!==2)continue}}if(s===1){xl(e,0),Fn(e,t,0,!0);break}e:{switch(l=e,c=s,c){case 0:case 1:throw Error(u(345));case 4:if((t&4194048)!==t)break;case 6:Fn(l,t,qt,!Qn);break e;case 2:yt=null;break;case 3:case 5:break;default:throw Error(u(329))}if((t&62914560)===t&&(s=su+300-Wt(),10<s)){if(Fn(l,t,qt,!Qn),Ii(l,0,!0)!==0)break e;l.timeoutHandle=qh(fh.bind(null,l,n,yt,$s,iu,t,qt,Ta,fl,Qn,c,2,-0,0),s);break e}fh(l,n,yt,$s,iu,t,qt,Ta,fl,Qn,c,0,-0,0)}}break}while(!0);nn(e)}function fh(e,t,n,l,s,c,h,g,y,T,z,R,E,A){if(e.timeoutHandle=-1,R=t.subtreeFlags,(R&8192||(R&16785408)===16785408)&&(bi={stylesheets:null,count:0,unsuspend:$p},ih(t),R=Yp(),R!==null)){e.cancelPendingCommit=R(yh.bind(null,e,t,c,n,l,s,h,g,y,z,1,E,A)),Fn(e,c,h,!T);return}yh(e,t,c,n,l,s,h,g,y)}function sp(e){for(var t=e;;){var n=t.tag;if((n===0||n===11||n===15)&&t.flags&16384&&(n=t.updateQueue,n!==null&&(n=n.stores,n!==null)))for(var l=0;l<n.length;l++){var s=n[l],c=s.getSnapshot;s=s.value;try{if(!_t(c(),s))return!1}catch{return!1}}if(n=t.child,t.subtreeFlags&16384&&n!==null)n.return=t,t=n;else{if(t===e)break;for(;t.sibling===null;){if(t.return===null||t.return===e)return!0;t=t.return}t.sibling.return=t.return,t=t.sibling}}return!0}function Fn(e,t,n,l){t&=~lu,t&=~Ta,e.suspendedLanes|=t,e.pingedLanes&=~t,l&&(e.warmLanes|=t),l=e.expirationTimes;for(var s=t;0<s;){var c=31-Ct(s),h=1<<c;l[c]=-1,s&=~h}n!==0&&So(e,n,t)}function Gs(){return(me&6)===0?(xi(0),!1):!0}function ou(){if(te!==null){if(xe===0)var e=te.return;else e=te,gn=ja=null,Er(e),cl=null,ii=0,e=te;for(;e!==null;)Qf(e.alternate,e),e=e.return;te=null}}function xl(e,t){var n=e.timeoutHandle;n!==-1&&(e.timeoutHandle=-1,Cp(n)),n=e.cancelPendingCommit,n!==null&&(e.cancelPendingCommit=null,n()),ou(),Ce=e,te=n=hn(e.current,null),le=t,xe=0,Dt=null,Qn=!1,dl=Ol(e,t),au=!1,fl=qt=lu=Ta=Vn=Le=0,yt=hi=null,iu=!1,(t&8)!==0&&(t|=t&32);var l=e.entangledLanes;if(l!==0)for(e=e.entanglements,l&=t;0<l;){var s=31-Ct(l),c=1<<s;t|=e[s],l&=~c}return Cn=t,os(),n}function hh(e,t){P=null,B.H=Ds,t===Jl||t===ys?(t=Dd(),xe=3):t===Td?(t=Dd(),xe=4):xe=t===Of?8:t!==null&&typeof t=="object"&&typeof t.then=="function"?6:1,Dt=t,te===null&&(Le=1,Bs(e,Rt(t,e.current)))}function mh(){var e=B.H;return B.H=Ds,e===null?Ds:e}function xh(){var e=B.A;return B.A=lp,e}function du(){Le=4,Qn||(le&4194048)!==le&&Ht.current!==null||(dl=!0),(Vn&134217727)===0&&(Ta&134217727)===0||Ce===null||Fn(Ce,le,qt,!1)}function fu(e,t,n){var l=me;me|=2;var s=mh(),c=xh();(Ce!==e||le!==t)&&($s=null,xl(e,t)),t=!1;var h=Le;e:do try{if(xe!==0&&te!==null){var g=te,y=Dt;switch(xe){case 8:ou(),h=6;break e;case 3:case 2:case 9:case 6:Ht.current===null&&(t=!0);var T=xe;if(xe=0,Dt=null,gl(e,g,y,T),n&&dl){h=0;break e}break;default:T=xe,xe=0,Dt=null,gl(e,g,y,T)}}cp(),h=Le;break}catch(z){hh(e,z)}while(!0);return t&&e.shellSuspendCounter++,gn=ja=null,me=l,B.H=s,B.A=c,te===null&&(Ce=null,le=0,os()),h}function cp(){for(;te!==null;)gh(te)}function rp(e,t){var n=me;me|=2;var l=mh(),s=xh();Ce!==e||le!==t?($s=null,qs=Wt()+500,xl(e,t)):dl=Ol(e,t);e:do try{if(xe!==0&&te!==null){t=te;var c=Dt;t:switch(xe){case 1:xe=0,Dt=null,gl(e,t,c,1);break;case 2:case 9:if(Ed(c)){xe=0,Dt=null,ph(t);break}t=function(){xe!==2&&xe!==9||Ce!==e||(xe=7),nn(e)},c.then(t,t);break e;case 3:xe=7;break e;case 4:xe=5;break e;case 7:Ed(c)?(xe=0,Dt=null,ph(t)):(xe=0,Dt=null,gl(e,t,c,7));break;case 5:var h=null;switch(te.tag){case 26:h=te.memoizedState;case 5:case 27:var g=te;if(!h||Ih(h)){xe=0,Dt=null;var y=g.sibling;if(y!==null)te=y;else{var T=g.return;T!==null?(te=T,Ys(T)):te=null}break t}}xe=0,Dt=null,gl(e,t,c,5);break;case 6:xe=0,Dt=null,gl(e,t,c,6);break;case 8:ou(),Le=6;break e;default:throw Error(u(462))}}up();break}catch(z){hh(e,z)}while(!0);return gn=ja=null,B.H=l,B.A=s,me=n,te!==null?0:(Ce=null,le=0,os(),Le)}function up(){for(;te!==null&&!Ox();)gh(te)}function gh(e){var t=Yf(e.alternate,e,Cn);e.memoizedProps=e.pendingProps,t===null?Ys(e):te=t}function ph(e){var t=e,n=t.alternate;switch(t.tag){case 15:case 0:t=Lf(n,t,t.pendingProps,t.type,void 0,le);break;case 11:t=Lf(n,t,t.pendingProps,t.type.render,t.ref,le);break;case 5:Er(t);default:Qf(n,t),t=te=pd(t,Cn),t=Yf(n,t,Cn)}e.memoizedProps=e.pendingProps,t===null?Ys(e):te=t}function gl(e,t,n,l){gn=ja=null,Er(t),cl=null,ii=0;var s=t.return;try{if(Ig(e,s,t,n,le)){Le=1,Bs(e,Rt(n,e.current)),te=null;return}}catch(c){if(s!==null)throw te=s,c;Le=1,Bs(e,Rt(n,e.current)),te=null;return}t.flags&32768?(re||l===1?e=!0:dl||(le&536870912)!==0?e=!1:(Qn=e=!0,(l===2||l===9||l===3||l===6)&&(l=Ht.current,l!==null&&l.tag===13&&(l.flags|=16384))),vh(t,e)):Ys(t)}function Ys(e){var t=e;do{if((t.flags&32768)!==0){vh(t,Qn);return}e=t.return;var n=ep(t.alternate,t,Cn);if(n!==null){te=n;return}if(t=t.sibling,t!==null){te=t;return}te=t=e}while(t!==null);Le===0&&(Le=5)}function vh(e,t){do{var n=tp(e.alternate,e);if(n!==null){n.flags&=32767,te=n;return}if(n=e.return,n!==null&&(n.flags|=32768,n.subtreeFlags=0,n.deletions=null),!t&&(e=e.sibling,e!==null)){te=e;return}te=e=n}while(e!==null);Le=6,te=null}function yh(e,t,n,l,s,c,h,g,y){e.cancelPendingCommit=null;do Xs();while(lt!==0);if((me&6)!==0)throw Error(u(327));if(t!==null){if(t===e.current)throw Error(u(177));if(c=t.lanes|t.childLanes,c|=nr,$x(e,n,c,h,g,y),e===Ce&&(te=Ce=null,le=0),hl=t,Kn=e,ml=n,cu=c,ru=s,uh=l,(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?(e.callbackNode=null,e.callbackPriority=0,hp(Fi,function(){return Ch(),null})):(e.callbackNode=null,e.callbackPriority=0),l=(t.flags&13878)!==0,(t.subtreeFlags&13878)!==0||l){l=B.T,B.T=null,s=G.p,G.p=2,h=me,me|=4;try{np(e,t,n)}finally{me=h,G.p=s,B.T=l}}lt=1,jh(),bh(),Sh()}}function jh(){if(lt===1){lt=0;var e=Kn,t=hl,n=(t.flags&13878)!==0;if((t.subtreeFlags&13878)!==0||n){n=B.T,B.T=null;var l=G.p;G.p=2;var s=me;me|=4;try{nh(t,e);var c=Cu,h=cd(e.containerInfo),g=c.focusedElem,y=c.selectionRange;if(h!==g&&g&&g.ownerDocument&&sd(g.ownerDocument.documentElement,g)){if(y!==null&&Wc(g)){var T=y.start,z=y.end;if(z===void 0&&(z=T),"selectionStart"in g)g.selectionStart=T,g.selectionEnd=Math.min(z,g.value.length);else{var R=g.ownerDocument||document,E=R&&R.defaultView||window;if(E.getSelection){var A=E.getSelection(),K=g.textContent.length,Q=Math.min(y.start,K),ye=y.end===void 0?Q:Math.min(y.end,K);!A.extend&&Q>ye&&(h=ye,ye=Q,Q=h);var w=id(g,Q),S=id(g,ye);if(w&&S&&(A.rangeCount!==1||A.anchorNode!==w.node||A.anchorOffset!==w.offset||A.focusNode!==S.node||A.focusOffset!==S.offset)){var _=R.createRange();_.setStart(w.node,w.offset),A.removeAllRanges(),Q>ye?(A.addRange(_),A.extend(S.node,S.offset)):(_.setEnd(S.node,S.offset),A.addRange(_))}}}}for(R=[],A=g;A=A.parentNode;)A.nodeType===1&&R.push({element:A,left:A.scrollLeft,top:A.scrollTop});for(typeof g.focus=="function"&&g.focus(),g=0;g<R.length;g++){var N=R[g];N.element.scrollLeft=N.left,N.element.scrollTop=N.top}}nc=!!wu,Cu=wu=null}finally{me=s,G.p=l,B.T=n}}e.current=t,lt=2}}function bh(){if(lt===2){lt=0;var e=Kn,t=hl,n=(t.flags&8772)!==0;if((t.subtreeFlags&8772)!==0||n){n=B.T,B.T=null;var l=G.p;G.p=2;var s=me;me|=4;try{If(e,t.alternate,t)}finally{me=s,G.p=l,B.T=n}}lt=3}}function Sh(){if(lt===4||lt===3){lt=0,zx();var e=Kn,t=hl,n=ml,l=uh;(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?lt=5:(lt=0,hl=Kn=null,wh(e,e.pendingLanes));var s=e.pendingLanes;if(s===0&&(Zn=null),Mc(n),t=t.stateNode,wt&&typeof wt.onCommitFiberRoot=="function")try{wt.onCommitFiberRoot(Ml,t,void 0,(t.current.flags&128)===128)}catch{}if(l!==null){t=B.T,s=G.p,G.p=2,B.T=null;try{for(var c=e.onRecoverableError,h=0;h<l.length;h++){var g=l[h];c(g.value,{componentStack:g.stack})}}finally{B.T=t,G.p=s}}(ml&3)!==0&&Xs(),nn(e),s=e.pendingLanes,(n&4194090)!==0&&(s&42)!==0?e===uu?mi++:(mi=0,uu=e):mi=0,xi(0)}}function wh(e,t){(e.pooledCacheLanes&=t)===0&&(t=e.pooledCache,t!=null&&(e.pooledCache=null,Kl(t)))}function Xs(e){return jh(),bh(),Sh(),Ch()}function Ch(){if(lt!==5)return!1;var e=Kn,t=cu;cu=0;var n=Mc(ml),l=B.T,s=G.p;try{G.p=32>n?32:n,B.T=null,n=ru,ru=null;var c=Kn,h=ml;if(lt=0,hl=Kn=null,ml=0,(me&6)!==0)throw Error(u(331));var g=me;if(me|=4,ch(c.current),lh(c,c.current,h,n),me=g,xi(0,!1),wt&&typeof wt.onPostCommitFiberRoot=="function")try{wt.onPostCommitFiberRoot(Ml,c)}catch{}return!0}finally{G.p=s,B.T=l,wh(e,t)}}function _h(e,t,n){t=Rt(n,t),t=$r(e.stateNode,t,2),e=kn(e,t,2),e!==null&&(zl(e,2),nn(e))}function be(e,t,n){if(e.tag===3)_h(e,e,n);else for(;t!==null;){if(t.tag===3){_h(t,e,n);break}else if(t.tag===1){var l=t.stateNode;if(typeof t.type.getDerivedStateFromError=="function"||typeof l.componentDidCatch=="function"&&(Zn===null||!Zn.has(l))){e=Rt(n,e),n=Df(2),l=kn(t,n,2),l!==null&&(Mf(n,l,t,e),zl(l,2),nn(l));break}}t=t.return}}function hu(e,t,n){var l=e.pingCache;if(l===null){l=e.pingCache=new ip;var s=new Set;l.set(t,s)}else s=l.get(t),s===void 0&&(s=new Set,l.set(t,s));s.has(n)||(au=!0,s.add(n),e=op.bind(null,e,t,n),t.then(e,e))}function op(e,t,n){var l=e.pingCache;l!==null&&l.delete(t),e.pingedLanes|=e.suspendedLanes&n,e.warmLanes&=~n,Ce===e&&(le&n)===n&&(Le===4||Le===3&&(le&62914560)===le&&300>Wt()-su?(me&2)===0&&xl(e,0):lu|=n,fl===le&&(fl=0)),nn(e)}function Th(e,t){t===0&&(t=bo()),e=Wa(e,t),e!==null&&(zl(e,t),nn(e))}function dp(e){var t=e.memoizedState,n=0;t!==null&&(n=t.retryLane),Th(e,n)}function fp(e,t){var n=0;switch(e.tag){case 13:var l=e.stateNode,s=e.memoizedState;s!==null&&(n=s.retryLane);break;case 19:l=e.stateNode;break;case 22:l=e.stateNode._retryCache;break;default:throw Error(u(314))}l!==null&&l.delete(t),Th(e,n)}function hp(e,t){return Tc(e,t)}var Qs=null,pl=null,mu=!1,Vs=!1,xu=!1,Ea=0;function nn(e){e!==pl&&e.next===null&&(pl===null?Qs=pl=e:pl=pl.next=e),Vs=!0,mu||(mu=!0,xp())}function xi(e,t){if(!xu&&Vs){xu=!0;do for(var n=!1,l=Qs;l!==null;){if(e!==0){var s=l.pendingLanes;if(s===0)var c=0;else{var h=l.suspendedLanes,g=l.pingedLanes;c=(1<<31-Ct(42|e)+1)-1,c&=s&~(h&~g),c=c&201326741?c&201326741|1:c?c|2:0}c!==0&&(n=!0,Mh(l,c))}else c=le,c=Ii(l,l===Ce?c:0,l.cancelPendingCommit!==null||l.timeoutHandle!==-1),(c&3)===0||Ol(l,c)||(n=!0,Mh(l,c));l=l.next}while(n);xu=!1}}function mp(){Eh()}function Eh(){Vs=mu=!1;var e=0;Ea!==0&&(wp()&&(e=Ea),Ea=0);for(var t=Wt(),n=null,l=Qs;l!==null;){var s=l.next,c=Ah(l,t);c===0?(l.next=null,n===null?Qs=s:n.next=s,s===null&&(pl=n)):(n=l,(e!==0||(c&3)!==0)&&(Vs=!0)),l=s}xi(e)}function Ah(e,t){for(var n=e.suspendedLanes,l=e.pingedLanes,s=e.expirationTimes,c=e.pendingLanes&-62914561;0<c;){var h=31-Ct(c),g=1<<h,y=s[h];y===-1?((g&n)===0||(g&l)!==0)&&(s[h]=qx(g,t)):y<=t&&(e.expiredLanes|=g),c&=~g}if(t=Ce,n=le,n=Ii(e,e===t?n:0,e.cancelPendingCommit!==null||e.timeoutHandle!==-1),l=e.callbackNode,n===0||e===t&&(xe===2||xe===9)||e.cancelPendingCommit!==null)return l!==null&&l!==null&&Ec(l),e.callbackNode=null,e.callbackPriority=0;if((n&3)===0||Ol(e,n)){if(t=n&-n,t===e.callbackPriority)return t;switch(l!==null&&Ec(l),Mc(n)){case 2:case 8:n=vo;break;case 32:n=Fi;break;case 268435456:n=yo;break;default:n=Fi}return l=Dh.bind(null,e),n=Tc(n,l),e.callbackPriority=t,e.callbackNode=n,t}return l!==null&&l!==null&&Ec(l),e.callbackPriority=2,e.callbackNode=null,2}function Dh(e,t){if(lt!==0&&lt!==5)return e.callbackNode=null,e.callbackPriority=0,null;var n=e.callbackNode;if(Xs()&&e.callbackNode!==n)return null;var l=le;return l=Ii(e,e===Ce?l:0,e.cancelPendingCommit!==null||e.timeoutHandle!==-1),l===0?null:(dh(e,l,t),Ah(e,Wt()),e.callbackNode!=null&&e.callbackNode===n?Dh.bind(null,e):null)}function Mh(e,t){if(Xs())return null;dh(e,t,!0)}function xp(){_p(function(){(me&6)!==0?Tc(po,mp):Eh()})}function gu(){return Ea===0&&(Ea=jo()),Ea}function Oh(e){return e==null||typeof e=="symbol"||typeof e=="boolean"?null:typeof e=="function"?e:as(""+e)}function zh(e,t){var n=t.ownerDocument.createElement("input");return n.name=t.name,n.value=t.value,e.id&&n.setAttribute("form",e.id),t.parentNode.insertBefore(n,t),e=new FormData(e),n.parentNode.removeChild(n),e}function gp(e,t,n,l,s){if(t==="submit"&&n&&n.stateNode===s){var c=Oh((s[xt]||null).action),h=l.submitter;h&&(t=(t=h[xt]||null)?Oh(t.formAction):h.getAttribute("formAction"),t!==null&&(c=t,h=null));var g=new cs("action","action",null,l,s);e.push({event:g,listeners:[{instance:null,listener:function(){if(l.defaultPrevented){if(Ea!==0){var y=h?zh(s,h):new FormData(s);Ur(n,{pending:!0,data:y,method:s.method,action:c},null,y)}}else typeof c=="function"&&(g.preventDefault(),y=h?zh(s,h):new FormData(s),Ur(n,{pending:!0,data:y,method:s.method,action:c},c,y))},currentTarget:s}]})}}for(var pu=0;pu<tr.length;pu++){var vu=tr[pu],pp=vu.toLowerCase(),vp=vu[0].toUpperCase()+vu.slice(1);Qt(pp,"on"+vp)}Qt(od,"onAnimationEnd"),Qt(dd,"onAnimationIteration"),Qt(fd,"onAnimationStart"),Qt("dblclick","onDoubleClick"),Qt("focusin","onFocus"),Qt("focusout","onBlur"),Qt(Rg,"onTransitionRun"),Qt(Ug,"onTransitionStart"),Qt(Lg,"onTransitionCancel"),Qt(hd,"onTransitionEnd"),$a("onMouseEnter",["mouseout","mouseover"]),$a("onMouseLeave",["mouseout","mouseover"]),$a("onPointerEnter",["pointerout","pointerover"]),$a("onPointerLeave",["pointerout","pointerover"]),da("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),da("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),da("onBeforeInput",["compositionend","keypress","textInput","paste"]),da("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),da("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),da("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var gi="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),yp=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(gi));function Nh(e,t){t=(t&4)!==0;for(var n=0;n<e.length;n++){var l=e[n],s=l.event;l=l.listeners;e:{var c=void 0;if(t)for(var h=l.length-1;0<=h;h--){var g=l[h],y=g.instance,T=g.currentTarget;if(g=g.listener,y!==c&&s.isPropagationStopped())break e;c=g,s.currentTarget=T;try{c(s)}catch(z){Ns(z)}s.currentTarget=null,c=y}else for(h=0;h<l.length;h++){if(g=l[h],y=g.instance,T=g.currentTarget,g=g.listener,y!==c&&s.isPropagationStopped())break e;c=g,s.currentTarget=T;try{c(s)}catch(z){Ns(z)}s.currentTarget=null,c=y}}}}function ne(e,t){var n=t[Oc];n===void 0&&(n=t[Oc]=new Set);var l=e+"__bubble";n.has(l)||(Bh(t,e,2,!1),n.add(l))}function yu(e,t,n){var l=0;t&&(l|=4),Bh(n,e,l,t)}var Zs="_reactListening"+Math.random().toString(36).slice(2);function ju(e){if(!e[Zs]){e[Zs]=!0,To.forEach(function(n){n!=="selectionchange"&&(yp.has(n)||yu(n,!1,e),yu(n,!0,e))});var t=e.nodeType===9?e:e.ownerDocument;t===null||t[Zs]||(t[Zs]=!0,yu("selectionchange",!1,t))}}function Bh(e,t,n,l){switch(lm(t)){case 2:var s=Vp;break;case 8:s=Zp;break;default:s=Bu}n=s.bind(null,t,n,e),s=void 0,!Gc||t!=="touchstart"&&t!=="touchmove"&&t!=="wheel"||(s=!0),l?s!==void 0?e.addEventListener(t,n,{capture:!0,passive:s}):e.addEventListener(t,n,!0):s!==void 0?e.addEventListener(t,n,{passive:s}):e.addEventListener(t,n,!1)}function bu(e,t,n,l,s){var c=l;if((t&1)===0&&(t&2)===0&&l!==null)e:for(;;){if(l===null)return;var h=l.tag;if(h===3||h===4){var g=l.stateNode.containerInfo;if(g===s)break;if(h===4)for(h=l.return;h!==null;){var y=h.tag;if((y===3||y===4)&&h.stateNode.containerInfo===s)return;h=h.return}for(;g!==null;){if(h=ka(g),h===null)return;if(y=h.tag,y===5||y===6||y===26||y===27){l=c=h;continue e}g=g.parentNode}}l=l.return}qo(function(){var T=c,z=qc(n),R=[];e:{var E=md.get(e);if(E!==void 0){var A=cs,K=e;switch(e){case"keypress":if(is(n)===0)break e;case"keydown":case"keyup":A=hg;break;case"focusin":K="focus",A=Vc;break;case"focusout":K="blur",A=Vc;break;case"beforeblur":case"afterblur":A=Vc;break;case"click":if(n.button===2)break e;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":A=Yo;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":A=tg;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":A=gg;break;case od:case dd:case fd:A=lg;break;case hd:A=vg;break;case"scroll":case"scrollend":A=Px;break;case"wheel":A=jg;break;case"copy":case"cut":case"paste":A=sg;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":A=Qo;break;case"toggle":case"beforetoggle":A=Sg}var Q=(t&4)!==0,ye=!Q&&(e==="scroll"||e==="scrollend"),w=Q?E!==null?E+"Capture":null:E;Q=[];for(var S=T,_;S!==null;){var N=S;if(_=N.stateNode,N=N.tag,N!==5&&N!==26&&N!==27||_===null||w===null||(N=Rl(S,w),N!=null&&Q.push(pi(S,N,_))),ye)break;S=S.return}0<Q.length&&(E=new A(E,K,null,n,z),R.push({event:E,listeners:Q}))}}if((t&7)===0){e:{if(E=e==="mouseover"||e==="pointerover",A=e==="mouseout"||e==="pointerout",E&&n!==Hc&&(K=n.relatedTarget||n.fromElement)&&(ka(K)||K[La]))break e;if((A||E)&&(E=z.window===z?z:(E=z.ownerDocument)?E.defaultView||E.parentWindow:window,A?(K=n.relatedTarget||n.toElement,A=T,K=K?ka(K):null,K!==null&&(ye=f(K),Q=K.tag,K!==ye||Q!==5&&Q!==27&&Q!==6)&&(K=null)):(A=null,K=T),A!==K)){if(Q=Yo,N="onMouseLeave",w="onMouseEnter",S="mouse",(e==="pointerout"||e==="pointerover")&&(Q=Qo,N="onPointerLeave",w="onPointerEnter",S="pointer"),ye=A==null?E:Bl(A),_=K==null?E:Bl(K),E=new Q(N,S+"leave",A,n,z),E.target=ye,E.relatedTarget=_,N=null,ka(z)===T&&(Q=new Q(w,S+"enter",K,n,z),Q.target=_,Q.relatedTarget=ye,N=Q),ye=N,A&&K)t:{for(Q=A,w=K,S=0,_=Q;_;_=vl(_))S++;for(_=0,N=w;N;N=vl(N))_++;for(;0<S-_;)Q=vl(Q),S--;for(;0<_-S;)w=vl(w),_--;for(;S--;){if(Q===w||w!==null&&Q===w.alternate)break t;Q=vl(Q),w=vl(w)}Q=null}else Q=null;A!==null&&Rh(R,E,A,Q,!1),K!==null&&ye!==null&&Rh(R,ye,K,Q,!0)}}e:{if(E=T?Bl(T):window,A=E.nodeName&&E.nodeName.toLowerCase(),A==="select"||A==="input"&&E.type==="file")var Y=Po;else if(Wo(E))if(ed)Y=zg;else{Y=Mg;var ee=Dg}else A=E.nodeName,!A||A.toLowerCase()!=="input"||E.type!=="checkbox"&&E.type!=="radio"?T&&kc(T.elementType)&&(Y=Po):Y=Og;if(Y&&(Y=Y(e,T))){Io(R,Y,n,z);break e}ee&&ee(e,E,T),e==="focusout"&&T&&E.type==="number"&&T.memoizedProps.value!=null&&Lc(E,"number",E.value)}switch(ee=T?Bl(T):window,e){case"focusin":(Wo(ee)||ee.contentEditable==="true")&&(Ka=ee,Ic=T,Yl=null);break;case"focusout":Yl=Ic=Ka=null;break;case"mousedown":Pc=!0;break;case"contextmenu":case"mouseup":case"dragend":Pc=!1,rd(R,n,z);break;case"selectionchange":if(Bg)break;case"keydown":case"keyup":rd(R,n,z)}var X;if(Kc)e:{switch(e){case"compositionstart":var V="onCompositionStart";break e;case"compositionend":V="onCompositionEnd";break e;case"compositionupdate":V="onCompositionUpdate";break e}V=void 0}else Za?Fo(e,n)&&(V="onCompositionEnd"):e==="keydown"&&n.keyCode===229&&(V="onCompositionStart");V&&(Vo&&n.locale!=="ko"&&(Za||V!=="onCompositionStart"?V==="onCompositionEnd"&&Za&&(X=$o()):(Bn=z,Yc="value"in Bn?Bn.value:Bn.textContent,Za=!0)),ee=Ks(T,V),0<ee.length&&(V=new Xo(V,e,null,n,z),R.push({event:V,listeners:ee}),X?V.data=X:(X=Jo(n),X!==null&&(V.data=X)))),(X=Cg?_g(e,n):Tg(e,n))&&(V=Ks(T,"onBeforeInput"),0<V.length&&(ee=new Xo("onBeforeInput","beforeinput",null,n,z),R.push({event:ee,listeners:V}),ee.data=X)),gp(R,e,T,n,z)}Nh(R,t)})}function pi(e,t,n){return{instance:e,listener:t,currentTarget:n}}function Ks(e,t){for(var n=t+"Capture",l=[];e!==null;){var s=e,c=s.stateNode;if(s=s.tag,s!==5&&s!==26&&s!==27||c===null||(s=Rl(e,n),s!=null&&l.unshift(pi(e,s,c)),s=Rl(e,t),s!=null&&l.push(pi(e,s,c))),e.tag===3)return l;e=e.return}return[]}function vl(e){if(e===null)return null;do e=e.return;while(e&&e.tag!==5&&e.tag!==27);return e||null}function Rh(e,t,n,l,s){for(var c=t._reactName,h=[];n!==null&&n!==l;){var g=n,y=g.alternate,T=g.stateNode;if(g=g.tag,y!==null&&y===l)break;g!==5&&g!==26&&g!==27||T===null||(y=T,s?(T=Rl(n,c),T!=null&&h.unshift(pi(n,T,y))):s||(T=Rl(n,c),T!=null&&h.push(pi(n,T,y)))),n=n.return}h.length!==0&&e.push({event:t,listeners:h})}var jp=/\r\n?/g,bp=/\u0000|\uFFFD/g;function Uh(e){return(typeof e=="string"?e:""+e).replace(jp,`
`).replace(bp,"")}function Lh(e,t){return t=Uh(t),Uh(e)===t}function Fs(){}function ve(e,t,n,l,s,c){switch(n){case"children":typeof l=="string"?t==="body"||t==="textarea"&&l===""||Xa(e,l):(typeof l=="number"||typeof l=="bigint")&&t!=="body"&&Xa(e,""+l);break;case"className":es(e,"class",l);break;case"tabIndex":es(e,"tabindex",l);break;case"dir":case"role":case"viewBox":case"width":case"height":es(e,n,l);break;case"style":ko(e,l,c);break;case"data":if(t!=="object"){es(e,"data",l);break}case"src":case"href":if(l===""&&(t!=="a"||n!=="href")){e.removeAttribute(n);break}if(l==null||typeof l=="function"||typeof l=="symbol"||typeof l=="boolean"){e.removeAttribute(n);break}l=as(""+l),e.setAttribute(n,l);break;case"action":case"formAction":if(typeof l=="function"){e.setAttribute(n,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof c=="function"&&(n==="formAction"?(t!=="input"&&ve(e,t,"name",s.name,s,null),ve(e,t,"formEncType",s.formEncType,s,null),ve(e,t,"formMethod",s.formMethod,s,null),ve(e,t,"formTarget",s.formTarget,s,null)):(ve(e,t,"encType",s.encType,s,null),ve(e,t,"method",s.method,s,null),ve(e,t,"target",s.target,s,null)));if(l==null||typeof l=="symbol"||typeof l=="boolean"){e.removeAttribute(n);break}l=as(""+l),e.setAttribute(n,l);break;case"onClick":l!=null&&(e.onclick=Fs);break;case"onScroll":l!=null&&ne("scroll",e);break;case"onScrollEnd":l!=null&&ne("scrollend",e);break;case"dangerouslySetInnerHTML":if(l!=null){if(typeof l!="object"||!("__html"in l))throw Error(u(61));if(n=l.__html,n!=null){if(s.children!=null)throw Error(u(60));e.innerHTML=n}}break;case"multiple":e.multiple=l&&typeof l!="function"&&typeof l!="symbol";break;case"muted":e.muted=l&&typeof l!="function"&&typeof l!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(l==null||typeof l=="function"||typeof l=="boolean"||typeof l=="symbol"){e.removeAttribute("xlink:href");break}n=as(""+l),e.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",n);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":l!=null&&typeof l!="function"&&typeof l!="symbol"?e.setAttribute(n,""+l):e.removeAttribute(n);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":l&&typeof l!="function"&&typeof l!="symbol"?e.setAttribute(n,""):e.removeAttribute(n);break;case"capture":case"download":l===!0?e.setAttribute(n,""):l!==!1&&l!=null&&typeof l!="function"&&typeof l!="symbol"?e.setAttribute(n,l):e.removeAttribute(n);break;case"cols":case"rows":case"size":case"span":l!=null&&typeof l!="function"&&typeof l!="symbol"&&!isNaN(l)&&1<=l?e.setAttribute(n,l):e.removeAttribute(n);break;case"rowSpan":case"start":l==null||typeof l=="function"||typeof l=="symbol"||isNaN(l)?e.removeAttribute(n):e.setAttribute(n,l);break;case"popover":ne("beforetoggle",e),ne("toggle",e),Pi(e,"popover",l);break;case"xlinkActuate":dn(e,"http://www.w3.org/1999/xlink","xlink:actuate",l);break;case"xlinkArcrole":dn(e,"http://www.w3.org/1999/xlink","xlink:arcrole",l);break;case"xlinkRole":dn(e,"http://www.w3.org/1999/xlink","xlink:role",l);break;case"xlinkShow":dn(e,"http://www.w3.org/1999/xlink","xlink:show",l);break;case"xlinkTitle":dn(e,"http://www.w3.org/1999/xlink","xlink:title",l);break;case"xlinkType":dn(e,"http://www.w3.org/1999/xlink","xlink:type",l);break;case"xmlBase":dn(e,"http://www.w3.org/XML/1998/namespace","xml:base",l);break;case"xmlLang":dn(e,"http://www.w3.org/XML/1998/namespace","xml:lang",l);break;case"xmlSpace":dn(e,"http://www.w3.org/XML/1998/namespace","xml:space",l);break;case"is":Pi(e,"is",l);break;case"innerText":case"textContent":break;default:(!(2<n.length)||n[0]!=="o"&&n[0]!=="O"||n[1]!=="n"&&n[1]!=="N")&&(n=Wx.get(n)||n,Pi(e,n,l))}}function Su(e,t,n,l,s,c){switch(n){case"style":ko(e,l,c);break;case"dangerouslySetInnerHTML":if(l!=null){if(typeof l!="object"||!("__html"in l))throw Error(u(61));if(n=l.__html,n!=null){if(s.children!=null)throw Error(u(60));e.innerHTML=n}}break;case"children":typeof l=="string"?Xa(e,l):(typeof l=="number"||typeof l=="bigint")&&Xa(e,""+l);break;case"onScroll":l!=null&&ne("scroll",e);break;case"onScrollEnd":l!=null&&ne("scrollend",e);break;case"onClick":l!=null&&(e.onclick=Fs);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!Eo.hasOwnProperty(n))e:{if(n[0]==="o"&&n[1]==="n"&&(s=n.endsWith("Capture"),t=n.slice(2,s?n.length-7:void 0),c=e[xt]||null,c=c!=null?c[n]:null,typeof c=="function"&&e.removeEventListener(t,c,s),typeof l=="function")){typeof c!="function"&&c!==null&&(n in e?e[n]=null:e.hasAttribute(n)&&e.removeAttribute(n)),e.addEventListener(t,l,s);break e}n in e?e[n]=l:l===!0?e.setAttribute(n,""):Pi(e,n,l)}}}function it(e,t,n){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":ne("error",e),ne("load",e);var l=!1,s=!1,c;for(c in n)if(n.hasOwnProperty(c)){var h=n[c];if(h!=null)switch(c){case"src":l=!0;break;case"srcSet":s=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(u(137,t));default:ve(e,t,c,h,n,null)}}s&&ve(e,t,"srcSet",n.srcSet,n,null),l&&ve(e,t,"src",n.src,n,null);return;case"input":ne("invalid",e);var g=c=h=s=null,y=null,T=null;for(l in n)if(n.hasOwnProperty(l)){var z=n[l];if(z!=null)switch(l){case"name":s=z;break;case"type":h=z;break;case"checked":y=z;break;case"defaultChecked":T=z;break;case"value":c=z;break;case"defaultValue":g=z;break;case"children":case"dangerouslySetInnerHTML":if(z!=null)throw Error(u(137,t));break;default:ve(e,t,l,z,n,null)}}Bo(e,c,g,y,T,h,s,!1),ts(e);return;case"select":ne("invalid",e),l=h=c=null;for(s in n)if(n.hasOwnProperty(s)&&(g=n[s],g!=null))switch(s){case"value":c=g;break;case"defaultValue":h=g;break;case"multiple":l=g;default:ve(e,t,s,g,n,null)}t=c,n=h,e.multiple=!!l,t!=null?Ya(e,!!l,t,!1):n!=null&&Ya(e,!!l,n,!0);return;case"textarea":ne("invalid",e),c=s=l=null;for(h in n)if(n.hasOwnProperty(h)&&(g=n[h],g!=null))switch(h){case"value":l=g;break;case"defaultValue":s=g;break;case"children":c=g;break;case"dangerouslySetInnerHTML":if(g!=null)throw Error(u(91));break;default:ve(e,t,h,g,n,null)}Uo(e,l,s,c),ts(e);return;case"option":for(y in n)if(n.hasOwnProperty(y)&&(l=n[y],l!=null))switch(y){case"selected":e.selected=l&&typeof l!="function"&&typeof l!="symbol";break;default:ve(e,t,y,l,n,null)}return;case"dialog":ne("beforetoggle",e),ne("toggle",e),ne("cancel",e),ne("close",e);break;case"iframe":case"object":ne("load",e);break;case"video":case"audio":for(l=0;l<gi.length;l++)ne(gi[l],e);break;case"image":ne("error",e),ne("load",e);break;case"details":ne("toggle",e);break;case"embed":case"source":case"link":ne("error",e),ne("load",e);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(T in n)if(n.hasOwnProperty(T)&&(l=n[T],l!=null))switch(T){case"children":case"dangerouslySetInnerHTML":throw Error(u(137,t));default:ve(e,t,T,l,n,null)}return;default:if(kc(t)){for(z in n)n.hasOwnProperty(z)&&(l=n[z],l!==void 0&&Su(e,t,z,l,n,void 0));return}}for(g in n)n.hasOwnProperty(g)&&(l=n[g],l!=null&&ve(e,t,g,l,n,null))}function Sp(e,t,n,l){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var s=null,c=null,h=null,g=null,y=null,T=null,z=null;for(A in n){var R=n[A];if(n.hasOwnProperty(A)&&R!=null)switch(A){case"checked":break;case"value":break;case"defaultValue":y=R;default:l.hasOwnProperty(A)||ve(e,t,A,null,l,R)}}for(var E in l){var A=l[E];if(R=n[E],l.hasOwnProperty(E)&&(A!=null||R!=null))switch(E){case"type":c=A;break;case"name":s=A;break;case"checked":T=A;break;case"defaultChecked":z=A;break;case"value":h=A;break;case"defaultValue":g=A;break;case"children":case"dangerouslySetInnerHTML":if(A!=null)throw Error(u(137,t));break;default:A!==R&&ve(e,t,E,A,l,R)}}Uc(e,h,g,y,T,z,c,s);return;case"select":A=h=g=E=null;for(c in n)if(y=n[c],n.hasOwnProperty(c)&&y!=null)switch(c){case"value":break;case"multiple":A=y;default:l.hasOwnProperty(c)||ve(e,t,c,null,l,y)}for(s in l)if(c=l[s],y=n[s],l.hasOwnProperty(s)&&(c!=null||y!=null))switch(s){case"value":E=c;break;case"defaultValue":g=c;break;case"multiple":h=c;default:c!==y&&ve(e,t,s,c,l,y)}t=g,n=h,l=A,E!=null?Ya(e,!!n,E,!1):!!l!=!!n&&(t!=null?Ya(e,!!n,t,!0):Ya(e,!!n,n?[]:"",!1));return;case"textarea":A=E=null;for(g in n)if(s=n[g],n.hasOwnProperty(g)&&s!=null&&!l.hasOwnProperty(g))switch(g){case"value":break;case"children":break;default:ve(e,t,g,null,l,s)}for(h in l)if(s=l[h],c=n[h],l.hasOwnProperty(h)&&(s!=null||c!=null))switch(h){case"value":E=s;break;case"defaultValue":A=s;break;case"children":break;case"dangerouslySetInnerHTML":if(s!=null)throw Error(u(91));break;default:s!==c&&ve(e,t,h,s,l,c)}Ro(e,E,A);return;case"option":for(var K in n)if(E=n[K],n.hasOwnProperty(K)&&E!=null&&!l.hasOwnProperty(K))switch(K){case"selected":e.selected=!1;break;default:ve(e,t,K,null,l,E)}for(y in l)if(E=l[y],A=n[y],l.hasOwnProperty(y)&&E!==A&&(E!=null||A!=null))switch(y){case"selected":e.selected=E&&typeof E!="function"&&typeof E!="symbol";break;default:ve(e,t,y,E,l,A)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var Q in n)E=n[Q],n.hasOwnProperty(Q)&&E!=null&&!l.hasOwnProperty(Q)&&ve(e,t,Q,null,l,E);for(T in l)if(E=l[T],A=n[T],l.hasOwnProperty(T)&&E!==A&&(E!=null||A!=null))switch(T){case"children":case"dangerouslySetInnerHTML":if(E!=null)throw Error(u(137,t));break;default:ve(e,t,T,E,l,A)}return;default:if(kc(t)){for(var ye in n)E=n[ye],n.hasOwnProperty(ye)&&E!==void 0&&!l.hasOwnProperty(ye)&&Su(e,t,ye,void 0,l,E);for(z in l)E=l[z],A=n[z],!l.hasOwnProperty(z)||E===A||E===void 0&&A===void 0||Su(e,t,z,E,l,A);return}}for(var w in n)E=n[w],n.hasOwnProperty(w)&&E!=null&&!l.hasOwnProperty(w)&&ve(e,t,w,null,l,E);for(R in l)E=l[R],A=n[R],!l.hasOwnProperty(R)||E===A||E==null&&A==null||ve(e,t,R,E,l,A)}var wu=null,Cu=null;function Js(e){return e.nodeType===9?e:e.ownerDocument}function kh(e){switch(e){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function Hh(e,t){if(e===0)switch(t){case"svg":return 1;case"math":return 2;default:return 0}return e===1&&t==="foreignObject"?0:e}function _u(e,t){return e==="textarea"||e==="noscript"||typeof t.children=="string"||typeof t.children=="number"||typeof t.children=="bigint"||typeof t.dangerouslySetInnerHTML=="object"&&t.dangerouslySetInnerHTML!==null&&t.dangerouslySetInnerHTML.__html!=null}var Tu=null;function wp(){var e=window.event;return e&&e.type==="popstate"?e===Tu?!1:(Tu=e,!0):(Tu=null,!1)}var qh=typeof setTimeout=="function"?setTimeout:void 0,Cp=typeof clearTimeout=="function"?clearTimeout:void 0,$h=typeof Promise=="function"?Promise:void 0,_p=typeof queueMicrotask=="function"?queueMicrotask:typeof $h<"u"?function(e){return $h.resolve(null).then(e).catch(Tp)}:qh;function Tp(e){setTimeout(function(){throw e})}function Jn(e){return e==="head"}function Gh(e,t){var n=t,l=0,s=0;do{var c=n.nextSibling;if(e.removeChild(n),c&&c.nodeType===8)if(n=c.data,n==="/$"){if(0<l&&8>l){n=l;var h=e.ownerDocument;if(n&1&&vi(h.documentElement),n&2&&vi(h.body),n&4)for(n=h.head,vi(n),h=n.firstChild;h;){var g=h.nextSibling,y=h.nodeName;h[Nl]||y==="SCRIPT"||y==="STYLE"||y==="LINK"&&h.rel.toLowerCase()==="stylesheet"||n.removeChild(h),h=g}}if(s===0){e.removeChild(c),Ti(t);return}s--}else n==="$"||n==="$?"||n==="$!"?s++:l=n.charCodeAt(0)-48;else l=0;n=c}while(n);Ti(t)}function Eu(e){var t=e.firstChild;for(t&&t.nodeType===10&&(t=t.nextSibling);t;){var n=t;switch(t=t.nextSibling,n.nodeName){case"HTML":case"HEAD":case"BODY":Eu(n),zc(n);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(n.rel.toLowerCase()==="stylesheet")continue}e.removeChild(n)}}function Ep(e,t,n,l){for(;e.nodeType===1;){var s=n;if(e.nodeName.toLowerCase()!==t.toLowerCase()){if(!l&&(e.nodeName!=="INPUT"||e.type!=="hidden"))break}else if(l){if(!e[Nl])switch(t){case"meta":if(!e.hasAttribute("itemprop"))break;return e;case"link":if(c=e.getAttribute("rel"),c==="stylesheet"&&e.hasAttribute("data-precedence"))break;if(c!==s.rel||e.getAttribute("href")!==(s.href==null||s.href===""?null:s.href)||e.getAttribute("crossorigin")!==(s.crossOrigin==null?null:s.crossOrigin)||e.getAttribute("title")!==(s.title==null?null:s.title))break;return e;case"style":if(e.hasAttribute("data-precedence"))break;return e;case"script":if(c=e.getAttribute("src"),(c!==(s.src==null?null:s.src)||e.getAttribute("type")!==(s.type==null?null:s.type)||e.getAttribute("crossorigin")!==(s.crossOrigin==null?null:s.crossOrigin))&&c&&e.hasAttribute("async")&&!e.hasAttribute("itemprop"))break;return e;default:return e}}else if(t==="input"&&e.type==="hidden"){var c=s.name==null?null:""+s.name;if(s.type==="hidden"&&e.getAttribute("name")===c)return e}else return e;if(e=Zt(e.nextSibling),e===null)break}return null}function Ap(e,t,n){if(t==="")return null;for(;e.nodeType!==3;)if((e.nodeType!==1||e.nodeName!=="INPUT"||e.type!=="hidden")&&!n||(e=Zt(e.nextSibling),e===null))return null;return e}function Au(e){return e.data==="$!"||e.data==="$?"&&e.ownerDocument.readyState==="complete"}function Dp(e,t){var n=e.ownerDocument;if(e.data!=="$?"||n.readyState==="complete")t();else{var l=function(){t(),n.removeEventListener("DOMContentLoaded",l)};n.addEventListener("DOMContentLoaded",l),e._reactRetry=l}}function Zt(e){for(;e!=null;e=e.nextSibling){var t=e.nodeType;if(t===1||t===3)break;if(t===8){if(t=e.data,t==="$"||t==="$!"||t==="$?"||t==="F!"||t==="F")break;if(t==="/$")return null}}return e}var Du=null;function Yh(e){e=e.previousSibling;for(var t=0;e;){if(e.nodeType===8){var n=e.data;if(n==="$"||n==="$!"||n==="$?"){if(t===0)return e;t--}else n==="/$"&&t++}e=e.previousSibling}return null}function Xh(e,t,n){switch(t=Js(n),e){case"html":if(e=t.documentElement,!e)throw Error(u(452));return e;case"head":if(e=t.head,!e)throw Error(u(453));return e;case"body":if(e=t.body,!e)throw Error(u(454));return e;default:throw Error(u(451))}}function vi(e){for(var t=e.attributes;t.length;)e.removeAttributeNode(t[0]);zc(e)}var $t=new Map,Qh=new Set;function Ws(e){return typeof e.getRootNode=="function"?e.getRootNode():e.nodeType===9?e:e.ownerDocument}var _n=G.d;G.d={f:Mp,r:Op,D:zp,C:Np,L:Bp,m:Rp,X:Lp,S:Up,M:kp};function Mp(){var e=_n.f(),t=Gs();return e||t}function Op(e){var t=Ha(e);t!==null&&t.tag===5&&t.type==="form"?df(t):_n.r(e)}var yl=typeof document>"u"?null:document;function Vh(e,t,n){var l=yl;if(l&&typeof t=="string"&&t){var s=Bt(t);s='link[rel="'+e+'"][href="'+s+'"]',typeof n=="string"&&(s+='[crossorigin="'+n+'"]'),Qh.has(s)||(Qh.add(s),e={rel:e,crossOrigin:n,href:t},l.querySelector(s)===null&&(t=l.createElement("link"),it(t,"link",e),Pe(t),l.head.appendChild(t)))}}function zp(e){_n.D(e),Vh("dns-prefetch",e,null)}function Np(e,t){_n.C(e,t),Vh("preconnect",e,t)}function Bp(e,t,n){_n.L(e,t,n);var l=yl;if(l&&e&&t){var s='link[rel="preload"][as="'+Bt(t)+'"]';t==="image"&&n&&n.imageSrcSet?(s+='[imagesrcset="'+Bt(n.imageSrcSet)+'"]',typeof n.imageSizes=="string"&&(s+='[imagesizes="'+Bt(n.imageSizes)+'"]')):s+='[href="'+Bt(e)+'"]';var c=s;switch(t){case"style":c=jl(e);break;case"script":c=bl(e)}$t.has(c)||(e=j({rel:"preload",href:t==="image"&&n&&n.imageSrcSet?void 0:e,as:t},n),$t.set(c,e),l.querySelector(s)!==null||t==="style"&&l.querySelector(yi(c))||t==="script"&&l.querySelector(ji(c))||(t=l.createElement("link"),it(t,"link",e),Pe(t),l.head.appendChild(t)))}}function Rp(e,t){_n.m(e,t);var n=yl;if(n&&e){var l=t&&typeof t.as=="string"?t.as:"script",s='link[rel="modulepreload"][as="'+Bt(l)+'"][href="'+Bt(e)+'"]',c=s;switch(l){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":c=bl(e)}if(!$t.has(c)&&(e=j({rel:"modulepreload",href:e},t),$t.set(c,e),n.querySelector(s)===null)){switch(l){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(n.querySelector(ji(c)))return}l=n.createElement("link"),it(l,"link",e),Pe(l),n.head.appendChild(l)}}}function Up(e,t,n){_n.S(e,t,n);var l=yl;if(l&&e){var s=qa(l).hoistableStyles,c=jl(e);t=t||"default";var h=s.get(c);if(!h){var g={loading:0,preload:null};if(h=l.querySelector(yi(c)))g.loading=5;else{e=j({rel:"stylesheet",href:e,"data-precedence":t},n),(n=$t.get(c))&&Mu(e,n);var y=h=l.createElement("link");Pe(y),it(y,"link",e),y._p=new Promise(function(T,z){y.onload=T,y.onerror=z}),y.addEventListener("load",function(){g.loading|=1}),y.addEventListener("error",function(){g.loading|=2}),g.loading|=4,Is(h,t,l)}h={type:"stylesheet",instance:h,count:1,state:g},s.set(c,h)}}}function Lp(e,t){_n.X(e,t);var n=yl;if(n&&e){var l=qa(n).hoistableScripts,s=bl(e),c=l.get(s);c||(c=n.querySelector(ji(s)),c||(e=j({src:e,async:!0},t),(t=$t.get(s))&&Ou(e,t),c=n.createElement("script"),Pe(c),it(c,"link",e),n.head.appendChild(c)),c={type:"script",instance:c,count:1,state:null},l.set(s,c))}}function kp(e,t){_n.M(e,t);var n=yl;if(n&&e){var l=qa(n).hoistableScripts,s=bl(e),c=l.get(s);c||(c=n.querySelector(ji(s)),c||(e=j({src:e,async:!0,type:"module"},t),(t=$t.get(s))&&Ou(e,t),c=n.createElement("script"),Pe(c),it(c,"link",e),n.head.appendChild(c)),c={type:"script",instance:c,count:1,state:null},l.set(s,c))}}function Zh(e,t,n,l){var s=(s=On.current)?Ws(s):null;if(!s)throw Error(u(446));switch(e){case"meta":case"title":return null;case"style":return typeof n.precedence=="string"&&typeof n.href=="string"?(t=jl(n.href),n=qa(s).hoistableStyles,l=n.get(t),l||(l={type:"style",instance:null,count:0,state:null},n.set(t,l)),l):{type:"void",instance:null,count:0,state:null};case"link":if(n.rel==="stylesheet"&&typeof n.href=="string"&&typeof n.precedence=="string"){e=jl(n.href);var c=qa(s).hoistableStyles,h=c.get(e);if(h||(s=s.ownerDocument||s,h={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},c.set(e,h),(c=s.querySelector(yi(e)))&&!c._p&&(h.instance=c,h.state.loading=5),$t.has(e)||(n={rel:"preload",as:"style",href:n.href,crossOrigin:n.crossOrigin,integrity:n.integrity,media:n.media,hrefLang:n.hrefLang,referrerPolicy:n.referrerPolicy},$t.set(e,n),c||Hp(s,e,n,h.state))),t&&l===null)throw Error(u(528,""));return h}if(t&&l!==null)throw Error(u(529,""));return null;case"script":return t=n.async,n=n.src,typeof n=="string"&&t&&typeof t!="function"&&typeof t!="symbol"?(t=bl(n),n=qa(s).hoistableScripts,l=n.get(t),l||(l={type:"script",instance:null,count:0,state:null},n.set(t,l)),l):{type:"void",instance:null,count:0,state:null};default:throw Error(u(444,e))}}function jl(e){return'href="'+Bt(e)+'"'}function yi(e){return'link[rel="stylesheet"]['+e+"]"}function Kh(e){return j({},e,{"data-precedence":e.precedence,precedence:null})}function Hp(e,t,n,l){e.querySelector('link[rel="preload"][as="style"]['+t+"]")?l.loading=1:(t=e.createElement("link"),l.preload=t,t.addEventListener("load",function(){return l.loading|=1}),t.addEventListener("error",function(){return l.loading|=2}),it(t,"link",n),Pe(t),e.head.appendChild(t))}function bl(e){return'[src="'+Bt(e)+'"]'}function ji(e){return"script[async]"+e}function Fh(e,t,n){if(t.count++,t.instance===null)switch(t.type){case"style":var l=e.querySelector('style[data-href~="'+Bt(n.href)+'"]');if(l)return t.instance=l,Pe(l),l;var s=j({},n,{"data-href":n.href,"data-precedence":n.precedence,href:null,precedence:null});return l=(e.ownerDocument||e).createElement("style"),Pe(l),it(l,"style",s),Is(l,n.precedence,e),t.instance=l;case"stylesheet":s=jl(n.href);var c=e.querySelector(yi(s));if(c)return t.state.loading|=4,t.instance=c,Pe(c),c;l=Kh(n),(s=$t.get(s))&&Mu(l,s),c=(e.ownerDocument||e).createElement("link"),Pe(c);var h=c;return h._p=new Promise(function(g,y){h.onload=g,h.onerror=y}),it(c,"link",l),t.state.loading|=4,Is(c,n.precedence,e),t.instance=c;case"script":return c=bl(n.src),(s=e.querySelector(ji(c)))?(t.instance=s,Pe(s),s):(l=n,(s=$t.get(c))&&(l=j({},n),Ou(l,s)),e=e.ownerDocument||e,s=e.createElement("script"),Pe(s),it(s,"link",l),e.head.appendChild(s),t.instance=s);case"void":return null;default:throw Error(u(443,t.type))}else t.type==="stylesheet"&&(t.state.loading&4)===0&&(l=t.instance,t.state.loading|=4,Is(l,n.precedence,e));return t.instance}function Is(e,t,n){for(var l=n.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),s=l.length?l[l.length-1]:null,c=s,h=0;h<l.length;h++){var g=l[h];if(g.dataset.precedence===t)c=g;else if(c!==s)break}c?c.parentNode.insertBefore(e,c.nextSibling):(t=n.nodeType===9?n.head:n,t.insertBefore(e,t.firstChild))}function Mu(e,t){e.crossOrigin==null&&(e.crossOrigin=t.crossOrigin),e.referrerPolicy==null&&(e.referrerPolicy=t.referrerPolicy),e.title==null&&(e.title=t.title)}function Ou(e,t){e.crossOrigin==null&&(e.crossOrigin=t.crossOrigin),e.referrerPolicy==null&&(e.referrerPolicy=t.referrerPolicy),e.integrity==null&&(e.integrity=t.integrity)}var Ps=null;function Jh(e,t,n){if(Ps===null){var l=new Map,s=Ps=new Map;s.set(n,l)}else s=Ps,l=s.get(n),l||(l=new Map,s.set(n,l));if(l.has(e))return l;for(l.set(e,null),n=n.getElementsByTagName(e),s=0;s<n.length;s++){var c=n[s];if(!(c[Nl]||c[rt]||e==="link"&&c.getAttribute("rel")==="stylesheet")&&c.namespaceURI!=="http://www.w3.org/2000/svg"){var h=c.getAttribute(t)||"";h=e+h;var g=l.get(h);g?g.push(c):l.set(h,[c])}}return l}function Wh(e,t,n){e=e.ownerDocument||e,e.head.insertBefore(n,t==="title"?e.querySelector("head > title"):null)}function qp(e,t,n){if(n===1||t.itemProp!=null)return!1;switch(e){case"meta":case"title":return!0;case"style":if(typeof t.precedence!="string"||typeof t.href!="string"||t.href==="")break;return!0;case"link":if(typeof t.rel!="string"||typeof t.href!="string"||t.href===""||t.onLoad||t.onError)break;switch(t.rel){case"stylesheet":return e=t.disabled,typeof t.precedence=="string"&&e==null;default:return!0}case"script":if(t.async&&typeof t.async!="function"&&typeof t.async!="symbol"&&!t.onLoad&&!t.onError&&t.src&&typeof t.src=="string")return!0}return!1}function Ih(e){return!(e.type==="stylesheet"&&(e.state.loading&3)===0)}var bi=null;function $p(){}function Gp(e,t,n){if(bi===null)throw Error(u(475));var l=bi;if(t.type==="stylesheet"&&(typeof n.media!="string"||matchMedia(n.media).matches!==!1)&&(t.state.loading&4)===0){if(t.instance===null){var s=jl(n.href),c=e.querySelector(yi(s));if(c){e=c._p,e!==null&&typeof e=="object"&&typeof e.then=="function"&&(l.count++,l=ec.bind(l),e.then(l,l)),t.state.loading|=4,t.instance=c,Pe(c);return}c=e.ownerDocument||e,n=Kh(n),(s=$t.get(s))&&Mu(n,s),c=c.createElement("link"),Pe(c);var h=c;h._p=new Promise(function(g,y){h.onload=g,h.onerror=y}),it(c,"link",n),t.instance=c}l.stylesheets===null&&(l.stylesheets=new Map),l.stylesheets.set(t,e),(e=t.state.preload)&&(t.state.loading&3)===0&&(l.count++,t=ec.bind(l),e.addEventListener("load",t),e.addEventListener("error",t))}}function Yp(){if(bi===null)throw Error(u(475));var e=bi;return e.stylesheets&&e.count===0&&zu(e,e.stylesheets),0<e.count?function(t){var n=setTimeout(function(){if(e.stylesheets&&zu(e,e.stylesheets),e.unsuspend){var l=e.unsuspend;e.unsuspend=null,l()}},6e4);return e.unsuspend=t,function(){e.unsuspend=null,clearTimeout(n)}}:null}function ec(){if(this.count--,this.count===0){if(this.stylesheets)zu(this,this.stylesheets);else if(this.unsuspend){var e=this.unsuspend;this.unsuspend=null,e()}}}var tc=null;function zu(e,t){e.stylesheets=null,e.unsuspend!==null&&(e.count++,tc=new Map,t.forEach(Xp,e),tc=null,ec.call(e))}function Xp(e,t){if(!(t.state.loading&4)){var n=tc.get(e);if(n)var l=n.get(null);else{n=new Map,tc.set(e,n);for(var s=e.querySelectorAll("link[data-precedence],style[data-precedence]"),c=0;c<s.length;c++){var h=s[c];(h.nodeName==="LINK"||h.getAttribute("media")!=="not all")&&(n.set(h.dataset.precedence,h),l=h)}l&&n.set(null,l)}s=t.instance,h=s.getAttribute("data-precedence"),c=n.get(h)||l,c===l&&n.set(null,s),n.set(h,s),this.count++,l=ec.bind(this),s.addEventListener("load",l),s.addEventListener("error",l),c?c.parentNode.insertBefore(s,c.nextSibling):(e=e.nodeType===9?e.head:e,e.insertBefore(s,e.firstChild)),t.state.loading|=4}}var Si={$$typeof:se,Provider:null,Consumer:null,_currentValue:F,_currentValue2:F,_threadCount:0};function Qp(e,t,n,l,s,c,h,g){this.tag=1,this.containerInfo=e,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=Ac(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=Ac(0),this.hiddenUpdates=Ac(null),this.identifierPrefix=l,this.onUncaughtError=s,this.onCaughtError=c,this.onRecoverableError=h,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=g,this.incompleteTransitions=new Map}function Ph(e,t,n,l,s,c,h,g,y,T,z,R){return e=new Qp(e,t,n,h,g,y,T,R),t=1,c===!0&&(t|=24),c=Tt(3,null,null,t),e.current=c,c.stateNode=e,t=hr(),t.refCount++,e.pooledCache=t,t.refCount++,c.memoizedState={element:l,isDehydrated:n,cache:t},pr(c),e}function em(e){return e?(e=Ia,e):Ia}function tm(e,t,n,l,s,c){s=em(s),l.context===null?l.context=s:l.pendingContext=s,l=Ln(t),l.payload={element:n},c=c===void 0?null:c,c!==null&&(l.callback=c),n=kn(e,l,t),n!==null&&(Ot(n,e,t),Il(n,e,t))}function nm(e,t){if(e=e.memoizedState,e!==null&&e.dehydrated!==null){var n=e.retryLane;e.retryLane=n!==0&&n<t?n:t}}function Nu(e,t){nm(e,t),(e=e.alternate)&&nm(e,t)}function am(e){if(e.tag===13){var t=Wa(e,67108864);t!==null&&Ot(t,e,67108864),Nu(e,67108864)}}var nc=!0;function Vp(e,t,n,l){var s=B.T;B.T=null;var c=G.p;try{G.p=2,Bu(e,t,n,l)}finally{G.p=c,B.T=s}}function Zp(e,t,n,l){var s=B.T;B.T=null;var c=G.p;try{G.p=8,Bu(e,t,n,l)}finally{G.p=c,B.T=s}}function Bu(e,t,n,l){if(nc){var s=Ru(l);if(s===null)bu(e,t,l,ac,n),im(e,l);else if(Fp(s,e,t,n,l))l.stopPropagation();else if(im(e,l),t&4&&-1<Kp.indexOf(e)){for(;s!==null;){var c=Ha(s);if(c!==null)switch(c.tag){case 3:if(c=c.stateNode,c.current.memoizedState.isDehydrated){var h=oa(c.pendingLanes);if(h!==0){var g=c;for(g.pendingLanes|=2,g.entangledLanes|=2;h;){var y=1<<31-Ct(h);g.entanglements[1]|=y,h&=~y}nn(c),(me&6)===0&&(qs=Wt()+500,xi(0))}}break;case 13:g=Wa(c,2),g!==null&&Ot(g,c,2),Gs(),Nu(c,2)}if(c=Ru(l),c===null&&bu(e,t,l,ac,n),c===s)break;s=c}s!==null&&l.stopPropagation()}else bu(e,t,l,null,n)}}function Ru(e){return e=qc(e),Uu(e)}var ac=null;function Uu(e){if(ac=null,e=ka(e),e!==null){var t=f(e);if(t===null)e=null;else{var n=t.tag;if(n===13){if(e=m(t),e!==null)return e;e=null}else if(n===3){if(t.stateNode.current.memoizedState.isDehydrated)return t.tag===3?t.stateNode.containerInfo:null;e=null}else t!==e&&(e=null)}}return ac=e,null}function lm(e){switch(e){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(Nx()){case po:return 2;case vo:return 8;case Fi:case Bx:return 32;case yo:return 268435456;default:return 32}default:return 32}}var Lu=!1,Wn=null,In=null,Pn=null,wi=new Map,Ci=new Map,ea=[],Kp="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function im(e,t){switch(e){case"focusin":case"focusout":Wn=null;break;case"dragenter":case"dragleave":In=null;break;case"mouseover":case"mouseout":Pn=null;break;case"pointerover":case"pointerout":wi.delete(t.pointerId);break;case"gotpointercapture":case"lostpointercapture":Ci.delete(t.pointerId)}}function _i(e,t,n,l,s,c){return e===null||e.nativeEvent!==c?(e={blockedOn:t,domEventName:n,eventSystemFlags:l,nativeEvent:c,targetContainers:[s]},t!==null&&(t=Ha(t),t!==null&&am(t)),e):(e.eventSystemFlags|=l,t=e.targetContainers,s!==null&&t.indexOf(s)===-1&&t.push(s),e)}function Fp(e,t,n,l,s){switch(t){case"focusin":return Wn=_i(Wn,e,t,n,l,s),!0;case"dragenter":return In=_i(In,e,t,n,l,s),!0;case"mouseover":return Pn=_i(Pn,e,t,n,l,s),!0;case"pointerover":var c=s.pointerId;return wi.set(c,_i(wi.get(c)||null,e,t,n,l,s)),!0;case"gotpointercapture":return c=s.pointerId,Ci.set(c,_i(Ci.get(c)||null,e,t,n,l,s)),!0}return!1}function sm(e){var t=ka(e.target);if(t!==null){var n=f(t);if(n!==null){if(t=n.tag,t===13){if(t=m(n),t!==null){e.blockedOn=t,Gx(e.priority,function(){if(n.tag===13){var l=Mt();l=Dc(l);var s=Wa(n,l);s!==null&&Ot(s,n,l),Nu(n,l)}});return}}else if(t===3&&n.stateNode.current.memoizedState.isDehydrated){e.blockedOn=n.tag===3?n.stateNode.containerInfo:null;return}}}e.blockedOn=null}function lc(e){if(e.blockedOn!==null)return!1;for(var t=e.targetContainers;0<t.length;){var n=Ru(e.nativeEvent);if(n===null){n=e.nativeEvent;var l=new n.constructor(n.type,n);Hc=l,n.target.dispatchEvent(l),Hc=null}else return t=Ha(n),t!==null&&am(t),e.blockedOn=n,!1;t.shift()}return!0}function cm(e,t,n){lc(e)&&n.delete(t)}function Jp(){Lu=!1,Wn!==null&&lc(Wn)&&(Wn=null),In!==null&&lc(In)&&(In=null),Pn!==null&&lc(Pn)&&(Pn=null),wi.forEach(cm),Ci.forEach(cm)}function ic(e,t){e.blockedOn===t&&(e.blockedOn=null,Lu||(Lu=!0,i.unstable_scheduleCallback(i.unstable_NormalPriority,Jp)))}var sc=null;function rm(e){sc!==e&&(sc=e,i.unstable_scheduleCallback(i.unstable_NormalPriority,function(){sc===e&&(sc=null);for(var t=0;t<e.length;t+=3){var n=e[t],l=e[t+1],s=e[t+2];if(typeof l!="function"){if(Uu(l||n)===null)continue;break}var c=Ha(n);c!==null&&(e.splice(t,3),t-=3,Ur(c,{pending:!0,data:s,method:n.method,action:l},l,s))}}))}function Ti(e){function t(y){return ic(y,e)}Wn!==null&&ic(Wn,e),In!==null&&ic(In,e),Pn!==null&&ic(Pn,e),wi.forEach(t),Ci.forEach(t);for(var n=0;n<ea.length;n++){var l=ea[n];l.blockedOn===e&&(l.blockedOn=null)}for(;0<ea.length&&(n=ea[0],n.blockedOn===null);)sm(n),n.blockedOn===null&&ea.shift();if(n=(e.ownerDocument||e).$$reactFormReplay,n!=null)for(l=0;l<n.length;l+=3){var s=n[l],c=n[l+1],h=s[xt]||null;if(typeof c=="function")h||rm(n);else if(h){var g=null;if(c&&c.hasAttribute("formAction")){if(s=c,h=c[xt]||null)g=h.formAction;else if(Uu(s)!==null)continue}else g=h.action;typeof g=="function"?n[l+1]=g:(n.splice(l,3),l-=3),rm(n)}}}function ku(e){this._internalRoot=e}cc.prototype.render=ku.prototype.render=function(e){var t=this._internalRoot;if(t===null)throw Error(u(409));var n=t.current,l=Mt();tm(n,l,e,t,null,null)},cc.prototype.unmount=ku.prototype.unmount=function(){var e=this._internalRoot;if(e!==null){this._internalRoot=null;var t=e.containerInfo;tm(e.current,2,null,e,null,null),Gs(),t[La]=null}};function cc(e){this._internalRoot=e}cc.prototype.unstable_scheduleHydration=function(e){if(e){var t=Co();e={blockedOn:null,target:e,priority:t};for(var n=0;n<ea.length&&t!==0&&t<ea[n].priority;n++);ea.splice(n,0,e),n===0&&sm(e)}};var um=r.version;if(um!=="19.1.0")throw Error(u(527,um,"19.1.0"));G.findDOMNode=function(e){var t=e._reactInternals;if(t===void 0)throw typeof e.render=="function"?Error(u(188)):(e=Object.keys(e).join(","),Error(u(268,e)));return e=p(t),e=e!==null?v(e):null,e=e===null?null:e.stateNode,e};var Wp={bundleType:0,version:"19.1.0",rendererPackageName:"react-dom",currentDispatcherRef:B,reconcilerVersion:"19.1.0"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var rc=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!rc.isDisabled&&rc.supportsFiber)try{Ml=rc.inject(Wp),wt=rc}catch{}}return Oi.createRoot=function(e,t){if(!d(e))throw Error(u(299));var n=!1,l="",s=_f,c=Tf,h=Ef,g=null;return t!=null&&(t.unstable_strictMode===!0&&(n=!0),t.identifierPrefix!==void 0&&(l=t.identifierPrefix),t.onUncaughtError!==void 0&&(s=t.onUncaughtError),t.onCaughtError!==void 0&&(c=t.onCaughtError),t.onRecoverableError!==void 0&&(h=t.onRecoverableError),t.unstable_transitionCallbacks!==void 0&&(g=t.unstable_transitionCallbacks)),t=Ph(e,1,!1,null,null,n,l,s,c,h,g,null),e[La]=t.current,ju(e),new ku(t)},Oi.hydrateRoot=function(e,t,n){if(!d(e))throw Error(u(299));var l=!1,s="",c=_f,h=Tf,g=Ef,y=null,T=null;return n!=null&&(n.unstable_strictMode===!0&&(l=!0),n.identifierPrefix!==void 0&&(s=n.identifierPrefix),n.onUncaughtError!==void 0&&(c=n.onUncaughtError),n.onCaughtError!==void 0&&(h=n.onCaughtError),n.onRecoverableError!==void 0&&(g=n.onRecoverableError),n.unstable_transitionCallbacks!==void 0&&(y=n.unstable_transitionCallbacks),n.formState!==void 0&&(T=n.formState)),t=Ph(e,1,!0,t,n??null,l,s,c,h,g,y,T),t.context=em(null),n=t.current,l=Mt(),l=Dc(l),s=Ln(l),s.callback=null,kn(n,s,l),n=l,t.current.lanes=n,zl(t,n),nn(t),e[La]=t.current,ju(e),new cc(t)},Oi.version="19.1.0",Oi}var Ym;function yb(){if(Ym)return Xu.exports;Ym=1;function i(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(i)}catch(r){console.error(r)}}return i(),Xu.exports=vb(),Xu.exports}var jb=yb();const bb=jb.createRoot(document.getElementById("root"));bb.render(a.jsx(b.StrictMode,{children:a.jsx(Oa,{children:a.jsx(xb,{})})}));
//# sourceMappingURL=index-D08LauTd.js.map
